"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingReply,
    LockstepProcessingRequest,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ModuleIO,
    ProcessingMode,
    ProcessingModule,
    ProcessingModuleList,
)


__all__ = (
    "LockstepProcessingRequest",
    "LockstepProcessingReply",
    "ProcessingMode",
    "ModuleIO",
    "ProcessingModule",
    "ProcessingModuleList",
)