syntax = "proto3";
package ubii.proto_v2.types.dataStructure;

message Matrix3x2 {
    double m00 = 1;
    double m01 = 2;
    double m10 = 3;
    double m11 = 4;
    double m20 = 5;
    double m21 = 6;
}