"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
    RepeatedField,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Vector8",
        "Vector8List",
    }
)


class Vector8(Message):
    v0 = Field(
        DOUBLE,
        number=1,
    )
    v1 = Field(
        DOUBLE,
        number=2,
    )
    v2 = Field(
        DOUBLE,
        number=3,
    )
    v3 = Field(
        DOUBLE,
        number=4,
    )
    v4 = Field(
        DOUBLE,
        number=5,
    )
    v5 = Field(
        DOUBLE,
        number=6,
    )
    v6 = Field(
        DOUBLE,
        number=7,
    )
    v7 = Field(
        DOUBLE,
        number=8,
    )



class Vector8List(Message):
    elements = RepeatedField(
        Vector8,
        number=1,
    )


