"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    INT32,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "LockstepProcessingRequest",
        "LockstepProcessingReply",
    }
)


class LockstepProcessingRequest(Message):
    processing_module_ids = RepeatedField(
        STRING,
        number=1,
    )
    records = RepeatedField(
        TopicDataRecord,
        number=2,
    )
    delta_time_ms = Field(
        INT32,
        number=3,
    )



class LockstepProcessingReply(Message):
    processing_module_ids = RepeatedField(
        STRING,
        number=1,
    )
    records = RepeatedField(
        TopicDataRecord,
        number=2,
    )


