// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/matrix3x2.proto

package ubii.dataStructure;

public final class Matrix3X2 {
  private Matrix3X2() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface Matrix3x2OrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.Matrix3x2)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>double m00 = 1;</code>
     */
    double getM00();

    /**
     * <code>double m01 = 2;</code>
     */
    double getM01();

    /**
     * <code>double m10 = 3;</code>
     */
    double getM10();

    /**
     * <code>double m11 = 4;</code>
     */
    double getM11();

    /**
     * <code>double m20 = 5;</code>
     */
    double getM20();

    /**
     * <code>double m21 = 6;</code>
     */
    double getM21();
  }
  /**
   * Protobuf type {@code ubii.dataStructure.Matrix3x2}
   */
  public  static final class Matrix3x2 extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.Matrix3x2)
      Matrix3x2OrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Matrix3x2.newBuilder() to construct.
    private Matrix3x2(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Matrix3x2() {
      m00_ = 0D;
      m01_ = 0D;
      m10_ = 0D;
      m11_ = 0D;
      m20_ = 0D;
      m21_ = 0D;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Matrix3x2(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 9: {

              m00_ = input.readDouble();
              break;
            }
            case 17: {

              m01_ = input.readDouble();
              break;
            }
            case 25: {

              m10_ = input.readDouble();
              break;
            }
            case 33: {

              m11_ = input.readDouble();
              break;
            }
            case 41: {

              m20_ = input.readDouble();
              break;
            }
            case 49: {

              m21_ = input.readDouble();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.Matrix3X2.internal_static_ubii_dataStructure_Matrix3x2_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.Matrix3X2.internal_static_ubii_dataStructure_Matrix3x2_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.Matrix3X2.Matrix3x2.class, ubii.dataStructure.Matrix3X2.Matrix3x2.Builder.class);
    }

    public static final int M00_FIELD_NUMBER = 1;
    private double m00_;
    /**
     * <code>double m00 = 1;</code>
     */
    public double getM00() {
      return m00_;
    }

    public static final int M01_FIELD_NUMBER = 2;
    private double m01_;
    /**
     * <code>double m01 = 2;</code>
     */
    public double getM01() {
      return m01_;
    }

    public static final int M10_FIELD_NUMBER = 3;
    private double m10_;
    /**
     * <code>double m10 = 3;</code>
     */
    public double getM10() {
      return m10_;
    }

    public static final int M11_FIELD_NUMBER = 4;
    private double m11_;
    /**
     * <code>double m11 = 4;</code>
     */
    public double getM11() {
      return m11_;
    }

    public static final int M20_FIELD_NUMBER = 5;
    private double m20_;
    /**
     * <code>double m20 = 5;</code>
     */
    public double getM20() {
      return m20_;
    }

    public static final int M21_FIELD_NUMBER = 6;
    private double m21_;
    /**
     * <code>double m21 = 6;</code>
     */
    public double getM21() {
      return m21_;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (m00_ != 0D) {
        output.writeDouble(1, m00_);
      }
      if (m01_ != 0D) {
        output.writeDouble(2, m01_);
      }
      if (m10_ != 0D) {
        output.writeDouble(3, m10_);
      }
      if (m11_ != 0D) {
        output.writeDouble(4, m11_);
      }
      if (m20_ != 0D) {
        output.writeDouble(5, m20_);
      }
      if (m21_ != 0D) {
        output.writeDouble(6, m21_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (m00_ != 0D) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(1, m00_);
      }
      if (m01_ != 0D) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(2, m01_);
      }
      if (m10_ != 0D) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(3, m10_);
      }
      if (m11_ != 0D) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(4, m11_);
      }
      if (m20_ != 0D) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(5, m20_);
      }
      if (m21_ != 0D) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(6, m21_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.Matrix3X2.Matrix3x2)) {
        return super.equals(obj);
      }
      ubii.dataStructure.Matrix3X2.Matrix3x2 other = (ubii.dataStructure.Matrix3X2.Matrix3x2) obj;

      boolean result = true;
      result = result && (
          java.lang.Double.doubleToLongBits(getM00())
          == java.lang.Double.doubleToLongBits(
              other.getM00()));
      result = result && (
          java.lang.Double.doubleToLongBits(getM01())
          == java.lang.Double.doubleToLongBits(
              other.getM01()));
      result = result && (
          java.lang.Double.doubleToLongBits(getM10())
          == java.lang.Double.doubleToLongBits(
              other.getM10()));
      result = result && (
          java.lang.Double.doubleToLongBits(getM11())
          == java.lang.Double.doubleToLongBits(
              other.getM11()));
      result = result && (
          java.lang.Double.doubleToLongBits(getM20())
          == java.lang.Double.doubleToLongBits(
              other.getM20()));
      result = result && (
          java.lang.Double.doubleToLongBits(getM21())
          == java.lang.Double.doubleToLongBits(
              other.getM21()));
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + M00_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
          java.lang.Double.doubleToLongBits(getM00()));
      hash = (37 * hash) + M01_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
          java.lang.Double.doubleToLongBits(getM01()));
      hash = (37 * hash) + M10_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
          java.lang.Double.doubleToLongBits(getM10()));
      hash = (37 * hash) + M11_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
          java.lang.Double.doubleToLongBits(getM11()));
      hash = (37 * hash) + M20_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
          java.lang.Double.doubleToLongBits(getM20()));
      hash = (37 * hash) + M21_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
          java.lang.Double.doubleToLongBits(getM21()));
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Matrix3X2.Matrix3x2 parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.Matrix3X2.Matrix3x2 prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.Matrix3x2}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.Matrix3x2)
        ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.Matrix3X2.internal_static_ubii_dataStructure_Matrix3x2_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.Matrix3X2.internal_static_ubii_dataStructure_Matrix3x2_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.Matrix3X2.Matrix3x2.class, ubii.dataStructure.Matrix3X2.Matrix3x2.Builder.class);
      }

      // Construct using ubii.dataStructure.Matrix3X2.Matrix3x2.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        m00_ = 0D;

        m01_ = 0D;

        m10_ = 0D;

        m11_ = 0D;

        m20_ = 0D;

        m21_ = 0D;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.Matrix3X2.internal_static_ubii_dataStructure_Matrix3x2_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.Matrix3X2.Matrix3x2 getDefaultInstanceForType() {
        return ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.Matrix3X2.Matrix3x2 build() {
        ubii.dataStructure.Matrix3X2.Matrix3x2 result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.Matrix3X2.Matrix3x2 buildPartial() {
        ubii.dataStructure.Matrix3X2.Matrix3x2 result = new ubii.dataStructure.Matrix3X2.Matrix3x2(this);
        result.m00_ = m00_;
        result.m01_ = m01_;
        result.m10_ = m10_;
        result.m11_ = m11_;
        result.m20_ = m20_;
        result.m21_ = m21_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.Matrix3X2.Matrix3x2) {
          return mergeFrom((ubii.dataStructure.Matrix3X2.Matrix3x2)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.Matrix3X2.Matrix3x2 other) {
        if (other == ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance()) return this;
        if (other.getM00() != 0D) {
          setM00(other.getM00());
        }
        if (other.getM01() != 0D) {
          setM01(other.getM01());
        }
        if (other.getM10() != 0D) {
          setM10(other.getM10());
        }
        if (other.getM11() != 0D) {
          setM11(other.getM11());
        }
        if (other.getM20() != 0D) {
          setM20(other.getM20());
        }
        if (other.getM21() != 0D) {
          setM21(other.getM21());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.Matrix3X2.Matrix3x2 parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.Matrix3X2.Matrix3x2) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private double m00_ ;
      /**
       * <code>double m00 = 1;</code>
       */
      public double getM00() {
        return m00_;
      }
      /**
       * <code>double m00 = 1;</code>
       */
      public Builder setM00(double value) {
        
        m00_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double m00 = 1;</code>
       */
      public Builder clearM00() {
        
        m00_ = 0D;
        onChanged();
        return this;
      }

      private double m01_ ;
      /**
       * <code>double m01 = 2;</code>
       */
      public double getM01() {
        return m01_;
      }
      /**
       * <code>double m01 = 2;</code>
       */
      public Builder setM01(double value) {
        
        m01_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double m01 = 2;</code>
       */
      public Builder clearM01() {
        
        m01_ = 0D;
        onChanged();
        return this;
      }

      private double m10_ ;
      /**
       * <code>double m10 = 3;</code>
       */
      public double getM10() {
        return m10_;
      }
      /**
       * <code>double m10 = 3;</code>
       */
      public Builder setM10(double value) {
        
        m10_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double m10 = 3;</code>
       */
      public Builder clearM10() {
        
        m10_ = 0D;
        onChanged();
        return this;
      }

      private double m11_ ;
      /**
       * <code>double m11 = 4;</code>
       */
      public double getM11() {
        return m11_;
      }
      /**
       * <code>double m11 = 4;</code>
       */
      public Builder setM11(double value) {
        
        m11_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double m11 = 4;</code>
       */
      public Builder clearM11() {
        
        m11_ = 0D;
        onChanged();
        return this;
      }

      private double m20_ ;
      /**
       * <code>double m20 = 5;</code>
       */
      public double getM20() {
        return m20_;
      }
      /**
       * <code>double m20 = 5;</code>
       */
      public Builder setM20(double value) {
        
        m20_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double m20 = 5;</code>
       */
      public Builder clearM20() {
        
        m20_ = 0D;
        onChanged();
        return this;
      }

      private double m21_ ;
      /**
       * <code>double m21 = 6;</code>
       */
      public double getM21() {
        return m21_;
      }
      /**
       * <code>double m21 = 6;</code>
       */
      public Builder setM21(double value) {
        
        m21_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double m21 = 6;</code>
       */
      public Builder clearM21() {
        
        m21_ = 0D;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.Matrix3x2)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.Matrix3x2)
    private static final ubii.dataStructure.Matrix3X2.Matrix3x2 DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.Matrix3X2.Matrix3x2();
    }

    public static ubii.dataStructure.Matrix3X2.Matrix3x2 getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Matrix3x2>
        PARSER = new com.google.protobuf.AbstractParser<Matrix3x2>() {
      @java.lang.Override
      public Matrix3x2 parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Matrix3x2(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Matrix3x2> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Matrix3x2> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.Matrix3X2.Matrix3x2 getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_Matrix3x2_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_Matrix3x2_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n=proto/topicData/topicDataRecord/dataSt" +
      "ructure/matrix3x2.proto\022\022ubii.dataStruct" +
      "ure\"Y\n\tMatrix3x2\022\013\n\003m00\030\001 \001(\001\022\013\n\003m01\030\002 \001" +
      "(\001\022\013\n\003m10\030\003 \001(\001\022\013\n\003m11\030\004 \001(\001\022\013\n\003m20\030\005 \001(" +
      "\001\022\013\n\003m21\030\006 \001(\001b\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
        }, assigner);
    internal_static_ubii_dataStructure_Matrix3x2_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_dataStructure_Matrix3x2_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_Matrix3x2_descriptor,
        new java.lang.String[] { "M00", "M01", "M10", "M11", "M20", "M21", });
  }

  // @@protoc_insertion_point(outer_class_scope)
}
