/**
 * @fileoverview
 * @enhanceable
 * @suppress {messageConventions} JS Compiler reports an error if a variable or
 *     field starts with 'MSG_' and isn't a translatable message.
 * @public
 */
// GENERATED CODE -- DO NOT EDIT!

var jspb = require('google-protobuf');
var goog = jspb;
var global = Function('return this')();

goog.exportSymbol('proto.ubii.processing.ModuleIO', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingMode', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingMode.Frequency', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingMode.Lockstep', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingMode.TriggerOnInput', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingModule', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingModule.Language', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingModule.Status', null, global);
goog.exportSymbol('proto.ubii.processing.ProcessingModuleList', null, global);

/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ProcessingMode = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, proto.ubii.processing.ProcessingMode.oneofGroups_);
};
goog.inherits(proto.ubii.processing.ProcessingMode, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ProcessingMode.displayName = 'proto.ubii.processing.ProcessingMode';
}
/**
 * Oneof group definitions for this message. Each group defines the field
 * numbers belonging to that group. When of these fields' value is set, all
 * other fields in the group are cleared. During deserialization, if multiple
 * fields are encountered for a group, only the last value seen will be kept.
 * @private {!Array<!Array<number>>}
 * @const
 */
proto.ubii.processing.ProcessingMode.oneofGroups_ = [[1,2,3]];

/**
 * @enum {number}
 */
proto.ubii.processing.ProcessingMode.ModeCase = {
  MODE_NOT_SET: 0,
  FREQUENCY: 1,
  LOCKSTEP: 2,
  TRIGGER_ON_INPUT: 3
};

/**
 * @return {proto.ubii.processing.ProcessingMode.ModeCase}
 */
proto.ubii.processing.ProcessingMode.prototype.getModeCase = function() {
  return /** @type {proto.ubii.processing.ProcessingMode.ModeCase} */(jspb.Message.computeOneofCase(this, proto.ubii.processing.ProcessingMode.oneofGroups_[0]));
};



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ProcessingMode.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ProcessingMode.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ProcessingMode} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.toObject = function(includeInstance, msg) {
  var f, obj = {
    frequency: (f = msg.getFrequency()) && proto.ubii.processing.ProcessingMode.Frequency.toObject(includeInstance, f),
    lockstep: (f = msg.getLockstep()) && proto.ubii.processing.ProcessingMode.Lockstep.toObject(includeInstance, f),
    triggerOnInput: (f = msg.getTriggerOnInput()) && proto.ubii.processing.ProcessingMode.TriggerOnInput.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ProcessingMode}
 */
proto.ubii.processing.ProcessingMode.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ProcessingMode;
  return proto.ubii.processing.ProcessingMode.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ProcessingMode} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ProcessingMode}
 */
proto.ubii.processing.ProcessingMode.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.ubii.processing.ProcessingMode.Frequency;
      reader.readMessage(value,proto.ubii.processing.ProcessingMode.Frequency.deserializeBinaryFromReader);
      msg.setFrequency(value);
      break;
    case 2:
      var value = new proto.ubii.processing.ProcessingMode.Lockstep;
      reader.readMessage(value,proto.ubii.processing.ProcessingMode.Lockstep.deserializeBinaryFromReader);
      msg.setLockstep(value);
      break;
    case 3:
      var value = new proto.ubii.processing.ProcessingMode.TriggerOnInput;
      reader.readMessage(value,proto.ubii.processing.ProcessingMode.TriggerOnInput.deserializeBinaryFromReader);
      msg.setTriggerOnInput(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ProcessingMode.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ProcessingMode.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ProcessingMode} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getFrequency();
  if (f != null) {
    writer.writeMessage(
      1,
      f,
      proto.ubii.processing.ProcessingMode.Frequency.serializeBinaryToWriter
    );
  }
  f = message.getLockstep();
  if (f != null) {
    writer.writeMessage(
      2,
      f,
      proto.ubii.processing.ProcessingMode.Lockstep.serializeBinaryToWriter
    );
  }
  f = message.getTriggerOnInput();
  if (f != null) {
    writer.writeMessage(
      3,
      f,
      proto.ubii.processing.ProcessingMode.TriggerOnInput.serializeBinaryToWriter
    );
  }
};



/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ProcessingMode.Frequency = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.ubii.processing.ProcessingMode.Frequency, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ProcessingMode.Frequency.displayName = 'proto.ubii.processing.ProcessingMode.Frequency';
}


if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ProcessingMode.Frequency.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ProcessingMode.Frequency.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ProcessingMode.Frequency} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.Frequency.toObject = function(includeInstance, msg) {
  var f, obj = {
    hertz: jspb.Message.getFieldWithDefault(msg, 1, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ProcessingMode.Frequency}
 */
proto.ubii.processing.ProcessingMode.Frequency.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ProcessingMode.Frequency;
  return proto.ubii.processing.ProcessingMode.Frequency.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ProcessingMode.Frequency} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ProcessingMode.Frequency}
 */
proto.ubii.processing.ProcessingMode.Frequency.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setHertz(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ProcessingMode.Frequency.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ProcessingMode.Frequency.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ProcessingMode.Frequency} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.Frequency.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getHertz();
  if (f !== 0) {
    writer.writeInt32(
      1,
      f
    );
  }
};


/**
 * optional int32 hertz = 1;
 * @return {number}
 */
proto.ubii.processing.ProcessingMode.Frequency.prototype.getHertz = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/** @param {number} value */
proto.ubii.processing.ProcessingMode.Frequency.prototype.setHertz = function(value) {
  jspb.Message.setProto3IntField(this, 1, value);
};



/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ProcessingMode.Lockstep = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.ubii.processing.ProcessingMode.Lockstep, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ProcessingMode.Lockstep.displayName = 'proto.ubii.processing.ProcessingMode.Lockstep';
}


if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ProcessingMode.Lockstep.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ProcessingMode.Lockstep.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ProcessingMode.Lockstep} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.Lockstep.toObject = function(includeInstance, msg) {
  var f, obj = {
    processRequestEndpoint: jspb.Message.getFieldWithDefault(msg, 1, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ProcessingMode.Lockstep}
 */
proto.ubii.processing.ProcessingMode.Lockstep.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ProcessingMode.Lockstep;
  return proto.ubii.processing.ProcessingMode.Lockstep.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ProcessingMode.Lockstep} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ProcessingMode.Lockstep}
 */
proto.ubii.processing.ProcessingMode.Lockstep.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {string} */ (reader.readString());
      msg.setProcessRequestEndpoint(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ProcessingMode.Lockstep.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ProcessingMode.Lockstep.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ProcessingMode.Lockstep} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.Lockstep.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getProcessRequestEndpoint();
  if (f.length > 0) {
    writer.writeString(
      1,
      f
    );
  }
};


/**
 * optional string process_request_endpoint = 1;
 * @return {string}
 */
proto.ubii.processing.ProcessingMode.Lockstep.prototype.getProcessRequestEndpoint = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 1, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingMode.Lockstep.prototype.setProcessRequestEndpoint = function(value) {
  jspb.Message.setProto3StringField(this, 1, value);
};



/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.ubii.processing.ProcessingMode.TriggerOnInput, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ProcessingMode.TriggerOnInput.displayName = 'proto.ubii.processing.ProcessingMode.TriggerOnInput';
}


if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ProcessingMode.TriggerOnInput.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ProcessingMode.TriggerOnInput} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.toObject = function(includeInstance, msg) {
  var f, obj = {
    minDelayMs: jspb.Message.getFieldWithDefault(msg, 1, 0),
    allInputsNeedUpdate: jspb.Message.getFieldWithDefault(msg, 2, false)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ProcessingMode.TriggerOnInput}
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ProcessingMode.TriggerOnInput;
  return proto.ubii.processing.ProcessingMode.TriggerOnInput.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ProcessingMode.TriggerOnInput} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ProcessingMode.TriggerOnInput}
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setMinDelayMs(value);
      break;
    case 2:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setAllInputsNeedUpdate(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ProcessingMode.TriggerOnInput.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ProcessingMode.TriggerOnInput} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getMinDelayMs();
  if (f !== 0) {
    writer.writeInt32(
      1,
      f
    );
  }
  f = message.getAllInputsNeedUpdate();
  if (f) {
    writer.writeBool(
      2,
      f
    );
  }
};


/**
 * optional int32 min_delay_ms = 1;
 * @return {number}
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.prototype.getMinDelayMs = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/** @param {number} value */
proto.ubii.processing.ProcessingMode.TriggerOnInput.prototype.setMinDelayMs = function(value) {
  jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional bool all_inputs_need_update = 2;
 * Note that Boolean fields may be set to 0/1 when serialized from a Java server.
 * You should avoid comparisons like {@code val === true/false} in those cases.
 * @return {boolean}
 */
proto.ubii.processing.ProcessingMode.TriggerOnInput.prototype.getAllInputsNeedUpdate = function() {
  return /** @type {boolean} */ (jspb.Message.getFieldWithDefault(this, 2, false));
};


/** @param {boolean} value */
proto.ubii.processing.ProcessingMode.TriggerOnInput.prototype.setAllInputsNeedUpdate = function(value) {
  jspb.Message.setProto3BooleanField(this, 2, value);
};


/**
 * optional Frequency frequency = 1;
 * @return {?proto.ubii.processing.ProcessingMode.Frequency}
 */
proto.ubii.processing.ProcessingMode.prototype.getFrequency = function() {
  return /** @type{?proto.ubii.processing.ProcessingMode.Frequency} */ (
    jspb.Message.getWrapperField(this, proto.ubii.processing.ProcessingMode.Frequency, 1));
};


/** @param {?proto.ubii.processing.ProcessingMode.Frequency|undefined} value */
proto.ubii.processing.ProcessingMode.prototype.setFrequency = function(value) {
  jspb.Message.setOneofWrapperField(this, 1, proto.ubii.processing.ProcessingMode.oneofGroups_[0], value);
};


proto.ubii.processing.ProcessingMode.prototype.clearFrequency = function() {
  this.setFrequency(undefined);
};


/**
 * Returns whether this field is set.
 * @return {!boolean}
 */
proto.ubii.processing.ProcessingMode.prototype.hasFrequency = function() {
  return jspb.Message.getField(this, 1) != null;
};


/**
 * optional Lockstep lockstep = 2;
 * @return {?proto.ubii.processing.ProcessingMode.Lockstep}
 */
proto.ubii.processing.ProcessingMode.prototype.getLockstep = function() {
  return /** @type{?proto.ubii.processing.ProcessingMode.Lockstep} */ (
    jspb.Message.getWrapperField(this, proto.ubii.processing.ProcessingMode.Lockstep, 2));
};


/** @param {?proto.ubii.processing.ProcessingMode.Lockstep|undefined} value */
proto.ubii.processing.ProcessingMode.prototype.setLockstep = function(value) {
  jspb.Message.setOneofWrapperField(this, 2, proto.ubii.processing.ProcessingMode.oneofGroups_[0], value);
};


proto.ubii.processing.ProcessingMode.prototype.clearLockstep = function() {
  this.setLockstep(undefined);
};


/**
 * Returns whether this field is set.
 * @return {!boolean}
 */
proto.ubii.processing.ProcessingMode.prototype.hasLockstep = function() {
  return jspb.Message.getField(this, 2) != null;
};


/**
 * optional TriggerOnInput trigger_on_input = 3;
 * @return {?proto.ubii.processing.ProcessingMode.TriggerOnInput}
 */
proto.ubii.processing.ProcessingMode.prototype.getTriggerOnInput = function() {
  return /** @type{?proto.ubii.processing.ProcessingMode.TriggerOnInput} */ (
    jspb.Message.getWrapperField(this, proto.ubii.processing.ProcessingMode.TriggerOnInput, 3));
};


/** @param {?proto.ubii.processing.ProcessingMode.TriggerOnInput|undefined} value */
proto.ubii.processing.ProcessingMode.prototype.setTriggerOnInput = function(value) {
  jspb.Message.setOneofWrapperField(this, 3, proto.ubii.processing.ProcessingMode.oneofGroups_[0], value);
};


proto.ubii.processing.ProcessingMode.prototype.clearTriggerOnInput = function() {
  this.setTriggerOnInput(undefined);
};


/**
 * Returns whether this field is set.
 * @return {!boolean}
 */
proto.ubii.processing.ProcessingMode.prototype.hasTriggerOnInput = function() {
  return jspb.Message.getField(this, 3) != null;
};



/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ModuleIO = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.ubii.processing.ModuleIO, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ModuleIO.displayName = 'proto.ubii.processing.ModuleIO';
}


if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ModuleIO.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ModuleIO.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ModuleIO} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ModuleIO.toObject = function(includeInstance, msg) {
  var f, obj = {
    internalName: jspb.Message.getFieldWithDefault(msg, 1, ""),
    messageFormat: jspb.Message.getFieldWithDefault(msg, 2, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ModuleIO}
 */
proto.ubii.processing.ModuleIO.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ModuleIO;
  return proto.ubii.processing.ModuleIO.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ModuleIO} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ModuleIO}
 */
proto.ubii.processing.ModuleIO.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {string} */ (reader.readString());
      msg.setInternalName(value);
      break;
    case 2:
      var value = /** @type {string} */ (reader.readString());
      msg.setMessageFormat(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ModuleIO.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ModuleIO.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ModuleIO} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ModuleIO.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getInternalName();
  if (f.length > 0) {
    writer.writeString(
      1,
      f
    );
  }
  f = message.getMessageFormat();
  if (f.length > 0) {
    writer.writeString(
      2,
      f
    );
  }
};


/**
 * optional string internal_name = 1;
 * @return {string}
 */
proto.ubii.processing.ModuleIO.prototype.getInternalName = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 1, ""));
};


/** @param {string} value */
proto.ubii.processing.ModuleIO.prototype.setInternalName = function(value) {
  jspb.Message.setProto3StringField(this, 1, value);
};


/**
 * optional string message_format = 2;
 * @return {string}
 */
proto.ubii.processing.ModuleIO.prototype.getMessageFormat = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 2, ""));
};


/** @param {string} value */
proto.ubii.processing.ModuleIO.prototype.setMessageFormat = function(value) {
  jspb.Message.setProto3StringField(this, 2, value);
};



/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ProcessingModule = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.ubii.processing.ProcessingModule.repeatedFields_, null);
};
goog.inherits(proto.ubii.processing.ProcessingModule, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ProcessingModule.displayName = 'proto.ubii.processing.ProcessingModule';
}
/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.ubii.processing.ProcessingModule.repeatedFields_ = [3,4,10,11];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ProcessingModule.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ProcessingModule.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ProcessingModule} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingModule.toObject = function(includeInstance, msg) {
  var f, obj = {
    id: jspb.Message.getFieldWithDefault(msg, 1, ""),
    name: jspb.Message.getFieldWithDefault(msg, 2, ""),
    authorsList: jspb.Message.getRepeatedField(msg, 3),
    tagsList: jspb.Message.getRepeatedField(msg, 4),
    description: jspb.Message.getFieldWithDefault(msg, 5, ""),
    nodeId: jspb.Message.getFieldWithDefault(msg, 6, ""),
    sessionId: jspb.Message.getFieldWithDefault(msg, 7, ""),
    status: jspb.Message.getFieldWithDefault(msg, 8, 0),
    processingMode: (f = msg.getProcessingMode()) && proto.ubii.processing.ProcessingMode.toObject(includeInstance, f),
    inputsList: jspb.Message.toObjectList(msg.getInputsList(),
    proto.ubii.processing.ModuleIO.toObject, includeInstance),
    outputsList: jspb.Message.toObjectList(msg.getOutputsList(),
    proto.ubii.processing.ModuleIO.toObject, includeInstance),
    language: jspb.Message.getFieldWithDefault(msg, 12, 0),
    onProcessingStringified: jspb.Message.getFieldWithDefault(msg, 13, ""),
    onCreatedStringified: jspb.Message.getFieldWithDefault(msg, 14, ""),
    onHaltedStringified: jspb.Message.getFieldWithDefault(msg, 15, ""),
    onDestroyedStringified: jspb.Message.getFieldWithDefault(msg, 16, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ProcessingModule}
 */
proto.ubii.processing.ProcessingModule.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ProcessingModule;
  return proto.ubii.processing.ProcessingModule.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ProcessingModule} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ProcessingModule}
 */
proto.ubii.processing.ProcessingModule.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {string} */ (reader.readString());
      msg.setId(value);
      break;
    case 2:
      var value = /** @type {string} */ (reader.readString());
      msg.setName(value);
      break;
    case 3:
      var value = /** @type {string} */ (reader.readString());
      msg.addAuthors(value);
      break;
    case 4:
      var value = /** @type {string} */ (reader.readString());
      msg.addTags(value);
      break;
    case 5:
      var value = /** @type {string} */ (reader.readString());
      msg.setDescription(value);
      break;
    case 6:
      var value = /** @type {string} */ (reader.readString());
      msg.setNodeId(value);
      break;
    case 7:
      var value = /** @type {string} */ (reader.readString());
      msg.setSessionId(value);
      break;
    case 8:
      var value = /** @type {!proto.ubii.processing.ProcessingModule.Status} */ (reader.readEnum());
      msg.setStatus(value);
      break;
    case 9:
      var value = new proto.ubii.processing.ProcessingMode;
      reader.readMessage(value,proto.ubii.processing.ProcessingMode.deserializeBinaryFromReader);
      msg.setProcessingMode(value);
      break;
    case 10:
      var value = new proto.ubii.processing.ModuleIO;
      reader.readMessage(value,proto.ubii.processing.ModuleIO.deserializeBinaryFromReader);
      msg.addInputs(value);
      break;
    case 11:
      var value = new proto.ubii.processing.ModuleIO;
      reader.readMessage(value,proto.ubii.processing.ModuleIO.deserializeBinaryFromReader);
      msg.addOutputs(value);
      break;
    case 12:
      var value = /** @type {!proto.ubii.processing.ProcessingModule.Language} */ (reader.readEnum());
      msg.setLanguage(value);
      break;
    case 13:
      var value = /** @type {string} */ (reader.readString());
      msg.setOnProcessingStringified(value);
      break;
    case 14:
      var value = /** @type {string} */ (reader.readString());
      msg.setOnCreatedStringified(value);
      break;
    case 15:
      var value = /** @type {string} */ (reader.readString());
      msg.setOnHaltedStringified(value);
      break;
    case 16:
      var value = /** @type {string} */ (reader.readString());
      msg.setOnDestroyedStringified(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ProcessingModule.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ProcessingModule.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ProcessingModule} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingModule.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getId();
  if (f.length > 0) {
    writer.writeString(
      1,
      f
    );
  }
  f = message.getName();
  if (f.length > 0) {
    writer.writeString(
      2,
      f
    );
  }
  f = message.getAuthorsList();
  if (f.length > 0) {
    writer.writeRepeatedString(
      3,
      f
    );
  }
  f = message.getTagsList();
  if (f.length > 0) {
    writer.writeRepeatedString(
      4,
      f
    );
  }
  f = message.getDescription();
  if (f.length > 0) {
    writer.writeString(
      5,
      f
    );
  }
  f = message.getNodeId();
  if (f.length > 0) {
    writer.writeString(
      6,
      f
    );
  }
  f = message.getSessionId();
  if (f.length > 0) {
    writer.writeString(
      7,
      f
    );
  }
  f = message.getStatus();
  if (f !== 0.0) {
    writer.writeEnum(
      8,
      f
    );
  }
  f = message.getProcessingMode();
  if (f != null) {
    writer.writeMessage(
      9,
      f,
      proto.ubii.processing.ProcessingMode.serializeBinaryToWriter
    );
  }
  f = message.getInputsList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      10,
      f,
      proto.ubii.processing.ModuleIO.serializeBinaryToWriter
    );
  }
  f = message.getOutputsList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      11,
      f,
      proto.ubii.processing.ModuleIO.serializeBinaryToWriter
    );
  }
  f = message.getLanguage();
  if (f !== 0.0) {
    writer.writeEnum(
      12,
      f
    );
  }
  f = message.getOnProcessingStringified();
  if (f.length > 0) {
    writer.writeString(
      13,
      f
    );
  }
  f = message.getOnCreatedStringified();
  if (f.length > 0) {
    writer.writeString(
      14,
      f
    );
  }
  f = message.getOnHaltedStringified();
  if (f.length > 0) {
    writer.writeString(
      15,
      f
    );
  }
  f = message.getOnDestroyedStringified();
  if (f.length > 0) {
    writer.writeString(
      16,
      f
    );
  }
};


/**
 * @enum {number}
 */
proto.ubii.processing.ProcessingModule.Status = {
  INITIALIZED: 0,
  CREATED: 1,
  PROCESSING: 2,
  HALTED: 3,
  DESTROYED: 4
};

/**
 * @enum {number}
 */
proto.ubii.processing.ProcessingModule.Language = {
  CPP: 0,
  PY: 1,
  JS: 2,
  CS: 3,
  JAVA: 4
};

/**
 * optional string id = 1;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getId = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 1, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setId = function(value) {
  jspb.Message.setProto3StringField(this, 1, value);
};


/**
 * optional string name = 2;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getName = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 2, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setName = function(value) {
  jspb.Message.setProto3StringField(this, 2, value);
};


/**
 * repeated string authors = 3;
 * @return {!Array<string>}
 */
proto.ubii.processing.ProcessingModule.prototype.getAuthorsList = function() {
  return /** @type {!Array<string>} */ (jspb.Message.getRepeatedField(this, 3));
};


/** @param {!Array<string>} value */
proto.ubii.processing.ProcessingModule.prototype.setAuthorsList = function(value) {
  jspb.Message.setField(this, 3, value || []);
};


/**
 * @param {!string} value
 * @param {number=} opt_index
 */
proto.ubii.processing.ProcessingModule.prototype.addAuthors = function(value, opt_index) {
  jspb.Message.addToRepeatedField(this, 3, value, opt_index);
};


proto.ubii.processing.ProcessingModule.prototype.clearAuthorsList = function() {
  this.setAuthorsList([]);
};


/**
 * repeated string tags = 4;
 * @return {!Array<string>}
 */
proto.ubii.processing.ProcessingModule.prototype.getTagsList = function() {
  return /** @type {!Array<string>} */ (jspb.Message.getRepeatedField(this, 4));
};


/** @param {!Array<string>} value */
proto.ubii.processing.ProcessingModule.prototype.setTagsList = function(value) {
  jspb.Message.setField(this, 4, value || []);
};


/**
 * @param {!string} value
 * @param {number=} opt_index
 */
proto.ubii.processing.ProcessingModule.prototype.addTags = function(value, opt_index) {
  jspb.Message.addToRepeatedField(this, 4, value, opt_index);
};


proto.ubii.processing.ProcessingModule.prototype.clearTagsList = function() {
  this.setTagsList([]);
};


/**
 * optional string description = 5;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getDescription = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 5, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setDescription = function(value) {
  jspb.Message.setProto3StringField(this, 5, value);
};


/**
 * optional string node_id = 6;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getNodeId = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 6, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setNodeId = function(value) {
  jspb.Message.setProto3StringField(this, 6, value);
};


/**
 * optional string session_id = 7;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getSessionId = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 7, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setSessionId = function(value) {
  jspb.Message.setProto3StringField(this, 7, value);
};


/**
 * optional Status status = 8;
 * @return {!proto.ubii.processing.ProcessingModule.Status}
 */
proto.ubii.processing.ProcessingModule.prototype.getStatus = function() {
  return /** @type {!proto.ubii.processing.ProcessingModule.Status} */ (jspb.Message.getFieldWithDefault(this, 8, 0));
};


/** @param {!proto.ubii.processing.ProcessingModule.Status} value */
proto.ubii.processing.ProcessingModule.prototype.setStatus = function(value) {
  jspb.Message.setProto3EnumField(this, 8, value);
};


/**
 * optional ProcessingMode processing_mode = 9;
 * @return {?proto.ubii.processing.ProcessingMode}
 */
proto.ubii.processing.ProcessingModule.prototype.getProcessingMode = function() {
  return /** @type{?proto.ubii.processing.ProcessingMode} */ (
    jspb.Message.getWrapperField(this, proto.ubii.processing.ProcessingMode, 9));
};


/** @param {?proto.ubii.processing.ProcessingMode|undefined} value */
proto.ubii.processing.ProcessingModule.prototype.setProcessingMode = function(value) {
  jspb.Message.setWrapperField(this, 9, value);
};


proto.ubii.processing.ProcessingModule.prototype.clearProcessingMode = function() {
  this.setProcessingMode(undefined);
};


/**
 * Returns whether this field is set.
 * @return {!boolean}
 */
proto.ubii.processing.ProcessingModule.prototype.hasProcessingMode = function() {
  return jspb.Message.getField(this, 9) != null;
};


/**
 * repeated ModuleIO inputs = 10;
 * @return {!Array<!proto.ubii.processing.ModuleIO>}
 */
proto.ubii.processing.ProcessingModule.prototype.getInputsList = function() {
  return /** @type{!Array<!proto.ubii.processing.ModuleIO>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.ubii.processing.ModuleIO, 10));
};


/** @param {!Array<!proto.ubii.processing.ModuleIO>} value */
proto.ubii.processing.ProcessingModule.prototype.setInputsList = function(value) {
  jspb.Message.setRepeatedWrapperField(this, 10, value);
};


/**
 * @param {!proto.ubii.processing.ModuleIO=} opt_value
 * @param {number=} opt_index
 * @return {!proto.ubii.processing.ModuleIO}
 */
proto.ubii.processing.ProcessingModule.prototype.addInputs = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 10, opt_value, proto.ubii.processing.ModuleIO, opt_index);
};


proto.ubii.processing.ProcessingModule.prototype.clearInputsList = function() {
  this.setInputsList([]);
};


/**
 * repeated ModuleIO outputs = 11;
 * @return {!Array<!proto.ubii.processing.ModuleIO>}
 */
proto.ubii.processing.ProcessingModule.prototype.getOutputsList = function() {
  return /** @type{!Array<!proto.ubii.processing.ModuleIO>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.ubii.processing.ModuleIO, 11));
};


/** @param {!Array<!proto.ubii.processing.ModuleIO>} value */
proto.ubii.processing.ProcessingModule.prototype.setOutputsList = function(value) {
  jspb.Message.setRepeatedWrapperField(this, 11, value);
};


/**
 * @param {!proto.ubii.processing.ModuleIO=} opt_value
 * @param {number=} opt_index
 * @return {!proto.ubii.processing.ModuleIO}
 */
proto.ubii.processing.ProcessingModule.prototype.addOutputs = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 11, opt_value, proto.ubii.processing.ModuleIO, opt_index);
};


proto.ubii.processing.ProcessingModule.prototype.clearOutputsList = function() {
  this.setOutputsList([]);
};


/**
 * optional Language language = 12;
 * @return {!proto.ubii.processing.ProcessingModule.Language}
 */
proto.ubii.processing.ProcessingModule.prototype.getLanguage = function() {
  return /** @type {!proto.ubii.processing.ProcessingModule.Language} */ (jspb.Message.getFieldWithDefault(this, 12, 0));
};


/** @param {!proto.ubii.processing.ProcessingModule.Language} value */
proto.ubii.processing.ProcessingModule.prototype.setLanguage = function(value) {
  jspb.Message.setProto3EnumField(this, 12, value);
};


/**
 * optional string on_processing_stringified = 13;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getOnProcessingStringified = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 13, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setOnProcessingStringified = function(value) {
  jspb.Message.setProto3StringField(this, 13, value);
};


/**
 * optional string on_created_stringified = 14;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getOnCreatedStringified = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 14, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setOnCreatedStringified = function(value) {
  jspb.Message.setProto3StringField(this, 14, value);
};


/**
 * optional string on_halted_stringified = 15;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getOnHaltedStringified = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 15, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setOnHaltedStringified = function(value) {
  jspb.Message.setProto3StringField(this, 15, value);
};


/**
 * optional string on_destroyed_stringified = 16;
 * @return {string}
 */
proto.ubii.processing.ProcessingModule.prototype.getOnDestroyedStringified = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 16, ""));
};


/** @param {string} value */
proto.ubii.processing.ProcessingModule.prototype.setOnDestroyedStringified = function(value) {
  jspb.Message.setProto3StringField(this, 16, value);
};



/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.ubii.processing.ProcessingModuleList = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.ubii.processing.ProcessingModuleList.repeatedFields_, null);
};
goog.inherits(proto.ubii.processing.ProcessingModuleList, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  proto.ubii.processing.ProcessingModuleList.displayName = 'proto.ubii.processing.ProcessingModuleList';
}
/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.ubii.processing.ProcessingModuleList.repeatedFields_ = [1];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto suitable for use in Soy templates.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     com.google.apps.jspb.JsClassTemplate.JS_RESERVED_WORDS.
 * @param {boolean=} opt_includeInstance Whether to include the JSPB instance
 *     for transitional soy proto support: http://goto/soy-param-migration
 * @return {!Object}
 */
proto.ubii.processing.ProcessingModuleList.prototype.toObject = function(opt_includeInstance) {
  return proto.ubii.processing.ProcessingModuleList.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Whether to include the JSPB
 *     instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.ubii.processing.ProcessingModuleList} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingModuleList.toObject = function(includeInstance, msg) {
  var f, obj = {
    elementsList: jspb.Message.toObjectList(msg.getElementsList(),
    proto.ubii.processing.ProcessingModule.toObject, includeInstance)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.ubii.processing.ProcessingModuleList}
 */
proto.ubii.processing.ProcessingModuleList.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.ubii.processing.ProcessingModuleList;
  return proto.ubii.processing.ProcessingModuleList.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.ubii.processing.ProcessingModuleList} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.ubii.processing.ProcessingModuleList}
 */
proto.ubii.processing.ProcessingModuleList.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.ubii.processing.ProcessingModule;
      reader.readMessage(value,proto.ubii.processing.ProcessingModule.deserializeBinaryFromReader);
      msg.addElements(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.ubii.processing.ProcessingModuleList.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.ubii.processing.ProcessingModuleList.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.ubii.processing.ProcessingModuleList} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.ubii.processing.ProcessingModuleList.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getElementsList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      1,
      f,
      proto.ubii.processing.ProcessingModule.serializeBinaryToWriter
    );
  }
};


/**
 * repeated ProcessingModule elements = 1;
 * @return {!Array<!proto.ubii.processing.ProcessingModule>}
 */
proto.ubii.processing.ProcessingModuleList.prototype.getElementsList = function() {
  return /** @type{!Array<!proto.ubii.processing.ProcessingModule>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.ubii.processing.ProcessingModule, 1));
};


/** @param {!Array<!proto.ubii.processing.ProcessingModule>} value */
proto.ubii.processing.ProcessingModuleList.prototype.setElementsList = function(value) {
  jspb.Message.setRepeatedWrapperField(this, 1, value);
};


/**
 * @param {!proto.ubii.processing.ProcessingModule=} opt_value
 * @param {number=} opt_index
 * @return {!proto.ubii.processing.ProcessingModule}
 */
proto.ubii.processing.ProcessingModuleList.prototype.addElements = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 1, opt_value, proto.ubii.processing.ProcessingModule, opt_index);
};


proto.ubii.processing.ProcessingModuleList.prototype.clearElementsList = function() {
  this.setElementsList([]);
};


goog.object.extend(exports, proto.ubii.processing);
