// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/pose2d.proto

package ubii.dataStructure;

public final class Pose2DOuterClass {
  private Pose2DOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface Pose2DOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.Pose2D)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>.ubii.dataStructure.Vector2 position = 1;</code>
     */
    boolean hasPosition();
    /**
     * <code>.ubii.dataStructure.Vector2 position = 1;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2 getPosition();
    /**
     * <code>.ubii.dataStructure.Vector2 position = 1;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getPositionOrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
     */
    boolean hasDirection();
    /**
     * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2 getDirection();
    /**
     * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getDirectionOrBuilder();

    /**
     * <code>float angle = 3;</code>
     */
    float getAngle();

    public ubii.dataStructure.Pose2DOuterClass.Pose2D.OrientationCase getOrientationCase();
  }
  /**
   * Protobuf type {@code ubii.dataStructure.Pose2D}
   */
  public  static final class Pose2D extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.Pose2D)
      Pose2DOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Pose2D.newBuilder() to construct.
    private Pose2D(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Pose2D() {
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Pose2D(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              ubii.dataStructure.Vector2OuterClass.Vector2.Builder subBuilder = null;
              if (position_ != null) {
                subBuilder = position_.toBuilder();
              }
              position_ = input.readMessage(ubii.dataStructure.Vector2OuterClass.Vector2.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(position_);
                position_ = subBuilder.buildPartial();
              }

              break;
            }
            case 18: {
              ubii.dataStructure.Vector2OuterClass.Vector2.Builder subBuilder = null;
              if (orientationCase_ == 2) {
                subBuilder = ((ubii.dataStructure.Vector2OuterClass.Vector2) orientation_).toBuilder();
              }
              orientation_ =
                  input.readMessage(ubii.dataStructure.Vector2OuterClass.Vector2.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector2OuterClass.Vector2) orientation_);
                orientation_ = subBuilder.buildPartial();
              }
              orientationCase_ = 2;
              break;
            }
            case 29: {
              orientationCase_ = 3;
              orientation_ = input.readFloat();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.Pose2DOuterClass.internal_static_ubii_dataStructure_Pose2D_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.Pose2DOuterClass.internal_static_ubii_dataStructure_Pose2D_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.Pose2DOuterClass.Pose2D.class, ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder.class);
    }

    private int orientationCase_ = 0;
    private java.lang.Object orientation_;
    public enum OrientationCase
        implements com.google.protobuf.Internal.EnumLite {
      DIRECTION(2),
      ANGLE(3),
      ORIENTATION_NOT_SET(0);
      private final int value;
      private OrientationCase(int value) {
        this.value = value;
      }
      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static OrientationCase valueOf(int value) {
        return forNumber(value);
      }

      public static OrientationCase forNumber(int value) {
        switch (value) {
          case 2: return DIRECTION;
          case 3: return ANGLE;
          case 0: return ORIENTATION_NOT_SET;
          default: return null;
        }
      }
      public int getNumber() {
        return this.value;
      }
    };

    public OrientationCase
    getOrientationCase() {
      return OrientationCase.forNumber(
          orientationCase_);
    }

    public static final int POSITION_FIELD_NUMBER = 1;
    private ubii.dataStructure.Vector2OuterClass.Vector2 position_;
    /**
     * <code>.ubii.dataStructure.Vector2 position = 1;</code>
     */
    public boolean hasPosition() {
      return position_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Vector2 position = 1;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2 getPosition() {
      return position_ == null ? ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance() : position_;
    }
    /**
     * <code>.ubii.dataStructure.Vector2 position = 1;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getPositionOrBuilder() {
      return getPosition();
    }

    public static final int DIRECTION_FIELD_NUMBER = 2;
    /**
     * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
     */
    public boolean hasDirection() {
      return orientationCase_ == 2;
    }
    /**
     * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2 getDirection() {
      if (orientationCase_ == 2) {
         return (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_;
      }
      return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getDirectionOrBuilder() {
      if (orientationCase_ == 2) {
         return (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_;
      }
      return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
    }

    public static final int ANGLE_FIELD_NUMBER = 3;
    /**
     * <code>float angle = 3;</code>
     */
    public float getAngle() {
      if (orientationCase_ == 3) {
        return (java.lang.Float) orientation_;
      }
      return 0F;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (position_ != null) {
        output.writeMessage(1, getPosition());
      }
      if (orientationCase_ == 2) {
        output.writeMessage(2, (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_);
      }
      if (orientationCase_ == 3) {
        output.writeFloat(
            3, (float)((java.lang.Float) orientation_));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (position_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, getPosition());
      }
      if (orientationCase_ == 2) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_);
      }
      if (orientationCase_ == 3) {
        size += com.google.protobuf.CodedOutputStream
          .computeFloatSize(
              3, (float)((java.lang.Float) orientation_));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.Pose2DOuterClass.Pose2D)) {
        return super.equals(obj);
      }
      ubii.dataStructure.Pose2DOuterClass.Pose2D other = (ubii.dataStructure.Pose2DOuterClass.Pose2D) obj;

      boolean result = true;
      result = result && (hasPosition() == other.hasPosition());
      if (hasPosition()) {
        result = result && getPosition()
            .equals(other.getPosition());
      }
      result = result && getOrientationCase().equals(
          other.getOrientationCase());
      if (!result) return false;
      switch (orientationCase_) {
        case 2:
          result = result && getDirection()
              .equals(other.getDirection());
          break;
        case 3:
          result = result && (
              java.lang.Float.floatToIntBits(getAngle())
              == java.lang.Float.floatToIntBits(
                  other.getAngle()));
          break;
        case 0:
        default:
      }
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (hasPosition()) {
        hash = (37 * hash) + POSITION_FIELD_NUMBER;
        hash = (53 * hash) + getPosition().hashCode();
      }
      switch (orientationCase_) {
        case 2:
          hash = (37 * hash) + DIRECTION_FIELD_NUMBER;
          hash = (53 * hash) + getDirection().hashCode();
          break;
        case 3:
          hash = (37 * hash) + ANGLE_FIELD_NUMBER;
          hash = (53 * hash) + java.lang.Float.floatToIntBits(
              getAngle());
          break;
        case 0:
        default:
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Pose2DOuterClass.Pose2D parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.Pose2DOuterClass.Pose2D prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.Pose2D}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.Pose2D)
        ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.Pose2DOuterClass.internal_static_ubii_dataStructure_Pose2D_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.Pose2DOuterClass.internal_static_ubii_dataStructure_Pose2D_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.Pose2DOuterClass.Pose2D.class, ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder.class);
      }

      // Construct using ubii.dataStructure.Pose2DOuterClass.Pose2D.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (positionBuilder_ == null) {
          position_ = null;
        } else {
          position_ = null;
          positionBuilder_ = null;
        }
        orientationCase_ = 0;
        orientation_ = null;
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.Pose2DOuterClass.internal_static_ubii_dataStructure_Pose2D_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.Pose2DOuterClass.Pose2D getDefaultInstanceForType() {
        return ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.Pose2DOuterClass.Pose2D build() {
        ubii.dataStructure.Pose2DOuterClass.Pose2D result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.Pose2DOuterClass.Pose2D buildPartial() {
        ubii.dataStructure.Pose2DOuterClass.Pose2D result = new ubii.dataStructure.Pose2DOuterClass.Pose2D(this);
        if (positionBuilder_ == null) {
          result.position_ = position_;
        } else {
          result.position_ = positionBuilder_.build();
        }
        if (orientationCase_ == 2) {
          if (directionBuilder_ == null) {
            result.orientation_ = orientation_;
          } else {
            result.orientation_ = directionBuilder_.build();
          }
        }
        if (orientationCase_ == 3) {
          result.orientation_ = orientation_;
        }
        result.orientationCase_ = orientationCase_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.Pose2DOuterClass.Pose2D) {
          return mergeFrom((ubii.dataStructure.Pose2DOuterClass.Pose2D)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.Pose2DOuterClass.Pose2D other) {
        if (other == ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance()) return this;
        if (other.hasPosition()) {
          mergePosition(other.getPosition());
        }
        switch (other.getOrientationCase()) {
          case DIRECTION: {
            mergeDirection(other.getDirection());
            break;
          }
          case ANGLE: {
            setAngle(other.getAngle());
            break;
          }
          case ORIENTATION_NOT_SET: {
            break;
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.Pose2DOuterClass.Pose2D parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.Pose2DOuterClass.Pose2D) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int orientationCase_ = 0;
      private java.lang.Object orientation_;
      public OrientationCase
          getOrientationCase() {
        return OrientationCase.forNumber(
            orientationCase_);
      }

      public Builder clearOrientation() {
        orientationCase_ = 0;
        orientation_ = null;
        onChanged();
        return this;
      }


      private ubii.dataStructure.Vector2OuterClass.Vector2 position_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> positionBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public boolean hasPosition() {
        return positionBuilder_ != null || position_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2 getPosition() {
        if (positionBuilder_ == null) {
          return position_ == null ? ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance() : position_;
        } else {
          return positionBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public Builder setPosition(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (positionBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          position_ = value;
          onChanged();
        } else {
          positionBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public Builder setPosition(
          ubii.dataStructure.Vector2OuterClass.Vector2.Builder builderForValue) {
        if (positionBuilder_ == null) {
          position_ = builderForValue.build();
          onChanged();
        } else {
          positionBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public Builder mergePosition(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (positionBuilder_ == null) {
          if (position_ != null) {
            position_ =
              ubii.dataStructure.Vector2OuterClass.Vector2.newBuilder(position_).mergeFrom(value).buildPartial();
          } else {
            position_ = value;
          }
          onChanged();
        } else {
          positionBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public Builder clearPosition() {
        if (positionBuilder_ == null) {
          position_ = null;
          onChanged();
        } else {
          position_ = null;
          positionBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2.Builder getPositionBuilder() {
        
        onChanged();
        return getPositionFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getPositionOrBuilder() {
        if (positionBuilder_ != null) {
          return positionBuilder_.getMessageOrBuilder();
        } else {
          return position_ == null ?
              ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance() : position_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 1;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> 
          getPositionFieldBuilder() {
        if (positionBuilder_ == null) {
          positionBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder>(
                  getPosition(),
                  getParentForChildren(),
                  isClean());
          position_ = null;
        }
        return positionBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> directionBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public boolean hasDirection() {
        return orientationCase_ == 2;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2 getDirection() {
        if (directionBuilder_ == null) {
          if (orientationCase_ == 2) {
            return (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_;
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
        } else {
          if (orientationCase_ == 2) {
            return directionBuilder_.getMessage();
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public Builder setDirection(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (directionBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          orientation_ = value;
          onChanged();
        } else {
          directionBuilder_.setMessage(value);
        }
        orientationCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public Builder setDirection(
          ubii.dataStructure.Vector2OuterClass.Vector2.Builder builderForValue) {
        if (directionBuilder_ == null) {
          orientation_ = builderForValue.build();
          onChanged();
        } else {
          directionBuilder_.setMessage(builderForValue.build());
        }
        orientationCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public Builder mergeDirection(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (directionBuilder_ == null) {
          if (orientationCase_ == 2 &&
              orientation_ != ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance()) {
            orientation_ = ubii.dataStructure.Vector2OuterClass.Vector2.newBuilder((ubii.dataStructure.Vector2OuterClass.Vector2) orientation_)
                .mergeFrom(value).buildPartial();
          } else {
            orientation_ = value;
          }
          onChanged();
        } else {
          if (orientationCase_ == 2) {
            directionBuilder_.mergeFrom(value);
          }
          directionBuilder_.setMessage(value);
        }
        orientationCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public Builder clearDirection() {
        if (directionBuilder_ == null) {
          if (orientationCase_ == 2) {
            orientationCase_ = 0;
            orientation_ = null;
            onChanged();
          }
        } else {
          if (orientationCase_ == 2) {
            orientationCase_ = 0;
            orientation_ = null;
          }
          directionBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2.Builder getDirectionBuilder() {
        return getDirectionFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getDirectionOrBuilder() {
        if ((orientationCase_ == 2) && (directionBuilder_ != null)) {
          return directionBuilder_.getMessageOrBuilder();
        } else {
          if (orientationCase_ == 2) {
            return (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_;
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 direction = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> 
          getDirectionFieldBuilder() {
        if (directionBuilder_ == null) {
          if (!(orientationCase_ == 2)) {
            orientation_ = ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
          }
          directionBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder>(
                  (ubii.dataStructure.Vector2OuterClass.Vector2) orientation_,
                  getParentForChildren(),
                  isClean());
          orientation_ = null;
        }
        orientationCase_ = 2;
        onChanged();;
        return directionBuilder_;
      }

      /**
       * <code>float angle = 3;</code>
       */
      public float getAngle() {
        if (orientationCase_ == 3) {
          return (java.lang.Float) orientation_;
        }
        return 0F;
      }
      /**
       * <code>float angle = 3;</code>
       */
      public Builder setAngle(float value) {
        orientationCase_ = 3;
        orientation_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>float angle = 3;</code>
       */
      public Builder clearAngle() {
        if (orientationCase_ == 3) {
          orientationCase_ = 0;
          orientation_ = null;
          onChanged();
        }
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.Pose2D)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.Pose2D)
    private static final ubii.dataStructure.Pose2DOuterClass.Pose2D DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.Pose2DOuterClass.Pose2D();
    }

    public static ubii.dataStructure.Pose2DOuterClass.Pose2D getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Pose2D>
        PARSER = new com.google.protobuf.AbstractParser<Pose2D>() {
      @java.lang.Override
      public Pose2D parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Pose2D(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Pose2D> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Pose2D> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.Pose2DOuterClass.Pose2D getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_Pose2D_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_Pose2D_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n:proto/topicData/topicDataRecord/dataSt" +
      "ructure/pose2d.proto\022\022ubii.dataStructure" +
      "\032;proto/topicData/topicDataRecord/dataSt" +
      "ructure/vector2.proto\"\211\001\n\006Pose2D\022-\n\010posi" +
      "tion\030\001 \001(\0132\033.ubii.dataStructure.Vector2\022" +
      "0\n\tdirection\030\002 \001(\0132\033.ubii.dataStructure." +
      "Vector2H\000\022\017\n\005angle\030\003 \001(\002H\000B\r\n\013orientatio" +
      "nb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.dataStructure.Vector2OuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_dataStructure_Pose2D_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_dataStructure_Pose2D_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_Pose2D_descriptor,
        new java.lang.String[] { "Position", "Direction", "Angle", "Orientation", });
    ubii.dataStructure.Vector2OuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
