// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/sessions/session.proto

package ubii.sessions;

public final class SessionOuterClass {
  private SessionOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  /**
   * Protobuf enum {@code ubii.sessions.SessionStatus}
   */
  public enum SessionStatus
      implements com.google.protobuf.ProtocolMessageEnum {
    /**
     * <code>CREATED = 0;</code>
     */
    CREATED(0),
    /**
     * <code>RUNNING = 1;</code>
     */
    RUNNING(1),
    /**
     * <code>PAUSED = 2;</code>
     */
    PAUSED(2),
    /**
     * <code>STOPPED = 3;</code>
     */
    STOPPED(3),
    UNRECOGNIZED(-1),
    ;

    /**
     * <code>CREATED = 0;</code>
     */
    public static final int CREATED_VALUE = 0;
    /**
     * <code>RUNNING = 1;</code>
     */
    public static final int RUNNING_VALUE = 1;
    /**
     * <code>PAUSED = 2;</code>
     */
    public static final int PAUSED_VALUE = 2;
    /**
     * <code>STOPPED = 3;</code>
     */
    public static final int STOPPED_VALUE = 3;


    public final int getNumber() {
      if (this == UNRECOGNIZED) {
        throw new java.lang.IllegalArgumentException(
            "Can't get the number of an unknown enum value.");
      }
      return value;
    }

    /**
     * @deprecated Use {@link #forNumber(int)} instead.
     */
    @java.lang.Deprecated
    public static SessionStatus valueOf(int value) {
      return forNumber(value);
    }

    public static SessionStatus forNumber(int value) {
      switch (value) {
        case 0: return CREATED;
        case 1: return RUNNING;
        case 2: return PAUSED;
        case 3: return STOPPED;
        default: return null;
      }
    }

    public static com.google.protobuf.Internal.EnumLiteMap<SessionStatus>
        internalGetValueMap() {
      return internalValueMap;
    }
    private static final com.google.protobuf.Internal.EnumLiteMap<
        SessionStatus> internalValueMap =
          new com.google.protobuf.Internal.EnumLiteMap<SessionStatus>() {
            public SessionStatus findValueByNumber(int number) {
              return SessionStatus.forNumber(number);
            }
          };

    public final com.google.protobuf.Descriptors.EnumValueDescriptor
        getValueDescriptor() {
      return getDescriptor().getValues().get(ordinal());
    }
    public final com.google.protobuf.Descriptors.EnumDescriptor
        getDescriptorForType() {
      return getDescriptor();
    }
    public static final com.google.protobuf.Descriptors.EnumDescriptor
        getDescriptor() {
      return ubii.sessions.SessionOuterClass.getDescriptor().getEnumTypes().get(0);
    }

    private static final SessionStatus[] VALUES = values();

    public static SessionStatus valueOf(
        com.google.protobuf.Descriptors.EnumValueDescriptor desc) {
      if (desc.getType() != getDescriptor()) {
        throw new java.lang.IllegalArgumentException(
          "EnumValueDescriptor is not for this type.");
      }
      if (desc.getIndex() == -1) {
        return UNRECOGNIZED;
      }
      return VALUES[desc.getIndex()];
    }

    private final int value;

    private SessionStatus(int value) {
      this.value = value;
    }

    // @@protoc_insertion_point(enum_scope:ubii.sessions.SessionStatus)
  }

  public interface SessionOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.Session)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string id = 1;</code>
     */
    java.lang.String getId();
    /**
     * <code>string id = 1;</code>
     */
    com.google.protobuf.ByteString
        getIdBytes();

    /**
     * <code>string name = 2;</code>
     */
    java.lang.String getName();
    /**
     * <code>string name = 2;</code>
     */
    com.google.protobuf.ByteString
        getNameBytes();

    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> 
        getProcessingModulesList();
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModules(int index);
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    int getProcessingModulesCount();
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    java.util.List<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
        getProcessingModulesOrBuilderList();
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModulesOrBuilder(
        int index);

    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    java.util.List<ubii.sessions.IoMappings.IOMapping> 
        getIoMappingsList();
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    ubii.sessions.IoMappings.IOMapping getIoMappings(int index);
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    int getIoMappingsCount();
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    java.util.List<? extends ubii.sessions.IoMappings.IOMappingOrBuilder> 
        getIoMappingsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    ubii.sessions.IoMappings.IOMappingOrBuilder getIoMappingsOrBuilder(
        int index);

    /**
     * <code>repeated string tags = 5;</code>
     */
    java.util.List<java.lang.String>
        getTagsList();
    /**
     * <code>repeated string tags = 5;</code>
     */
    int getTagsCount();
    /**
     * <code>repeated string tags = 5;</code>
     */
    java.lang.String getTags(int index);
    /**
     * <code>repeated string tags = 5;</code>
     */
    com.google.protobuf.ByteString
        getTagsBytes(int index);

    /**
     * <code>string description = 6;</code>
     */
    java.lang.String getDescription();
    /**
     * <code>string description = 6;</code>
     */
    com.google.protobuf.ByteString
        getDescriptionBytes();

    /**
     * <code>repeated string authors = 7;</code>
     */
    java.util.List<java.lang.String>
        getAuthorsList();
    /**
     * <code>repeated string authors = 7;</code>
     */
    int getAuthorsCount();
    /**
     * <code>repeated string authors = 7;</code>
     */
    java.lang.String getAuthors(int index);
    /**
     * <code>repeated string authors = 7;</code>
     */
    com.google.protobuf.ByteString
        getAuthorsBytes(int index);

    /**
     * <code>.ubii.sessions.SessionStatus status = 8;</code>
     */
    int getStatusValue();
    /**
     * <code>.ubii.sessions.SessionStatus status = 8;</code>
     */
    ubii.sessions.SessionOuterClass.SessionStatus getStatus();

    /**
     * <code>bool editable = 9;</code>
     */
    boolean getEditable();
  }
  /**
   * Protobuf type {@code ubii.sessions.Session}
   */
  public  static final class Session extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.Session)
      SessionOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Session.newBuilder() to construct.
    private Session(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Session() {
      id_ = "";
      name_ = "";
      processingModules_ = java.util.Collections.emptyList();
      ioMappings_ = java.util.Collections.emptyList();
      tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      description_ = "";
      authors_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      status_ = 0;
      editable_ = false;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Session(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              id_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();

              name_ = s;
              break;
            }
            case 26: {
              if (!((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
                processingModules_ = new java.util.ArrayList<ubii.processing.ProcessingModuleOuterClass.ProcessingModule>();
                mutable_bitField0_ |= 0x00000004;
              }
              processingModules_.add(
                  input.readMessage(ubii.processing.ProcessingModuleOuterClass.ProcessingModule.parser(), extensionRegistry));
              break;
            }
            case 34: {
              if (!((mutable_bitField0_ & 0x00000008) == 0x00000008)) {
                ioMappings_ = new java.util.ArrayList<ubii.sessions.IoMappings.IOMapping>();
                mutable_bitField0_ |= 0x00000008;
              }
              ioMappings_.add(
                  input.readMessage(ubii.sessions.IoMappings.IOMapping.parser(), extensionRegistry));
              break;
            }
            case 42: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000010) == 0x00000010)) {
                tags_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000010;
              }
              tags_.add(s);
              break;
            }
            case 50: {
              java.lang.String s = input.readStringRequireUtf8();

              description_ = s;
              break;
            }
            case 58: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000040) == 0x00000040)) {
                authors_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000040;
              }
              authors_.add(s);
              break;
            }
            case 64: {
              int rawValue = input.readEnum();

              status_ = rawValue;
              break;
            }
            case 72: {

              editable_ = input.readBool();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
          processingModules_ = java.util.Collections.unmodifiableList(processingModules_);
        }
        if (((mutable_bitField0_ & 0x00000008) == 0x00000008)) {
          ioMappings_ = java.util.Collections.unmodifiableList(ioMappings_);
        }
        if (((mutable_bitField0_ & 0x00000010) == 0x00000010)) {
          tags_ = tags_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000040) == 0x00000040)) {
          authors_ = authors_.getUnmodifiableView();
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_Session_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_Session_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.SessionOuterClass.Session.class, ubii.sessions.SessionOuterClass.Session.Builder.class);
    }

    private int bitField0_;
    public static final int ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object id_;
    /**
     * <code>string id = 1;</code>
     */
    public java.lang.String getId() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        id_ = s;
        return s;
      }
    }
    /**
     * <code>string id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getIdBytes() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        id_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int NAME_FIELD_NUMBER = 2;
    private volatile java.lang.Object name_;
    /**
     * <code>string name = 2;</code>
     */
    public java.lang.String getName() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        name_ = s;
        return s;
      }
    }
    /**
     * <code>string name = 2;</code>
     */
    public com.google.protobuf.ByteString
        getNameBytes() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        name_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int PROCESSING_MODULES_FIELD_NUMBER = 3;
    private java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> processingModules_;
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    public java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> getProcessingModulesList() {
      return processingModules_;
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    public java.util.List<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
        getProcessingModulesOrBuilderList() {
      return processingModules_;
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    public int getProcessingModulesCount() {
      return processingModules_.size();
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModules(int index) {
      return processingModules_.get(index);
    }
    /**
     * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModulesOrBuilder(
        int index) {
      return processingModules_.get(index);
    }

    public static final int IO_MAPPINGS_FIELD_NUMBER = 4;
    private java.util.List<ubii.sessions.IoMappings.IOMapping> ioMappings_;
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    public java.util.List<ubii.sessions.IoMappings.IOMapping> getIoMappingsList() {
      return ioMappings_;
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    public java.util.List<? extends ubii.sessions.IoMappings.IOMappingOrBuilder> 
        getIoMappingsOrBuilderList() {
      return ioMappings_;
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    public int getIoMappingsCount() {
      return ioMappings_.size();
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    public ubii.sessions.IoMappings.IOMapping getIoMappings(int index) {
      return ioMappings_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
     */
    public ubii.sessions.IoMappings.IOMappingOrBuilder getIoMappingsOrBuilder(
        int index) {
      return ioMappings_.get(index);
    }

    public static final int TAGS_FIELD_NUMBER = 5;
    private com.google.protobuf.LazyStringList tags_;
    /**
     * <code>repeated string tags = 5;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getTagsList() {
      return tags_;
    }
    /**
     * <code>repeated string tags = 5;</code>
     */
    public int getTagsCount() {
      return tags_.size();
    }
    /**
     * <code>repeated string tags = 5;</code>
     */
    public java.lang.String getTags(int index) {
      return tags_.get(index);
    }
    /**
     * <code>repeated string tags = 5;</code>
     */
    public com.google.protobuf.ByteString
        getTagsBytes(int index) {
      return tags_.getByteString(index);
    }

    public static final int DESCRIPTION_FIELD_NUMBER = 6;
    private volatile java.lang.Object description_;
    /**
     * <code>string description = 6;</code>
     */
    public java.lang.String getDescription() {
      java.lang.Object ref = description_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        description_ = s;
        return s;
      }
    }
    /**
     * <code>string description = 6;</code>
     */
    public com.google.protobuf.ByteString
        getDescriptionBytes() {
      java.lang.Object ref = description_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        description_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int AUTHORS_FIELD_NUMBER = 7;
    private com.google.protobuf.LazyStringList authors_;
    /**
     * <code>repeated string authors = 7;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getAuthorsList() {
      return authors_;
    }
    /**
     * <code>repeated string authors = 7;</code>
     */
    public int getAuthorsCount() {
      return authors_.size();
    }
    /**
     * <code>repeated string authors = 7;</code>
     */
    public java.lang.String getAuthors(int index) {
      return authors_.get(index);
    }
    /**
     * <code>repeated string authors = 7;</code>
     */
    public com.google.protobuf.ByteString
        getAuthorsBytes(int index) {
      return authors_.getByteString(index);
    }

    public static final int STATUS_FIELD_NUMBER = 8;
    private int status_;
    /**
     * <code>.ubii.sessions.SessionStatus status = 8;</code>
     */
    public int getStatusValue() {
      return status_;
    }
    /**
     * <code>.ubii.sessions.SessionStatus status = 8;</code>
     */
    public ubii.sessions.SessionOuterClass.SessionStatus getStatus() {
      @SuppressWarnings("deprecation")
      ubii.sessions.SessionOuterClass.SessionStatus result = ubii.sessions.SessionOuterClass.SessionStatus.valueOf(status_);
      return result == null ? ubii.sessions.SessionOuterClass.SessionStatus.UNRECOGNIZED : result;
    }

    public static final int EDITABLE_FIELD_NUMBER = 9;
    private boolean editable_;
    /**
     * <code>bool editable = 9;</code>
     */
    public boolean getEditable() {
      return editable_;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, name_);
      }
      for (int i = 0; i < processingModules_.size(); i++) {
        output.writeMessage(3, processingModules_.get(i));
      }
      for (int i = 0; i < ioMappings_.size(); i++) {
        output.writeMessage(4, ioMappings_.get(i));
      }
      for (int i = 0; i < tags_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 5, tags_.getRaw(i));
      }
      if (!getDescriptionBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 6, description_);
      }
      for (int i = 0; i < authors_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 7, authors_.getRaw(i));
      }
      if (status_ != ubii.sessions.SessionOuterClass.SessionStatus.CREATED.getNumber()) {
        output.writeEnum(8, status_);
      }
      if (editable_ != false) {
        output.writeBool(9, editable_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(2, name_);
      }
      for (int i = 0; i < processingModules_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, processingModules_.get(i));
      }
      for (int i = 0; i < ioMappings_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(4, ioMappings_.get(i));
      }
      {
        int dataSize = 0;
        for (int i = 0; i < tags_.size(); i++) {
          dataSize += computeStringSizeNoTag(tags_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getTagsList().size();
      }
      if (!getDescriptionBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(6, description_);
      }
      {
        int dataSize = 0;
        for (int i = 0; i < authors_.size(); i++) {
          dataSize += computeStringSizeNoTag(authors_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getAuthorsList().size();
      }
      if (status_ != ubii.sessions.SessionOuterClass.SessionStatus.CREATED.getNumber()) {
        size += com.google.protobuf.CodedOutputStream
          .computeEnumSize(8, status_);
      }
      if (editable_ != false) {
        size += com.google.protobuf.CodedOutputStream
          .computeBoolSize(9, editable_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.SessionOuterClass.Session)) {
        return super.equals(obj);
      }
      ubii.sessions.SessionOuterClass.Session other = (ubii.sessions.SessionOuterClass.Session) obj;

      boolean result = true;
      result = result && getId()
          .equals(other.getId());
      result = result && getName()
          .equals(other.getName());
      result = result && getProcessingModulesList()
          .equals(other.getProcessingModulesList());
      result = result && getIoMappingsList()
          .equals(other.getIoMappingsList());
      result = result && getTagsList()
          .equals(other.getTagsList());
      result = result && getDescription()
          .equals(other.getDescription());
      result = result && getAuthorsList()
          .equals(other.getAuthorsList());
      result = result && status_ == other.status_;
      result = result && (getEditable()
          == other.getEditable());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + ID_FIELD_NUMBER;
      hash = (53 * hash) + getId().hashCode();
      hash = (37 * hash) + NAME_FIELD_NUMBER;
      hash = (53 * hash) + getName().hashCode();
      if (getProcessingModulesCount() > 0) {
        hash = (37 * hash) + PROCESSING_MODULES_FIELD_NUMBER;
        hash = (53 * hash) + getProcessingModulesList().hashCode();
      }
      if (getIoMappingsCount() > 0) {
        hash = (37 * hash) + IO_MAPPINGS_FIELD_NUMBER;
        hash = (53 * hash) + getIoMappingsList().hashCode();
      }
      if (getTagsCount() > 0) {
        hash = (37 * hash) + TAGS_FIELD_NUMBER;
        hash = (53 * hash) + getTagsList().hashCode();
      }
      hash = (37 * hash) + DESCRIPTION_FIELD_NUMBER;
      hash = (53 * hash) + getDescription().hashCode();
      if (getAuthorsCount() > 0) {
        hash = (37 * hash) + AUTHORS_FIELD_NUMBER;
        hash = (53 * hash) + getAuthorsList().hashCode();
      }
      hash = (37 * hash) + STATUS_FIELD_NUMBER;
      hash = (53 * hash) + status_;
      hash = (37 * hash) + EDITABLE_FIELD_NUMBER;
      hash = (53 * hash) + com.google.protobuf.Internal.hashBoolean(
          getEditable());
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.Session parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.SessionOuterClass.Session parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.SessionOuterClass.Session parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.SessionOuterClass.Session prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.Session}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.Session)
        ubii.sessions.SessionOuterClass.SessionOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_Session_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_Session_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.SessionOuterClass.Session.class, ubii.sessions.SessionOuterClass.Session.Builder.class);
      }

      // Construct using ubii.sessions.SessionOuterClass.Session.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getProcessingModulesFieldBuilder();
          getIoMappingsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        id_ = "";

        name_ = "";

        if (processingModulesBuilder_ == null) {
          processingModules_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000004);
        } else {
          processingModulesBuilder_.clear();
        }
        if (ioMappingsBuilder_ == null) {
          ioMappings_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000008);
        } else {
          ioMappingsBuilder_.clear();
        }
        tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000010);
        description_ = "";

        authors_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000040);
        status_ = 0;

        editable_ = false;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_Session_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.SessionOuterClass.Session getDefaultInstanceForType() {
        return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.SessionOuterClass.Session build() {
        ubii.sessions.SessionOuterClass.Session result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.SessionOuterClass.Session buildPartial() {
        ubii.sessions.SessionOuterClass.Session result = new ubii.sessions.SessionOuterClass.Session(this);
        int from_bitField0_ = bitField0_;
        int to_bitField0_ = 0;
        result.id_ = id_;
        result.name_ = name_;
        if (processingModulesBuilder_ == null) {
          if (((bitField0_ & 0x00000004) == 0x00000004)) {
            processingModules_ = java.util.Collections.unmodifiableList(processingModules_);
            bitField0_ = (bitField0_ & ~0x00000004);
          }
          result.processingModules_ = processingModules_;
        } else {
          result.processingModules_ = processingModulesBuilder_.build();
        }
        if (ioMappingsBuilder_ == null) {
          if (((bitField0_ & 0x00000008) == 0x00000008)) {
            ioMappings_ = java.util.Collections.unmodifiableList(ioMappings_);
            bitField0_ = (bitField0_ & ~0x00000008);
          }
          result.ioMappings_ = ioMappings_;
        } else {
          result.ioMappings_ = ioMappingsBuilder_.build();
        }
        if (((bitField0_ & 0x00000010) == 0x00000010)) {
          tags_ = tags_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000010);
        }
        result.tags_ = tags_;
        result.description_ = description_;
        if (((bitField0_ & 0x00000040) == 0x00000040)) {
          authors_ = authors_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000040);
        }
        result.authors_ = authors_;
        result.status_ = status_;
        result.editable_ = editable_;
        result.bitField0_ = to_bitField0_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.SessionOuterClass.Session) {
          return mergeFrom((ubii.sessions.SessionOuterClass.Session)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.SessionOuterClass.Session other) {
        if (other == ubii.sessions.SessionOuterClass.Session.getDefaultInstance()) return this;
        if (!other.getId().isEmpty()) {
          id_ = other.id_;
          onChanged();
        }
        if (!other.getName().isEmpty()) {
          name_ = other.name_;
          onChanged();
        }
        if (processingModulesBuilder_ == null) {
          if (!other.processingModules_.isEmpty()) {
            if (processingModules_.isEmpty()) {
              processingModules_ = other.processingModules_;
              bitField0_ = (bitField0_ & ~0x00000004);
            } else {
              ensureProcessingModulesIsMutable();
              processingModules_.addAll(other.processingModules_);
            }
            onChanged();
          }
        } else {
          if (!other.processingModules_.isEmpty()) {
            if (processingModulesBuilder_.isEmpty()) {
              processingModulesBuilder_.dispose();
              processingModulesBuilder_ = null;
              processingModules_ = other.processingModules_;
              bitField0_ = (bitField0_ & ~0x00000004);
              processingModulesBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getProcessingModulesFieldBuilder() : null;
            } else {
              processingModulesBuilder_.addAllMessages(other.processingModules_);
            }
          }
        }
        if (ioMappingsBuilder_ == null) {
          if (!other.ioMappings_.isEmpty()) {
            if (ioMappings_.isEmpty()) {
              ioMappings_ = other.ioMappings_;
              bitField0_ = (bitField0_ & ~0x00000008);
            } else {
              ensureIoMappingsIsMutable();
              ioMappings_.addAll(other.ioMappings_);
            }
            onChanged();
          }
        } else {
          if (!other.ioMappings_.isEmpty()) {
            if (ioMappingsBuilder_.isEmpty()) {
              ioMappingsBuilder_.dispose();
              ioMappingsBuilder_ = null;
              ioMappings_ = other.ioMappings_;
              bitField0_ = (bitField0_ & ~0x00000008);
              ioMappingsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getIoMappingsFieldBuilder() : null;
            } else {
              ioMappingsBuilder_.addAllMessages(other.ioMappings_);
            }
          }
        }
        if (!other.tags_.isEmpty()) {
          if (tags_.isEmpty()) {
            tags_ = other.tags_;
            bitField0_ = (bitField0_ & ~0x00000010);
          } else {
            ensureTagsIsMutable();
            tags_.addAll(other.tags_);
          }
          onChanged();
        }
        if (!other.getDescription().isEmpty()) {
          description_ = other.description_;
          onChanged();
        }
        if (!other.authors_.isEmpty()) {
          if (authors_.isEmpty()) {
            authors_ = other.authors_;
            bitField0_ = (bitField0_ & ~0x00000040);
          } else {
            ensureAuthorsIsMutable();
            authors_.addAll(other.authors_);
          }
          onChanged();
        }
        if (other.status_ != 0) {
          setStatusValue(other.getStatusValue());
        }
        if (other.getEditable() != false) {
          setEditable(other.getEditable());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.SessionOuterClass.Session parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.SessionOuterClass.Session) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.lang.Object id_ = "";
      /**
       * <code>string id = 1;</code>
       */
      public java.lang.String getId() {
        java.lang.Object ref = id_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          id_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getIdBytes() {
        java.lang.Object ref = id_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          id_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        id_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder clearId() {
        
        id_ = getDefaultInstance().getId();
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        id_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object name_ = "";
      /**
       * <code>string name = 2;</code>
       */
      public java.lang.String getName() {
        java.lang.Object ref = name_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          name_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public com.google.protobuf.ByteString
          getNameBytes() {
        java.lang.Object ref = name_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          name_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        name_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder clearName() {
        
        name_ = getDefaultInstance().getName();
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        name_ = value;
        onChanged();
        return this;
      }

      private java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> processingModules_ =
        java.util.Collections.emptyList();
      private void ensureProcessingModulesIsMutable() {
        if (!((bitField0_ & 0x00000004) == 0x00000004)) {
          processingModules_ = new java.util.ArrayList<ubii.processing.ProcessingModuleOuterClass.ProcessingModule>(processingModules_);
          bitField0_ |= 0x00000004;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> processingModulesBuilder_;

      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule> getProcessingModulesList() {
        if (processingModulesBuilder_ == null) {
          return java.util.Collections.unmodifiableList(processingModules_);
        } else {
          return processingModulesBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public int getProcessingModulesCount() {
        if (processingModulesBuilder_ == null) {
          return processingModules_.size();
        } else {
          return processingModulesBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModules(int index) {
        if (processingModulesBuilder_ == null) {
          return processingModules_.get(index);
        } else {
          return processingModulesBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder setProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModulesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureProcessingModulesIsMutable();
          processingModules_.set(index, value);
          onChanged();
        } else {
          processingModulesBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder setProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.set(index, builderForValue.build());
          onChanged();
        } else {
          processingModulesBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder addProcessingModules(ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModulesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureProcessingModulesIsMutable();
          processingModules_.add(value);
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder addProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModulesBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureProcessingModulesIsMutable();
          processingModules_.add(index, value);
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder addProcessingModules(
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.add(builderForValue.build());
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder addProcessingModules(
          int index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.add(index, builderForValue.build());
          onChanged();
        } else {
          processingModulesBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder addAllProcessingModules(
          java.lang.Iterable<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModule> values) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, processingModules_);
          onChanged();
        } else {
          processingModulesBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder clearProcessingModules() {
        if (processingModulesBuilder_ == null) {
          processingModules_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000004);
          onChanged();
        } else {
          processingModulesBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public Builder removeProcessingModules(int index) {
        if (processingModulesBuilder_ == null) {
          ensureProcessingModulesIsMutable();
          processingModules_.remove(index);
          onChanged();
        } else {
          processingModulesBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder getProcessingModulesBuilder(
          int index) {
        return getProcessingModulesFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModulesOrBuilder(
          int index) {
        if (processingModulesBuilder_ == null) {
          return processingModules_.get(index);  } else {
          return processingModulesBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public java.util.List<? extends ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
           getProcessingModulesOrBuilderList() {
        if (processingModulesBuilder_ != null) {
          return processingModulesBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(processingModules_);
        }
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder addProcessingModulesBuilder() {
        return getProcessingModulesFieldBuilder().addBuilder(
            ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder addProcessingModulesBuilder(
          int index) {
        return getProcessingModulesFieldBuilder().addBuilder(
            index, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.processing.ProcessingModule processing_modules = 3;</code>
       */
      public java.util.List<ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder> 
           getProcessingModulesBuilderList() {
        return getProcessingModulesFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
          getProcessingModulesFieldBuilder() {
        if (processingModulesBuilder_ == null) {
          processingModulesBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder>(
                  processingModules_,
                  ((bitField0_ & 0x00000004) == 0x00000004),
                  getParentForChildren(),
                  isClean());
          processingModules_ = null;
        }
        return processingModulesBuilder_;
      }

      private java.util.List<ubii.sessions.IoMappings.IOMapping> ioMappings_ =
        java.util.Collections.emptyList();
      private void ensureIoMappingsIsMutable() {
        if (!((bitField0_ & 0x00000008) == 0x00000008)) {
          ioMappings_ = new java.util.ArrayList<ubii.sessions.IoMappings.IOMapping>(ioMappings_);
          bitField0_ |= 0x00000008;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.IOMapping, ubii.sessions.IoMappings.IOMapping.Builder, ubii.sessions.IoMappings.IOMappingOrBuilder> ioMappingsBuilder_;

      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.IOMapping> getIoMappingsList() {
        if (ioMappingsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(ioMappings_);
        } else {
          return ioMappingsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public int getIoMappingsCount() {
        if (ioMappingsBuilder_ == null) {
          return ioMappings_.size();
        } else {
          return ioMappingsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public ubii.sessions.IoMappings.IOMapping getIoMappings(int index) {
        if (ioMappingsBuilder_ == null) {
          return ioMappings_.get(index);
        } else {
          return ioMappingsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder setIoMappings(
          int index, ubii.sessions.IoMappings.IOMapping value) {
        if (ioMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureIoMappingsIsMutable();
          ioMappings_.set(index, value);
          onChanged();
        } else {
          ioMappingsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder setIoMappings(
          int index, ubii.sessions.IoMappings.IOMapping.Builder builderForValue) {
        if (ioMappingsBuilder_ == null) {
          ensureIoMappingsIsMutable();
          ioMappings_.set(index, builderForValue.build());
          onChanged();
        } else {
          ioMappingsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder addIoMappings(ubii.sessions.IoMappings.IOMapping value) {
        if (ioMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureIoMappingsIsMutable();
          ioMappings_.add(value);
          onChanged();
        } else {
          ioMappingsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder addIoMappings(
          int index, ubii.sessions.IoMappings.IOMapping value) {
        if (ioMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureIoMappingsIsMutable();
          ioMappings_.add(index, value);
          onChanged();
        } else {
          ioMappingsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder addIoMappings(
          ubii.sessions.IoMappings.IOMapping.Builder builderForValue) {
        if (ioMappingsBuilder_ == null) {
          ensureIoMappingsIsMutable();
          ioMappings_.add(builderForValue.build());
          onChanged();
        } else {
          ioMappingsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder addIoMappings(
          int index, ubii.sessions.IoMappings.IOMapping.Builder builderForValue) {
        if (ioMappingsBuilder_ == null) {
          ensureIoMappingsIsMutable();
          ioMappings_.add(index, builderForValue.build());
          onChanged();
        } else {
          ioMappingsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder addAllIoMappings(
          java.lang.Iterable<? extends ubii.sessions.IoMappings.IOMapping> values) {
        if (ioMappingsBuilder_ == null) {
          ensureIoMappingsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, ioMappings_);
          onChanged();
        } else {
          ioMappingsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder clearIoMappings() {
        if (ioMappingsBuilder_ == null) {
          ioMappings_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000008);
          onChanged();
        } else {
          ioMappingsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public Builder removeIoMappings(int index) {
        if (ioMappingsBuilder_ == null) {
          ensureIoMappingsIsMutable();
          ioMappings_.remove(index);
          onChanged();
        } else {
          ioMappingsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public ubii.sessions.IoMappings.IOMapping.Builder getIoMappingsBuilder(
          int index) {
        return getIoMappingsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public ubii.sessions.IoMappings.IOMappingOrBuilder getIoMappingsOrBuilder(
          int index) {
        if (ioMappingsBuilder_ == null) {
          return ioMappings_.get(index);  } else {
          return ioMappingsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public java.util.List<? extends ubii.sessions.IoMappings.IOMappingOrBuilder> 
           getIoMappingsOrBuilderList() {
        if (ioMappingsBuilder_ != null) {
          return ioMappingsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(ioMappings_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public ubii.sessions.IoMappings.IOMapping.Builder addIoMappingsBuilder() {
        return getIoMappingsFieldBuilder().addBuilder(
            ubii.sessions.IoMappings.IOMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public ubii.sessions.IoMappings.IOMapping.Builder addIoMappingsBuilder(
          int index) {
        return getIoMappingsFieldBuilder().addBuilder(
            index, ubii.sessions.IoMappings.IOMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping io_mappings = 4;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.IOMapping.Builder> 
           getIoMappingsBuilderList() {
        return getIoMappingsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.IOMapping, ubii.sessions.IoMappings.IOMapping.Builder, ubii.sessions.IoMappings.IOMappingOrBuilder> 
          getIoMappingsFieldBuilder() {
        if (ioMappingsBuilder_ == null) {
          ioMappingsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.IoMappings.IOMapping, ubii.sessions.IoMappings.IOMapping.Builder, ubii.sessions.IoMappings.IOMappingOrBuilder>(
                  ioMappings_,
                  ((bitField0_ & 0x00000008) == 0x00000008),
                  getParentForChildren(),
                  isClean());
          ioMappings_ = null;
        }
        return ioMappingsBuilder_;
      }

      private com.google.protobuf.LazyStringList tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureTagsIsMutable() {
        if (!((bitField0_ & 0x00000010) == 0x00000010)) {
          tags_ = new com.google.protobuf.LazyStringArrayList(tags_);
          bitField0_ |= 0x00000010;
         }
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getTagsList() {
        return tags_.getUnmodifiableView();
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public int getTagsCount() {
        return tags_.size();
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public java.lang.String getTags(int index) {
        return tags_.get(index);
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public com.google.protobuf.ByteString
          getTagsBytes(int index) {
        return tags_.getByteString(index);
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public Builder setTags(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureTagsIsMutable();
        tags_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public Builder addTags(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureTagsIsMutable();
        tags_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public Builder addAllTags(
          java.lang.Iterable<java.lang.String> values) {
        ensureTagsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, tags_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public Builder clearTags() {
        tags_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000010);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string tags = 5;</code>
       */
      public Builder addTagsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureTagsIsMutable();
        tags_.add(value);
        onChanged();
        return this;
      }

      private java.lang.Object description_ = "";
      /**
       * <code>string description = 6;</code>
       */
      public java.lang.String getDescription() {
        java.lang.Object ref = description_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          description_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string description = 6;</code>
       */
      public com.google.protobuf.ByteString
          getDescriptionBytes() {
        java.lang.Object ref = description_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          description_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string description = 6;</code>
       */
      public Builder setDescription(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        description_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string description = 6;</code>
       */
      public Builder clearDescription() {
        
        description_ = getDefaultInstance().getDescription();
        onChanged();
        return this;
      }
      /**
       * <code>string description = 6;</code>
       */
      public Builder setDescriptionBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        description_ = value;
        onChanged();
        return this;
      }

      private com.google.protobuf.LazyStringList authors_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureAuthorsIsMutable() {
        if (!((bitField0_ & 0x00000040) == 0x00000040)) {
          authors_ = new com.google.protobuf.LazyStringArrayList(authors_);
          bitField0_ |= 0x00000040;
         }
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getAuthorsList() {
        return authors_.getUnmodifiableView();
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public int getAuthorsCount() {
        return authors_.size();
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public java.lang.String getAuthors(int index) {
        return authors_.get(index);
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public com.google.protobuf.ByteString
          getAuthorsBytes(int index) {
        return authors_.getByteString(index);
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public Builder setAuthors(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureAuthorsIsMutable();
        authors_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public Builder addAuthors(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureAuthorsIsMutable();
        authors_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public Builder addAllAuthors(
          java.lang.Iterable<java.lang.String> values) {
        ensureAuthorsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, authors_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public Builder clearAuthors() {
        authors_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000040);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string authors = 7;</code>
       */
      public Builder addAuthorsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureAuthorsIsMutable();
        authors_.add(value);
        onChanged();
        return this;
      }

      private int status_ = 0;
      /**
       * <code>.ubii.sessions.SessionStatus status = 8;</code>
       */
      public int getStatusValue() {
        return status_;
      }
      /**
       * <code>.ubii.sessions.SessionStatus status = 8;</code>
       */
      public Builder setStatusValue(int value) {
        status_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.sessions.SessionStatus status = 8;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionStatus getStatus() {
        @SuppressWarnings("deprecation")
        ubii.sessions.SessionOuterClass.SessionStatus result = ubii.sessions.SessionOuterClass.SessionStatus.valueOf(status_);
        return result == null ? ubii.sessions.SessionOuterClass.SessionStatus.UNRECOGNIZED : result;
      }
      /**
       * <code>.ubii.sessions.SessionStatus status = 8;</code>
       */
      public Builder setStatus(ubii.sessions.SessionOuterClass.SessionStatus value) {
        if (value == null) {
          throw new NullPointerException();
        }
        
        status_ = value.getNumber();
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.sessions.SessionStatus status = 8;</code>
       */
      public Builder clearStatus() {
        
        status_ = 0;
        onChanged();
        return this;
      }

      private boolean editable_ ;
      /**
       * <code>bool editable = 9;</code>
       */
      public boolean getEditable() {
        return editable_;
      }
      /**
       * <code>bool editable = 9;</code>
       */
      public Builder setEditable(boolean value) {
        
        editable_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>bool editable = 9;</code>
       */
      public Builder clearEditable() {
        
        editable_ = false;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.Session)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.Session)
    private static final ubii.sessions.SessionOuterClass.Session DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.SessionOuterClass.Session();
    }

    public static ubii.sessions.SessionOuterClass.Session getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Session>
        PARSER = new com.google.protobuf.AbstractParser<Session>() {
      @java.lang.Override
      public Session parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Session(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Session> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Session> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.SessionOuterClass.Session getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface SessionListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.SessionList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    java.util.List<ubii.sessions.SessionOuterClass.Session> 
        getElementsList();
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    ubii.sessions.SessionOuterClass.Session getElements(int index);
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    java.util.List<? extends ubii.sessions.SessionOuterClass.SessionOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    ubii.sessions.SessionOuterClass.SessionOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.sessions.SessionList}
   */
  public  static final class SessionList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.SessionList)
      SessionListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use SessionList.newBuilder() to construct.
    private SessionList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private SessionList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private SessionList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.sessions.SessionOuterClass.Session>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.sessions.SessionOuterClass.Session.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_SessionList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_SessionList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.SessionOuterClass.SessionList.class, ubii.sessions.SessionOuterClass.SessionList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.sessions.SessionOuterClass.Session> elements_;
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    public java.util.List<ubii.sessions.SessionOuterClass.Session> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    public java.util.List<? extends ubii.sessions.SessionOuterClass.SessionOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    public ubii.sessions.SessionOuterClass.Session getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.Session elements = 1;</code>
     */
    public ubii.sessions.SessionOuterClass.SessionOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.SessionOuterClass.SessionList)) {
        return super.equals(obj);
      }
      ubii.sessions.SessionOuterClass.SessionList other = (ubii.sessions.SessionOuterClass.SessionList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.SessionOuterClass.SessionList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.SessionOuterClass.SessionList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.SessionList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.SessionList)
        ubii.sessions.SessionOuterClass.SessionListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_SessionList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_SessionList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.SessionOuterClass.SessionList.class, ubii.sessions.SessionOuterClass.SessionList.Builder.class);
      }

      // Construct using ubii.sessions.SessionOuterClass.SessionList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.SessionOuterClass.internal_static_ubii_sessions_SessionList_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.SessionOuterClass.SessionList getDefaultInstanceForType() {
        return ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.SessionOuterClass.SessionList build() {
        ubii.sessions.SessionOuterClass.SessionList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.SessionOuterClass.SessionList buildPartial() {
        ubii.sessions.SessionOuterClass.SessionList result = new ubii.sessions.SessionOuterClass.SessionList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.SessionOuterClass.SessionList) {
          return mergeFrom((ubii.sessions.SessionOuterClass.SessionList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.SessionOuterClass.SessionList other) {
        if (other == ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.SessionOuterClass.SessionList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.SessionOuterClass.SessionList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.sessions.SessionOuterClass.Session> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.sessions.SessionOuterClass.Session>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public java.util.List<ubii.sessions.SessionOuterClass.Session> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public ubii.sessions.SessionOuterClass.Session getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.SessionOuterClass.Session value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.SessionOuterClass.Session.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder addElements(ubii.sessions.SessionOuterClass.Session value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.SessionOuterClass.Session value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder addElements(
          ubii.sessions.SessionOuterClass.Session.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.SessionOuterClass.Session.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.sessions.SessionOuterClass.Session> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public ubii.sessions.SessionOuterClass.Session.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public java.util.List<? extends ubii.sessions.SessionOuterClass.SessionOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public ubii.sessions.SessionOuterClass.Session.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.sessions.SessionOuterClass.Session.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public ubii.sessions.SessionOuterClass.Session.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.sessions.SessionOuterClass.Session.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.Session elements = 1;</code>
       */
      public java.util.List<ubii.sessions.SessionOuterClass.Session.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.SessionList)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.SessionList)
    private static final ubii.sessions.SessionOuterClass.SessionList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.SessionOuterClass.SessionList();
    }

    public static ubii.sessions.SessionOuterClass.SessionList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<SessionList>
        PARSER = new com.google.protobuf.AbstractParser<SessionList>() {
      @java.lang.Override
      public SessionList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new SessionList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<SessionList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<SessionList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.SessionOuterClass.SessionList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_Session_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_Session_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_SessionList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_SessionList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n\034proto/sessions/session.proto\022\rubii.ses" +
      "sions\032\037proto/sessions/ioMappings.proto\032\'" +
      "proto/processing/processingModule.proto\"" +
      "\205\002\n\007Session\022\n\n\002id\030\001 \001(\t\022\014\n\004name\030\002 \001(\t\022=\n" +
      "\022processing_modules\030\003 \003(\0132!.ubii.process" +
      "ing.ProcessingModule\022-\n\013io_mappings\030\004 \003(" +
      "\0132\030.ubii.sessions.IOMapping\022\014\n\004tags\030\005 \003(" +
      "\t\022\023\n\013description\030\006 \001(\t\022\017\n\007authors\030\007 \003(\t\022" +
      ",\n\006status\030\010 \001(\0162\034.ubii.sessions.SessionS" +
      "tatus\022\020\n\010editable\030\t \001(\010\"7\n\013SessionList\022(" +
      "\n\010elements\030\001 \003(\0132\026.ubii.sessions.Session" +
      "*B\n\rSessionStatus\022\013\n\007CREATED\020\000\022\013\n\007RUNNIN" +
      "G\020\001\022\n\n\006PAUSED\020\002\022\013\n\007STOPPED\020\003b\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.sessions.IoMappings.getDescriptor(),
          ubii.processing.ProcessingModuleOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_sessions_Session_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_sessions_Session_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_Session_descriptor,
        new java.lang.String[] { "Id", "Name", "ProcessingModules", "IoMappings", "Tags", "Description", "Authors", "Status", "Editable", });
    internal_static_ubii_sessions_SessionList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_sessions_SessionList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_SessionList_descriptor,
        new java.lang.String[] { "Elements", });
    ubii.sessions.IoMappings.getDescriptor();
    ubii.processing.ProcessingModuleOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
