syntax = "proto3";
package ubii.proto_v2.types.dataStructure;

import "ubii/proto_v2/types/dataStructure/pose2d.proto";
import "ubii/proto_v2/types/dataStructure/vector2.proto";

message Object2D {
    string id = 1;
    ubii.proto_v2.types.dataStructure.Pose2D pose = 2;
    ubii.proto_v2.types.dataStructure.Vector2 size = 3;
    string user_data_json = 4;
}

message Object2DList {
    repeated ubii.proto_v2.types.dataStructure.Object2D elements = 1;
}