// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/processing/lockstepProcessing.proto

#ifndef PROTOBUF_INCLUDED_proto_2fprocessing_2flockstepProcessing_2eproto
#define PROTOBUF_INCLUDED_proto_2fprocessing_2flockstepProcessing_2eproto

#include <string>

#include <google/protobuf/stubs/common.h>

#if GOOGLE_PROTOBUF_VERSION < 3006001
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please update
#error your headers.
#endif
#if 3006001 < GOOGLE_PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "proto/topicData/topicDataRecord/topicDataRecord.pb.h"
// @@protoc_insertion_point(includes)
#define PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2flockstepProcessing_2eproto 

namespace protobuf_proto_2fprocessing_2flockstepProcessing_2eproto {
// Internal implementation detail -- do not use these members.
struct TableStruct {
  static const ::google::protobuf::internal::ParseTableField entries[];
  static const ::google::protobuf::internal::AuxillaryParseTableField aux[];
  static const ::google::protobuf::internal::ParseTable schema[2];
  static const ::google::protobuf::internal::FieldMetadata field_metadata[];
  static const ::google::protobuf::internal::SerializationTable serialization_table[];
  static const ::google::protobuf::uint32 offsets[];
};
void AddDescriptors();
}  // namespace protobuf_proto_2fprocessing_2flockstepProcessing_2eproto
namespace ubii {
namespace processing {
class LockstepProcessingReply;
class LockstepProcessingReplyDefaultTypeInternal;
extern LockstepProcessingReplyDefaultTypeInternal _LockstepProcessingReply_default_instance_;
class LockstepProcessingRequest;
class LockstepProcessingRequestDefaultTypeInternal;
extern LockstepProcessingRequestDefaultTypeInternal _LockstepProcessingRequest_default_instance_;
}  // namespace processing
}  // namespace ubii
namespace google {
namespace protobuf {
template<> ::ubii::processing::LockstepProcessingReply* Arena::CreateMaybeMessage<::ubii::processing::LockstepProcessingReply>(Arena*);
template<> ::ubii::processing::LockstepProcessingRequest* Arena::CreateMaybeMessage<::ubii::processing::LockstepProcessingRequest>(Arena*);
}  // namespace protobuf
}  // namespace google
namespace ubii {
namespace processing {

// ===================================================================

class LockstepProcessingRequest : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.processing.LockstepProcessingRequest) */ {
 public:
  LockstepProcessingRequest();
  virtual ~LockstepProcessingRequest();

  LockstepProcessingRequest(const LockstepProcessingRequest& from);

  inline LockstepProcessingRequest& operator=(const LockstepProcessingRequest& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  LockstepProcessingRequest(LockstepProcessingRequest&& from) noexcept
    : LockstepProcessingRequest() {
    *this = ::std::move(from);
  }

  inline LockstepProcessingRequest& operator=(LockstepProcessingRequest&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const LockstepProcessingRequest& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const LockstepProcessingRequest* internal_default_instance() {
    return reinterpret_cast<const LockstepProcessingRequest*>(
               &_LockstepProcessingRequest_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  void Swap(LockstepProcessingRequest* other);
  friend void swap(LockstepProcessingRequest& a, LockstepProcessingRequest& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline LockstepProcessingRequest* New() const final {
    return CreateMaybeMessage<LockstepProcessingRequest>(NULL);
  }

  LockstepProcessingRequest* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<LockstepProcessingRequest>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const LockstepProcessingRequest& from);
  void MergeFrom(const LockstepProcessingRequest& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(LockstepProcessingRequest* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // repeated string processing_module_ids = 1;
  int processing_module_ids_size() const;
  void clear_processing_module_ids();
  static const int kProcessingModuleIdsFieldNumber = 1;
  const ::std::string& processing_module_ids(int index) const;
  ::std::string* mutable_processing_module_ids(int index);
  void set_processing_module_ids(int index, const ::std::string& value);
  #if LANG_CXX11
  void set_processing_module_ids(int index, ::std::string&& value);
  #endif
  void set_processing_module_ids(int index, const char* value);
  void set_processing_module_ids(int index, const char* value, size_t size);
  ::std::string* add_processing_module_ids();
  void add_processing_module_ids(const ::std::string& value);
  #if LANG_CXX11
  void add_processing_module_ids(::std::string&& value);
  #endif
  void add_processing_module_ids(const char* value);
  void add_processing_module_ids(const char* value, size_t size);
  const ::google::protobuf::RepeatedPtrField< ::std::string>& processing_module_ids() const;
  ::google::protobuf::RepeatedPtrField< ::std::string>* mutable_processing_module_ids();

  // repeated .ubii.topicData.TopicDataRecord records = 2;
  int records_size() const;
  void clear_records();
  static const int kRecordsFieldNumber = 2;
  ::ubii::topicData::TopicDataRecord* mutable_records(int index);
  ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >*
      mutable_records();
  const ::ubii::topicData::TopicDataRecord& records(int index) const;
  ::ubii::topicData::TopicDataRecord* add_records();
  const ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >&
      records() const;

  // int32 delta_time_ms = 3;
  void clear_delta_time_ms();
  static const int kDeltaTimeMsFieldNumber = 3;
  ::google::protobuf::int32 delta_time_ms() const;
  void set_delta_time_ms(::google::protobuf::int32 value);

  // @@protoc_insertion_point(class_scope:ubii.processing.LockstepProcessingRequest)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::RepeatedPtrField< ::std::string> processing_module_ids_;
  ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord > records_;
  ::google::protobuf::int32 delta_time_ms_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2fprocessing_2flockstepProcessing_2eproto::TableStruct;
};
// -------------------------------------------------------------------

class LockstepProcessingReply : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.processing.LockstepProcessingReply) */ {
 public:
  LockstepProcessingReply();
  virtual ~LockstepProcessingReply();

  LockstepProcessingReply(const LockstepProcessingReply& from);

  inline LockstepProcessingReply& operator=(const LockstepProcessingReply& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  LockstepProcessingReply(LockstepProcessingReply&& from) noexcept
    : LockstepProcessingReply() {
    *this = ::std::move(from);
  }

  inline LockstepProcessingReply& operator=(LockstepProcessingReply&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const LockstepProcessingReply& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const LockstepProcessingReply* internal_default_instance() {
    return reinterpret_cast<const LockstepProcessingReply*>(
               &_LockstepProcessingReply_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  void Swap(LockstepProcessingReply* other);
  friend void swap(LockstepProcessingReply& a, LockstepProcessingReply& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline LockstepProcessingReply* New() const final {
    return CreateMaybeMessage<LockstepProcessingReply>(NULL);
  }

  LockstepProcessingReply* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<LockstepProcessingReply>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const LockstepProcessingReply& from);
  void MergeFrom(const LockstepProcessingReply& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(LockstepProcessingReply* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // repeated string processing_module_ids = 1;
  int processing_module_ids_size() const;
  void clear_processing_module_ids();
  static const int kProcessingModuleIdsFieldNumber = 1;
  const ::std::string& processing_module_ids(int index) const;
  ::std::string* mutable_processing_module_ids(int index);
  void set_processing_module_ids(int index, const ::std::string& value);
  #if LANG_CXX11
  void set_processing_module_ids(int index, ::std::string&& value);
  #endif
  void set_processing_module_ids(int index, const char* value);
  void set_processing_module_ids(int index, const char* value, size_t size);
  ::std::string* add_processing_module_ids();
  void add_processing_module_ids(const ::std::string& value);
  #if LANG_CXX11
  void add_processing_module_ids(::std::string&& value);
  #endif
  void add_processing_module_ids(const char* value);
  void add_processing_module_ids(const char* value, size_t size);
  const ::google::protobuf::RepeatedPtrField< ::std::string>& processing_module_ids() const;
  ::google::protobuf::RepeatedPtrField< ::std::string>* mutable_processing_module_ids();

  // repeated .ubii.topicData.TopicDataRecord records = 2;
  int records_size() const;
  void clear_records();
  static const int kRecordsFieldNumber = 2;
  ::ubii::topicData::TopicDataRecord* mutable_records(int index);
  ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >*
      mutable_records();
  const ::ubii::topicData::TopicDataRecord& records(int index) const;
  ::ubii::topicData::TopicDataRecord* add_records();
  const ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >&
      records() const;

  // @@protoc_insertion_point(class_scope:ubii.processing.LockstepProcessingReply)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::RepeatedPtrField< ::std::string> processing_module_ids_;
  ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord > records_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2fprocessing_2flockstepProcessing_2eproto::TableStruct;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// LockstepProcessingRequest

// repeated string processing_module_ids = 1;
inline int LockstepProcessingRequest::processing_module_ids_size() const {
  return processing_module_ids_.size();
}
inline void LockstepProcessingRequest::clear_processing_module_ids() {
  processing_module_ids_.Clear();
}
inline const ::std::string& LockstepProcessingRequest::processing_module_ids(int index) const {
  // @@protoc_insertion_point(field_get:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  return processing_module_ids_.Get(index);
}
inline ::std::string* LockstepProcessingRequest::mutable_processing_module_ids(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  return processing_module_ids_.Mutable(index);
}
inline void LockstepProcessingRequest::set_processing_module_ids(int index, const ::std::string& value) {
  // @@protoc_insertion_point(field_set:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  processing_module_ids_.Mutable(index)->assign(value);
}
#if LANG_CXX11
inline void LockstepProcessingRequest::set_processing_module_ids(int index, ::std::string&& value) {
  // @@protoc_insertion_point(field_set:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  processing_module_ids_.Mutable(index)->assign(std::move(value));
}
#endif
inline void LockstepProcessingRequest::set_processing_module_ids(int index, const char* value) {
  GOOGLE_DCHECK(value != NULL);
  processing_module_ids_.Mutable(index)->assign(value);
  // @@protoc_insertion_point(field_set_char:ubii.processing.LockstepProcessingRequest.processing_module_ids)
}
inline void LockstepProcessingRequest::set_processing_module_ids(int index, const char* value, size_t size) {
  processing_module_ids_.Mutable(index)->assign(
    reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_set_pointer:ubii.processing.LockstepProcessingRequest.processing_module_ids)
}
inline ::std::string* LockstepProcessingRequest::add_processing_module_ids() {
  // @@protoc_insertion_point(field_add_mutable:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  return processing_module_ids_.Add();
}
inline void LockstepProcessingRequest::add_processing_module_ids(const ::std::string& value) {
  processing_module_ids_.Add()->assign(value);
  // @@protoc_insertion_point(field_add:ubii.processing.LockstepProcessingRequest.processing_module_ids)
}
#if LANG_CXX11
inline void LockstepProcessingRequest::add_processing_module_ids(::std::string&& value) {
  processing_module_ids_.Add(std::move(value));
  // @@protoc_insertion_point(field_add:ubii.processing.LockstepProcessingRequest.processing_module_ids)
}
#endif
inline void LockstepProcessingRequest::add_processing_module_ids(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  processing_module_ids_.Add()->assign(value);
  // @@protoc_insertion_point(field_add_char:ubii.processing.LockstepProcessingRequest.processing_module_ids)
}
inline void LockstepProcessingRequest::add_processing_module_ids(const char* value, size_t size) {
  processing_module_ids_.Add()->assign(reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_add_pointer:ubii.processing.LockstepProcessingRequest.processing_module_ids)
}
inline const ::google::protobuf::RepeatedPtrField< ::std::string>&
LockstepProcessingRequest::processing_module_ids() const {
  // @@protoc_insertion_point(field_list:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  return processing_module_ids_;
}
inline ::google::protobuf::RepeatedPtrField< ::std::string>*
LockstepProcessingRequest::mutable_processing_module_ids() {
  // @@protoc_insertion_point(field_mutable_list:ubii.processing.LockstepProcessingRequest.processing_module_ids)
  return &processing_module_ids_;
}

// repeated .ubii.topicData.TopicDataRecord records = 2;
inline int LockstepProcessingRequest::records_size() const {
  return records_.size();
}
inline ::ubii::topicData::TopicDataRecord* LockstepProcessingRequest::mutable_records(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.processing.LockstepProcessingRequest.records)
  return records_.Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >*
LockstepProcessingRequest::mutable_records() {
  // @@protoc_insertion_point(field_mutable_list:ubii.processing.LockstepProcessingRequest.records)
  return &records_;
}
inline const ::ubii::topicData::TopicDataRecord& LockstepProcessingRequest::records(int index) const {
  // @@protoc_insertion_point(field_get:ubii.processing.LockstepProcessingRequest.records)
  return records_.Get(index);
}
inline ::ubii::topicData::TopicDataRecord* LockstepProcessingRequest::add_records() {
  // @@protoc_insertion_point(field_add:ubii.processing.LockstepProcessingRequest.records)
  return records_.Add();
}
inline const ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >&
LockstepProcessingRequest::records() const {
  // @@protoc_insertion_point(field_list:ubii.processing.LockstepProcessingRequest.records)
  return records_;
}

// int32 delta_time_ms = 3;
inline void LockstepProcessingRequest::clear_delta_time_ms() {
  delta_time_ms_ = 0;
}
inline ::google::protobuf::int32 LockstepProcessingRequest::delta_time_ms() const {
  // @@protoc_insertion_point(field_get:ubii.processing.LockstepProcessingRequest.delta_time_ms)
  return delta_time_ms_;
}
inline void LockstepProcessingRequest::set_delta_time_ms(::google::protobuf::int32 value) {
  
  delta_time_ms_ = value;
  // @@protoc_insertion_point(field_set:ubii.processing.LockstepProcessingRequest.delta_time_ms)
}

// -------------------------------------------------------------------

// LockstepProcessingReply

// repeated string processing_module_ids = 1;
inline int LockstepProcessingReply::processing_module_ids_size() const {
  return processing_module_ids_.size();
}
inline void LockstepProcessingReply::clear_processing_module_ids() {
  processing_module_ids_.Clear();
}
inline const ::std::string& LockstepProcessingReply::processing_module_ids(int index) const {
  // @@protoc_insertion_point(field_get:ubii.processing.LockstepProcessingReply.processing_module_ids)
  return processing_module_ids_.Get(index);
}
inline ::std::string* LockstepProcessingReply::mutable_processing_module_ids(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.processing.LockstepProcessingReply.processing_module_ids)
  return processing_module_ids_.Mutable(index);
}
inline void LockstepProcessingReply::set_processing_module_ids(int index, const ::std::string& value) {
  // @@protoc_insertion_point(field_set:ubii.processing.LockstepProcessingReply.processing_module_ids)
  processing_module_ids_.Mutable(index)->assign(value);
}
#if LANG_CXX11
inline void LockstepProcessingReply::set_processing_module_ids(int index, ::std::string&& value) {
  // @@protoc_insertion_point(field_set:ubii.processing.LockstepProcessingReply.processing_module_ids)
  processing_module_ids_.Mutable(index)->assign(std::move(value));
}
#endif
inline void LockstepProcessingReply::set_processing_module_ids(int index, const char* value) {
  GOOGLE_DCHECK(value != NULL);
  processing_module_ids_.Mutable(index)->assign(value);
  // @@protoc_insertion_point(field_set_char:ubii.processing.LockstepProcessingReply.processing_module_ids)
}
inline void LockstepProcessingReply::set_processing_module_ids(int index, const char* value, size_t size) {
  processing_module_ids_.Mutable(index)->assign(
    reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_set_pointer:ubii.processing.LockstepProcessingReply.processing_module_ids)
}
inline ::std::string* LockstepProcessingReply::add_processing_module_ids() {
  // @@protoc_insertion_point(field_add_mutable:ubii.processing.LockstepProcessingReply.processing_module_ids)
  return processing_module_ids_.Add();
}
inline void LockstepProcessingReply::add_processing_module_ids(const ::std::string& value) {
  processing_module_ids_.Add()->assign(value);
  // @@protoc_insertion_point(field_add:ubii.processing.LockstepProcessingReply.processing_module_ids)
}
#if LANG_CXX11
inline void LockstepProcessingReply::add_processing_module_ids(::std::string&& value) {
  processing_module_ids_.Add(std::move(value));
  // @@protoc_insertion_point(field_add:ubii.processing.LockstepProcessingReply.processing_module_ids)
}
#endif
inline void LockstepProcessingReply::add_processing_module_ids(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  processing_module_ids_.Add()->assign(value);
  // @@protoc_insertion_point(field_add_char:ubii.processing.LockstepProcessingReply.processing_module_ids)
}
inline void LockstepProcessingReply::add_processing_module_ids(const char* value, size_t size) {
  processing_module_ids_.Add()->assign(reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_add_pointer:ubii.processing.LockstepProcessingReply.processing_module_ids)
}
inline const ::google::protobuf::RepeatedPtrField< ::std::string>&
LockstepProcessingReply::processing_module_ids() const {
  // @@protoc_insertion_point(field_list:ubii.processing.LockstepProcessingReply.processing_module_ids)
  return processing_module_ids_;
}
inline ::google::protobuf::RepeatedPtrField< ::std::string>*
LockstepProcessingReply::mutable_processing_module_ids() {
  // @@protoc_insertion_point(field_mutable_list:ubii.processing.LockstepProcessingReply.processing_module_ids)
  return &processing_module_ids_;
}

// repeated .ubii.topicData.TopicDataRecord records = 2;
inline int LockstepProcessingReply::records_size() const {
  return records_.size();
}
inline ::ubii::topicData::TopicDataRecord* LockstepProcessingReply::mutable_records(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.processing.LockstepProcessingReply.records)
  return records_.Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >*
LockstepProcessingReply::mutable_records() {
  // @@protoc_insertion_point(field_mutable_list:ubii.processing.LockstepProcessingReply.records)
  return &records_;
}
inline const ::ubii::topicData::TopicDataRecord& LockstepProcessingReply::records(int index) const {
  // @@protoc_insertion_point(field_get:ubii.processing.LockstepProcessingReply.records)
  return records_.Get(index);
}
inline ::ubii::topicData::TopicDataRecord* LockstepProcessingReply::add_records() {
  // @@protoc_insertion_point(field_add:ubii.processing.LockstepProcessingReply.records)
  return records_.Add();
}
inline const ::google::protobuf::RepeatedPtrField< ::ubii::topicData::TopicDataRecord >&
LockstepProcessingReply::records() const {
  // @@protoc_insertion_point(field_list:ubii.processing.LockstepProcessingReply.records)
  return records_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


// @@protoc_insertion_point(namespace_scope)

}  // namespace processing
}  // namespace ubii

// @@protoc_insertion_point(global_scope)

#endif  // PROTOBUF_INCLUDED_proto_2fprocessing_2flockstepProcessing_2eproto
