"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.services.request.topicSubscription_pb_plus import (
    TopicSubscription,
)


__all__ = (
    "TopicSubscription",
)