syntax = "proto3";
package ubii.proto_v1.types.dataStructure;

import "ubii/proto_v1/types/dataStructure/vector3.proto";
import "ubii/proto_v1/types/dataStructure/quaternion.proto";

message Pose3D {
    ubii.proto_v1.types.dataStructure.Vector3 position = 1;
    oneof orientation {
        ubii.proto_v1.types.dataStructure.Quaternion quaternion = 2;
        ubii.proto_v1.types.dataStructure.Vector3 euler = 3;
    }
}