"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    BOOL,
    DOUBLE,
    FLOAT,
    INT32,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "StringList",
        "DoubleList",
        "FloatList",
        "BoolList",
        "Int32List",
    }
)


class StringList(Message):
    elements = RepeatedField(
        STRING,
        number=1,
    )



class DoubleList(Message):
    elements = RepeatedField(
        DOUBLE,
        number=1,
    )



class FloatList(Message):
    elements = RepeatedField(
        FLOAT,
        number=1,
    )



class BoolList(Message):
    elements = RepeatedField(
        BOOL,
        number=1,
    )



class Int32List(Message):
    elements = RepeatedField(
        INT32,
        number=1,
    )


