"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    FLOAT,
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Pose2D",
    }
)


class Pose2D(Message):
    position = Field(
        Vector2,
        number=1,
    )
    direction = Field(
        Vector2,
        number=2,
        oneof='orientation',
    )
    angle = Field(
        FLOAT,
        number=3,
        oneof='orientation',
    )


