"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Matrix3x2",
    }
)


class Matrix3x2(Message):
    m00 = Field(
        DOUBLE,
        number=1,
    )
    m01 = Field(
        DOUBLE,
        number=2,
    )
    m10 = Field(
        DOUBLE,
        number=3,
    )
    m11 = Field(
        DOUBLE,
        number=4,
    )
    m20 = Field(
        DOUBLE,
        number=5,
    )
    m21 = Field(
        DOUBLE,
        number=6,
    )


