// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/processing/lockstepProcessing.proto

package ubii.processing;

public final class LockstepProcessing {
  private LockstepProcessing() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface LockstepProcessingRequestOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.processing.LockstepProcessingRequest)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    java.util.List<java.lang.String>
        getProcessingModuleIdsList();
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    int getProcessingModuleIdsCount();
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    java.lang.String getProcessingModuleIds(int index);
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    com.google.protobuf.ByteString
        getProcessingModuleIdsBytes(int index);

    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> 
        getRecordsList();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getRecords(int index);
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    int getRecordsCount();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
        getRecordsOrBuilderList();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getRecordsOrBuilder(
        int index);

    /**
     * <code>int32 delta_time_ms = 3;</code>
     */
    int getDeltaTimeMs();
  }
  /**
   * Protobuf type {@code ubii.processing.LockstepProcessingRequest}
   */
  public  static final class LockstepProcessingRequest extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.processing.LockstepProcessingRequest)
      LockstepProcessingRequestOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use LockstepProcessingRequest.newBuilder() to construct.
    private LockstepProcessingRequest(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private LockstepProcessingRequest() {
      processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      records_ = java.util.Collections.emptyList();
      deltaTimeMs_ = 0;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private LockstepProcessingRequest(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                processingModuleIds_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000001;
              }
              processingModuleIds_.add(s);
              break;
            }
            case 18: {
              if (!((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
                records_ = new java.util.ArrayList<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord>();
                mutable_bitField0_ |= 0x00000002;
              }
              records_.add(
                  input.readMessage(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.parser(), extensionRegistry));
              break;
            }
            case 24: {

              deltaTimeMs_ = input.readInt32();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          processingModuleIds_ = processingModuleIds_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
          records_ = java.util.Collections.unmodifiableList(records_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingRequest_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingRequest_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.processing.LockstepProcessing.LockstepProcessingRequest.class, ubii.processing.LockstepProcessing.LockstepProcessingRequest.Builder.class);
    }

    private int bitField0_;
    public static final int PROCESSING_MODULE_IDS_FIELD_NUMBER = 1;
    private com.google.protobuf.LazyStringList processingModuleIds_;
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getProcessingModuleIdsList() {
      return processingModuleIds_;
    }
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public int getProcessingModuleIdsCount() {
      return processingModuleIds_.size();
    }
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public java.lang.String getProcessingModuleIds(int index) {
      return processingModuleIds_.get(index);
    }
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public com.google.protobuf.ByteString
        getProcessingModuleIdsBytes(int index) {
      return processingModuleIds_.getByteString(index);
    }

    public static final int RECORDS_FIELD_NUMBER = 2;
    private java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> records_;
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> getRecordsList() {
      return records_;
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
        getRecordsOrBuilderList() {
      return records_;
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public int getRecordsCount() {
      return records_.size();
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getRecords(int index) {
      return records_.get(index);
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getRecordsOrBuilder(
        int index) {
      return records_.get(index);
    }

    public static final int DELTA_TIME_MS_FIELD_NUMBER = 3;
    private int deltaTimeMs_;
    /**
     * <code>int32 delta_time_ms = 3;</code>
     */
    public int getDeltaTimeMs() {
      return deltaTimeMs_;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < processingModuleIds_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, processingModuleIds_.getRaw(i));
      }
      for (int i = 0; i < records_.size(); i++) {
        output.writeMessage(2, records_.get(i));
      }
      if (deltaTimeMs_ != 0) {
        output.writeInt32(3, deltaTimeMs_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      {
        int dataSize = 0;
        for (int i = 0; i < processingModuleIds_.size(); i++) {
          dataSize += computeStringSizeNoTag(processingModuleIds_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getProcessingModuleIdsList().size();
      }
      for (int i = 0; i < records_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, records_.get(i));
      }
      if (deltaTimeMs_ != 0) {
        size += com.google.protobuf.CodedOutputStream
          .computeInt32Size(3, deltaTimeMs_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.processing.LockstepProcessing.LockstepProcessingRequest)) {
        return super.equals(obj);
      }
      ubii.processing.LockstepProcessing.LockstepProcessingRequest other = (ubii.processing.LockstepProcessing.LockstepProcessingRequest) obj;

      boolean result = true;
      result = result && getProcessingModuleIdsList()
          .equals(other.getProcessingModuleIdsList());
      result = result && getRecordsList()
          .equals(other.getRecordsList());
      result = result && (getDeltaTimeMs()
          == other.getDeltaTimeMs());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getProcessingModuleIdsCount() > 0) {
        hash = (37 * hash) + PROCESSING_MODULE_IDS_FIELD_NUMBER;
        hash = (53 * hash) + getProcessingModuleIdsList().hashCode();
      }
      if (getRecordsCount() > 0) {
        hash = (37 * hash) + RECORDS_FIELD_NUMBER;
        hash = (53 * hash) + getRecordsList().hashCode();
      }
      hash = (37 * hash) + DELTA_TIME_MS_FIELD_NUMBER;
      hash = (53 * hash) + getDeltaTimeMs();
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.processing.LockstepProcessing.LockstepProcessingRequest prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.processing.LockstepProcessingRequest}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.processing.LockstepProcessingRequest)
        ubii.processing.LockstepProcessing.LockstepProcessingRequestOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingRequest_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingRequest_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.processing.LockstepProcessing.LockstepProcessingRequest.class, ubii.processing.LockstepProcessing.LockstepProcessingRequest.Builder.class);
      }

      // Construct using ubii.processing.LockstepProcessing.LockstepProcessingRequest.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getRecordsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000001);
        if (recordsBuilder_ == null) {
          records_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000002);
        } else {
          recordsBuilder_.clear();
        }
        deltaTimeMs_ = 0;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingRequest_descriptor;
      }

      @java.lang.Override
      public ubii.processing.LockstepProcessing.LockstepProcessingRequest getDefaultInstanceForType() {
        return ubii.processing.LockstepProcessing.LockstepProcessingRequest.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.processing.LockstepProcessing.LockstepProcessingRequest build() {
        ubii.processing.LockstepProcessing.LockstepProcessingRequest result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.processing.LockstepProcessing.LockstepProcessingRequest buildPartial() {
        ubii.processing.LockstepProcessing.LockstepProcessingRequest result = new ubii.processing.LockstepProcessing.LockstepProcessingRequest(this);
        int from_bitField0_ = bitField0_;
        int to_bitField0_ = 0;
        if (((bitField0_ & 0x00000001) == 0x00000001)) {
          processingModuleIds_ = processingModuleIds_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000001);
        }
        result.processingModuleIds_ = processingModuleIds_;
        if (recordsBuilder_ == null) {
          if (((bitField0_ & 0x00000002) == 0x00000002)) {
            records_ = java.util.Collections.unmodifiableList(records_);
            bitField0_ = (bitField0_ & ~0x00000002);
          }
          result.records_ = records_;
        } else {
          result.records_ = recordsBuilder_.build();
        }
        result.deltaTimeMs_ = deltaTimeMs_;
        result.bitField0_ = to_bitField0_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.processing.LockstepProcessing.LockstepProcessingRequest) {
          return mergeFrom((ubii.processing.LockstepProcessing.LockstepProcessingRequest)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.processing.LockstepProcessing.LockstepProcessingRequest other) {
        if (other == ubii.processing.LockstepProcessing.LockstepProcessingRequest.getDefaultInstance()) return this;
        if (!other.processingModuleIds_.isEmpty()) {
          if (processingModuleIds_.isEmpty()) {
            processingModuleIds_ = other.processingModuleIds_;
            bitField0_ = (bitField0_ & ~0x00000001);
          } else {
            ensureProcessingModuleIdsIsMutable();
            processingModuleIds_.addAll(other.processingModuleIds_);
          }
          onChanged();
        }
        if (recordsBuilder_ == null) {
          if (!other.records_.isEmpty()) {
            if (records_.isEmpty()) {
              records_ = other.records_;
              bitField0_ = (bitField0_ & ~0x00000002);
            } else {
              ensureRecordsIsMutable();
              records_.addAll(other.records_);
            }
            onChanged();
          }
        } else {
          if (!other.records_.isEmpty()) {
            if (recordsBuilder_.isEmpty()) {
              recordsBuilder_.dispose();
              recordsBuilder_ = null;
              records_ = other.records_;
              bitField0_ = (bitField0_ & ~0x00000002);
              recordsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getRecordsFieldBuilder() : null;
            } else {
              recordsBuilder_.addAllMessages(other.records_);
            }
          }
        }
        if (other.getDeltaTimeMs() != 0) {
          setDeltaTimeMs(other.getDeltaTimeMs());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.processing.LockstepProcessing.LockstepProcessingRequest parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.processing.LockstepProcessing.LockstepProcessingRequest) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private com.google.protobuf.LazyStringList processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureProcessingModuleIdsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          processingModuleIds_ = new com.google.protobuf.LazyStringArrayList(processingModuleIds_);
          bitField0_ |= 0x00000001;
         }
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getProcessingModuleIdsList() {
        return processingModuleIds_.getUnmodifiableView();
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public int getProcessingModuleIdsCount() {
        return processingModuleIds_.size();
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public java.lang.String getProcessingModuleIds(int index) {
        return processingModuleIds_.get(index);
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public com.google.protobuf.ByteString
          getProcessingModuleIdsBytes(int index) {
        return processingModuleIds_.getByteString(index);
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder setProcessingModuleIds(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureProcessingModuleIdsIsMutable();
        processingModuleIds_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder addProcessingModuleIds(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureProcessingModuleIdsIsMutable();
        processingModuleIds_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder addAllProcessingModuleIds(
          java.lang.Iterable<java.lang.String> values) {
        ensureProcessingModuleIdsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, processingModuleIds_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder clearProcessingModuleIds() {
        processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000001);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder addProcessingModuleIdsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureProcessingModuleIdsIsMutable();
        processingModuleIds_.add(value);
        onChanged();
        return this;
      }

      private java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> records_ =
        java.util.Collections.emptyList();
      private void ensureRecordsIsMutable() {
        if (!((bitField0_ & 0x00000002) == 0x00000002)) {
          records_ = new java.util.ArrayList<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord>(records_);
          bitField0_ |= 0x00000002;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> recordsBuilder_;

      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> getRecordsList() {
        if (recordsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(records_);
        } else {
          return recordsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public int getRecordsCount() {
        if (recordsBuilder_ == null) {
          return records_.size();
        } else {
          return recordsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getRecords(int index) {
        if (recordsBuilder_ == null) {
          return records_.get(index);
        } else {
          return recordsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder setRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (recordsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureRecordsIsMutable();
          records_.set(index, value);
          onChanged();
        } else {
          recordsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder setRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.set(index, builderForValue.build());
          onChanged();
        } else {
          recordsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (recordsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureRecordsIsMutable();
          records_.add(value);
          onChanged();
        } else {
          recordsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (recordsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureRecordsIsMutable();
          records_.add(index, value);
          onChanged();
        } else {
          recordsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.add(builderForValue.build());
          onChanged();
        } else {
          recordsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.add(index, builderForValue.build());
          onChanged();
        } else {
          recordsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addAllRecords(
          java.lang.Iterable<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> values) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, records_);
          onChanged();
        } else {
          recordsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder clearRecords() {
        if (recordsBuilder_ == null) {
          records_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000002);
          onChanged();
        } else {
          recordsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder removeRecords(int index) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.remove(index);
          onChanged();
        } else {
          recordsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder getRecordsBuilder(
          int index) {
        return getRecordsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getRecordsOrBuilder(
          int index) {
        if (recordsBuilder_ == null) {
          return records_.get(index);  } else {
          return recordsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
           getRecordsOrBuilderList() {
        if (recordsBuilder_ != null) {
          return recordsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(records_);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder addRecordsBuilder() {
        return getRecordsFieldBuilder().addBuilder(
            ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder addRecordsBuilder(
          int index) {
        return getRecordsFieldBuilder().addBuilder(
            index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder> 
           getRecordsBuilderList() {
        return getRecordsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
          getRecordsFieldBuilder() {
        if (recordsBuilder_ == null) {
          recordsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder>(
                  records_,
                  ((bitField0_ & 0x00000002) == 0x00000002),
                  getParentForChildren(),
                  isClean());
          records_ = null;
        }
        return recordsBuilder_;
      }

      private int deltaTimeMs_ ;
      /**
       * <code>int32 delta_time_ms = 3;</code>
       */
      public int getDeltaTimeMs() {
        return deltaTimeMs_;
      }
      /**
       * <code>int32 delta_time_ms = 3;</code>
       */
      public Builder setDeltaTimeMs(int value) {
        
        deltaTimeMs_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>int32 delta_time_ms = 3;</code>
       */
      public Builder clearDeltaTimeMs() {
        
        deltaTimeMs_ = 0;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.processing.LockstepProcessingRequest)
    }

    // @@protoc_insertion_point(class_scope:ubii.processing.LockstepProcessingRequest)
    private static final ubii.processing.LockstepProcessing.LockstepProcessingRequest DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.processing.LockstepProcessing.LockstepProcessingRequest();
    }

    public static ubii.processing.LockstepProcessing.LockstepProcessingRequest getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<LockstepProcessingRequest>
        PARSER = new com.google.protobuf.AbstractParser<LockstepProcessingRequest>() {
      @java.lang.Override
      public LockstepProcessingRequest parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new LockstepProcessingRequest(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<LockstepProcessingRequest> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<LockstepProcessingRequest> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.processing.LockstepProcessing.LockstepProcessingRequest getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface LockstepProcessingReplyOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.processing.LockstepProcessingReply)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    java.util.List<java.lang.String>
        getProcessingModuleIdsList();
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    int getProcessingModuleIdsCount();
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    java.lang.String getProcessingModuleIds(int index);
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    com.google.protobuf.ByteString
        getProcessingModuleIdsBytes(int index);

    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> 
        getRecordsList();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getRecords(int index);
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    int getRecordsCount();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
        getRecordsOrBuilderList();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getRecordsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.processing.LockstepProcessingReply}
   */
  public  static final class LockstepProcessingReply extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.processing.LockstepProcessingReply)
      LockstepProcessingReplyOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use LockstepProcessingReply.newBuilder() to construct.
    private LockstepProcessingReply(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private LockstepProcessingReply() {
      processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      records_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private LockstepProcessingReply(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                processingModuleIds_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000001;
              }
              processingModuleIds_.add(s);
              break;
            }
            case 18: {
              if (!((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
                records_ = new java.util.ArrayList<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord>();
                mutable_bitField0_ |= 0x00000002;
              }
              records_.add(
                  input.readMessage(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          processingModuleIds_ = processingModuleIds_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
          records_ = java.util.Collections.unmodifiableList(records_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingReply_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingReply_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.processing.LockstepProcessing.LockstepProcessingReply.class, ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder.class);
    }

    public static final int PROCESSING_MODULE_IDS_FIELD_NUMBER = 1;
    private com.google.protobuf.LazyStringList processingModuleIds_;
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getProcessingModuleIdsList() {
      return processingModuleIds_;
    }
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public int getProcessingModuleIdsCount() {
      return processingModuleIds_.size();
    }
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public java.lang.String getProcessingModuleIds(int index) {
      return processingModuleIds_.get(index);
    }
    /**
     * <code>repeated string processing_module_ids = 1;</code>
     */
    public com.google.protobuf.ByteString
        getProcessingModuleIdsBytes(int index) {
      return processingModuleIds_.getByteString(index);
    }

    public static final int RECORDS_FIELD_NUMBER = 2;
    private java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> records_;
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> getRecordsList() {
      return records_;
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
        getRecordsOrBuilderList() {
      return records_;
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public int getRecordsCount() {
      return records_.size();
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getRecords(int index) {
      return records_.get(index);
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getRecordsOrBuilder(
        int index) {
      return records_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < processingModuleIds_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, processingModuleIds_.getRaw(i));
      }
      for (int i = 0; i < records_.size(); i++) {
        output.writeMessage(2, records_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      {
        int dataSize = 0;
        for (int i = 0; i < processingModuleIds_.size(); i++) {
          dataSize += computeStringSizeNoTag(processingModuleIds_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getProcessingModuleIdsList().size();
      }
      for (int i = 0; i < records_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, records_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.processing.LockstepProcessing.LockstepProcessingReply)) {
        return super.equals(obj);
      }
      ubii.processing.LockstepProcessing.LockstepProcessingReply other = (ubii.processing.LockstepProcessing.LockstepProcessingReply) obj;

      boolean result = true;
      result = result && getProcessingModuleIdsList()
          .equals(other.getProcessingModuleIdsList());
      result = result && getRecordsList()
          .equals(other.getRecordsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getProcessingModuleIdsCount() > 0) {
        hash = (37 * hash) + PROCESSING_MODULE_IDS_FIELD_NUMBER;
        hash = (53 * hash) + getProcessingModuleIdsList().hashCode();
      }
      if (getRecordsCount() > 0) {
        hash = (37 * hash) + RECORDS_FIELD_NUMBER;
        hash = (53 * hash) + getRecordsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.processing.LockstepProcessing.LockstepProcessingReply parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.processing.LockstepProcessing.LockstepProcessingReply prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.processing.LockstepProcessingReply}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.processing.LockstepProcessingReply)
        ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingReply_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingReply_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.processing.LockstepProcessing.LockstepProcessingReply.class, ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder.class);
      }

      // Construct using ubii.processing.LockstepProcessing.LockstepProcessingReply.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getRecordsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000001);
        if (recordsBuilder_ == null) {
          records_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000002);
        } else {
          recordsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.processing.LockstepProcessing.internal_static_ubii_processing_LockstepProcessingReply_descriptor;
      }

      @java.lang.Override
      public ubii.processing.LockstepProcessing.LockstepProcessingReply getDefaultInstanceForType() {
        return ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.processing.LockstepProcessing.LockstepProcessingReply build() {
        ubii.processing.LockstepProcessing.LockstepProcessingReply result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.processing.LockstepProcessing.LockstepProcessingReply buildPartial() {
        ubii.processing.LockstepProcessing.LockstepProcessingReply result = new ubii.processing.LockstepProcessing.LockstepProcessingReply(this);
        int from_bitField0_ = bitField0_;
        if (((bitField0_ & 0x00000001) == 0x00000001)) {
          processingModuleIds_ = processingModuleIds_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000001);
        }
        result.processingModuleIds_ = processingModuleIds_;
        if (recordsBuilder_ == null) {
          if (((bitField0_ & 0x00000002) == 0x00000002)) {
            records_ = java.util.Collections.unmodifiableList(records_);
            bitField0_ = (bitField0_ & ~0x00000002);
          }
          result.records_ = records_;
        } else {
          result.records_ = recordsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.processing.LockstepProcessing.LockstepProcessingReply) {
          return mergeFrom((ubii.processing.LockstepProcessing.LockstepProcessingReply)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.processing.LockstepProcessing.LockstepProcessingReply other) {
        if (other == ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance()) return this;
        if (!other.processingModuleIds_.isEmpty()) {
          if (processingModuleIds_.isEmpty()) {
            processingModuleIds_ = other.processingModuleIds_;
            bitField0_ = (bitField0_ & ~0x00000001);
          } else {
            ensureProcessingModuleIdsIsMutable();
            processingModuleIds_.addAll(other.processingModuleIds_);
          }
          onChanged();
        }
        if (recordsBuilder_ == null) {
          if (!other.records_.isEmpty()) {
            if (records_.isEmpty()) {
              records_ = other.records_;
              bitField0_ = (bitField0_ & ~0x00000002);
            } else {
              ensureRecordsIsMutable();
              records_.addAll(other.records_);
            }
            onChanged();
          }
        } else {
          if (!other.records_.isEmpty()) {
            if (recordsBuilder_.isEmpty()) {
              recordsBuilder_.dispose();
              recordsBuilder_ = null;
              records_ = other.records_;
              bitField0_ = (bitField0_ & ~0x00000002);
              recordsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getRecordsFieldBuilder() : null;
            } else {
              recordsBuilder_.addAllMessages(other.records_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.processing.LockstepProcessing.LockstepProcessingReply parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.processing.LockstepProcessing.LockstepProcessingReply) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private com.google.protobuf.LazyStringList processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureProcessingModuleIdsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          processingModuleIds_ = new com.google.protobuf.LazyStringArrayList(processingModuleIds_);
          bitField0_ |= 0x00000001;
         }
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getProcessingModuleIdsList() {
        return processingModuleIds_.getUnmodifiableView();
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public int getProcessingModuleIdsCount() {
        return processingModuleIds_.size();
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public java.lang.String getProcessingModuleIds(int index) {
        return processingModuleIds_.get(index);
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public com.google.protobuf.ByteString
          getProcessingModuleIdsBytes(int index) {
        return processingModuleIds_.getByteString(index);
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder setProcessingModuleIds(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureProcessingModuleIdsIsMutable();
        processingModuleIds_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder addProcessingModuleIds(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureProcessingModuleIdsIsMutable();
        processingModuleIds_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder addAllProcessingModuleIds(
          java.lang.Iterable<java.lang.String> values) {
        ensureProcessingModuleIdsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, processingModuleIds_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder clearProcessingModuleIds() {
        processingModuleIds_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000001);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string processing_module_ids = 1;</code>
       */
      public Builder addProcessingModuleIdsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureProcessingModuleIdsIsMutable();
        processingModuleIds_.add(value);
        onChanged();
        return this;
      }

      private java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> records_ =
        java.util.Collections.emptyList();
      private void ensureRecordsIsMutable() {
        if (!((bitField0_ & 0x00000002) == 0x00000002)) {
          records_ = new java.util.ArrayList<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord>(records_);
          bitField0_ |= 0x00000002;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> recordsBuilder_;

      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> getRecordsList() {
        if (recordsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(records_);
        } else {
          return recordsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public int getRecordsCount() {
        if (recordsBuilder_ == null) {
          return records_.size();
        } else {
          return recordsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getRecords(int index) {
        if (recordsBuilder_ == null) {
          return records_.get(index);
        } else {
          return recordsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder setRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (recordsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureRecordsIsMutable();
          records_.set(index, value);
          onChanged();
        } else {
          recordsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder setRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.set(index, builderForValue.build());
          onChanged();
        } else {
          recordsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (recordsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureRecordsIsMutable();
          records_.add(value);
          onChanged();
        } else {
          recordsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (recordsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureRecordsIsMutable();
          records_.add(index, value);
          onChanged();
        } else {
          recordsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.add(builderForValue.build());
          onChanged();
        } else {
          recordsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addRecords(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.add(index, builderForValue.build());
          onChanged();
        } else {
          recordsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder addAllRecords(
          java.lang.Iterable<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> values) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, records_);
          onChanged();
        } else {
          recordsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder clearRecords() {
        if (recordsBuilder_ == null) {
          records_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000002);
          onChanged();
        } else {
          recordsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public Builder removeRecords(int index) {
        if (recordsBuilder_ == null) {
          ensureRecordsIsMutable();
          records_.remove(index);
          onChanged();
        } else {
          recordsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder getRecordsBuilder(
          int index) {
        return getRecordsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getRecordsOrBuilder(
          int index) {
        if (recordsBuilder_ == null) {
          return records_.get(index);  } else {
          return recordsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
           getRecordsOrBuilderList() {
        if (recordsBuilder_ != null) {
          return recordsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(records_);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder addRecordsBuilder() {
        return getRecordsFieldBuilder().addBuilder(
            ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder addRecordsBuilder(
          int index) {
        return getRecordsFieldBuilder().addBuilder(
            index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord records = 2;</code>
       */
      public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder> 
           getRecordsBuilderList() {
        return getRecordsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
          getRecordsFieldBuilder() {
        if (recordsBuilder_ == null) {
          recordsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder>(
                  records_,
                  ((bitField0_ & 0x00000002) == 0x00000002),
                  getParentForChildren(),
                  isClean());
          records_ = null;
        }
        return recordsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.processing.LockstepProcessingReply)
    }

    // @@protoc_insertion_point(class_scope:ubii.processing.LockstepProcessingReply)
    private static final ubii.processing.LockstepProcessing.LockstepProcessingReply DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.processing.LockstepProcessing.LockstepProcessingReply();
    }

    public static ubii.processing.LockstepProcessing.LockstepProcessingReply getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<LockstepProcessingReply>
        PARSER = new com.google.protobuf.AbstractParser<LockstepProcessingReply>() {
      @java.lang.Override
      public LockstepProcessingReply parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new LockstepProcessingReply(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<LockstepProcessingReply> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<LockstepProcessingReply> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.processing.LockstepProcessing.LockstepProcessingReply getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_processing_LockstepProcessingRequest_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_processing_LockstepProcessingRequest_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_processing_LockstepProcessingReply_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_processing_LockstepProcessingReply_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n)proto/processing/lockstepProcessing.pr" +
      "oto\022\017ubii.processing\0325proto/topicData/to" +
      "picDataRecord/topicDataRecord.proto\"\203\001\n\031" +
      "LockstepProcessingRequest\022\035\n\025processing_" +
      "module_ids\030\001 \003(\t\0220\n\007records\030\002 \003(\0132\037.ubii" +
      ".topicData.TopicDataRecord\022\025\n\rdelta_time" +
      "_ms\030\003 \001(\005\"j\n\027LockstepProcessingReply\022\035\n\025" +
      "processing_module_ids\030\001 \003(\t\0220\n\007records\030\002" +
      " \003(\0132\037.ubii.topicData.TopicDataRecordb\006p" +
      "roto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.topicData.TopicDataRecordOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_processing_LockstepProcessingRequest_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_processing_LockstepProcessingRequest_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_processing_LockstepProcessingRequest_descriptor,
        new java.lang.String[] { "ProcessingModuleIds", "Records", "DeltaTimeMs", });
    internal_static_ubii_processing_LockstepProcessingReply_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_processing_LockstepProcessingReply_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_processing_LockstepProcessingReply_descriptor,
        new java.lang.String[] { "ProcessingModuleIds", "Records", });
    ubii.topicData.TopicDataRecordOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
