/**
 * @fileoverview
 * @enhanceable
 * @suppress {messageConventions} JS Compiler reports an error if a variable or
 *     field starts with 'MSG_' and isn't a translatable message.
 * @public
 */
// GENERATED CODE -- DO NOT EDIT!

var jspb = require('google-protobuf');
var goog = jspb;
var global = Function('return this')();

goog.exportSymbol('proto.ubii.dataStructure.ButtonEventType', null, global);
/**
 * @enum {number}
 */
proto.ubii.dataStructure.ButtonEventType = {
  UP: 0,
  DOWN: 1
};

goog.object.extend(exports, proto.ubii.dataStructure);
