// <auto-generated>
//     Generated by the protocol buffer compiler.  DO NOT EDIT!
//     source: proto/topicData/topicDataRecord/dataStructure/myoEvent.proto
// </auto-generated>
#pragma warning disable 1591, 0612, 3021
#region Designer generated code

using pb = global::Google.Protobuf;
using pbc = global::Google.Protobuf.Collections;
using pbr = global::Google.Protobuf.Reflection;
using scg = global::System.Collections.Generic;
namespace Ubii.DataStructure {

  /// <summary>Holder for reflection information generated from proto/topicData/topicDataRecord/dataStructure/myoEvent.proto</summary>
  public static partial class MyoEventReflection {

    #region Descriptor
    /// <summary>File descriptor for proto/topicData/topicDataRecord/dataStructure/myoEvent.proto</summary>
    public static pbr::FileDescriptor Descriptor {
      get { return descriptor; }
    }
    private static pbr::FileDescriptor descriptor;

    static MyoEventReflection() {
      byte[] descriptorData = global::System.Convert.FromBase64String(
          string.Concat(
            "Cjxwcm90by90b3BpY0RhdGEvdG9waWNEYXRhUmVjb3JkL2RhdGFTdHJ1Y3R1",
            "cmUvbXlvRXZlbnQucHJvdG8SEnViaWkuZGF0YVN0cnVjdHVyZRo7cHJvdG8v",
            "dG9waWNEYXRhL3RvcGljRGF0YVJlY29yZC9kYXRhU3RydWN0dXJlL3ZlY3Rv",
            "cjgucHJvdG8aO3Byb3RvL3RvcGljRGF0YS90b3BpY0RhdGFSZWNvcmQvZGF0",
            "YVN0cnVjdHVyZS92ZWN0b3IzLnByb3RvGj5wcm90by90b3BpY0RhdGEvdG9w",
            "aWNEYXRhUmVjb3JkL2RhdGFTdHJ1Y3R1cmUvcXVhdGVybmlvbi5wcm90bxpD",
            "cHJvdG8vdG9waWNEYXRhL3RvcGljRGF0YVJlY29yZC9kYXRhU3RydWN0dXJl",
            "L2hhbmRHZXN0dXJlVHlwZS5wcm90byKDAgoITXlvRXZlbnQSKAoDZW1nGAEg",
            "ASgLMhsudWJpaS5kYXRhU3RydWN0dXJlLlZlY3RvcjgSMwoLb3JpZW50YXRp",
            "b24YAiABKAsyHi51YmlpLmRhdGFTdHJ1Y3R1cmUuUXVhdGVybmlvbhIuCgln",
            "eXJvc2NvcGUYAyABKAsyGy51YmlpLmRhdGFTdHJ1Y3R1cmUuVmVjdG9yMxIy",
            "Cg1hY2NlbGVyb21ldGVyGAQgASgLMhsudWJpaS5kYXRhU3RydWN0dXJlLlZl",
            "Y3RvcjMSNAoHZ2VzdHVyZRgFIAEoDjIjLnViaWkuZGF0YVN0cnVjdHVyZS5I",
            "YW5kR2VzdHVyZVR5cGViBnByb3RvMw=="));
      descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
          new pbr::FileDescriptor[] { global::Ubii.DataStructure.Vector8Reflection.Descriptor, global::Ubii.DataStructure.Vector3Reflection.Descriptor, global::Ubii.DataStructure.QuaternionReflection.Descriptor, global::Ubii.DataStructure.HandGestureTypeReflection.Descriptor, },
          new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
            new pbr::GeneratedClrTypeInfo(typeof(global::Ubii.DataStructure.MyoEvent), global::Ubii.DataStructure.MyoEvent.Parser, new[]{ "Emg", "Orientation", "Gyroscope", "Accelerometer", "Gesture" }, null, null, null)
          }));
    }
    #endregion

  }
  #region Messages
  public sealed partial class MyoEvent : pb::IMessage<MyoEvent> {
    private static readonly pb::MessageParser<MyoEvent> _parser = new pb::MessageParser<MyoEvent>(() => new MyoEvent());
    private pb::UnknownFieldSet _unknownFields;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public static pb::MessageParser<MyoEvent> Parser { get { return _parser; } }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public static pbr::MessageDescriptor Descriptor {
      get { return global::Ubii.DataStructure.MyoEventReflection.Descriptor.MessageTypes[0]; }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    pbr::MessageDescriptor pb::IMessage.Descriptor {
      get { return Descriptor; }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public MyoEvent() {
      OnConstruction();
    }

    partial void OnConstruction();

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public MyoEvent(MyoEvent other) : this() {
      emg_ = other.emg_ != null ? other.emg_.Clone() : null;
      orientation_ = other.orientation_ != null ? other.orientation_.Clone() : null;
      gyroscope_ = other.gyroscope_ != null ? other.gyroscope_.Clone() : null;
      accelerometer_ = other.accelerometer_ != null ? other.accelerometer_.Clone() : null;
      gesture_ = other.gesture_;
      _unknownFields = pb::UnknownFieldSet.Clone(other._unknownFields);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public MyoEvent Clone() {
      return new MyoEvent(this);
    }

    /// <summary>Field number for the "emg" field.</summary>
    public const int EmgFieldNumber = 1;
    private global::Ubii.DataStructure.Vector8 emg_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public global::Ubii.DataStructure.Vector8 Emg {
      get { return emg_; }
      set {
        emg_ = value;
      }
    }

    /// <summary>Field number for the "orientation" field.</summary>
    public const int OrientationFieldNumber = 2;
    private global::Ubii.DataStructure.Quaternion orientation_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public global::Ubii.DataStructure.Quaternion Orientation {
      get { return orientation_; }
      set {
        orientation_ = value;
      }
    }

    /// <summary>Field number for the "gyroscope" field.</summary>
    public const int GyroscopeFieldNumber = 3;
    private global::Ubii.DataStructure.Vector3 gyroscope_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public global::Ubii.DataStructure.Vector3 Gyroscope {
      get { return gyroscope_; }
      set {
        gyroscope_ = value;
      }
    }

    /// <summary>Field number for the "accelerometer" field.</summary>
    public const int AccelerometerFieldNumber = 4;
    private global::Ubii.DataStructure.Vector3 accelerometer_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public global::Ubii.DataStructure.Vector3 Accelerometer {
      get { return accelerometer_; }
      set {
        accelerometer_ = value;
      }
    }

    /// <summary>Field number for the "gesture" field.</summary>
    public const int GestureFieldNumber = 5;
    private global::Ubii.DataStructure.HandGestureType gesture_ = 0;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public global::Ubii.DataStructure.HandGestureType Gesture {
      get { return gesture_; }
      set {
        gesture_ = value;
      }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public override bool Equals(object other) {
      return Equals(other as MyoEvent);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public bool Equals(MyoEvent other) {
      if (ReferenceEquals(other, null)) {
        return false;
      }
      if (ReferenceEquals(other, this)) {
        return true;
      }
      if (!object.Equals(Emg, other.Emg)) return false;
      if (!object.Equals(Orientation, other.Orientation)) return false;
      if (!object.Equals(Gyroscope, other.Gyroscope)) return false;
      if (!object.Equals(Accelerometer, other.Accelerometer)) return false;
      if (Gesture != other.Gesture) return false;
      return Equals(_unknownFields, other._unknownFields);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public override int GetHashCode() {
      int hash = 1;
      if (emg_ != null) hash ^= Emg.GetHashCode();
      if (orientation_ != null) hash ^= Orientation.GetHashCode();
      if (gyroscope_ != null) hash ^= Gyroscope.GetHashCode();
      if (accelerometer_ != null) hash ^= Accelerometer.GetHashCode();
      if (Gesture != 0) hash ^= Gesture.GetHashCode();
      if (_unknownFields != null) {
        hash ^= _unknownFields.GetHashCode();
      }
      return hash;
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public override string ToString() {
      return pb::JsonFormatter.ToDiagnosticString(this);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public void WriteTo(pb::CodedOutputStream output) {
      if (emg_ != null) {
        output.WriteRawTag(10);
        output.WriteMessage(Emg);
      }
      if (orientation_ != null) {
        output.WriteRawTag(18);
        output.WriteMessage(Orientation);
      }
      if (gyroscope_ != null) {
        output.WriteRawTag(26);
        output.WriteMessage(Gyroscope);
      }
      if (accelerometer_ != null) {
        output.WriteRawTag(34);
        output.WriteMessage(Accelerometer);
      }
      if (Gesture != 0) {
        output.WriteRawTag(40);
        output.WriteEnum((int) Gesture);
      }
      if (_unknownFields != null) {
        _unknownFields.WriteTo(output);
      }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public int CalculateSize() {
      int size = 0;
      if (emg_ != null) {
        size += 1 + pb::CodedOutputStream.ComputeMessageSize(Emg);
      }
      if (orientation_ != null) {
        size += 1 + pb::CodedOutputStream.ComputeMessageSize(Orientation);
      }
      if (gyroscope_ != null) {
        size += 1 + pb::CodedOutputStream.ComputeMessageSize(Gyroscope);
      }
      if (accelerometer_ != null) {
        size += 1 + pb::CodedOutputStream.ComputeMessageSize(Accelerometer);
      }
      if (Gesture != 0) {
        size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) Gesture);
      }
      if (_unknownFields != null) {
        size += _unknownFields.CalculateSize();
      }
      return size;
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public void MergeFrom(MyoEvent other) {
      if (other == null) {
        return;
      }
      if (other.emg_ != null) {
        if (emg_ == null) {
          emg_ = new global::Ubii.DataStructure.Vector8();
        }
        Emg.MergeFrom(other.Emg);
      }
      if (other.orientation_ != null) {
        if (orientation_ == null) {
          orientation_ = new global::Ubii.DataStructure.Quaternion();
        }
        Orientation.MergeFrom(other.Orientation);
      }
      if (other.gyroscope_ != null) {
        if (gyroscope_ == null) {
          gyroscope_ = new global::Ubii.DataStructure.Vector3();
        }
        Gyroscope.MergeFrom(other.Gyroscope);
      }
      if (other.accelerometer_ != null) {
        if (accelerometer_ == null) {
          accelerometer_ = new global::Ubii.DataStructure.Vector3();
        }
        Accelerometer.MergeFrom(other.Accelerometer);
      }
      if (other.Gesture != 0) {
        Gesture = other.Gesture;
      }
      _unknownFields = pb::UnknownFieldSet.MergeFrom(_unknownFields, other._unknownFields);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public void MergeFrom(pb::CodedInputStream input) {
      uint tag;
      while ((tag = input.ReadTag()) != 0) {
        switch(tag) {
          default:
            _unknownFields = pb::UnknownFieldSet.MergeFieldFrom(_unknownFields, input);
            break;
          case 10: {
            if (emg_ == null) {
              emg_ = new global::Ubii.DataStructure.Vector8();
            }
            input.ReadMessage(emg_);
            break;
          }
          case 18: {
            if (orientation_ == null) {
              orientation_ = new global::Ubii.DataStructure.Quaternion();
            }
            input.ReadMessage(orientation_);
            break;
          }
          case 26: {
            if (gyroscope_ == null) {
              gyroscope_ = new global::Ubii.DataStructure.Vector3();
            }
            input.ReadMessage(gyroscope_);
            break;
          }
          case 34: {
            if (accelerometer_ == null) {
              accelerometer_ = new global::Ubii.DataStructure.Vector3();
            }
            input.ReadMessage(accelerometer_);
            break;
          }
          case 40: {
            gesture_ = (global::Ubii.DataStructure.HandGestureType) input.ReadEnum();
            break;
          }
        }
      }
    }

  }

  #endregion

}

#endregion Designer generated code
