// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/vector8.proto

#ifndef PROTOBUF_INCLUDED_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto
#define PROTOBUF_INCLUDED_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto

#include <string>

#include <google/protobuf/stubs/common.h>

#if GOOGLE_PROTOBUF_VERSION < 3006001
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please update
#error your headers.
#endif
#if 3006001 < GOOGLE_PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
// @@protoc_insertion_point(includes)
#define PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto 

namespace protobuf_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto {
// Internal implementation detail -- do not use these members.
struct TableStruct {
  static const ::google::protobuf::internal::ParseTableField entries[];
  static const ::google::protobuf::internal::AuxillaryParseTableField aux[];
  static const ::google::protobuf::internal::ParseTable schema[2];
  static const ::google::protobuf::internal::FieldMetadata field_metadata[];
  static const ::google::protobuf::internal::SerializationTable serialization_table[];
  static const ::google::protobuf::uint32 offsets[];
};
void AddDescriptors();
}  // namespace protobuf_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto
namespace ubii {
namespace dataStructure {
class Vector8;
class Vector8DefaultTypeInternal;
extern Vector8DefaultTypeInternal _Vector8_default_instance_;
class Vector8List;
class Vector8ListDefaultTypeInternal;
extern Vector8ListDefaultTypeInternal _Vector8List_default_instance_;
}  // namespace dataStructure
}  // namespace ubii
namespace google {
namespace protobuf {
template<> ::ubii::dataStructure::Vector8* Arena::CreateMaybeMessage<::ubii::dataStructure::Vector8>(Arena*);
template<> ::ubii::dataStructure::Vector8List* Arena::CreateMaybeMessage<::ubii::dataStructure::Vector8List>(Arena*);
}  // namespace protobuf
}  // namespace google
namespace ubii {
namespace dataStructure {

// ===================================================================

class Vector8 : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.dataStructure.Vector8) */ {
 public:
  Vector8();
  virtual ~Vector8();

  Vector8(const Vector8& from);

  inline Vector8& operator=(const Vector8& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  Vector8(Vector8&& from) noexcept
    : Vector8() {
    *this = ::std::move(from);
  }

  inline Vector8& operator=(Vector8&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const Vector8& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Vector8* internal_default_instance() {
    return reinterpret_cast<const Vector8*>(
               &_Vector8_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  void Swap(Vector8* other);
  friend void swap(Vector8& a, Vector8& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline Vector8* New() const final {
    return CreateMaybeMessage<Vector8>(NULL);
  }

  Vector8* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<Vector8>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const Vector8& from);
  void MergeFrom(const Vector8& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Vector8* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // double v0 = 1;
  void clear_v0();
  static const int kV0FieldNumber = 1;
  double v0() const;
  void set_v0(double value);

  // double v1 = 2;
  void clear_v1();
  static const int kV1FieldNumber = 2;
  double v1() const;
  void set_v1(double value);

  // double v2 = 3;
  void clear_v2();
  static const int kV2FieldNumber = 3;
  double v2() const;
  void set_v2(double value);

  // double v3 = 4;
  void clear_v3();
  static const int kV3FieldNumber = 4;
  double v3() const;
  void set_v3(double value);

  // double v4 = 5;
  void clear_v4();
  static const int kV4FieldNumber = 5;
  double v4() const;
  void set_v4(double value);

  // double v5 = 6;
  void clear_v5();
  static const int kV5FieldNumber = 6;
  double v5() const;
  void set_v5(double value);

  // double v6 = 7;
  void clear_v6();
  static const int kV6FieldNumber = 7;
  double v6() const;
  void set_v6(double value);

  // double v7 = 8;
  void clear_v7();
  static const int kV7FieldNumber = 8;
  double v7() const;
  void set_v7(double value);

  // @@protoc_insertion_point(class_scope:ubii.dataStructure.Vector8)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  double v0_;
  double v1_;
  double v2_;
  double v3_;
  double v4_;
  double v5_;
  double v6_;
  double v7_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto::TableStruct;
};
// -------------------------------------------------------------------

class Vector8List : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.dataStructure.Vector8List) */ {
 public:
  Vector8List();
  virtual ~Vector8List();

  Vector8List(const Vector8List& from);

  inline Vector8List& operator=(const Vector8List& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  Vector8List(Vector8List&& from) noexcept
    : Vector8List() {
    *this = ::std::move(from);
  }

  inline Vector8List& operator=(Vector8List&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const Vector8List& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Vector8List* internal_default_instance() {
    return reinterpret_cast<const Vector8List*>(
               &_Vector8List_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  void Swap(Vector8List* other);
  friend void swap(Vector8List& a, Vector8List& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline Vector8List* New() const final {
    return CreateMaybeMessage<Vector8List>(NULL);
  }

  Vector8List* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<Vector8List>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const Vector8List& from);
  void MergeFrom(const Vector8List& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Vector8List* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // repeated .ubii.dataStructure.Vector8 elements = 1;
  int elements_size() const;
  void clear_elements();
  static const int kElementsFieldNumber = 1;
  ::ubii::dataStructure::Vector8* mutable_elements(int index);
  ::google::protobuf::RepeatedPtrField< ::ubii::dataStructure::Vector8 >*
      mutable_elements();
  const ::ubii::dataStructure::Vector8& elements(int index) const;
  ::ubii::dataStructure::Vector8* add_elements();
  const ::google::protobuf::RepeatedPtrField< ::ubii::dataStructure::Vector8 >&
      elements() const;

  // @@protoc_insertion_point(class_scope:ubii.dataStructure.Vector8List)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::RepeatedPtrField< ::ubii::dataStructure::Vector8 > elements_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto::TableStruct;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Vector8

// double v0 = 1;
inline void Vector8::clear_v0() {
  v0_ = 0;
}
inline double Vector8::v0() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v0)
  return v0_;
}
inline void Vector8::set_v0(double value) {
  
  v0_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v0)
}

// double v1 = 2;
inline void Vector8::clear_v1() {
  v1_ = 0;
}
inline double Vector8::v1() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v1)
  return v1_;
}
inline void Vector8::set_v1(double value) {
  
  v1_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v1)
}

// double v2 = 3;
inline void Vector8::clear_v2() {
  v2_ = 0;
}
inline double Vector8::v2() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v2)
  return v2_;
}
inline void Vector8::set_v2(double value) {
  
  v2_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v2)
}

// double v3 = 4;
inline void Vector8::clear_v3() {
  v3_ = 0;
}
inline double Vector8::v3() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v3)
  return v3_;
}
inline void Vector8::set_v3(double value) {
  
  v3_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v3)
}

// double v4 = 5;
inline void Vector8::clear_v4() {
  v4_ = 0;
}
inline double Vector8::v4() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v4)
  return v4_;
}
inline void Vector8::set_v4(double value) {
  
  v4_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v4)
}

// double v5 = 6;
inline void Vector8::clear_v5() {
  v5_ = 0;
}
inline double Vector8::v5() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v5)
  return v5_;
}
inline void Vector8::set_v5(double value) {
  
  v5_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v5)
}

// double v6 = 7;
inline void Vector8::clear_v6() {
  v6_ = 0;
}
inline double Vector8::v6() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v6)
  return v6_;
}
inline void Vector8::set_v6(double value) {
  
  v6_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v6)
}

// double v7 = 8;
inline void Vector8::clear_v7() {
  v7_ = 0;
}
inline double Vector8::v7() const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8.v7)
  return v7_;
}
inline void Vector8::set_v7(double value) {
  
  v7_ = value;
  // @@protoc_insertion_point(field_set:ubii.dataStructure.Vector8.v7)
}

// -------------------------------------------------------------------

// Vector8List

// repeated .ubii.dataStructure.Vector8 elements = 1;
inline int Vector8List::elements_size() const {
  return elements_.size();
}
inline void Vector8List::clear_elements() {
  elements_.Clear();
}
inline ::ubii::dataStructure::Vector8* Vector8List::mutable_elements(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.dataStructure.Vector8List.elements)
  return elements_.Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField< ::ubii::dataStructure::Vector8 >*
Vector8List::mutable_elements() {
  // @@protoc_insertion_point(field_mutable_list:ubii.dataStructure.Vector8List.elements)
  return &elements_;
}
inline const ::ubii::dataStructure::Vector8& Vector8List::elements(int index) const {
  // @@protoc_insertion_point(field_get:ubii.dataStructure.Vector8List.elements)
  return elements_.Get(index);
}
inline ::ubii::dataStructure::Vector8* Vector8List::add_elements() {
  // @@protoc_insertion_point(field_add:ubii.dataStructure.Vector8List.elements)
  return elements_.Add();
}
inline const ::google::protobuf::RepeatedPtrField< ::ubii::dataStructure::Vector8 >&
Vector8List::elements() const {
  // @@protoc_insertion_point(field_list:ubii.dataStructure.Vector8List.elements)
  return elements_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


// @@protoc_insertion_point(namespace_scope)

}  // namespace dataStructure
}  // namespace ubii

// @@protoc_insertion_point(global_scope)

#endif  // PROTOBUF_INCLUDED_proto_2ftopicData_2ftopicDataRecord_2fdataStructure_2fvector8_2eproto
