"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.pose2d_pb_plus import (
    Pose2D,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Object2D",
        "Object2DList",
    }
)


class Object2D(Message):
    id = Field(
        STRING,
        number=1,
    )
    pose = Field(
        Pose2D,
        number=2,
    )
    size = Field(
        Vector2,
        number=3,
    )
    user_data_json = Field(
        STRING,
        number=4,
    )



class Object2DList(Message):
    elements = RepeatedField(
        Object2D,
        number=1,
    )


