"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicDemux",
        "TopicDemuxList",
    }
)


class TopicDemux(Message):
    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    data_type = Field(
        STRING,
        number=3,
    )
    output_topic_format = Field(
        STRING,
        number=4,
    )



class TopicDemuxList(Message):
    elements = RepeatedField(
        TopicDemux,
        number=1,
    )


