// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/general/success.proto

#ifndef PROTOBUF_INCLUDED_proto_2fgeneral_2fsuccess_2eproto
#define PROTOBUF_INCLUDED_proto_2fgeneral_2fsuccess_2eproto

#include <string>

#include <google/protobuf/stubs/common.h>

#if GOOGLE_PROTOBUF_VERSION < 3006001
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please update
#error your headers.
#endif
#if 3006001 < GOOGLE_PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
// @@protoc_insertion_point(includes)
#define PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fgeneral_2fsuccess_2eproto 

namespace protobuf_proto_2fgeneral_2fsuccess_2eproto {
// Internal implementation detail -- do not use these members.
struct TableStruct {
  static const ::google::protobuf::internal::ParseTableField entries[];
  static const ::google::protobuf::internal::AuxillaryParseTableField aux[];
  static const ::google::protobuf::internal::ParseTable schema[2];
  static const ::google::protobuf::internal::FieldMetadata field_metadata[];
  static const ::google::protobuf::internal::SerializationTable serialization_table[];
  static const ::google::protobuf::uint32 offsets[];
};
void AddDescriptors();
}  // namespace protobuf_proto_2fgeneral_2fsuccess_2eproto
namespace ubii {
namespace general {
class Success;
class SuccessDefaultTypeInternal;
extern SuccessDefaultTypeInternal _Success_default_instance_;
class SuccessList;
class SuccessListDefaultTypeInternal;
extern SuccessListDefaultTypeInternal _SuccessList_default_instance_;
}  // namespace general
}  // namespace ubii
namespace google {
namespace protobuf {
template<> ::ubii::general::Success* Arena::CreateMaybeMessage<::ubii::general::Success>(Arena*);
template<> ::ubii::general::SuccessList* Arena::CreateMaybeMessage<::ubii::general::SuccessList>(Arena*);
}  // namespace protobuf
}  // namespace google
namespace ubii {
namespace general {

// ===================================================================

class Success : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.general.Success) */ {
 public:
  Success();
  virtual ~Success();

  Success(const Success& from);

  inline Success& operator=(const Success& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  Success(Success&& from) noexcept
    : Success() {
    *this = ::std::move(from);
  }

  inline Success& operator=(Success&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const Success& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Success* internal_default_instance() {
    return reinterpret_cast<const Success*>(
               &_Success_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  void Swap(Success* other);
  friend void swap(Success& a, Success& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline Success* New() const final {
    return CreateMaybeMessage<Success>(NULL);
  }

  Success* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<Success>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const Success& from);
  void MergeFrom(const Success& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Success* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // string title = 1;
  void clear_title();
  static const int kTitleFieldNumber = 1;
  const ::std::string& title() const;
  void set_title(const ::std::string& value);
  #if LANG_CXX11
  void set_title(::std::string&& value);
  #endif
  void set_title(const char* value);
  void set_title(const char* value, size_t size);
  ::std::string* mutable_title();
  ::std::string* release_title();
  void set_allocated_title(::std::string* title);

  // string message = 2;
  void clear_message();
  static const int kMessageFieldNumber = 2;
  const ::std::string& message() const;
  void set_message(const ::std::string& value);
  #if LANG_CXX11
  void set_message(::std::string&& value);
  #endif
  void set_message(const char* value);
  void set_message(const char* value, size_t size);
  ::std::string* mutable_message();
  ::std::string* release_message();
  void set_allocated_message(::std::string* message);

  // @@protoc_insertion_point(class_scope:ubii.general.Success)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::internal::ArenaStringPtr title_;
  ::google::protobuf::internal::ArenaStringPtr message_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2fgeneral_2fsuccess_2eproto::TableStruct;
};
// -------------------------------------------------------------------

class SuccessList : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.general.SuccessList) */ {
 public:
  SuccessList();
  virtual ~SuccessList();

  SuccessList(const SuccessList& from);

  inline SuccessList& operator=(const SuccessList& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  SuccessList(SuccessList&& from) noexcept
    : SuccessList() {
    *this = ::std::move(from);
  }

  inline SuccessList& operator=(SuccessList&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const SuccessList& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const SuccessList* internal_default_instance() {
    return reinterpret_cast<const SuccessList*>(
               &_SuccessList_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  void Swap(SuccessList* other);
  friend void swap(SuccessList& a, SuccessList& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline SuccessList* New() const final {
    return CreateMaybeMessage<SuccessList>(NULL);
  }

  SuccessList* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<SuccessList>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const SuccessList& from);
  void MergeFrom(const SuccessList& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SuccessList* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // repeated .ubii.general.Success elements = 1;
  int elements_size() const;
  void clear_elements();
  static const int kElementsFieldNumber = 1;
  ::ubii::general::Success* mutable_elements(int index);
  ::google::protobuf::RepeatedPtrField< ::ubii::general::Success >*
      mutable_elements();
  const ::ubii::general::Success& elements(int index) const;
  ::ubii::general::Success* add_elements();
  const ::google::protobuf::RepeatedPtrField< ::ubii::general::Success >&
      elements() const;

  // @@protoc_insertion_point(class_scope:ubii.general.SuccessList)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::RepeatedPtrField< ::ubii::general::Success > elements_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2fgeneral_2fsuccess_2eproto::TableStruct;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Success

// string title = 1;
inline void Success::clear_title() {
  title_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline const ::std::string& Success::title() const {
  // @@protoc_insertion_point(field_get:ubii.general.Success.title)
  return title_.GetNoArena();
}
inline void Success::set_title(const ::std::string& value) {
  
  title_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), value);
  // @@protoc_insertion_point(field_set:ubii.general.Success.title)
}
#if LANG_CXX11
inline void Success::set_title(::std::string&& value) {
  
  title_.SetNoArena(
    &::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::move(value));
  // @@protoc_insertion_point(field_set_rvalue:ubii.general.Success.title)
}
#endif
inline void Success::set_title(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  
  title_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::string(value));
  // @@protoc_insertion_point(field_set_char:ubii.general.Success.title)
}
inline void Success::set_title(const char* value, size_t size) {
  
  title_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(),
      ::std::string(reinterpret_cast<const char*>(value), size));
  // @@protoc_insertion_point(field_set_pointer:ubii.general.Success.title)
}
inline ::std::string* Success::mutable_title() {
  
  // @@protoc_insertion_point(field_mutable:ubii.general.Success.title)
  return title_.MutableNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline ::std::string* Success::release_title() {
  // @@protoc_insertion_point(field_release:ubii.general.Success.title)
  
  return title_.ReleaseNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline void Success::set_allocated_title(::std::string* title) {
  if (title != NULL) {
    
  } else {
    
  }
  title_.SetAllocatedNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), title);
  // @@protoc_insertion_point(field_set_allocated:ubii.general.Success.title)
}

// string message = 2;
inline void Success::clear_message() {
  message_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline const ::std::string& Success::message() const {
  // @@protoc_insertion_point(field_get:ubii.general.Success.message)
  return message_.GetNoArena();
}
inline void Success::set_message(const ::std::string& value) {
  
  message_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), value);
  // @@protoc_insertion_point(field_set:ubii.general.Success.message)
}
#if LANG_CXX11
inline void Success::set_message(::std::string&& value) {
  
  message_.SetNoArena(
    &::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::move(value));
  // @@protoc_insertion_point(field_set_rvalue:ubii.general.Success.message)
}
#endif
inline void Success::set_message(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  
  message_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::string(value));
  // @@protoc_insertion_point(field_set_char:ubii.general.Success.message)
}
inline void Success::set_message(const char* value, size_t size) {
  
  message_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(),
      ::std::string(reinterpret_cast<const char*>(value), size));
  // @@protoc_insertion_point(field_set_pointer:ubii.general.Success.message)
}
inline ::std::string* Success::mutable_message() {
  
  // @@protoc_insertion_point(field_mutable:ubii.general.Success.message)
  return message_.MutableNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline ::std::string* Success::release_message() {
  // @@protoc_insertion_point(field_release:ubii.general.Success.message)
  
  return message_.ReleaseNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline void Success::set_allocated_message(::std::string* message) {
  if (message != NULL) {
    
  } else {
    
  }
  message_.SetAllocatedNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), message);
  // @@protoc_insertion_point(field_set_allocated:ubii.general.Success.message)
}

// -------------------------------------------------------------------

// SuccessList

// repeated .ubii.general.Success elements = 1;
inline int SuccessList::elements_size() const {
  return elements_.size();
}
inline void SuccessList::clear_elements() {
  elements_.Clear();
}
inline ::ubii::general::Success* SuccessList::mutable_elements(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.general.SuccessList.elements)
  return elements_.Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField< ::ubii::general::Success >*
SuccessList::mutable_elements() {
  // @@protoc_insertion_point(field_mutable_list:ubii.general.SuccessList.elements)
  return &elements_;
}
inline const ::ubii::general::Success& SuccessList::elements(int index) const {
  // @@protoc_insertion_point(field_get:ubii.general.SuccessList.elements)
  return elements_.Get(index);
}
inline ::ubii::general::Success* SuccessList::add_elements() {
  // @@protoc_insertion_point(field_add:ubii.general.SuccessList.elements)
  return elements_.Add();
}
inline const ::google::protobuf::RepeatedPtrField< ::ubii::general::Success >&
SuccessList::elements() const {
  // @@protoc_insertion_point(field_list:ubii.general.SuccessList.elements)
  return elements_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


// @@protoc_insertion_point(namespace_scope)

}  // namespace general
}  // namespace ubii

// @@protoc_insertion_point(global_scope)

#endif  // PROTOBUF_INCLUDED_proto_2fgeneral_2fsuccess_2eproto
