"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Matrix4x4",
    }
)


class Matrix4x4(Message):
    m00 = Field(
        DOUBLE,
        number=1,
    )
    m01 = Field(
        DOUBLE,
        number=2,
    )
    m02 = Field(
        DOUBLE,
        number=3,
    )
    m03 = Field(
        DOUBLE,
        number=4,
    )
    m10 = Field(
        DOUBLE,
        number=5,
    )
    m11 = Field(
        DOUBLE,
        number=6,
    )
    m12 = Field(
        DOUBLE,
        number=7,
    )
    m13 = Field(
        DOUBLE,
        number=8,
    )
    m20 = Field(
        DOUBLE,
        number=9,
    )
    m21 = Field(
        DOUBLE,
        number=10,
    )
    m22 = Field(
        DOUBLE,
        number=11,
    )
    m23 = Field(
        DOUBLE,
        number=12,
    )
    m30 = Field(
        DOUBLE,
        number=13,
    )
    m31 = Field(
        DOUBLE,
        number=14,
    )
    m32 = Field(
        DOUBLE,
        number=15,
    )
    m33 = Field(
        DOUBLE,
        number=16,
    )


