"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    BOOL,
    Enum,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ProcessingModule,
)

from ubii.proto_v1.types.sessions.ioMappings_pb_plus import (
    IOMapping,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Session",
        "SessionList",
        "SessionStatus",
    }
)


class SessionStatus(Enum):
    CREATED = 0
    RUNNING = 1
    PAUSED = 2
    STOPPED = 3


class Session(Message):
    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    processing_modules = RepeatedField(
        ProcessingModule,
        number=3,
    )
    io_mappings = RepeatedField(
        IOMapping,
        number=4,
    )
    tags = RepeatedField(
        STRING,
        number=5,
    )
    description = Field(
        STRING,
        number=6,
    )
    authors = RepeatedField(
        STRING,
        number=7,
    )
    status = Field(
        SessionStatus,
        number=8,
    )
    editable = Field(
        BOOL,
        number=9,
    )



class SessionList(Message):
    elements = RepeatedField(
        Session,
        number=1,
    )


