# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/processing/lockstepProcessing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.topicData import topicDataRecord_pb2 as ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/processing/lockstepProcessing.proto',
  package='ubii.proto_v2.types.processing',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7ubii/proto_v2/types/processing/lockstepProcessing.proto\x12\x1eubii.proto_v2.types.processing\x1a\x33ubii/proto_v2/types/topicData/topicDataRecord.proto\"\x92\x01\n\x19LockstepProcessingRequest\x12\x1d\n\x15processing_module_ids\x18\x01 \x03(\t\x12?\n\x07records\x18\x02 \x03(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecord\x12\x15\n\rdelta_time_ms\x18\x03 \x01(\x05\"y\n\x17LockstepProcessingReply\x12\x1d\n\x15processing_module_ids\x18\x01 \x03(\t\x12?\n\x07records\x18\x02 \x03(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecordb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2.DESCRIPTOR,])




_LOCKSTEPPROCESSINGREQUEST = _descriptor.Descriptor(
  name='LockstepProcessingRequest',
  full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_module_ids', full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest.processing_module_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_time_ms', full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest.delta_time_ms', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=291,
)


_LOCKSTEPPROCESSINGREPLY = _descriptor.Descriptor(
  name='LockstepProcessingReply',
  full_name='ubii.proto_v2.types.processing.LockstepProcessingReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_module_ids', full_name='ubii.proto_v2.types.processing.LockstepProcessingReply.processing_module_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='ubii.proto_v2.types.processing.LockstepProcessingReply.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=414,
)

_LOCKSTEPPROCESSINGREQUEST.fields_by_name['records'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORD
_LOCKSTEPPROCESSINGREPLY.fields_by_name['records'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORD
DESCRIPTOR.message_types_by_name['LockstepProcessingRequest'] = _LOCKSTEPPROCESSINGREQUEST
DESCRIPTOR.message_types_by_name['LockstepProcessingReply'] = _LOCKSTEPPROCESSINGREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LockstepProcessingRequest = _reflection.GeneratedProtocolMessageType('LockstepProcessingRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPPROCESSINGREQUEST,
  '__module__' : 'ubii.proto_v2.types.processing.lockstepProcessing_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.LockstepProcessingRequest)
  })
_sym_db.RegisterMessage(LockstepProcessingRequest)

LockstepProcessingReply = _reflection.GeneratedProtocolMessageType('LockstepProcessingReply', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPPROCESSINGREPLY,
  '__module__' : 'ubii.proto_v2.types.processing.lockstepProcessing_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.LockstepProcessingReply)
  })
_sym_db.RegisterMessage(LockstepProcessingReply)


# @@protoc_insertion_point(module_scope)
