"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.services.serviceReply_pb_plus import (
    ServiceReply,
)

from ubii.proto_v1.types.services.serviceRequest_pb_plus import (
    ServiceRequest,
)

from ubii.proto_v1.types.services.service_pb_plus import (
    Service,
    ServiceList,
)


__all__ = (
    "Service",
    "ServiceList",
    "ServiceReply",
    "ServiceRequest",
)