// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/devices/topicMux.proto

package ubii.devices;

public final class TopicMuxOuterClass {
  private TopicMuxOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface TopicMuxOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.devices.TopicMux)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string id = 1;</code>
     */
    java.lang.String getId();
    /**
     * <code>string id = 1;</code>
     */
    com.google.protobuf.ByteString
        getIdBytes();

    /**
     * <code>string name = 2;</code>
     */
    java.lang.String getName();
    /**
     * <code>string name = 2;</code>
     */
    com.google.protobuf.ByteString
        getNameBytes();

    /**
     * <code>string data_type = 3;</code>
     */
    java.lang.String getDataType();
    /**
     * <code>string data_type = 3;</code>
     */
    com.google.protobuf.ByteString
        getDataTypeBytes();

    /**
     * <code>string topic_selector = 4;</code>
     */
    java.lang.String getTopicSelector();
    /**
     * <code>string topic_selector = 4;</code>
     */
    com.google.protobuf.ByteString
        getTopicSelectorBytes();

    /**
     * <code>string identity_match_pattern = 5;</code>
     */
    java.lang.String getIdentityMatchPattern();
    /**
     * <code>string identity_match_pattern = 5;</code>
     */
    com.google.protobuf.ByteString
        getIdentityMatchPatternBytes();
  }
  /**
   * Protobuf type {@code ubii.devices.TopicMux}
   */
  public  static final class TopicMux extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.devices.TopicMux)
      TopicMuxOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicMux.newBuilder() to construct.
    private TopicMux(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicMux() {
      id_ = "";
      name_ = "";
      dataType_ = "";
      topicSelector_ = "";
      identityMatchPattern_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicMux(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              id_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();

              name_ = s;
              break;
            }
            case 26: {
              java.lang.String s = input.readStringRequireUtf8();

              dataType_ = s;
              break;
            }
            case 34: {
              java.lang.String s = input.readStringRequireUtf8();

              topicSelector_ = s;
              break;
            }
            case 42: {
              java.lang.String s = input.readStringRequireUtf8();

              identityMatchPattern_ = s;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMux_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMux_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.devices.TopicMuxOuterClass.TopicMux.class, ubii.devices.TopicMuxOuterClass.TopicMux.Builder.class);
    }

    public static final int ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object id_;
    /**
     * <code>string id = 1;</code>
     */
    public java.lang.String getId() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        id_ = s;
        return s;
      }
    }
    /**
     * <code>string id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getIdBytes() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        id_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int NAME_FIELD_NUMBER = 2;
    private volatile java.lang.Object name_;
    /**
     * <code>string name = 2;</code>
     */
    public java.lang.String getName() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        name_ = s;
        return s;
      }
    }
    /**
     * <code>string name = 2;</code>
     */
    public com.google.protobuf.ByteString
        getNameBytes() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        name_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int DATA_TYPE_FIELD_NUMBER = 3;
    private volatile java.lang.Object dataType_;
    /**
     * <code>string data_type = 3;</code>
     */
    public java.lang.String getDataType() {
      java.lang.Object ref = dataType_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        dataType_ = s;
        return s;
      }
    }
    /**
     * <code>string data_type = 3;</code>
     */
    public com.google.protobuf.ByteString
        getDataTypeBytes() {
      java.lang.Object ref = dataType_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        dataType_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int TOPIC_SELECTOR_FIELD_NUMBER = 4;
    private volatile java.lang.Object topicSelector_;
    /**
     * <code>string topic_selector = 4;</code>
     */
    public java.lang.String getTopicSelector() {
      java.lang.Object ref = topicSelector_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        topicSelector_ = s;
        return s;
      }
    }
    /**
     * <code>string topic_selector = 4;</code>
     */
    public com.google.protobuf.ByteString
        getTopicSelectorBytes() {
      java.lang.Object ref = topicSelector_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        topicSelector_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int IDENTITY_MATCH_PATTERN_FIELD_NUMBER = 5;
    private volatile java.lang.Object identityMatchPattern_;
    /**
     * <code>string identity_match_pattern = 5;</code>
     */
    public java.lang.String getIdentityMatchPattern() {
      java.lang.Object ref = identityMatchPattern_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        identityMatchPattern_ = s;
        return s;
      }
    }
    /**
     * <code>string identity_match_pattern = 5;</code>
     */
    public com.google.protobuf.ByteString
        getIdentityMatchPatternBytes() {
      java.lang.Object ref = identityMatchPattern_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        identityMatchPattern_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, name_);
      }
      if (!getDataTypeBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 3, dataType_);
      }
      if (!getTopicSelectorBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 4, topicSelector_);
      }
      if (!getIdentityMatchPatternBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 5, identityMatchPattern_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(2, name_);
      }
      if (!getDataTypeBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(3, dataType_);
      }
      if (!getTopicSelectorBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(4, topicSelector_);
      }
      if (!getIdentityMatchPatternBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(5, identityMatchPattern_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.devices.TopicMuxOuterClass.TopicMux)) {
        return super.equals(obj);
      }
      ubii.devices.TopicMuxOuterClass.TopicMux other = (ubii.devices.TopicMuxOuterClass.TopicMux) obj;

      boolean result = true;
      result = result && getId()
          .equals(other.getId());
      result = result && getName()
          .equals(other.getName());
      result = result && getDataType()
          .equals(other.getDataType());
      result = result && getTopicSelector()
          .equals(other.getTopicSelector());
      result = result && getIdentityMatchPattern()
          .equals(other.getIdentityMatchPattern());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + ID_FIELD_NUMBER;
      hash = (53 * hash) + getId().hashCode();
      hash = (37 * hash) + NAME_FIELD_NUMBER;
      hash = (53 * hash) + getName().hashCode();
      hash = (37 * hash) + DATA_TYPE_FIELD_NUMBER;
      hash = (53 * hash) + getDataType().hashCode();
      hash = (37 * hash) + TOPIC_SELECTOR_FIELD_NUMBER;
      hash = (53 * hash) + getTopicSelector().hashCode();
      hash = (37 * hash) + IDENTITY_MATCH_PATTERN_FIELD_NUMBER;
      hash = (53 * hash) + getIdentityMatchPattern().hashCode();
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMux parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.devices.TopicMuxOuterClass.TopicMux prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.devices.TopicMux}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.devices.TopicMux)
        ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMux_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMux_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.devices.TopicMuxOuterClass.TopicMux.class, ubii.devices.TopicMuxOuterClass.TopicMux.Builder.class);
      }

      // Construct using ubii.devices.TopicMuxOuterClass.TopicMux.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        id_ = "";

        name_ = "";

        dataType_ = "";

        topicSelector_ = "";

        identityMatchPattern_ = "";

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMux_descriptor;
      }

      @java.lang.Override
      public ubii.devices.TopicMuxOuterClass.TopicMux getDefaultInstanceForType() {
        return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.devices.TopicMuxOuterClass.TopicMux build() {
        ubii.devices.TopicMuxOuterClass.TopicMux result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.devices.TopicMuxOuterClass.TopicMux buildPartial() {
        ubii.devices.TopicMuxOuterClass.TopicMux result = new ubii.devices.TopicMuxOuterClass.TopicMux(this);
        result.id_ = id_;
        result.name_ = name_;
        result.dataType_ = dataType_;
        result.topicSelector_ = topicSelector_;
        result.identityMatchPattern_ = identityMatchPattern_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.devices.TopicMuxOuterClass.TopicMux) {
          return mergeFrom((ubii.devices.TopicMuxOuterClass.TopicMux)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.devices.TopicMuxOuterClass.TopicMux other) {
        if (other == ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance()) return this;
        if (!other.getId().isEmpty()) {
          id_ = other.id_;
          onChanged();
        }
        if (!other.getName().isEmpty()) {
          name_ = other.name_;
          onChanged();
        }
        if (!other.getDataType().isEmpty()) {
          dataType_ = other.dataType_;
          onChanged();
        }
        if (!other.getTopicSelector().isEmpty()) {
          topicSelector_ = other.topicSelector_;
          onChanged();
        }
        if (!other.getIdentityMatchPattern().isEmpty()) {
          identityMatchPattern_ = other.identityMatchPattern_;
          onChanged();
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.devices.TopicMuxOuterClass.TopicMux parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.devices.TopicMuxOuterClass.TopicMux) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private java.lang.Object id_ = "";
      /**
       * <code>string id = 1;</code>
       */
      public java.lang.String getId() {
        java.lang.Object ref = id_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          id_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getIdBytes() {
        java.lang.Object ref = id_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          id_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        id_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder clearId() {
        
        id_ = getDefaultInstance().getId();
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        id_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object name_ = "";
      /**
       * <code>string name = 2;</code>
       */
      public java.lang.String getName() {
        java.lang.Object ref = name_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          name_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public com.google.protobuf.ByteString
          getNameBytes() {
        java.lang.Object ref = name_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          name_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        name_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder clearName() {
        
        name_ = getDefaultInstance().getName();
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        name_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object dataType_ = "";
      /**
       * <code>string data_type = 3;</code>
       */
      public java.lang.String getDataType() {
        java.lang.Object ref = dataType_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          dataType_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string data_type = 3;</code>
       */
      public com.google.protobuf.ByteString
          getDataTypeBytes() {
        java.lang.Object ref = dataType_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          dataType_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string data_type = 3;</code>
       */
      public Builder setDataType(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        dataType_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string data_type = 3;</code>
       */
      public Builder clearDataType() {
        
        dataType_ = getDefaultInstance().getDataType();
        onChanged();
        return this;
      }
      /**
       * <code>string data_type = 3;</code>
       */
      public Builder setDataTypeBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        dataType_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object topicSelector_ = "";
      /**
       * <code>string topic_selector = 4;</code>
       */
      public java.lang.String getTopicSelector() {
        java.lang.Object ref = topicSelector_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          topicSelector_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string topic_selector = 4;</code>
       */
      public com.google.protobuf.ByteString
          getTopicSelectorBytes() {
        java.lang.Object ref = topicSelector_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          topicSelector_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string topic_selector = 4;</code>
       */
      public Builder setTopicSelector(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        topicSelector_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string topic_selector = 4;</code>
       */
      public Builder clearTopicSelector() {
        
        topicSelector_ = getDefaultInstance().getTopicSelector();
        onChanged();
        return this;
      }
      /**
       * <code>string topic_selector = 4;</code>
       */
      public Builder setTopicSelectorBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        topicSelector_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object identityMatchPattern_ = "";
      /**
       * <code>string identity_match_pattern = 5;</code>
       */
      public java.lang.String getIdentityMatchPattern() {
        java.lang.Object ref = identityMatchPattern_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          identityMatchPattern_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string identity_match_pattern = 5;</code>
       */
      public com.google.protobuf.ByteString
          getIdentityMatchPatternBytes() {
        java.lang.Object ref = identityMatchPattern_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          identityMatchPattern_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string identity_match_pattern = 5;</code>
       */
      public Builder setIdentityMatchPattern(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        identityMatchPattern_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string identity_match_pattern = 5;</code>
       */
      public Builder clearIdentityMatchPattern() {
        
        identityMatchPattern_ = getDefaultInstance().getIdentityMatchPattern();
        onChanged();
        return this;
      }
      /**
       * <code>string identity_match_pattern = 5;</code>
       */
      public Builder setIdentityMatchPatternBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        identityMatchPattern_ = value;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.devices.TopicMux)
    }

    // @@protoc_insertion_point(class_scope:ubii.devices.TopicMux)
    private static final ubii.devices.TopicMuxOuterClass.TopicMux DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.devices.TopicMuxOuterClass.TopicMux();
    }

    public static ubii.devices.TopicMuxOuterClass.TopicMux getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicMux>
        PARSER = new com.google.protobuf.AbstractParser<TopicMux>() {
      @java.lang.Override
      public TopicMux parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicMux(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicMux> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicMux> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.devices.TopicMuxOuterClass.TopicMux getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface TopicMuxListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.devices.TopicMuxList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    java.util.List<ubii.devices.TopicMuxOuterClass.TopicMux> 
        getElementsList();
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMux getElements(int index);
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    java.util.List<? extends ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.devices.TopicMuxList}
   */
  public  static final class TopicMuxList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.devices.TopicMuxList)
      TopicMuxListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicMuxList.newBuilder() to construct.
    private TopicMuxList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicMuxList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicMuxList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.devices.TopicMuxOuterClass.TopicMux>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.devices.TopicMuxOuterClass.TopicMux.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMuxList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMuxList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.devices.TopicMuxOuterClass.TopicMuxList.class, ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.devices.TopicMuxOuterClass.TopicMux> elements_;
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    public java.util.List<ubii.devices.TopicMuxOuterClass.TopicMux> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    public java.util.List<? extends ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMux getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.devices.TopicMuxOuterClass.TopicMuxList)) {
        return super.equals(obj);
      }
      ubii.devices.TopicMuxOuterClass.TopicMuxList other = (ubii.devices.TopicMuxOuterClass.TopicMuxList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.devices.TopicMuxOuterClass.TopicMuxList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.devices.TopicMuxOuterClass.TopicMuxList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.devices.TopicMuxList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.devices.TopicMuxList)
        ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMuxList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMuxList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.devices.TopicMuxOuterClass.TopicMuxList.class, ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder.class);
      }

      // Construct using ubii.devices.TopicMuxOuterClass.TopicMuxList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.devices.TopicMuxOuterClass.internal_static_ubii_devices_TopicMuxList_descriptor;
      }

      @java.lang.Override
      public ubii.devices.TopicMuxOuterClass.TopicMuxList getDefaultInstanceForType() {
        return ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.devices.TopicMuxOuterClass.TopicMuxList build() {
        ubii.devices.TopicMuxOuterClass.TopicMuxList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.devices.TopicMuxOuterClass.TopicMuxList buildPartial() {
        ubii.devices.TopicMuxOuterClass.TopicMuxList result = new ubii.devices.TopicMuxOuterClass.TopicMuxList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.devices.TopicMuxOuterClass.TopicMuxList) {
          return mergeFrom((ubii.devices.TopicMuxOuterClass.TopicMuxList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.devices.TopicMuxOuterClass.TopicMuxList other) {
        if (other == ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.devices.TopicMuxOuterClass.TopicMuxList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.devices.TopicMuxOuterClass.TopicMuxList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.devices.TopicMuxOuterClass.TopicMux> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.devices.TopicMuxOuterClass.TopicMux>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public java.util.List<ubii.devices.TopicMuxOuterClass.TopicMux> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.devices.TopicMuxOuterClass.TopicMux.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder addElements(ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder addElements(
          ubii.devices.TopicMuxOuterClass.TopicMux.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.devices.TopicMuxOuterClass.TopicMux.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.devices.TopicMuxOuterClass.TopicMux> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public java.util.List<? extends ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.devices.TopicMux elements = 1;</code>
       */
      public java.util.List<ubii.devices.TopicMuxOuterClass.TopicMux.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.devices.TopicMuxList)
    }

    // @@protoc_insertion_point(class_scope:ubii.devices.TopicMuxList)
    private static final ubii.devices.TopicMuxOuterClass.TopicMuxList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.devices.TopicMuxOuterClass.TopicMuxList();
    }

    public static ubii.devices.TopicMuxOuterClass.TopicMuxList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicMuxList>
        PARSER = new com.google.protobuf.AbstractParser<TopicMuxList>() {
      @java.lang.Override
      public TopicMuxList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicMuxList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicMuxList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicMuxList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.devices.TopicMuxOuterClass.TopicMuxList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_devices_TopicMux_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_devices_TopicMux_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_devices_TopicMuxList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_devices_TopicMuxList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n\034proto/devices/topicMux.proto\022\014ubii.dev" +
      "ices\"o\n\010TopicMux\022\n\n\002id\030\001 \001(\t\022\014\n\004name\030\002 \001" +
      "(\t\022\021\n\tdata_type\030\003 \001(\t\022\026\n\016topic_selector\030" +
      "\004 \001(\t\022\036\n\026identity_match_pattern\030\005 \001(\t\"8\n" +
      "\014TopicMuxList\022(\n\010elements\030\001 \003(\0132\026.ubii.d" +
      "evices.TopicMuxb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
        }, assigner);
    internal_static_ubii_devices_TopicMux_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_devices_TopicMux_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_devices_TopicMux_descriptor,
        new java.lang.String[] { "Id", "Name", "DataType", "TopicSelector", "IdentityMatchPattern", });
    internal_static_ubii_devices_TopicMuxList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_devices_TopicMuxList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_devices_TopicMuxList_descriptor,
        new java.lang.String[] { "Elements", });
  }

  // @@protoc_insertion_point(outer_class_scope)
}
