"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Constants",
    }
)


class Constants(Message):
    class DefaultTopics(Message):
        class Services(Message):
            SERVER_CONFIG = Field(
                STRING,
                number=1,
            )
            CLIENT_REGISTRATION = Field(
                STRING,
                number=2,
            )
            CLIENT_DEREGISTRATION = Field(
                STRING,
                number=3,
            )
            CLIENT_GET_LIST = Field(
                STRING,
                number=4,
            )
            DEVICE_REGISTRATION = Field(
                STRING,
                number=5,
            )
            DEVICE_DEREGISTRATION = Field(
                STRING,
                number=6,
            )
            DEVICE_GET = Field(
                STRING,
                number=7,
            )
            DEVICE_GET_LIST = Field(
                STRING,
                number=8,
            )
            PM_DATABASE_SAVE = Field(
                STRING,
                number=9,
            )
            PM_DATABASE_DELETE = Field(
                STRING,
                number=10,
            )
            PM_DATABASE_GET = Field(
                STRING,
                number=11,
            )
            PM_DATABASE_GET_LIST = Field(
                STRING,
                number=12,
            )
            PM_DATABASE_ONLINE_GET_LIST = Field(
                STRING,
                number=13,
            )
            PM_DATABASE_LOCAL_GET_LIST = Field(
                STRING,
                number=14,
            )
            PM_RUNTIME_ADD = Field(
                STRING,
                number=15,
            )
            PM_RUNTIME_REMOVE = Field(
                STRING,
                number=16,
            )
            PM_RUNTIME_GET = Field(
                STRING,
                number=17,
            )
            PM_RUNTIME_GET_LIST = Field(
                STRING,
                number=18,
            )
            SESSION_DATABASE_SAVE = Field(
                STRING,
                number=19,
            )
            SESSION_DATABASE_DELETE = Field(
                STRING,
                number=20,
            )
            SESSION_DATABASE_GET = Field(
                STRING,
                number=21,
            )
            SESSION_DATABASE_GET_LIST = Field(
                STRING,
                number=22,
            )
            SESSION_DATABASE_ONLINE_GET_LIST = Field(
                STRING,
                number=23,
            )
            SESSION_DATABASE_LOCAL_GET_LIST = Field(
                STRING,
                number=24,
            )
            SESSION_RUNTIME_ADD = Field(
                STRING,
                number=25,
            )
            SESSION_RUNTIME_REMOVE = Field(
                STRING,
                number=26,
            )
            SESSION_RUNTIME_GET = Field(
                STRING,
                number=27,
            )
            SESSION_RUNTIME_GET_LIST = Field(
                STRING,
                number=28,
            )
            SESSION_RUNTIME_START = Field(
                STRING,
                number=29,
            )
            SESSION_RUNTIME_STOP = Field(
                STRING,
                number=30,
            )
            SESSION_RUNTIME_UPDATE = Field(
                STRING,
                number=31,
            )
            TOPIC_DEMUX_DATABASE_SAVE = Field(
                STRING,
                number=32,
            )
            TOPIC_DEMUX_DATABASE_DELETE = Field(
                STRING,
                number=33,
            )
            TOPIC_DEMUX_DATABASE_GET = Field(
                STRING,
                number=34,
            )
            TOPIC_DEMUX_DATABASE_GET_LIST = Field(
                STRING,
                number=35,
            )
            TOPIC_DEMUX_RUNTIME_GET = Field(
                STRING,
                number=36,
            )
            TOPIC_DEMUX_RUNTIME_GET_LIST = Field(
                STRING,
                number=37,
            )
            TOPIC_MUX_DATABASE_SAVE = Field(
                STRING,
                number=38,
            )
            TOPIC_MUX_DATABASE_DELETE = Field(
                STRING,
                number=39,
            )
            TOPIC_MUX_DATABASE_GET = Field(
                STRING,
                number=40,
            )
            TOPIC_MUX_DATABASE_GET_LIST = Field(
                STRING,
                number=41,
            )
            TOPIC_MUX_RUNTIME_GET = Field(
                STRING,
                number=42,
            )
            TOPIC_MUX_RUNTIME_GET_LIST = Field(
                STRING,
                number=43,
            )
            SERVICE_LIST = Field(
                STRING,
                number=44,
            )
            TOPIC_LIST = Field(
                STRING,
                number=45,
            )
            TOPIC_SUBSCRIPTION = Field(
                STRING,
                number=46,
            )
            LATENCY_CLIENTS_LIST = Field(
                STRING,
                number=47,
            )
        


        class InfoTopics(Message):
            REGEX_ALL_INFOS = Field(
                STRING,
                number=1,
            )
            REGEX_PM_INFOS = Field(
                STRING,
                number=2,
            )
            NEW_PM = Field(
                STRING,
                number=3,
            )
            START_PM = Field(
                STRING,
                number=4,
            )
            DELETE_PM = Field(
                STRING,
                number=5,
            )
            CHANGE_PM = Field(
                STRING,
                number=6,
            )
            PROCESSED_PM = Field(
                STRING,
                number=7,
            )
            REGEX_SESSION_INFOS = Field(
                STRING,
                number=8,
            )
            NEW_SESSION = Field(
                STRING,
                number=9,
            )
            DELETE_SESSION = Field(
                STRING,
                number=10,
            )
            CHANGE_SESSION = Field(
                STRING,
                number=11,
            )
            START_SESSION = Field(
                STRING,
                number=12,
            )
            STOP_SESSION = Field(
                STRING,
                number=13,
            )
            RUNNING_SESSION = Field(
                STRING,
                number=14,
            )
        


        SERVICES = Field(
            Services,
            number=1,
        )
        INFO_TOPICS = Field(
            InfoTopics,
            number=2,
        )
    


    class MsgTypes(Message):
        ERROR = Field(
            STRING,
            number=1,
        )
        SUCCESS = Field(
            STRING,
            number=2,
        )
        SERVER = Field(
            STRING,
            number=3,
        )
        CLIENT = Field(
            STRING,
            number=4,
        )
        CLIENT_LIST = Field(
            STRING,
            number=5,
        )
        DEVICE = Field(
            STRING,
            number=6,
        )
        DEVICE_LIST = Field(
            STRING,
            number=7,
        )
        COMPONENT = Field(
            STRING,
            number=8,
        )
        COMPONENT_LIST = Field(
            STRING,
            number=9,
        )
        TOPIC_MUX = Field(
            STRING,
            number=10,
        )
        TOPIC_MUX_LIST = Field(
            STRING,
            number=11,
        )
        TOPIC_DEMUX = Field(
            STRING,
            number=12,
        )
        TOPIC_DEMUX_LIST = Field(
            STRING,
            number=13,
        )
        SERVICE = Field(
            STRING,
            number=14,
        )
        SERVICE_LIST = Field(
            STRING,
            number=15,
        )
        SERVICE_REQUEST = Field(
            STRING,
            number=16,
        )
        SERVICE_REPLY = Field(
            STRING,
            number=17,
        )
        SERVICE_REUEST_TOPIC_SUBSCRIPTION = Field(
            STRING,
            number=18,
        )
        SESSION = Field(
            STRING,
            number=19,
        )
        SESSION_LIST = Field(
            STRING,
            number=20,
        )
        SESSION_IO_MAPPING = Field(
            STRING,
            number=21,
        )
        PM = Field(
            STRING,
            number=22,
        )
        PM_LIST = Field(
            STRING,
            number=24,
        )
        PM_MODULE_IO = Field(
            STRING,
            number=25,
        )
        PM_PROCESSING_MODE = Field(
            STRING,
            number=26,
        )
        TOPIC_DATA = Field(
            STRING,
            number=27,
        )
        TOPIC_DATA_RECORD = Field(
            STRING,
            number=28,
        )
        TOPIC_DATA_RECORD_LIST = Field(
            STRING,
            number=29,
        )
        TOPIC_DATA_TIMESTAMP = Field(
            STRING,
            number=30,
        )
        DATASTRUCTURE_BOOL = Field(
            STRING,
            number=31,
        )
        DATASTRUCTURE_BOOL_LIST = Field(
            STRING,
            number=32,
        )
        DATASTRUCTURE_INT32 = Field(
            STRING,
            number=33,
        )
        DATASTRUCTURE_INT32_LIST = Field(
            STRING,
            number=34,
        )
        DATASTRUCTURE_STRING = Field(
            STRING,
            number=35,
        )
        DATASTRUCTURE_STRING_LIST = Field(
            STRING,
            number=36,
        )
        DATASTRUCTURE_FLOAT = Field(
            STRING,
            number=37,
        )
        DATASTRUCTURE_FLOAT_LIST = Field(
            STRING,
            number=38,
        )
        DATASTRUCTURE_DOUBLE = Field(
            STRING,
            number=39,
        )
        DATASTRUCTURE_DOUBLE_LIST = Field(
            STRING,
            number=40,
        )
        DATASTRUCTURE_COLOR = Field(
            STRING,
            number=41,
        )
        DATASTRUCTURE_IMAGE = Field(
            STRING,
            number=42,
        )
        DATASTRUCTURE_IMAGE_LIST = Field(
            STRING,
            number=43,
        )
        DATASTRUCTURE_KEY_EVENT = Field(
            STRING,
            number=44,
        )
        DATASTRUCTURE_MATRIX_3X2 = Field(
            STRING,
            number=45,
        )
        DATASTRUCTURE_MATRIX_4X4 = Field(
            STRING,
            number=46,
        )
        DATASTRUCTURE_MOUSE_EVENT = Field(
            STRING,
            number=47,
        )
        DATASTRUCTURE_OBJECT2D = Field(
            STRING,
            number=48,
        )
        DATASTRUCTURE_OBJECT2D_LIST = Field(
            STRING,
            number=49,
        )
        DATASTRUCTURE_OBJECT3D = Field(
            STRING,
            number=50,
        )
        DATASTRUCTURE_OBJECT3D_LIST = Field(
            STRING,
            number=51,
        )
        DATASTRUCTURE_POSE2D = Field(
            STRING,
            number=52,
        )
        DATASTRUCTURE_POSE3D = Field(
            STRING,
            number=53,
        )
        DATASTRUCTURE_QUATERNION = Field(
            STRING,
            number=54,
        )
        DATASTRUCTURE_TOUCH_EVENT = Field(
            STRING,
            number=55,
        )
        DATASTRUCTURE_VECTOR2 = Field(
            STRING,
            number=56,
        )
        DATASTRUCTURE_VECTOR3 = Field(
            STRING,
            number=57,
        )
        DATASTRUCTURE_VECTOR4 = Field(
            STRING,
            number=58,
        )
        DATASTRUCTURE_VECTOR8 = Field(
            STRING,
            number=59,
        )
    


    DEFAULT_TOPICS = Field(
        DefaultTopics,
        number=1,
    )
    MSG_TYPES = Field(
        MsgTypes,
        number=2,
    )


