"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Server",
    }
)


class Server(Message):
    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    ip_ethernet = Field(
        STRING,
        number=3,
    )
    ip_wlan = Field(
        STRING,
        number=4,
    )
    port_service_zmq = Field(
        STRING,
        number=5,
    )
    port_service_rest = Field(
        STRING,
        number=6,
    )
    port_topic_data_zmq = Field(
        STRING,
        number=7,
    )
    port_topic_data_ws = Field(
        STRING,
        number=8,
    )
    constants_json = Field(
        STRING,
        number=9,
    )


