"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
    ErrorList,
)

from ubii.proto_v1.types.general.success_pb_plus import (
    Success,
    SuccessList,
)


__all__ = (
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
)