"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicSubscription",
    }
)


class TopicSubscription(Message):
    client_id = Field(
        STRING,
        number=1,
    )
    subscribe_topics = RepeatedField(
        STRING,
        number=2,
    )
    unsubscribe_topics = RepeatedField(
        STRING,
        number=3,
    )
    subscribe_topic_regexp = RepeatedField(
        STRING,
        number=4,
    )
    unsubscribe_topic_regexp = RepeatedField(
        STRING,
        number=5,
    )


