syntax = "proto3";
package ubii.proto_v1.types.general;

message Success {
    string title = 1;
    string message = 2;
}

message SuccessList {
    repeated ubii.proto_v1.types.general.Success elements = 1;
}