// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicData.proto

package ubii.topicData;

public final class TopicDataOuterClass {
  private TopicDataOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface TopicDataOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.topicData.TopicData)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
     */
    boolean hasTopicDataRecord();
    /**
     * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getTopicDataRecord();
    /**
     * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getTopicDataRecordOrBuilder();

    /**
     * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
     */
    boolean hasTopicDataRecordList();
    /**
     * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList getTopicDataRecordList();
    /**
     * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder getTopicDataRecordListOrBuilder();

    /**
     * <code>.ubii.general.Error error = 4;</code>
     */
    boolean hasError();
    /**
     * <code>.ubii.general.Error error = 4;</code>
     */
    ubii.general.ErrorOuterClass.Error getError();
    /**
     * <code>.ubii.general.Error error = 4;</code>
     */
    ubii.general.ErrorOuterClass.ErrorOrBuilder getErrorOrBuilder();

    public ubii.topicData.TopicDataOuterClass.TopicData.TypeCase getTypeCase();
  }
  /**
   * Protobuf type {@code ubii.topicData.TopicData}
   */
  public  static final class TopicData extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.topicData.TopicData)
      TopicDataOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicData.newBuilder() to construct.
    private TopicData(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicData() {
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicData(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 18: {
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder subBuilder = null;
              if (typeCase_ == 2) {
                subBuilder = ((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 2;
              break;
            }
            case 26: {
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder subBuilder = null;
              if (typeCase_ == 3) {
                subBuilder = ((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 3;
              break;
            }
            case 34: {
              ubii.general.ErrorOuterClass.Error.Builder subBuilder = null;
              if (typeCase_ == 4) {
                subBuilder = ((ubii.general.ErrorOuterClass.Error) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.general.ErrorOuterClass.Error.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.general.ErrorOuterClass.Error) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 4;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.topicData.TopicDataOuterClass.internal_static_ubii_topicData_TopicData_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.topicData.TopicDataOuterClass.internal_static_ubii_topicData_TopicData_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.topicData.TopicDataOuterClass.TopicData.class, ubii.topicData.TopicDataOuterClass.TopicData.Builder.class);
    }

    private int typeCase_ = 0;
    private java.lang.Object type_;
    public enum TypeCase
        implements com.google.protobuf.Internal.EnumLite {
      TOPIC_DATA_RECORD(2),
      TOPIC_DATA_RECORD_LIST(3),
      ERROR(4),
      TYPE_NOT_SET(0);
      private final int value;
      private TypeCase(int value) {
        this.value = value;
      }
      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static TypeCase valueOf(int value) {
        return forNumber(value);
      }

      public static TypeCase forNumber(int value) {
        switch (value) {
          case 2: return TOPIC_DATA_RECORD;
          case 3: return TOPIC_DATA_RECORD_LIST;
          case 4: return ERROR;
          case 0: return TYPE_NOT_SET;
          default: return null;
        }
      }
      public int getNumber() {
        return this.value;
      }
    };

    public TypeCase
    getTypeCase() {
      return TypeCase.forNumber(
          typeCase_);
    }

    public static final int TOPIC_DATA_RECORD_FIELD_NUMBER = 2;
    /**
     * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
     */
    public boolean hasTopicDataRecord() {
      return typeCase_ == 2;
    }
    /**
     * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getTopicDataRecord() {
      if (typeCase_ == 2) {
         return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_;
      }
      return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
    }
    /**
     * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getTopicDataRecordOrBuilder() {
      if (typeCase_ == 2) {
         return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_;
      }
      return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
    }

    public static final int TOPIC_DATA_RECORD_LIST_FIELD_NUMBER = 3;
    /**
     * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
     */
    public boolean hasTopicDataRecordList() {
      return typeCase_ == 3;
    }
    /**
     * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList getTopicDataRecordList() {
      if (typeCase_ == 3) {
         return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_;
      }
      return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
    }
    /**
     * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder getTopicDataRecordListOrBuilder() {
      if (typeCase_ == 3) {
         return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_;
      }
      return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
    }

    public static final int ERROR_FIELD_NUMBER = 4;
    /**
     * <code>.ubii.general.Error error = 4;</code>
     */
    public boolean hasError() {
      return typeCase_ == 4;
    }
    /**
     * <code>.ubii.general.Error error = 4;</code>
     */
    public ubii.general.ErrorOuterClass.Error getError() {
      if (typeCase_ == 4) {
         return (ubii.general.ErrorOuterClass.Error) type_;
      }
      return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
    }
    /**
     * <code>.ubii.general.Error error = 4;</code>
     */
    public ubii.general.ErrorOuterClass.ErrorOrBuilder getErrorOrBuilder() {
      if (typeCase_ == 4) {
         return (ubii.general.ErrorOuterClass.Error) type_;
      }
      return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (typeCase_ == 2) {
        output.writeMessage(2, (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_);
      }
      if (typeCase_ == 3) {
        output.writeMessage(3, (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_);
      }
      if (typeCase_ == 4) {
        output.writeMessage(4, (ubii.general.ErrorOuterClass.Error) type_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (typeCase_ == 2) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_);
      }
      if (typeCase_ == 3) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_);
      }
      if (typeCase_ == 4) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(4, (ubii.general.ErrorOuterClass.Error) type_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.topicData.TopicDataOuterClass.TopicData)) {
        return super.equals(obj);
      }
      ubii.topicData.TopicDataOuterClass.TopicData other = (ubii.topicData.TopicDataOuterClass.TopicData) obj;

      boolean result = true;
      result = result && getTypeCase().equals(
          other.getTypeCase());
      if (!result) return false;
      switch (typeCase_) {
        case 2:
          result = result && getTopicDataRecord()
              .equals(other.getTopicDataRecord());
          break;
        case 3:
          result = result && getTopicDataRecordList()
              .equals(other.getTopicDataRecordList());
          break;
        case 4:
          result = result && getError()
              .equals(other.getError());
          break;
        case 0:
        default:
      }
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      switch (typeCase_) {
        case 2:
          hash = (37 * hash) + TOPIC_DATA_RECORD_FIELD_NUMBER;
          hash = (53 * hash) + getTopicDataRecord().hashCode();
          break;
        case 3:
          hash = (37 * hash) + TOPIC_DATA_RECORD_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getTopicDataRecordList().hashCode();
          break;
        case 4:
          hash = (37 * hash) + ERROR_FIELD_NUMBER;
          hash = (53 * hash) + getError().hashCode();
          break;
        case 0:
        default:
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataOuterClass.TopicData parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.topicData.TopicDataOuterClass.TopicData prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.topicData.TopicData}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.topicData.TopicData)
        ubii.topicData.TopicDataOuterClass.TopicDataOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.topicData.TopicDataOuterClass.internal_static_ubii_topicData_TopicData_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.topicData.TopicDataOuterClass.internal_static_ubii_topicData_TopicData_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.topicData.TopicDataOuterClass.TopicData.class, ubii.topicData.TopicDataOuterClass.TopicData.Builder.class);
      }

      // Construct using ubii.topicData.TopicDataOuterClass.TopicData.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        typeCase_ = 0;
        type_ = null;
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.topicData.TopicDataOuterClass.internal_static_ubii_topicData_TopicData_descriptor;
      }

      @java.lang.Override
      public ubii.topicData.TopicDataOuterClass.TopicData getDefaultInstanceForType() {
        return ubii.topicData.TopicDataOuterClass.TopicData.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.topicData.TopicDataOuterClass.TopicData build() {
        ubii.topicData.TopicDataOuterClass.TopicData result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.topicData.TopicDataOuterClass.TopicData buildPartial() {
        ubii.topicData.TopicDataOuterClass.TopicData result = new ubii.topicData.TopicDataOuterClass.TopicData(this);
        if (typeCase_ == 2) {
          if (topicDataRecordBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = topicDataRecordBuilder_.build();
          }
        }
        if (typeCase_ == 3) {
          if (topicDataRecordListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = topicDataRecordListBuilder_.build();
          }
        }
        if (typeCase_ == 4) {
          if (errorBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = errorBuilder_.build();
          }
        }
        result.typeCase_ = typeCase_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.topicData.TopicDataOuterClass.TopicData) {
          return mergeFrom((ubii.topicData.TopicDataOuterClass.TopicData)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.topicData.TopicDataOuterClass.TopicData other) {
        if (other == ubii.topicData.TopicDataOuterClass.TopicData.getDefaultInstance()) return this;
        switch (other.getTypeCase()) {
          case TOPIC_DATA_RECORD: {
            mergeTopicDataRecord(other.getTopicDataRecord());
            break;
          }
          case TOPIC_DATA_RECORD_LIST: {
            mergeTopicDataRecordList(other.getTopicDataRecordList());
            break;
          }
          case ERROR: {
            mergeError(other.getError());
            break;
          }
          case TYPE_NOT_SET: {
            break;
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.topicData.TopicDataOuterClass.TopicData parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.topicData.TopicDataOuterClass.TopicData) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int typeCase_ = 0;
      private java.lang.Object type_;
      public TypeCase
          getTypeCase() {
        return TypeCase.forNumber(
            typeCase_);
      }

      public Builder clearType() {
        typeCase_ = 0;
        type_ = null;
        onChanged();
        return this;
      }


      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> topicDataRecordBuilder_;
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public boolean hasTopicDataRecord() {
        return typeCase_ == 2;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getTopicDataRecord() {
        if (topicDataRecordBuilder_ == null) {
          if (typeCase_ == 2) {
            return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_;
          }
          return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
        } else {
          if (typeCase_ == 2) {
            return topicDataRecordBuilder_.getMessage();
          }
          return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public Builder setTopicDataRecord(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (topicDataRecordBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          topicDataRecordBuilder_.setMessage(value);
        }
        typeCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public Builder setTopicDataRecord(
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (topicDataRecordBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          topicDataRecordBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public Builder mergeTopicDataRecord(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (topicDataRecordBuilder_ == null) {
          if (typeCase_ == 2 &&
              type_ != ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance()) {
            type_ = ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.newBuilder((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 2) {
            topicDataRecordBuilder_.mergeFrom(value);
          }
          topicDataRecordBuilder_.setMessage(value);
        }
        typeCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public Builder clearTopicDataRecord() {
        if (topicDataRecordBuilder_ == null) {
          if (typeCase_ == 2) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 2) {
            typeCase_ = 0;
            type_ = null;
          }
          topicDataRecordBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder getTopicDataRecordBuilder() {
        return getTopicDataRecordFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getTopicDataRecordOrBuilder() {
        if ((typeCase_ == 2) && (topicDataRecordBuilder_ != null)) {
          return topicDataRecordBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 2) {
            return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_;
          }
          return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.topicData.TopicDataRecord topic_data_record = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
          getTopicDataRecordFieldBuilder() {
        if (topicDataRecordBuilder_ == null) {
          if (!(typeCase_ == 2)) {
            type_ = ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
          }
          topicDataRecordBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder>(
                  (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 2;
        onChanged();;
        return topicDataRecordBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder> topicDataRecordListBuilder_;
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public boolean hasTopicDataRecordList() {
        return typeCase_ == 3;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList getTopicDataRecordList() {
        if (topicDataRecordListBuilder_ == null) {
          if (typeCase_ == 3) {
            return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_;
          }
          return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
        } else {
          if (typeCase_ == 3) {
            return topicDataRecordListBuilder_.getMessage();
          }
          return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public Builder setTopicDataRecordList(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList value) {
        if (topicDataRecordListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          topicDataRecordListBuilder_.setMessage(value);
        }
        typeCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public Builder setTopicDataRecordList(
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder builderForValue) {
        if (topicDataRecordListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          topicDataRecordListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public Builder mergeTopicDataRecordList(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList value) {
        if (topicDataRecordListBuilder_ == null) {
          if (typeCase_ == 3 &&
              type_ != ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance()) {
            type_ = ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.newBuilder((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 3) {
            topicDataRecordListBuilder_.mergeFrom(value);
          }
          topicDataRecordListBuilder_.setMessage(value);
        }
        typeCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public Builder clearTopicDataRecordList() {
        if (topicDataRecordListBuilder_ == null) {
          if (typeCase_ == 3) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 3) {
            typeCase_ = 0;
            type_ = null;
          }
          topicDataRecordListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder getTopicDataRecordListBuilder() {
        return getTopicDataRecordListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder getTopicDataRecordListOrBuilder() {
        if ((typeCase_ == 3) && (topicDataRecordListBuilder_ != null)) {
          return topicDataRecordListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 3) {
            return (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_;
          }
          return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.topicData.TopicDataRecordList topic_data_record_list = 3;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder> 
          getTopicDataRecordListFieldBuilder() {
        if (topicDataRecordListBuilder_ == null) {
          if (!(typeCase_ == 3)) {
            type_ = ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
          }
          topicDataRecordListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder>(
                  (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 3;
        onChanged();;
        return topicDataRecordListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.general.ErrorOuterClass.Error, ubii.general.ErrorOuterClass.Error.Builder, ubii.general.ErrorOuterClass.ErrorOrBuilder> errorBuilder_;
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public boolean hasError() {
        return typeCase_ == 4;
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public ubii.general.ErrorOuterClass.Error getError() {
        if (errorBuilder_ == null) {
          if (typeCase_ == 4) {
            return (ubii.general.ErrorOuterClass.Error) type_;
          }
          return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
        } else {
          if (typeCase_ == 4) {
            return errorBuilder_.getMessage();
          }
          return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public Builder setError(ubii.general.ErrorOuterClass.Error value) {
        if (errorBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          errorBuilder_.setMessage(value);
        }
        typeCase_ = 4;
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public Builder setError(
          ubii.general.ErrorOuterClass.Error.Builder builderForValue) {
        if (errorBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          errorBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 4;
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public Builder mergeError(ubii.general.ErrorOuterClass.Error value) {
        if (errorBuilder_ == null) {
          if (typeCase_ == 4 &&
              type_ != ubii.general.ErrorOuterClass.Error.getDefaultInstance()) {
            type_ = ubii.general.ErrorOuterClass.Error.newBuilder((ubii.general.ErrorOuterClass.Error) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 4) {
            errorBuilder_.mergeFrom(value);
          }
          errorBuilder_.setMessage(value);
        }
        typeCase_ = 4;
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public Builder clearError() {
        if (errorBuilder_ == null) {
          if (typeCase_ == 4) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 4) {
            typeCase_ = 0;
            type_ = null;
          }
          errorBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public ubii.general.ErrorOuterClass.Error.Builder getErrorBuilder() {
        return getErrorFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      public ubii.general.ErrorOuterClass.ErrorOrBuilder getErrorOrBuilder() {
        if ((typeCase_ == 4) && (errorBuilder_ != null)) {
          return errorBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 4) {
            return (ubii.general.ErrorOuterClass.Error) type_;
          }
          return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.general.Error error = 4;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.general.ErrorOuterClass.Error, ubii.general.ErrorOuterClass.Error.Builder, ubii.general.ErrorOuterClass.ErrorOrBuilder> 
          getErrorFieldBuilder() {
        if (errorBuilder_ == null) {
          if (!(typeCase_ == 4)) {
            type_ = ubii.general.ErrorOuterClass.Error.getDefaultInstance();
          }
          errorBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.general.ErrorOuterClass.Error, ubii.general.ErrorOuterClass.Error.Builder, ubii.general.ErrorOuterClass.ErrorOrBuilder>(
                  (ubii.general.ErrorOuterClass.Error) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 4;
        onChanged();;
        return errorBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.topicData.TopicData)
    }

    // @@protoc_insertion_point(class_scope:ubii.topicData.TopicData)
    private static final ubii.topicData.TopicDataOuterClass.TopicData DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.topicData.TopicDataOuterClass.TopicData();
    }

    public static ubii.topicData.TopicDataOuterClass.TopicData getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicData>
        PARSER = new com.google.protobuf.AbstractParser<TopicData>() {
      @java.lang.Override
      public TopicData parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicData(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicData> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicData> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.topicData.TopicDataOuterClass.TopicData getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_topicData_TopicData_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_topicData_TopicData_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n\037proto/topicData/topicData.proto\022\016ubii." +
      "topicData\0325proto/topicData/topicDataReco" +
      "rd/topicDataRecord.proto\032\031proto/general/" +
      "error.proto\"\276\001\n\tTopicData\022<\n\021topic_data_" +
      "record\030\002 \001(\0132\037.ubii.topicData.TopicDataR" +
      "ecordH\000\022E\n\026topic_data_record_list\030\003 \001(\0132" +
      "#.ubii.topicData.TopicDataRecordListH\000\022$" +
      "\n\005error\030\004 \001(\0132\023.ubii.general.ErrorH\000B\006\n\004" +
      "typeb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.topicData.TopicDataRecordOuterClass.getDescriptor(),
          ubii.general.ErrorOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_topicData_TopicData_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_topicData_TopicData_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_topicData_TopicData_descriptor,
        new java.lang.String[] { "TopicDataRecord", "TopicDataRecordList", "Error", "Type", });
    ubii.topicData.TopicDataRecordOuterClass.getDescriptor();
    ubii.general.ErrorOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
