# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/services/request/topicSubscription.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/services/request/topicSubscription.proto',
  package='ubii.proto_v2.types.services.request',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<ubii/proto_v2/types/services/request/topicSubscription.proto\x12$ubii.proto_v2.types.services.request\"\x9e\x01\n\x11TopicSubscription\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x18\n\x10subscribe_topics\x18\x02 \x03(\t\x12\x1a\n\x12unsubscribe_topics\x18\x03 \x03(\t\x12\x1e\n\x16subscribe_topic_regexp\x18\x04 \x03(\t\x12 \n\x18unsubscribe_topic_regexp\x18\x05 \x03(\tb\x06proto3'
)




_TOPICSUBSCRIPTION = _descriptor.Descriptor(
  name='TopicSubscription',
  full_name='ubii.proto_v2.types.services.request.TopicSubscription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ubii.proto_v2.types.services.request.TopicSubscription.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe_topics', full_name='ubii.proto_v2.types.services.request.TopicSubscription.subscribe_topics', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_topics', full_name='ubii.proto_v2.types.services.request.TopicSubscription.unsubscribe_topics', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe_topic_regexp', full_name='ubii.proto_v2.types.services.request.TopicSubscription.subscribe_topic_regexp', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_topic_regexp', full_name='ubii.proto_v2.types.services.request.TopicSubscription.unsubscribe_topic_regexp', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=261,
)

DESCRIPTOR.message_types_by_name['TopicSubscription'] = _TOPICSUBSCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicSubscription = _reflection.GeneratedProtocolMessageType('TopicSubscription', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSUBSCRIPTION,
  '__module__' : 'ubii.proto_v2.types.services.request.topicSubscription_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.services.request.TopicSubscription)
  })
_sym_db.RegisterMessage(TopicSubscription)


# @@protoc_insertion_point(module_scope)
