"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.pose3d_pb_plus import (
    Pose3D,
)

from ubii.proto_v1.types.dataStructure.vector3_pb_plus import (
    Vector3,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Object3D",
        "Object3DList",
    }
)


class Object3D(Message):
    id = Field(
        STRING,
        number=1,
    )
    pose = Field(
        Pose3D,
        number=2,
    )
    size = Field(
        Vector3,
        number=3,
    )
    user_data_json = Field(
        STRING,
        number=4,
    )



class Object3DList(Message):
    elements = RepeatedField(
        Object3D,
        number=1,
    )


