# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/topicData/topicData.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.topicData import topicDataRecord_pb2 as ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2
from ubii.proto_v2.types.general import error_pb2 as ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/topicData/topicData.proto',
  package='ubii.proto_v2.types.topicData',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/topicData/topicData.proto\x12\x1dubii.proto_v2.types.topicData\x1a\x33ubii/proto_v2/types/topicData/topicDataRecord.proto\x1a\'ubii/proto_v2/types/general/error.proto\"\xeb\x01\n\tTopicData\x12K\n\x11topic_data_record\x18\x02 \x01(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecordH\x00\x12T\n\x16topic_data_record_list\x18\x03 \x01(\x0b\x32\x32.ubii.proto_v2.types.topicData.TopicDataRecordListH\x00\x12\x33\n\x05\x65rror\x18\x04 \x01(\x0b\x32\".ubii.proto_v2.types.general.ErrorH\x00\x42\x06\n\x04typeb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2.DESCRIPTOR,])




_TOPICDATA = _descriptor.Descriptor(
  name='TopicData',
  full_name='ubii.proto_v2.types.topicData.TopicData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_data_record', full_name='ubii.proto_v2.types.topicData.TopicData.topic_data_record', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_data_record_list', full_name='ubii.proto_v2.types.topicData.TopicData.topic_data_record_list', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ubii.proto_v2.types.topicData.TopicData.error', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ubii.proto_v2.types.topicData.TopicData.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=175,
  serialized_end=410,
)

_TOPICDATA.fields_by_name['topic_data_record'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORD
_TOPICDATA.fields_by_name['topic_data_record_list'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORDLIST
_TOPICDATA.fields_by_name['error'].message_type = ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2._ERROR
_TOPICDATA.oneofs_by_name['type'].fields.append(
  _TOPICDATA.fields_by_name['topic_data_record'])
_TOPICDATA.fields_by_name['topic_data_record'].containing_oneof = _TOPICDATA.oneofs_by_name['type']
_TOPICDATA.oneofs_by_name['type'].fields.append(
  _TOPICDATA.fields_by_name['topic_data_record_list'])
_TOPICDATA.fields_by_name['topic_data_record_list'].containing_oneof = _TOPICDATA.oneofs_by_name['type']
_TOPICDATA.oneofs_by_name['type'].fields.append(
  _TOPICDATA.fields_by_name['error'])
_TOPICDATA.fields_by_name['error'].containing_oneof = _TOPICDATA.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['TopicData'] = _TOPICDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicData = _reflection.GeneratedProtocolMessageType('TopicData', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDATA,
  '__module__' : 'ubii.proto_v2.types.topicData.topicData_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.topicData.TopicData)
  })
_sym_db.RegisterMessage(TopicData)


# @@protoc_insertion_point(module_scope)
