syntax = "proto3";
package ubii.proto_v1.types.dataStructure;

import "ubii/proto_v1/types/dataStructure/buttonEventType.proto";

message KeyEvent {
    ubii.proto_v1.types.dataStructure.ButtonEventType type = 1;
    string key = 2;
}