// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/object3d.proto

package ubii.dataStructure;

public final class Object3DOuterClass {
  private Object3DOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface Object3DOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.Object3D)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string id = 1;</code>
     */
    java.lang.String getId();
    /**
     * <code>string id = 1;</code>
     */
    com.google.protobuf.ByteString
        getIdBytes();

    /**
     * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
     */
    boolean hasPose();
    /**
     * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
     */
    ubii.dataStructure.Pose3DOuterClass.Pose3D getPose();
    /**
     * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
     */
    ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder getPoseOrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector3 size = 3;</code>
     */
    boolean hasSize();
    /**
     * <code>.ubii.dataStructure.Vector3 size = 3;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3 getSize();
    /**
     * <code>.ubii.dataStructure.Vector3 size = 3;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getSizeOrBuilder();

    /**
     * <code>string user_data_json = 4;</code>
     */
    java.lang.String getUserDataJson();
    /**
     * <code>string user_data_json = 4;</code>
     */
    com.google.protobuf.ByteString
        getUserDataJsonBytes();
  }
  /**
   * Protobuf type {@code ubii.dataStructure.Object3D}
   */
  public  static final class Object3D extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.Object3D)
      Object3DOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Object3D.newBuilder() to construct.
    private Object3D(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Object3D() {
      id_ = "";
      userDataJson_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Object3D(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              id_ = s;
              break;
            }
            case 18: {
              ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder subBuilder = null;
              if (pose_ != null) {
                subBuilder = pose_.toBuilder();
              }
              pose_ = input.readMessage(ubii.dataStructure.Pose3DOuterClass.Pose3D.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(pose_);
                pose_ = subBuilder.buildPartial();
              }

              break;
            }
            case 26: {
              ubii.dataStructure.Vector3OuterClass.Vector3.Builder subBuilder = null;
              if (size_ != null) {
                subBuilder = size_.toBuilder();
              }
              size_ = input.readMessage(ubii.dataStructure.Vector3OuterClass.Vector3.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(size_);
                size_ = subBuilder.buildPartial();
              }

              break;
            }
            case 34: {
              java.lang.String s = input.readStringRequireUtf8();

              userDataJson_ = s;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3D_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3D_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.Object3DOuterClass.Object3D.class, ubii.dataStructure.Object3DOuterClass.Object3D.Builder.class);
    }

    public static final int ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object id_;
    /**
     * <code>string id = 1;</code>
     */
    public java.lang.String getId() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        id_ = s;
        return s;
      }
    }
    /**
     * <code>string id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getIdBytes() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        id_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int POSE_FIELD_NUMBER = 2;
    private ubii.dataStructure.Pose3DOuterClass.Pose3D pose_;
    /**
     * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
     */
    public boolean hasPose() {
      return pose_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
     */
    public ubii.dataStructure.Pose3DOuterClass.Pose3D getPose() {
      return pose_ == null ? ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance() : pose_;
    }
    /**
     * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
     */
    public ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder getPoseOrBuilder() {
      return getPose();
    }

    public static final int SIZE_FIELD_NUMBER = 3;
    private ubii.dataStructure.Vector3OuterClass.Vector3 size_;
    /**
     * <code>.ubii.dataStructure.Vector3 size = 3;</code>
     */
    public boolean hasSize() {
      return size_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 size = 3;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3 getSize() {
      return size_ == null ? ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : size_;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 size = 3;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getSizeOrBuilder() {
      return getSize();
    }

    public static final int USER_DATA_JSON_FIELD_NUMBER = 4;
    private volatile java.lang.Object userDataJson_;
    /**
     * <code>string user_data_json = 4;</code>
     */
    public java.lang.String getUserDataJson() {
      java.lang.Object ref = userDataJson_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        userDataJson_ = s;
        return s;
      }
    }
    /**
     * <code>string user_data_json = 4;</code>
     */
    public com.google.protobuf.ByteString
        getUserDataJsonBytes() {
      java.lang.Object ref = userDataJson_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        userDataJson_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, id_);
      }
      if (pose_ != null) {
        output.writeMessage(2, getPose());
      }
      if (size_ != null) {
        output.writeMessage(3, getSize());
      }
      if (!getUserDataJsonBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 4, userDataJson_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, id_);
      }
      if (pose_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, getPose());
      }
      if (size_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, getSize());
      }
      if (!getUserDataJsonBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(4, userDataJson_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.Object3DOuterClass.Object3D)) {
        return super.equals(obj);
      }
      ubii.dataStructure.Object3DOuterClass.Object3D other = (ubii.dataStructure.Object3DOuterClass.Object3D) obj;

      boolean result = true;
      result = result && getId()
          .equals(other.getId());
      result = result && (hasPose() == other.hasPose());
      if (hasPose()) {
        result = result && getPose()
            .equals(other.getPose());
      }
      result = result && (hasSize() == other.hasSize());
      if (hasSize()) {
        result = result && getSize()
            .equals(other.getSize());
      }
      result = result && getUserDataJson()
          .equals(other.getUserDataJson());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + ID_FIELD_NUMBER;
      hash = (53 * hash) + getId().hashCode();
      if (hasPose()) {
        hash = (37 * hash) + POSE_FIELD_NUMBER;
        hash = (53 * hash) + getPose().hashCode();
      }
      if (hasSize()) {
        hash = (37 * hash) + SIZE_FIELD_NUMBER;
        hash = (53 * hash) + getSize().hashCode();
      }
      hash = (37 * hash) + USER_DATA_JSON_FIELD_NUMBER;
      hash = (53 * hash) + getUserDataJson().hashCode();
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3D parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.Object3DOuterClass.Object3D prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.Object3D}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.Object3D)
        ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3D_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3D_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.Object3DOuterClass.Object3D.class, ubii.dataStructure.Object3DOuterClass.Object3D.Builder.class);
      }

      // Construct using ubii.dataStructure.Object3DOuterClass.Object3D.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        id_ = "";

        if (poseBuilder_ == null) {
          pose_ = null;
        } else {
          pose_ = null;
          poseBuilder_ = null;
        }
        if (sizeBuilder_ == null) {
          size_ = null;
        } else {
          size_ = null;
          sizeBuilder_ = null;
        }
        userDataJson_ = "";

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3D_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.Object3DOuterClass.Object3D getDefaultInstanceForType() {
        return ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.Object3DOuterClass.Object3D build() {
        ubii.dataStructure.Object3DOuterClass.Object3D result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.Object3DOuterClass.Object3D buildPartial() {
        ubii.dataStructure.Object3DOuterClass.Object3D result = new ubii.dataStructure.Object3DOuterClass.Object3D(this);
        result.id_ = id_;
        if (poseBuilder_ == null) {
          result.pose_ = pose_;
        } else {
          result.pose_ = poseBuilder_.build();
        }
        if (sizeBuilder_ == null) {
          result.size_ = size_;
        } else {
          result.size_ = sizeBuilder_.build();
        }
        result.userDataJson_ = userDataJson_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.Object3DOuterClass.Object3D) {
          return mergeFrom((ubii.dataStructure.Object3DOuterClass.Object3D)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.Object3DOuterClass.Object3D other) {
        if (other == ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance()) return this;
        if (!other.getId().isEmpty()) {
          id_ = other.id_;
          onChanged();
        }
        if (other.hasPose()) {
          mergePose(other.getPose());
        }
        if (other.hasSize()) {
          mergeSize(other.getSize());
        }
        if (!other.getUserDataJson().isEmpty()) {
          userDataJson_ = other.userDataJson_;
          onChanged();
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.Object3DOuterClass.Object3D parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.Object3DOuterClass.Object3D) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private java.lang.Object id_ = "";
      /**
       * <code>string id = 1;</code>
       */
      public java.lang.String getId() {
        java.lang.Object ref = id_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          id_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getIdBytes() {
        java.lang.Object ref = id_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          id_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        id_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder clearId() {
        
        id_ = getDefaultInstance().getId();
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        id_ = value;
        onChanged();
        return this;
      }

      private ubii.dataStructure.Pose3DOuterClass.Pose3D pose_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Pose3DOuterClass.Pose3D, ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder, ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder> poseBuilder_;
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public boolean hasPose() {
        return poseBuilder_ != null || pose_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public ubii.dataStructure.Pose3DOuterClass.Pose3D getPose() {
        if (poseBuilder_ == null) {
          return pose_ == null ? ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance() : pose_;
        } else {
          return poseBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public Builder setPose(ubii.dataStructure.Pose3DOuterClass.Pose3D value) {
        if (poseBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          pose_ = value;
          onChanged();
        } else {
          poseBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public Builder setPose(
          ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder builderForValue) {
        if (poseBuilder_ == null) {
          pose_ = builderForValue.build();
          onChanged();
        } else {
          poseBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public Builder mergePose(ubii.dataStructure.Pose3DOuterClass.Pose3D value) {
        if (poseBuilder_ == null) {
          if (pose_ != null) {
            pose_ =
              ubii.dataStructure.Pose3DOuterClass.Pose3D.newBuilder(pose_).mergeFrom(value).buildPartial();
          } else {
            pose_ = value;
          }
          onChanged();
        } else {
          poseBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public Builder clearPose() {
        if (poseBuilder_ == null) {
          pose_ = null;
          onChanged();
        } else {
          pose_ = null;
          poseBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder getPoseBuilder() {
        
        onChanged();
        return getPoseFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      public ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder getPoseOrBuilder() {
        if (poseBuilder_ != null) {
          return poseBuilder_.getMessageOrBuilder();
        } else {
          return pose_ == null ?
              ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance() : pose_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Pose3DOuterClass.Pose3D, ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder, ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder> 
          getPoseFieldBuilder() {
        if (poseBuilder_ == null) {
          poseBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Pose3DOuterClass.Pose3D, ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder, ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder>(
                  getPose(),
                  getParentForChildren(),
                  isClean());
          pose_ = null;
        }
        return poseBuilder_;
      }

      private ubii.dataStructure.Vector3OuterClass.Vector3 size_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> sizeBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public boolean hasSize() {
        return sizeBuilder_ != null || size_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3 getSize() {
        if (sizeBuilder_ == null) {
          return size_ == null ? ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : size_;
        } else {
          return sizeBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public Builder setSize(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (sizeBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          size_ = value;
          onChanged();
        } else {
          sizeBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public Builder setSize(
          ubii.dataStructure.Vector3OuterClass.Vector3.Builder builderForValue) {
        if (sizeBuilder_ == null) {
          size_ = builderForValue.build();
          onChanged();
        } else {
          sizeBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public Builder mergeSize(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (sizeBuilder_ == null) {
          if (size_ != null) {
            size_ =
              ubii.dataStructure.Vector3OuterClass.Vector3.newBuilder(size_).mergeFrom(value).buildPartial();
          } else {
            size_ = value;
          }
          onChanged();
        } else {
          sizeBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public Builder clearSize() {
        if (sizeBuilder_ == null) {
          size_ = null;
          onChanged();
        } else {
          size_ = null;
          sizeBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3.Builder getSizeBuilder() {
        
        onChanged();
        return getSizeFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getSizeOrBuilder() {
        if (sizeBuilder_ != null) {
          return sizeBuilder_.getMessageOrBuilder();
        } else {
          return size_ == null ?
              ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : size_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 size = 3;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> 
          getSizeFieldBuilder() {
        if (sizeBuilder_ == null) {
          sizeBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder>(
                  getSize(),
                  getParentForChildren(),
                  isClean());
          size_ = null;
        }
        return sizeBuilder_;
      }

      private java.lang.Object userDataJson_ = "";
      /**
       * <code>string user_data_json = 4;</code>
       */
      public java.lang.String getUserDataJson() {
        java.lang.Object ref = userDataJson_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          userDataJson_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string user_data_json = 4;</code>
       */
      public com.google.protobuf.ByteString
          getUserDataJsonBytes() {
        java.lang.Object ref = userDataJson_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          userDataJson_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string user_data_json = 4;</code>
       */
      public Builder setUserDataJson(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        userDataJson_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string user_data_json = 4;</code>
       */
      public Builder clearUserDataJson() {
        
        userDataJson_ = getDefaultInstance().getUserDataJson();
        onChanged();
        return this;
      }
      /**
       * <code>string user_data_json = 4;</code>
       */
      public Builder setUserDataJsonBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        userDataJson_ = value;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.Object3D)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.Object3D)
    private static final ubii.dataStructure.Object3DOuterClass.Object3D DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.Object3DOuterClass.Object3D();
    }

    public static ubii.dataStructure.Object3DOuterClass.Object3D getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Object3D>
        PARSER = new com.google.protobuf.AbstractParser<Object3D>() {
      @java.lang.Override
      public Object3D parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Object3D(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Object3D> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Object3D> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.Object3DOuterClass.Object3D getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface Object3DListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.Object3DList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    java.util.List<ubii.dataStructure.Object3DOuterClass.Object3D> 
        getElementsList();
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    ubii.dataStructure.Object3DOuterClass.Object3D getElements(int index);
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    java.util.List<? extends ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.dataStructure.Object3DList}
   */
  public  static final class Object3DList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.Object3DList)
      Object3DListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Object3DList.newBuilder() to construct.
    private Object3DList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Object3DList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Object3DList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.dataStructure.Object3DOuterClass.Object3D>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.dataStructure.Object3DOuterClass.Object3D.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3DList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3DList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.Object3DOuterClass.Object3DList.class, ubii.dataStructure.Object3DOuterClass.Object3DList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.dataStructure.Object3DOuterClass.Object3D> elements_;
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    public java.util.List<ubii.dataStructure.Object3DOuterClass.Object3D> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    public java.util.List<? extends ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    public ubii.dataStructure.Object3DOuterClass.Object3D getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
     */
    public ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.Object3DOuterClass.Object3DList)) {
        return super.equals(obj);
      }
      ubii.dataStructure.Object3DOuterClass.Object3DList other = (ubii.dataStructure.Object3DOuterClass.Object3DList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.Object3DOuterClass.Object3DList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.Object3DOuterClass.Object3DList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.Object3DList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.Object3DList)
        ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3DList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3DList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.Object3DOuterClass.Object3DList.class, ubii.dataStructure.Object3DOuterClass.Object3DList.Builder.class);
      }

      // Construct using ubii.dataStructure.Object3DOuterClass.Object3DList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.Object3DOuterClass.internal_static_ubii_dataStructure_Object3DList_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.Object3DOuterClass.Object3DList getDefaultInstanceForType() {
        return ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.Object3DOuterClass.Object3DList build() {
        ubii.dataStructure.Object3DOuterClass.Object3DList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.Object3DOuterClass.Object3DList buildPartial() {
        ubii.dataStructure.Object3DOuterClass.Object3DList result = new ubii.dataStructure.Object3DOuterClass.Object3DList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.Object3DOuterClass.Object3DList) {
          return mergeFrom((ubii.dataStructure.Object3DOuterClass.Object3DList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.Object3DOuterClass.Object3DList other) {
        if (other == ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.Object3DOuterClass.Object3DList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.Object3DOuterClass.Object3DList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.dataStructure.Object3DOuterClass.Object3D> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.dataStructure.Object3DOuterClass.Object3D>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.dataStructure.Object3DOuterClass.Object3D, ubii.dataStructure.Object3DOuterClass.Object3D.Builder, ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public java.util.List<ubii.dataStructure.Object3DOuterClass.Object3D> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3D getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.dataStructure.Object3DOuterClass.Object3D value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.dataStructure.Object3DOuterClass.Object3D.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder addElements(ubii.dataStructure.Object3DOuterClass.Object3D value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.dataStructure.Object3DOuterClass.Object3D value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder addElements(
          ubii.dataStructure.Object3DOuterClass.Object3D.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.dataStructure.Object3DOuterClass.Object3D.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.dataStructure.Object3DOuterClass.Object3D> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3D.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public java.util.List<? extends ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3D.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3D.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.dataStructure.Object3D elements = 1;</code>
       */
      public java.util.List<ubii.dataStructure.Object3DOuterClass.Object3D.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.dataStructure.Object3DOuterClass.Object3D, ubii.dataStructure.Object3DOuterClass.Object3D.Builder, ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.dataStructure.Object3DOuterClass.Object3D, ubii.dataStructure.Object3DOuterClass.Object3D.Builder, ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.Object3DList)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.Object3DList)
    private static final ubii.dataStructure.Object3DOuterClass.Object3DList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.Object3DOuterClass.Object3DList();
    }

    public static ubii.dataStructure.Object3DOuterClass.Object3DList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Object3DList>
        PARSER = new com.google.protobuf.AbstractParser<Object3DList>() {
      @java.lang.Override
      public Object3DList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Object3DList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Object3DList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Object3DList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.Object3DOuterClass.Object3DList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_Object3D_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_Object3D_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_Object3DList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_Object3DList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n<proto/topicData/topicDataRecord/dataSt" +
      "ructure/object3d.proto\022\022ubii.dataStructu" +
      "re\032:proto/topicData/topicDataRecord/data" +
      "Structure/pose3d.proto\032;proto/topicData/" +
      "topicDataRecord/dataStructure/vector3.pr" +
      "oto\"\203\001\n\010Object3D\022\n\n\002id\030\001 \001(\t\022(\n\004pose\030\002 \001" +
      "(\0132\032.ubii.dataStructure.Pose3D\022)\n\004size\030\003" +
      " \001(\0132\033.ubii.dataStructure.Vector3\022\026\n\016use" +
      "r_data_json\030\004 \001(\t\">\n\014Object3DList\022.\n\010ele" +
      "ments\030\001 \003(\0132\034.ubii.dataStructure.Object3" +
      "Db\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.dataStructure.Pose3DOuterClass.getDescriptor(),
          ubii.dataStructure.Vector3OuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_dataStructure_Object3D_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_dataStructure_Object3D_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_Object3D_descriptor,
        new java.lang.String[] { "Id", "Pose", "Size", "UserDataJson", });
    internal_static_ubii_dataStructure_Object3DList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_dataStructure_Object3DList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_Object3DList_descriptor,
        new java.lang.String[] { "Elements", });
    ubii.dataStructure.Pose3DOuterClass.getDescriptor();
    ubii.dataStructure.Vector3OuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
