// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/mouseEvent.proto

package ubii.dataStructure;

public final class MouseEventOuterClass {
  private MouseEventOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface MouseEventOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.MouseEvent)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
     */
    int getTypeValue();
    /**
     * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
     */
    ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType getType();

    /**
     * <code>int32 button = 2;</code>
     */
    int getButton();
  }
  /**
   * Protobuf type {@code ubii.dataStructure.MouseEvent}
   */
  public  static final class MouseEvent extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.MouseEvent)
      MouseEventOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use MouseEvent.newBuilder() to construct.
    private MouseEvent(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private MouseEvent() {
      type_ = 0;
      button_ = 0;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private MouseEvent(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 8: {
              int rawValue = input.readEnum();

              type_ = rawValue;
              break;
            }
            case 16: {

              button_ = input.readInt32();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.MouseEventOuterClass.internal_static_ubii_dataStructure_MouseEvent_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.MouseEventOuterClass.internal_static_ubii_dataStructure_MouseEvent_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.MouseEventOuterClass.MouseEvent.class, ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder.class);
    }

    public static final int TYPE_FIELD_NUMBER = 1;
    private int type_;
    /**
     * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
     */
    public int getTypeValue() {
      return type_;
    }
    /**
     * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
     */
    public ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType getType() {
      @SuppressWarnings("deprecation")
      ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType result = ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType.valueOf(type_);
      return result == null ? ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType.UNRECOGNIZED : result;
    }

    public static final int BUTTON_FIELD_NUMBER = 2;
    private int button_;
    /**
     * <code>int32 button = 2;</code>
     */
    public int getButton() {
      return button_;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (type_ != ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType.UP.getNumber()) {
        output.writeEnum(1, type_);
      }
      if (button_ != 0) {
        output.writeInt32(2, button_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (type_ != ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType.UP.getNumber()) {
        size += com.google.protobuf.CodedOutputStream
          .computeEnumSize(1, type_);
      }
      if (button_ != 0) {
        size += com.google.protobuf.CodedOutputStream
          .computeInt32Size(2, button_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.MouseEventOuterClass.MouseEvent)) {
        return super.equals(obj);
      }
      ubii.dataStructure.MouseEventOuterClass.MouseEvent other = (ubii.dataStructure.MouseEventOuterClass.MouseEvent) obj;

      boolean result = true;
      result = result && type_ == other.type_;
      result = result && (getButton()
          == other.getButton());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + TYPE_FIELD_NUMBER;
      hash = (53 * hash) + type_;
      hash = (37 * hash) + BUTTON_FIELD_NUMBER;
      hash = (53 * hash) + getButton();
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.MouseEventOuterClass.MouseEvent prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.MouseEvent}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.MouseEvent)
        ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.MouseEventOuterClass.internal_static_ubii_dataStructure_MouseEvent_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.MouseEventOuterClass.internal_static_ubii_dataStructure_MouseEvent_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.MouseEventOuterClass.MouseEvent.class, ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder.class);
      }

      // Construct using ubii.dataStructure.MouseEventOuterClass.MouseEvent.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        type_ = 0;

        button_ = 0;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.MouseEventOuterClass.internal_static_ubii_dataStructure_MouseEvent_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.MouseEventOuterClass.MouseEvent getDefaultInstanceForType() {
        return ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.MouseEventOuterClass.MouseEvent build() {
        ubii.dataStructure.MouseEventOuterClass.MouseEvent result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.MouseEventOuterClass.MouseEvent buildPartial() {
        ubii.dataStructure.MouseEventOuterClass.MouseEvent result = new ubii.dataStructure.MouseEventOuterClass.MouseEvent(this);
        result.type_ = type_;
        result.button_ = button_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.MouseEventOuterClass.MouseEvent) {
          return mergeFrom((ubii.dataStructure.MouseEventOuterClass.MouseEvent)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.MouseEventOuterClass.MouseEvent other) {
        if (other == ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance()) return this;
        if (other.type_ != 0) {
          setTypeValue(other.getTypeValue());
        }
        if (other.getButton() != 0) {
          setButton(other.getButton());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.MouseEventOuterClass.MouseEvent parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.MouseEventOuterClass.MouseEvent) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private int type_ = 0;
      /**
       * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
       */
      public int getTypeValue() {
        return type_;
      }
      /**
       * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
       */
      public Builder setTypeValue(int value) {
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
       */
      public ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType getType() {
        @SuppressWarnings("deprecation")
        ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType result = ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType.valueOf(type_);
        return result == null ? ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType.UNRECOGNIZED : result;
      }
      /**
       * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
       */
      public Builder setType(ubii.dataStructure.ButtonEventTypeOuterClass.ButtonEventType value) {
        if (value == null) {
          throw new NullPointerException();
        }
        
        type_ = value.getNumber();
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.dataStructure.ButtonEventType type = 1;</code>
       */
      public Builder clearType() {
        
        type_ = 0;
        onChanged();
        return this;
      }

      private int button_ ;
      /**
       * <code>int32 button = 2;</code>
       */
      public int getButton() {
        return button_;
      }
      /**
       * <code>int32 button = 2;</code>
       */
      public Builder setButton(int value) {
        
        button_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>int32 button = 2;</code>
       */
      public Builder clearButton() {
        
        button_ = 0;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.MouseEvent)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.MouseEvent)
    private static final ubii.dataStructure.MouseEventOuterClass.MouseEvent DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.MouseEventOuterClass.MouseEvent();
    }

    public static ubii.dataStructure.MouseEventOuterClass.MouseEvent getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<MouseEvent>
        PARSER = new com.google.protobuf.AbstractParser<MouseEvent>() {
      @java.lang.Override
      public MouseEvent parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new MouseEvent(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<MouseEvent> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<MouseEvent> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.MouseEventOuterClass.MouseEvent getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_MouseEvent_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_MouseEvent_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n>proto/topicData/topicDataRecord/dataSt" +
      "ructure/mouseEvent.proto\022\022ubii.dataStruc" +
      "ture\032Cproto/topicData/topicDataRecord/da" +
      "taStructure/buttonEventType.proto\"O\n\nMou" +
      "seEvent\0221\n\004type\030\001 \001(\0162#.ubii.dataStructu" +
      "re.ButtonEventType\022\016\n\006button\030\002 \001(\005b\006prot" +
      "o3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.dataStructure.ButtonEventTypeOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_dataStructure_MouseEvent_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_dataStructure_MouseEvent_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_MouseEvent_descriptor,
        new java.lang.String[] { "Type", "Button", });
    ubii.dataStructure.ButtonEventTypeOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
