"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.clients.client_pb_plus import (
    Client,
    ClientList,
)


__all__ = (
    "Client",
    "ClientList",
)