// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/myoEvent.proto

package ubii.dataStructure;

public final class MyoEventOuterClass {
  private MyoEventOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface MyoEventOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.MyoEvent)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
     */
    boolean hasEmg();
    /**
     * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
     */
    ubii.dataStructure.Vector8OuterClass.Vector8 getEmg();
    /**
     * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
     */
    ubii.dataStructure.Vector8OuterClass.Vector8OrBuilder getEmgOrBuilder();

    /**
     * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
     */
    boolean hasOrientation();
    /**
     * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
     */
    ubii.dataStructure.QuaternionOuterClass.Quaternion getOrientation();
    /**
     * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
     */
    ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getOrientationOrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
     */
    boolean hasGyroscope();
    /**
     * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3 getGyroscope();
    /**
     * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getGyroscopeOrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
     */
    boolean hasAccelerometer();
    /**
     * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3 getAccelerometer();
    /**
     * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getAccelerometerOrBuilder();

    /**
     * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
     */
    int getGestureValue();
    /**
     * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
     */
    ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType getGesture();
  }
  /**
   * Protobuf type {@code ubii.dataStructure.MyoEvent}
   */
  public  static final class MyoEvent extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.MyoEvent)
      MyoEventOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use MyoEvent.newBuilder() to construct.
    private MyoEvent(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private MyoEvent() {
      gesture_ = 0;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private MyoEvent(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              ubii.dataStructure.Vector8OuterClass.Vector8.Builder subBuilder = null;
              if (emg_ != null) {
                subBuilder = emg_.toBuilder();
              }
              emg_ = input.readMessage(ubii.dataStructure.Vector8OuterClass.Vector8.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(emg_);
                emg_ = subBuilder.buildPartial();
              }

              break;
            }
            case 18: {
              ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder subBuilder = null;
              if (orientation_ != null) {
                subBuilder = orientation_.toBuilder();
              }
              orientation_ = input.readMessage(ubii.dataStructure.QuaternionOuterClass.Quaternion.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(orientation_);
                orientation_ = subBuilder.buildPartial();
              }

              break;
            }
            case 26: {
              ubii.dataStructure.Vector3OuterClass.Vector3.Builder subBuilder = null;
              if (gyroscope_ != null) {
                subBuilder = gyroscope_.toBuilder();
              }
              gyroscope_ = input.readMessage(ubii.dataStructure.Vector3OuterClass.Vector3.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(gyroscope_);
                gyroscope_ = subBuilder.buildPartial();
              }

              break;
            }
            case 34: {
              ubii.dataStructure.Vector3OuterClass.Vector3.Builder subBuilder = null;
              if (accelerometer_ != null) {
                subBuilder = accelerometer_.toBuilder();
              }
              accelerometer_ = input.readMessage(ubii.dataStructure.Vector3OuterClass.Vector3.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(accelerometer_);
                accelerometer_ = subBuilder.buildPartial();
              }

              break;
            }
            case 40: {
              int rawValue = input.readEnum();

              gesture_ = rawValue;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.MyoEventOuterClass.internal_static_ubii_dataStructure_MyoEvent_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.MyoEventOuterClass.internal_static_ubii_dataStructure_MyoEvent_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.MyoEventOuterClass.MyoEvent.class, ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder.class);
    }

    public static final int EMG_FIELD_NUMBER = 1;
    private ubii.dataStructure.Vector8OuterClass.Vector8 emg_;
    /**
     * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
     */
    public boolean hasEmg() {
      return emg_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
     */
    public ubii.dataStructure.Vector8OuterClass.Vector8 getEmg() {
      return emg_ == null ? ubii.dataStructure.Vector8OuterClass.Vector8.getDefaultInstance() : emg_;
    }
    /**
     * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
     */
    public ubii.dataStructure.Vector8OuterClass.Vector8OrBuilder getEmgOrBuilder() {
      return getEmg();
    }

    public static final int ORIENTATION_FIELD_NUMBER = 2;
    private ubii.dataStructure.QuaternionOuterClass.Quaternion orientation_;
    /**
     * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
     */
    public boolean hasOrientation() {
      return orientation_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
     */
    public ubii.dataStructure.QuaternionOuterClass.Quaternion getOrientation() {
      return orientation_ == null ? ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance() : orientation_;
    }
    /**
     * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
     */
    public ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getOrientationOrBuilder() {
      return getOrientation();
    }

    public static final int GYROSCOPE_FIELD_NUMBER = 3;
    private ubii.dataStructure.Vector3OuterClass.Vector3 gyroscope_;
    /**
     * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
     */
    public boolean hasGyroscope() {
      return gyroscope_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3 getGyroscope() {
      return gyroscope_ == null ? ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : gyroscope_;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getGyroscopeOrBuilder() {
      return getGyroscope();
    }

    public static final int ACCELEROMETER_FIELD_NUMBER = 4;
    private ubii.dataStructure.Vector3OuterClass.Vector3 accelerometer_;
    /**
     * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
     */
    public boolean hasAccelerometer() {
      return accelerometer_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3 getAccelerometer() {
      return accelerometer_ == null ? ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : accelerometer_;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getAccelerometerOrBuilder() {
      return getAccelerometer();
    }

    public static final int GESTURE_FIELD_NUMBER = 5;
    private int gesture_;
    /**
     * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
     */
    public int getGestureValue() {
      return gesture_;
    }
    /**
     * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
     */
    public ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType getGesture() {
      @SuppressWarnings("deprecation")
      ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType result = ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType.valueOf(gesture_);
      return result == null ? ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType.UNRECOGNIZED : result;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (emg_ != null) {
        output.writeMessage(1, getEmg());
      }
      if (orientation_ != null) {
        output.writeMessage(2, getOrientation());
      }
      if (gyroscope_ != null) {
        output.writeMessage(3, getGyroscope());
      }
      if (accelerometer_ != null) {
        output.writeMessage(4, getAccelerometer());
      }
      if (gesture_ != ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType.REST.getNumber()) {
        output.writeEnum(5, gesture_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (emg_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, getEmg());
      }
      if (orientation_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, getOrientation());
      }
      if (gyroscope_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, getGyroscope());
      }
      if (accelerometer_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(4, getAccelerometer());
      }
      if (gesture_ != ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType.REST.getNumber()) {
        size += com.google.protobuf.CodedOutputStream
          .computeEnumSize(5, gesture_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.MyoEventOuterClass.MyoEvent)) {
        return super.equals(obj);
      }
      ubii.dataStructure.MyoEventOuterClass.MyoEvent other = (ubii.dataStructure.MyoEventOuterClass.MyoEvent) obj;

      boolean result = true;
      result = result && (hasEmg() == other.hasEmg());
      if (hasEmg()) {
        result = result && getEmg()
            .equals(other.getEmg());
      }
      result = result && (hasOrientation() == other.hasOrientation());
      if (hasOrientation()) {
        result = result && getOrientation()
            .equals(other.getOrientation());
      }
      result = result && (hasGyroscope() == other.hasGyroscope());
      if (hasGyroscope()) {
        result = result && getGyroscope()
            .equals(other.getGyroscope());
      }
      result = result && (hasAccelerometer() == other.hasAccelerometer());
      if (hasAccelerometer()) {
        result = result && getAccelerometer()
            .equals(other.getAccelerometer());
      }
      result = result && gesture_ == other.gesture_;
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (hasEmg()) {
        hash = (37 * hash) + EMG_FIELD_NUMBER;
        hash = (53 * hash) + getEmg().hashCode();
      }
      if (hasOrientation()) {
        hash = (37 * hash) + ORIENTATION_FIELD_NUMBER;
        hash = (53 * hash) + getOrientation().hashCode();
      }
      if (hasGyroscope()) {
        hash = (37 * hash) + GYROSCOPE_FIELD_NUMBER;
        hash = (53 * hash) + getGyroscope().hashCode();
      }
      if (hasAccelerometer()) {
        hash = (37 * hash) + ACCELEROMETER_FIELD_NUMBER;
        hash = (53 * hash) + getAccelerometer().hashCode();
      }
      hash = (37 * hash) + GESTURE_FIELD_NUMBER;
      hash = (53 * hash) + gesture_;
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.MyoEventOuterClass.MyoEvent prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.MyoEvent}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.MyoEvent)
        ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.MyoEventOuterClass.internal_static_ubii_dataStructure_MyoEvent_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.MyoEventOuterClass.internal_static_ubii_dataStructure_MyoEvent_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.MyoEventOuterClass.MyoEvent.class, ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder.class);
      }

      // Construct using ubii.dataStructure.MyoEventOuterClass.MyoEvent.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (emgBuilder_ == null) {
          emg_ = null;
        } else {
          emg_ = null;
          emgBuilder_ = null;
        }
        if (orientationBuilder_ == null) {
          orientation_ = null;
        } else {
          orientation_ = null;
          orientationBuilder_ = null;
        }
        if (gyroscopeBuilder_ == null) {
          gyroscope_ = null;
        } else {
          gyroscope_ = null;
          gyroscopeBuilder_ = null;
        }
        if (accelerometerBuilder_ == null) {
          accelerometer_ = null;
        } else {
          accelerometer_ = null;
          accelerometerBuilder_ = null;
        }
        gesture_ = 0;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.MyoEventOuterClass.internal_static_ubii_dataStructure_MyoEvent_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.MyoEventOuterClass.MyoEvent getDefaultInstanceForType() {
        return ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.MyoEventOuterClass.MyoEvent build() {
        ubii.dataStructure.MyoEventOuterClass.MyoEvent result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.MyoEventOuterClass.MyoEvent buildPartial() {
        ubii.dataStructure.MyoEventOuterClass.MyoEvent result = new ubii.dataStructure.MyoEventOuterClass.MyoEvent(this);
        if (emgBuilder_ == null) {
          result.emg_ = emg_;
        } else {
          result.emg_ = emgBuilder_.build();
        }
        if (orientationBuilder_ == null) {
          result.orientation_ = orientation_;
        } else {
          result.orientation_ = orientationBuilder_.build();
        }
        if (gyroscopeBuilder_ == null) {
          result.gyroscope_ = gyroscope_;
        } else {
          result.gyroscope_ = gyroscopeBuilder_.build();
        }
        if (accelerometerBuilder_ == null) {
          result.accelerometer_ = accelerometer_;
        } else {
          result.accelerometer_ = accelerometerBuilder_.build();
        }
        result.gesture_ = gesture_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.MyoEventOuterClass.MyoEvent) {
          return mergeFrom((ubii.dataStructure.MyoEventOuterClass.MyoEvent)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.MyoEventOuterClass.MyoEvent other) {
        if (other == ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance()) return this;
        if (other.hasEmg()) {
          mergeEmg(other.getEmg());
        }
        if (other.hasOrientation()) {
          mergeOrientation(other.getOrientation());
        }
        if (other.hasGyroscope()) {
          mergeGyroscope(other.getGyroscope());
        }
        if (other.hasAccelerometer()) {
          mergeAccelerometer(other.getAccelerometer());
        }
        if (other.gesture_ != 0) {
          setGestureValue(other.getGestureValue());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.MyoEventOuterClass.MyoEvent parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.MyoEventOuterClass.MyoEvent) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private ubii.dataStructure.Vector8OuterClass.Vector8 emg_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector8OuterClass.Vector8, ubii.dataStructure.Vector8OuterClass.Vector8.Builder, ubii.dataStructure.Vector8OuterClass.Vector8OrBuilder> emgBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public boolean hasEmg() {
        return emgBuilder_ != null || emg_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public ubii.dataStructure.Vector8OuterClass.Vector8 getEmg() {
        if (emgBuilder_ == null) {
          return emg_ == null ? ubii.dataStructure.Vector8OuterClass.Vector8.getDefaultInstance() : emg_;
        } else {
          return emgBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public Builder setEmg(ubii.dataStructure.Vector8OuterClass.Vector8 value) {
        if (emgBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          emg_ = value;
          onChanged();
        } else {
          emgBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public Builder setEmg(
          ubii.dataStructure.Vector8OuterClass.Vector8.Builder builderForValue) {
        if (emgBuilder_ == null) {
          emg_ = builderForValue.build();
          onChanged();
        } else {
          emgBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public Builder mergeEmg(ubii.dataStructure.Vector8OuterClass.Vector8 value) {
        if (emgBuilder_ == null) {
          if (emg_ != null) {
            emg_ =
              ubii.dataStructure.Vector8OuterClass.Vector8.newBuilder(emg_).mergeFrom(value).buildPartial();
          } else {
            emg_ = value;
          }
          onChanged();
        } else {
          emgBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public Builder clearEmg() {
        if (emgBuilder_ == null) {
          emg_ = null;
          onChanged();
        } else {
          emg_ = null;
          emgBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public ubii.dataStructure.Vector8OuterClass.Vector8.Builder getEmgBuilder() {
        
        onChanged();
        return getEmgFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      public ubii.dataStructure.Vector8OuterClass.Vector8OrBuilder getEmgOrBuilder() {
        if (emgBuilder_ != null) {
          return emgBuilder_.getMessageOrBuilder();
        } else {
          return emg_ == null ?
              ubii.dataStructure.Vector8OuterClass.Vector8.getDefaultInstance() : emg_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector8 emg = 1;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector8OuterClass.Vector8, ubii.dataStructure.Vector8OuterClass.Vector8.Builder, ubii.dataStructure.Vector8OuterClass.Vector8OrBuilder> 
          getEmgFieldBuilder() {
        if (emgBuilder_ == null) {
          emgBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector8OuterClass.Vector8, ubii.dataStructure.Vector8OuterClass.Vector8.Builder, ubii.dataStructure.Vector8OuterClass.Vector8OrBuilder>(
                  getEmg(),
                  getParentForChildren(),
                  isClean());
          emg_ = null;
        }
        return emgBuilder_;
      }

      private ubii.dataStructure.QuaternionOuterClass.Quaternion orientation_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder> orientationBuilder_;
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public boolean hasOrientation() {
        return orientationBuilder_ != null || orientation_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.Quaternion getOrientation() {
        if (orientationBuilder_ == null) {
          return orientation_ == null ? ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance() : orientation_;
        } else {
          return orientationBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public Builder setOrientation(ubii.dataStructure.QuaternionOuterClass.Quaternion value) {
        if (orientationBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          orientation_ = value;
          onChanged();
        } else {
          orientationBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public Builder setOrientation(
          ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder builderForValue) {
        if (orientationBuilder_ == null) {
          orientation_ = builderForValue.build();
          onChanged();
        } else {
          orientationBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public Builder mergeOrientation(ubii.dataStructure.QuaternionOuterClass.Quaternion value) {
        if (orientationBuilder_ == null) {
          if (orientation_ != null) {
            orientation_ =
              ubii.dataStructure.QuaternionOuterClass.Quaternion.newBuilder(orientation_).mergeFrom(value).buildPartial();
          } else {
            orientation_ = value;
          }
          onChanged();
        } else {
          orientationBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public Builder clearOrientation() {
        if (orientationBuilder_ == null) {
          orientation_ = null;
          onChanged();
        } else {
          orientation_ = null;
          orientationBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder getOrientationBuilder() {
        
        onChanged();
        return getOrientationFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getOrientationOrBuilder() {
        if (orientationBuilder_ != null) {
          return orientationBuilder_.getMessageOrBuilder();
        } else {
          return orientation_ == null ?
              ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance() : orientation_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Quaternion orientation = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder> 
          getOrientationFieldBuilder() {
        if (orientationBuilder_ == null) {
          orientationBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder>(
                  getOrientation(),
                  getParentForChildren(),
                  isClean());
          orientation_ = null;
        }
        return orientationBuilder_;
      }

      private ubii.dataStructure.Vector3OuterClass.Vector3 gyroscope_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> gyroscopeBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public boolean hasGyroscope() {
        return gyroscopeBuilder_ != null || gyroscope_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3 getGyroscope() {
        if (gyroscopeBuilder_ == null) {
          return gyroscope_ == null ? ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : gyroscope_;
        } else {
          return gyroscopeBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public Builder setGyroscope(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (gyroscopeBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          gyroscope_ = value;
          onChanged();
        } else {
          gyroscopeBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public Builder setGyroscope(
          ubii.dataStructure.Vector3OuterClass.Vector3.Builder builderForValue) {
        if (gyroscopeBuilder_ == null) {
          gyroscope_ = builderForValue.build();
          onChanged();
        } else {
          gyroscopeBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public Builder mergeGyroscope(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (gyroscopeBuilder_ == null) {
          if (gyroscope_ != null) {
            gyroscope_ =
              ubii.dataStructure.Vector3OuterClass.Vector3.newBuilder(gyroscope_).mergeFrom(value).buildPartial();
          } else {
            gyroscope_ = value;
          }
          onChanged();
        } else {
          gyroscopeBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public Builder clearGyroscope() {
        if (gyroscopeBuilder_ == null) {
          gyroscope_ = null;
          onChanged();
        } else {
          gyroscope_ = null;
          gyroscopeBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3.Builder getGyroscopeBuilder() {
        
        onChanged();
        return getGyroscopeFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getGyroscopeOrBuilder() {
        if (gyroscopeBuilder_ != null) {
          return gyroscopeBuilder_.getMessageOrBuilder();
        } else {
          return gyroscope_ == null ?
              ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : gyroscope_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 gyroscope = 3;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> 
          getGyroscopeFieldBuilder() {
        if (gyroscopeBuilder_ == null) {
          gyroscopeBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder>(
                  getGyroscope(),
                  getParentForChildren(),
                  isClean());
          gyroscope_ = null;
        }
        return gyroscopeBuilder_;
      }

      private ubii.dataStructure.Vector3OuterClass.Vector3 accelerometer_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> accelerometerBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public boolean hasAccelerometer() {
        return accelerometerBuilder_ != null || accelerometer_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3 getAccelerometer() {
        if (accelerometerBuilder_ == null) {
          return accelerometer_ == null ? ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : accelerometer_;
        } else {
          return accelerometerBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public Builder setAccelerometer(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (accelerometerBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          accelerometer_ = value;
          onChanged();
        } else {
          accelerometerBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public Builder setAccelerometer(
          ubii.dataStructure.Vector3OuterClass.Vector3.Builder builderForValue) {
        if (accelerometerBuilder_ == null) {
          accelerometer_ = builderForValue.build();
          onChanged();
        } else {
          accelerometerBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public Builder mergeAccelerometer(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (accelerometerBuilder_ == null) {
          if (accelerometer_ != null) {
            accelerometer_ =
              ubii.dataStructure.Vector3OuterClass.Vector3.newBuilder(accelerometer_).mergeFrom(value).buildPartial();
          } else {
            accelerometer_ = value;
          }
          onChanged();
        } else {
          accelerometerBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public Builder clearAccelerometer() {
        if (accelerometerBuilder_ == null) {
          accelerometer_ = null;
          onChanged();
        } else {
          accelerometer_ = null;
          accelerometerBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3.Builder getAccelerometerBuilder() {
        
        onChanged();
        return getAccelerometerFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getAccelerometerOrBuilder() {
        if (accelerometerBuilder_ != null) {
          return accelerometerBuilder_.getMessageOrBuilder();
        } else {
          return accelerometer_ == null ?
              ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance() : accelerometer_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 accelerometer = 4;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> 
          getAccelerometerFieldBuilder() {
        if (accelerometerBuilder_ == null) {
          accelerometerBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder>(
                  getAccelerometer(),
                  getParentForChildren(),
                  isClean());
          accelerometer_ = null;
        }
        return accelerometerBuilder_;
      }

      private int gesture_ = 0;
      /**
       * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
       */
      public int getGestureValue() {
        return gesture_;
      }
      /**
       * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
       */
      public Builder setGestureValue(int value) {
        gesture_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
       */
      public ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType getGesture() {
        @SuppressWarnings("deprecation")
        ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType result = ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType.valueOf(gesture_);
        return result == null ? ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType.UNRECOGNIZED : result;
      }
      /**
       * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
       */
      public Builder setGesture(ubii.dataStructure.HandGestureTypeOuterClass.HandGestureType value) {
        if (value == null) {
          throw new NullPointerException();
        }
        
        gesture_ = value.getNumber();
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.dataStructure.HandGestureType gesture = 5;</code>
       */
      public Builder clearGesture() {
        
        gesture_ = 0;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.MyoEvent)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.MyoEvent)
    private static final ubii.dataStructure.MyoEventOuterClass.MyoEvent DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.MyoEventOuterClass.MyoEvent();
    }

    public static ubii.dataStructure.MyoEventOuterClass.MyoEvent getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<MyoEvent>
        PARSER = new com.google.protobuf.AbstractParser<MyoEvent>() {
      @java.lang.Override
      public MyoEvent parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new MyoEvent(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<MyoEvent> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<MyoEvent> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.MyoEventOuterClass.MyoEvent getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_MyoEvent_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_MyoEvent_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n<proto/topicData/topicDataRecord/dataSt" +
      "ructure/myoEvent.proto\022\022ubii.dataStructu" +
      "re\032;proto/topicData/topicDataRecord/data" +
      "Structure/vector8.proto\032;proto/topicData" +
      "/topicDataRecord/dataStructure/vector3.p" +
      "roto\032>proto/topicData/topicDataRecord/da" +
      "taStructure/quaternion.proto\032Cproto/topi" +
      "cData/topicDataRecord/dataStructure/hand" +
      "GestureType.proto\"\203\002\n\010MyoEvent\022(\n\003emg\030\001 " +
      "\001(\0132\033.ubii.dataStructure.Vector8\0223\n\013orie" +
      "ntation\030\002 \001(\0132\036.ubii.dataStructure.Quate" +
      "rnion\022.\n\tgyroscope\030\003 \001(\0132\033.ubii.dataStru" +
      "cture.Vector3\0222\n\raccelerometer\030\004 \001(\0132\033.u" +
      "bii.dataStructure.Vector3\0224\n\007gesture\030\005 \001" +
      "(\0162#.ubii.dataStructure.HandGestureTypeb" +
      "\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.dataStructure.Vector8OuterClass.getDescriptor(),
          ubii.dataStructure.Vector3OuterClass.getDescriptor(),
          ubii.dataStructure.QuaternionOuterClass.getDescriptor(),
          ubii.dataStructure.HandGestureTypeOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_dataStructure_MyoEvent_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_dataStructure_MyoEvent_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_MyoEvent_descriptor,
        new java.lang.String[] { "Emg", "Orientation", "Gyroscope", "Accelerometer", "Gesture", });
    ubii.dataStructure.Vector8OuterClass.getDescriptor();
    ubii.dataStructure.Vector3OuterClass.getDescriptor();
    ubii.dataStructure.QuaternionOuterClass.getDescriptor();
    ubii.dataStructure.HandGestureTypeOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
