# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/buttonEventType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/buttonEventType.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7ubii/proto_v2/types/dataStructure/buttonEventType.proto\x12!ubii.proto_v2.types.dataStructure*#\n\x0f\x42uttonEventType\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x62\x06proto3'
)

_BUTTONEVENTTYPE = _descriptor.EnumDescriptor(
  name='ButtonEventType',
  full_name='ubii.proto_v2.types.dataStructure.ButtonEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=94,
  serialized_end=129,
)
_sym_db.RegisterEnumDescriptor(_BUTTONEVENTTYPE)

ButtonEventType = enum_type_wrapper.EnumTypeWrapper(_BUTTONEVENTTYPE)
UP = 0
DOWN = 1


DESCRIPTOR.enum_types_by_name['ButtonEventType'] = _BUTTONEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
