// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/touchEvent.proto

package ubii.dataStructure;

public final class TouchEventOuterClass {
  private TouchEventOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface TouchEventOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.TouchEvent)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
     */
    int getTypeValue();
    /**
     * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType getType();

    /**
     * <code>.ubii.dataStructure.Vector2 position = 2;</code>
     */
    boolean hasPosition();
    /**
     * <code>.ubii.dataStructure.Vector2 position = 2;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2 getPosition();
    /**
     * <code>.ubii.dataStructure.Vector2 position = 2;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getPositionOrBuilder();

    /**
     * <code>string id = 3;</code>
     */
    java.lang.String getId();
    /**
     * <code>string id = 3;</code>
     */
    com.google.protobuf.ByteString
        getIdBytes();

    /**
     * <code>float force = 4;</code>
     */
    float getForce();
  }
  /**
   * Protobuf type {@code ubii.dataStructure.TouchEvent}
   */
  public  static final class TouchEvent extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.TouchEvent)
      TouchEventOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TouchEvent.newBuilder() to construct.
    private TouchEvent(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TouchEvent() {
      type_ = 0;
      id_ = "";
      force_ = 0F;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TouchEvent(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 8: {
              int rawValue = input.readEnum();

              type_ = rawValue;
              break;
            }
            case 18: {
              ubii.dataStructure.Vector2OuterClass.Vector2.Builder subBuilder = null;
              if (position_ != null) {
                subBuilder = position_.toBuilder();
              }
              position_ = input.readMessage(ubii.dataStructure.Vector2OuterClass.Vector2.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(position_);
                position_ = subBuilder.buildPartial();
              }

              break;
            }
            case 26: {
              java.lang.String s = input.readStringRequireUtf8();

              id_ = s;
              break;
            }
            case 37: {

              force_ = input.readFloat();
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEvent_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEvent_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.TouchEventOuterClass.TouchEvent.class, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder.class);
    }

    /**
     * Protobuf enum {@code ubii.dataStructure.TouchEvent.TouchEventType}
     */
    public enum TouchEventType
        implements com.google.protobuf.ProtocolMessageEnum {
      /**
       * <code>TOUCH_START = 0;</code>
       */
      TOUCH_START(0),
      /**
       * <code>TOUCH_MOVE = 1;</code>
       */
      TOUCH_MOVE(1),
      /**
       * <code>TOUCH_END = 2;</code>
       */
      TOUCH_END(2),
      UNRECOGNIZED(-1),
      ;

      /**
       * <code>TOUCH_START = 0;</code>
       */
      public static final int TOUCH_START_VALUE = 0;
      /**
       * <code>TOUCH_MOVE = 1;</code>
       */
      public static final int TOUCH_MOVE_VALUE = 1;
      /**
       * <code>TOUCH_END = 2;</code>
       */
      public static final int TOUCH_END_VALUE = 2;


      public final int getNumber() {
        if (this == UNRECOGNIZED) {
          throw new java.lang.IllegalArgumentException(
              "Can't get the number of an unknown enum value.");
        }
        return value;
      }

      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static TouchEventType valueOf(int value) {
        return forNumber(value);
      }

      public static TouchEventType forNumber(int value) {
        switch (value) {
          case 0: return TOUCH_START;
          case 1: return TOUCH_MOVE;
          case 2: return TOUCH_END;
          default: return null;
        }
      }

      public static com.google.protobuf.Internal.EnumLiteMap<TouchEventType>
          internalGetValueMap() {
        return internalValueMap;
      }
      private static final com.google.protobuf.Internal.EnumLiteMap<
          TouchEventType> internalValueMap =
            new com.google.protobuf.Internal.EnumLiteMap<TouchEventType>() {
              public TouchEventType findValueByNumber(int number) {
                return TouchEventType.forNumber(number);
              }
            };

      public final com.google.protobuf.Descriptors.EnumValueDescriptor
          getValueDescriptor() {
        return getDescriptor().getValues().get(ordinal());
      }
      public final com.google.protobuf.Descriptors.EnumDescriptor
          getDescriptorForType() {
        return getDescriptor();
      }
      public static final com.google.protobuf.Descriptors.EnumDescriptor
          getDescriptor() {
        return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDescriptor().getEnumTypes().get(0);
      }

      private static final TouchEventType[] VALUES = values();

      public static TouchEventType valueOf(
          com.google.protobuf.Descriptors.EnumValueDescriptor desc) {
        if (desc.getType() != getDescriptor()) {
          throw new java.lang.IllegalArgumentException(
            "EnumValueDescriptor is not for this type.");
        }
        if (desc.getIndex() == -1) {
          return UNRECOGNIZED;
        }
        return VALUES[desc.getIndex()];
      }

      private final int value;

      private TouchEventType(int value) {
        this.value = value;
      }

      // @@protoc_insertion_point(enum_scope:ubii.dataStructure.TouchEvent.TouchEventType)
    }

    public static final int TYPE_FIELD_NUMBER = 1;
    private int type_;
    /**
     * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
     */
    public int getTypeValue() {
      return type_;
    }
    /**
     * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType getType() {
      @SuppressWarnings("deprecation")
      ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType result = ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType.valueOf(type_);
      return result == null ? ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType.UNRECOGNIZED : result;
    }

    public static final int POSITION_FIELD_NUMBER = 2;
    private ubii.dataStructure.Vector2OuterClass.Vector2 position_;
    /**
     * <code>.ubii.dataStructure.Vector2 position = 2;</code>
     */
    public boolean hasPosition() {
      return position_ != null;
    }
    /**
     * <code>.ubii.dataStructure.Vector2 position = 2;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2 getPosition() {
      return position_ == null ? ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance() : position_;
    }
    /**
     * <code>.ubii.dataStructure.Vector2 position = 2;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getPositionOrBuilder() {
      return getPosition();
    }

    public static final int ID_FIELD_NUMBER = 3;
    private volatile java.lang.Object id_;
    /**
     * <code>string id = 3;</code>
     */
    public java.lang.String getId() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        id_ = s;
        return s;
      }
    }
    /**
     * <code>string id = 3;</code>
     */
    public com.google.protobuf.ByteString
        getIdBytes() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        id_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int FORCE_FIELD_NUMBER = 4;
    private float force_;
    /**
     * <code>float force = 4;</code>
     */
    public float getForce() {
      return force_;
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (type_ != ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType.TOUCH_START.getNumber()) {
        output.writeEnum(1, type_);
      }
      if (position_ != null) {
        output.writeMessage(2, getPosition());
      }
      if (!getIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 3, id_);
      }
      if (force_ != 0F) {
        output.writeFloat(4, force_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (type_ != ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType.TOUCH_START.getNumber()) {
        size += com.google.protobuf.CodedOutputStream
          .computeEnumSize(1, type_);
      }
      if (position_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, getPosition());
      }
      if (!getIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(3, id_);
      }
      if (force_ != 0F) {
        size += com.google.protobuf.CodedOutputStream
          .computeFloatSize(4, force_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.TouchEventOuterClass.TouchEvent)) {
        return super.equals(obj);
      }
      ubii.dataStructure.TouchEventOuterClass.TouchEvent other = (ubii.dataStructure.TouchEventOuterClass.TouchEvent) obj;

      boolean result = true;
      result = result && type_ == other.type_;
      result = result && (hasPosition() == other.hasPosition());
      if (hasPosition()) {
        result = result && getPosition()
            .equals(other.getPosition());
      }
      result = result && getId()
          .equals(other.getId());
      result = result && (
          java.lang.Float.floatToIntBits(getForce())
          == java.lang.Float.floatToIntBits(
              other.getForce()));
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + TYPE_FIELD_NUMBER;
      hash = (53 * hash) + type_;
      if (hasPosition()) {
        hash = (37 * hash) + POSITION_FIELD_NUMBER;
        hash = (53 * hash) + getPosition().hashCode();
      }
      hash = (37 * hash) + ID_FIELD_NUMBER;
      hash = (53 * hash) + getId().hashCode();
      hash = (37 * hash) + FORCE_FIELD_NUMBER;
      hash = (53 * hash) + java.lang.Float.floatToIntBits(
          getForce());
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.TouchEventOuterClass.TouchEvent prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.TouchEvent}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.TouchEvent)
        ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEvent_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEvent_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.TouchEventOuterClass.TouchEvent.class, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder.class);
      }

      // Construct using ubii.dataStructure.TouchEventOuterClass.TouchEvent.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        type_ = 0;

        if (positionBuilder_ == null) {
          position_ = null;
        } else {
          position_ = null;
          positionBuilder_ = null;
        }
        id_ = "";

        force_ = 0F;

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEvent_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent getDefaultInstanceForType() {
        return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent build() {
        ubii.dataStructure.TouchEventOuterClass.TouchEvent result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent buildPartial() {
        ubii.dataStructure.TouchEventOuterClass.TouchEvent result = new ubii.dataStructure.TouchEventOuterClass.TouchEvent(this);
        result.type_ = type_;
        if (positionBuilder_ == null) {
          result.position_ = position_;
        } else {
          result.position_ = positionBuilder_.build();
        }
        result.id_ = id_;
        result.force_ = force_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.TouchEventOuterClass.TouchEvent) {
          return mergeFrom((ubii.dataStructure.TouchEventOuterClass.TouchEvent)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.TouchEventOuterClass.TouchEvent other) {
        if (other == ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance()) return this;
        if (other.type_ != 0) {
          setTypeValue(other.getTypeValue());
        }
        if (other.hasPosition()) {
          mergePosition(other.getPosition());
        }
        if (!other.getId().isEmpty()) {
          id_ = other.id_;
          onChanged();
        }
        if (other.getForce() != 0F) {
          setForce(other.getForce());
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.TouchEventOuterClass.TouchEvent parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.TouchEventOuterClass.TouchEvent) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private int type_ = 0;
      /**
       * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
       */
      public int getTypeValue() {
        return type_;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
       */
      public Builder setTypeValue(int value) {
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType getType() {
        @SuppressWarnings("deprecation")
        ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType result = ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType.valueOf(type_);
        return result == null ? ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType.UNRECOGNIZED : result;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
       */
      public Builder setType(ubii.dataStructure.TouchEventOuterClass.TouchEvent.TouchEventType value) {
        if (value == null) {
          throw new NullPointerException();
        }
        
        type_ = value.getNumber();
        onChanged();
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent.TouchEventType type = 1;</code>
       */
      public Builder clearType() {
        
        type_ = 0;
        onChanged();
        return this;
      }

      private ubii.dataStructure.Vector2OuterClass.Vector2 position_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> positionBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public boolean hasPosition() {
        return positionBuilder_ != null || position_ != null;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2 getPosition() {
        if (positionBuilder_ == null) {
          return position_ == null ? ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance() : position_;
        } else {
          return positionBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public Builder setPosition(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (positionBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          position_ = value;
          onChanged();
        } else {
          positionBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public Builder setPosition(
          ubii.dataStructure.Vector2OuterClass.Vector2.Builder builderForValue) {
        if (positionBuilder_ == null) {
          position_ = builderForValue.build();
          onChanged();
        } else {
          positionBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public Builder mergePosition(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (positionBuilder_ == null) {
          if (position_ != null) {
            position_ =
              ubii.dataStructure.Vector2OuterClass.Vector2.newBuilder(position_).mergeFrom(value).buildPartial();
          } else {
            position_ = value;
          }
          onChanged();
        } else {
          positionBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public Builder clearPosition() {
        if (positionBuilder_ == null) {
          position_ = null;
          onChanged();
        } else {
          position_ = null;
          positionBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2.Builder getPositionBuilder() {
        
        onChanged();
        return getPositionFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getPositionOrBuilder() {
        if (positionBuilder_ != null) {
          return positionBuilder_.getMessageOrBuilder();
        } else {
          return position_ == null ?
              ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance() : position_;
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 position = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> 
          getPositionFieldBuilder() {
        if (positionBuilder_ == null) {
          positionBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder>(
                  getPosition(),
                  getParentForChildren(),
                  isClean());
          position_ = null;
        }
        return positionBuilder_;
      }

      private java.lang.Object id_ = "";
      /**
       * <code>string id = 3;</code>
       */
      public java.lang.String getId() {
        java.lang.Object ref = id_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          id_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string id = 3;</code>
       */
      public com.google.protobuf.ByteString
          getIdBytes() {
        java.lang.Object ref = id_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          id_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string id = 3;</code>
       */
      public Builder setId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        id_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string id = 3;</code>
       */
      public Builder clearId() {
        
        id_ = getDefaultInstance().getId();
        onChanged();
        return this;
      }
      /**
       * <code>string id = 3;</code>
       */
      public Builder setIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        id_ = value;
        onChanged();
        return this;
      }

      private float force_ ;
      /**
       * <code>float force = 4;</code>
       */
      public float getForce() {
        return force_;
      }
      /**
       * <code>float force = 4;</code>
       */
      public Builder setForce(float value) {
        
        force_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>float force = 4;</code>
       */
      public Builder clearForce() {
        
        force_ = 0F;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.TouchEvent)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.TouchEvent)
    private static final ubii.dataStructure.TouchEventOuterClass.TouchEvent DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.TouchEventOuterClass.TouchEvent();
    }

    public static ubii.dataStructure.TouchEventOuterClass.TouchEvent getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TouchEvent>
        PARSER = new com.google.protobuf.AbstractParser<TouchEvent>() {
      @java.lang.Override
      public TouchEvent parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TouchEvent(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TouchEvent> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TouchEvent> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.TouchEventOuterClass.TouchEvent getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface TouchEventListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.dataStructure.TouchEventList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    java.util.List<ubii.dataStructure.TouchEventOuterClass.TouchEvent> 
        getElementsList();
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEvent getElements(int index);
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    java.util.List<? extends ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.dataStructure.TouchEventList}
   */
  public  static final class TouchEventList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.dataStructure.TouchEventList)
      TouchEventListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TouchEventList.newBuilder() to construct.
    private TouchEventList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TouchEventList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TouchEventList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.dataStructure.TouchEventOuterClass.TouchEvent>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.dataStructure.TouchEventOuterClass.TouchEvent.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEventList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEventList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.dataStructure.TouchEventOuterClass.TouchEventList.class, ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.dataStructure.TouchEventOuterClass.TouchEvent> elements_;
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    public java.util.List<ubii.dataStructure.TouchEventOuterClass.TouchEvent> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    public java.util.List<? extends ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEvent getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.dataStructure.TouchEventOuterClass.TouchEventList)) {
        return super.equals(obj);
      }
      ubii.dataStructure.TouchEventOuterClass.TouchEventList other = (ubii.dataStructure.TouchEventOuterClass.TouchEventList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.dataStructure.TouchEventOuterClass.TouchEventList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.dataStructure.TouchEventList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.dataStructure.TouchEventList)
        ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEventList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEventList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.dataStructure.TouchEventOuterClass.TouchEventList.class, ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder.class);
      }

      // Construct using ubii.dataStructure.TouchEventOuterClass.TouchEventList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.dataStructure.TouchEventOuterClass.internal_static_ubii_dataStructure_TouchEventList_descriptor;
      }

      @java.lang.Override
      public ubii.dataStructure.TouchEventOuterClass.TouchEventList getDefaultInstanceForType() {
        return ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.dataStructure.TouchEventOuterClass.TouchEventList build() {
        ubii.dataStructure.TouchEventOuterClass.TouchEventList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.dataStructure.TouchEventOuterClass.TouchEventList buildPartial() {
        ubii.dataStructure.TouchEventOuterClass.TouchEventList result = new ubii.dataStructure.TouchEventOuterClass.TouchEventList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.dataStructure.TouchEventOuterClass.TouchEventList) {
          return mergeFrom((ubii.dataStructure.TouchEventOuterClass.TouchEventList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.dataStructure.TouchEventOuterClass.TouchEventList other) {
        if (other == ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.dataStructure.TouchEventOuterClass.TouchEventList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.dataStructure.TouchEventOuterClass.TouchEventList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.dataStructure.TouchEventOuterClass.TouchEvent> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.dataStructure.TouchEventOuterClass.TouchEvent>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.dataStructure.TouchEventOuterClass.TouchEvent, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public java.util.List<ubii.dataStructure.TouchEventOuterClass.TouchEvent> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.dataStructure.TouchEventOuterClass.TouchEvent value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder addElements(ubii.dataStructure.TouchEventOuterClass.TouchEvent value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.dataStructure.TouchEventOuterClass.TouchEvent value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder addElements(
          ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.dataStructure.TouchEventOuterClass.TouchEvent> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public java.util.List<? extends ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.dataStructure.TouchEvent elements = 1;</code>
       */
      public java.util.List<ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.dataStructure.TouchEventOuterClass.TouchEvent, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.dataStructure.TouchEventOuterClass.TouchEvent, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.dataStructure.TouchEventList)
    }

    // @@protoc_insertion_point(class_scope:ubii.dataStructure.TouchEventList)
    private static final ubii.dataStructure.TouchEventOuterClass.TouchEventList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.dataStructure.TouchEventOuterClass.TouchEventList();
    }

    public static ubii.dataStructure.TouchEventOuterClass.TouchEventList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TouchEventList>
        PARSER = new com.google.protobuf.AbstractParser<TouchEventList>() {
      @java.lang.Override
      public TouchEventList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TouchEventList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TouchEventList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TouchEventList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.dataStructure.TouchEventOuterClass.TouchEventList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_TouchEvent_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_TouchEvent_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_dataStructure_TouchEventList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_dataStructure_TouchEventList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n>proto/topicData/topicDataRecord/dataSt" +
      "ructure/touchEvent.proto\022\022ubii.dataStruc" +
      "ture\032Cproto/topicData/topicDataRecord/da" +
      "taStructure/buttonEventType.proto\032;proto" +
      "/topicData/topicDataRecord/dataStructure" +
      "/vector2.proto\"\325\001\n\nTouchEvent\022;\n\004type\030\001 " +
      "\001(\0162-.ubii.dataStructure.TouchEvent.Touc" +
      "hEventType\022-\n\010position\030\002 \001(\0132\033.ubii.data" +
      "Structure.Vector2\022\n\n\002id\030\003 \001(\t\022\r\n\005force\030\004" +
      " \001(\002\"@\n\016TouchEventType\022\017\n\013TOUCH_START\020\000\022" +
      "\016\n\nTOUCH_MOVE\020\001\022\r\n\tTOUCH_END\020\002\"B\n\016TouchE" +
      "ventList\0220\n\010elements\030\001 \003(\0132\036.ubii.dataSt" +
      "ructure.TouchEventb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.dataStructure.ButtonEventTypeOuterClass.getDescriptor(),
          ubii.dataStructure.Vector2OuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_dataStructure_TouchEvent_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_dataStructure_TouchEvent_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_TouchEvent_descriptor,
        new java.lang.String[] { "Type", "Position", "Id", "Force", });
    internal_static_ubii_dataStructure_TouchEventList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_dataStructure_TouchEventList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_dataStructure_TouchEventList_descriptor,
        new java.lang.String[] { "Elements", });
    ubii.dataStructure.ButtonEventTypeOuterClass.getDescriptor();
    ubii.dataStructure.Vector2OuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
