syntax = "proto3";
package ubii.proto_v2.types.devices;

import "ubii/proto_v2/types/devices/component.proto";

message Device {
    string id = 1;
    string name = 2;
    enum DeviceType {
        PARTICIPANT = 0;
        WATCHER = 1;
    }
    ubii.proto_v2.types.devices.Device.DeviceType device_type = 3;
    repeated ubii.proto_v2.types.devices.Component components = 4;
    string client_id = 5;
    repeated string tags = 6;
    string description = 7;
}

message DeviceList {
    repeated ubii.proto_v2.types.devices.Device elements = 1;
}
