# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/devices/component.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/devices/component.proto',
  package='ubii.proto_v2.types.devices',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+ubii/proto_v2/types/devices/component.proto\x12\x1bubii.proto_v2.types.devices\"\xeb\x01\n\tComponent\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\x12>\n\x07io_type\x18\x03 \x01(\x0e\x32-.ubii.proto_v2.types.devices.Component.IOType\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\"\'\n\x06IOType\x12\r\n\tPUBLISHER\x10\x00\x12\x0e\n\nSUBSCRIBER\x10\x01\"I\n\rComponentList\x12\x38\n\x08\x65lements\x18\x01 \x03(\x0b\x32&.ubii.proto_v2.types.devices.Componentb\x06proto3'
)



_COMPONENT_IOTYPE = _descriptor.EnumDescriptor(
  name='IOType',
  full_name='ubii.proto_v2.types.devices.Component.IOType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLISHER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUBSCRIBER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=273,
  serialized_end=312,
)
_sym_db.RegisterEnumDescriptor(_COMPONENT_IOTYPE)


_COMPONENT = _descriptor.Descriptor(
  name='Component',
  full_name='ubii.proto_v2.types.devices.Component',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.devices.Component.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_format', full_name='ubii.proto_v2.types.devices.Component.message_format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_type', full_name='ubii.proto_v2.types.devices.Component.io_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='ubii.proto_v2.types.devices.Component.device_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.devices.Component.tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.devices.Component.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.devices.Component.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.devices.Component.name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPONENT_IOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=312,
)


_COMPONENTLIST = _descriptor.Descriptor(
  name='ComponentList',
  full_name='ubii.proto_v2.types.devices.ComponentList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.devices.ComponentList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=387,
)

_COMPONENT.fields_by_name['io_type'].enum_type = _COMPONENT_IOTYPE
_COMPONENT_IOTYPE.containing_type = _COMPONENT
_COMPONENTLIST.fields_by_name['elements'].message_type = _COMPONENT
DESCRIPTOR.message_types_by_name['Component'] = _COMPONENT
DESCRIPTOR.message_types_by_name['ComponentList'] = _COMPONENTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT,
  '__module__' : 'ubii.proto_v2.types.devices.component_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.Component)
  })
_sym_db.RegisterMessage(Component)

ComponentList = _reflection.GeneratedProtocolMessageType('ComponentList', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTLIST,
  '__module__' : 'ubii.proto_v2.types.devices.component_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.ComponentList)
  })
_sym_db.RegisterMessage(ComponentList)


# @@protoc_insertion_point(module_scope)
