// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/servers/server.proto

package ubii.servers;

public final class ServerOuterClass {
  private ServerOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface ServerOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.servers.Server)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string id = 1;</code>
     */
    java.lang.String getId();
    /**
     * <code>string id = 1;</code>
     */
    com.google.protobuf.ByteString
        getIdBytes();

    /**
     * <code>string name = 2;</code>
     */
    java.lang.String getName();
    /**
     * <code>string name = 2;</code>
     */
    com.google.protobuf.ByteString
        getNameBytes();

    /**
     * <code>string ip_ethernet = 3;</code>
     */
    java.lang.String getIpEthernet();
    /**
     * <code>string ip_ethernet = 3;</code>
     */
    com.google.protobuf.ByteString
        getIpEthernetBytes();

    /**
     * <code>string ip_wlan = 4;</code>
     */
    java.lang.String getIpWlan();
    /**
     * <code>string ip_wlan = 4;</code>
     */
    com.google.protobuf.ByteString
        getIpWlanBytes();

    /**
     * <code>string port_service_zmq = 5;</code>
     */
    java.lang.String getPortServiceZmq();
    /**
     * <code>string port_service_zmq = 5;</code>
     */
    com.google.protobuf.ByteString
        getPortServiceZmqBytes();

    /**
     * <code>string port_service_rest = 6;</code>
     */
    java.lang.String getPortServiceRest();
    /**
     * <code>string port_service_rest = 6;</code>
     */
    com.google.protobuf.ByteString
        getPortServiceRestBytes();

    /**
     * <code>string port_topic_data_zmq = 7;</code>
     */
    java.lang.String getPortTopicDataZmq();
    /**
     * <code>string port_topic_data_zmq = 7;</code>
     */
    com.google.protobuf.ByteString
        getPortTopicDataZmqBytes();

    /**
     * <code>string port_topic_data_ws = 8;</code>
     */
    java.lang.String getPortTopicDataWs();
    /**
     * <code>string port_topic_data_ws = 8;</code>
     */
    com.google.protobuf.ByteString
        getPortTopicDataWsBytes();

    /**
     * <code>string constants_json = 9;</code>
     */
    java.lang.String getConstantsJson();
    /**
     * <code>string constants_json = 9;</code>
     */
    com.google.protobuf.ByteString
        getConstantsJsonBytes();
  }
  /**
   * Protobuf type {@code ubii.servers.Server}
   */
  public  static final class Server extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.servers.Server)
      ServerOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use Server.newBuilder() to construct.
    private Server(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private Server() {
      id_ = "";
      name_ = "";
      ipEthernet_ = "";
      ipWlan_ = "";
      portServiceZmq_ = "";
      portServiceRest_ = "";
      portTopicDataZmq_ = "";
      portTopicDataWs_ = "";
      constantsJson_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private Server(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              id_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();

              name_ = s;
              break;
            }
            case 26: {
              java.lang.String s = input.readStringRequireUtf8();

              ipEthernet_ = s;
              break;
            }
            case 34: {
              java.lang.String s = input.readStringRequireUtf8();

              ipWlan_ = s;
              break;
            }
            case 42: {
              java.lang.String s = input.readStringRequireUtf8();

              portServiceZmq_ = s;
              break;
            }
            case 50: {
              java.lang.String s = input.readStringRequireUtf8();

              portServiceRest_ = s;
              break;
            }
            case 58: {
              java.lang.String s = input.readStringRequireUtf8();

              portTopicDataZmq_ = s;
              break;
            }
            case 66: {
              java.lang.String s = input.readStringRequireUtf8();

              portTopicDataWs_ = s;
              break;
            }
            case 74: {
              java.lang.String s = input.readStringRequireUtf8();

              constantsJson_ = s;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.servers.ServerOuterClass.internal_static_ubii_servers_Server_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.servers.ServerOuterClass.internal_static_ubii_servers_Server_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.servers.ServerOuterClass.Server.class, ubii.servers.ServerOuterClass.Server.Builder.class);
    }

    public static final int ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object id_;
    /**
     * <code>string id = 1;</code>
     */
    public java.lang.String getId() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        id_ = s;
        return s;
      }
    }
    /**
     * <code>string id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getIdBytes() {
      java.lang.Object ref = id_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        id_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int NAME_FIELD_NUMBER = 2;
    private volatile java.lang.Object name_;
    /**
     * <code>string name = 2;</code>
     */
    public java.lang.String getName() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        name_ = s;
        return s;
      }
    }
    /**
     * <code>string name = 2;</code>
     */
    public com.google.protobuf.ByteString
        getNameBytes() {
      java.lang.Object ref = name_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        name_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int IP_ETHERNET_FIELD_NUMBER = 3;
    private volatile java.lang.Object ipEthernet_;
    /**
     * <code>string ip_ethernet = 3;</code>
     */
    public java.lang.String getIpEthernet() {
      java.lang.Object ref = ipEthernet_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        ipEthernet_ = s;
        return s;
      }
    }
    /**
     * <code>string ip_ethernet = 3;</code>
     */
    public com.google.protobuf.ByteString
        getIpEthernetBytes() {
      java.lang.Object ref = ipEthernet_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        ipEthernet_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int IP_WLAN_FIELD_NUMBER = 4;
    private volatile java.lang.Object ipWlan_;
    /**
     * <code>string ip_wlan = 4;</code>
     */
    public java.lang.String getIpWlan() {
      java.lang.Object ref = ipWlan_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        ipWlan_ = s;
        return s;
      }
    }
    /**
     * <code>string ip_wlan = 4;</code>
     */
    public com.google.protobuf.ByteString
        getIpWlanBytes() {
      java.lang.Object ref = ipWlan_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        ipWlan_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int PORT_SERVICE_ZMQ_FIELD_NUMBER = 5;
    private volatile java.lang.Object portServiceZmq_;
    /**
     * <code>string port_service_zmq = 5;</code>
     */
    public java.lang.String getPortServiceZmq() {
      java.lang.Object ref = portServiceZmq_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        portServiceZmq_ = s;
        return s;
      }
    }
    /**
     * <code>string port_service_zmq = 5;</code>
     */
    public com.google.protobuf.ByteString
        getPortServiceZmqBytes() {
      java.lang.Object ref = portServiceZmq_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        portServiceZmq_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int PORT_SERVICE_REST_FIELD_NUMBER = 6;
    private volatile java.lang.Object portServiceRest_;
    /**
     * <code>string port_service_rest = 6;</code>
     */
    public java.lang.String getPortServiceRest() {
      java.lang.Object ref = portServiceRest_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        portServiceRest_ = s;
        return s;
      }
    }
    /**
     * <code>string port_service_rest = 6;</code>
     */
    public com.google.protobuf.ByteString
        getPortServiceRestBytes() {
      java.lang.Object ref = portServiceRest_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        portServiceRest_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int PORT_TOPIC_DATA_ZMQ_FIELD_NUMBER = 7;
    private volatile java.lang.Object portTopicDataZmq_;
    /**
     * <code>string port_topic_data_zmq = 7;</code>
     */
    public java.lang.String getPortTopicDataZmq() {
      java.lang.Object ref = portTopicDataZmq_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        portTopicDataZmq_ = s;
        return s;
      }
    }
    /**
     * <code>string port_topic_data_zmq = 7;</code>
     */
    public com.google.protobuf.ByteString
        getPortTopicDataZmqBytes() {
      java.lang.Object ref = portTopicDataZmq_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        portTopicDataZmq_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int PORT_TOPIC_DATA_WS_FIELD_NUMBER = 8;
    private volatile java.lang.Object portTopicDataWs_;
    /**
     * <code>string port_topic_data_ws = 8;</code>
     */
    public java.lang.String getPortTopicDataWs() {
      java.lang.Object ref = portTopicDataWs_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        portTopicDataWs_ = s;
        return s;
      }
    }
    /**
     * <code>string port_topic_data_ws = 8;</code>
     */
    public com.google.protobuf.ByteString
        getPortTopicDataWsBytes() {
      java.lang.Object ref = portTopicDataWs_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        portTopicDataWs_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int CONSTANTS_JSON_FIELD_NUMBER = 9;
    private volatile java.lang.Object constantsJson_;
    /**
     * <code>string constants_json = 9;</code>
     */
    public java.lang.String getConstantsJson() {
      java.lang.Object ref = constantsJson_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        constantsJson_ = s;
        return s;
      }
    }
    /**
     * <code>string constants_json = 9;</code>
     */
    public com.google.protobuf.ByteString
        getConstantsJsonBytes() {
      java.lang.Object ref = constantsJson_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        constantsJson_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, name_);
      }
      if (!getIpEthernetBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 3, ipEthernet_);
      }
      if (!getIpWlanBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 4, ipWlan_);
      }
      if (!getPortServiceZmqBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 5, portServiceZmq_);
      }
      if (!getPortServiceRestBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 6, portServiceRest_);
      }
      if (!getPortTopicDataZmqBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 7, portTopicDataZmq_);
      }
      if (!getPortTopicDataWsBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 8, portTopicDataWs_);
      }
      if (!getConstantsJsonBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 9, constantsJson_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, id_);
      }
      if (!getNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(2, name_);
      }
      if (!getIpEthernetBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(3, ipEthernet_);
      }
      if (!getIpWlanBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(4, ipWlan_);
      }
      if (!getPortServiceZmqBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(5, portServiceZmq_);
      }
      if (!getPortServiceRestBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(6, portServiceRest_);
      }
      if (!getPortTopicDataZmqBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(7, portTopicDataZmq_);
      }
      if (!getPortTopicDataWsBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(8, portTopicDataWs_);
      }
      if (!getConstantsJsonBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(9, constantsJson_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.servers.ServerOuterClass.Server)) {
        return super.equals(obj);
      }
      ubii.servers.ServerOuterClass.Server other = (ubii.servers.ServerOuterClass.Server) obj;

      boolean result = true;
      result = result && getId()
          .equals(other.getId());
      result = result && getName()
          .equals(other.getName());
      result = result && getIpEthernet()
          .equals(other.getIpEthernet());
      result = result && getIpWlan()
          .equals(other.getIpWlan());
      result = result && getPortServiceZmq()
          .equals(other.getPortServiceZmq());
      result = result && getPortServiceRest()
          .equals(other.getPortServiceRest());
      result = result && getPortTopicDataZmq()
          .equals(other.getPortTopicDataZmq());
      result = result && getPortTopicDataWs()
          .equals(other.getPortTopicDataWs());
      result = result && getConstantsJson()
          .equals(other.getConstantsJson());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + ID_FIELD_NUMBER;
      hash = (53 * hash) + getId().hashCode();
      hash = (37 * hash) + NAME_FIELD_NUMBER;
      hash = (53 * hash) + getName().hashCode();
      hash = (37 * hash) + IP_ETHERNET_FIELD_NUMBER;
      hash = (53 * hash) + getIpEthernet().hashCode();
      hash = (37 * hash) + IP_WLAN_FIELD_NUMBER;
      hash = (53 * hash) + getIpWlan().hashCode();
      hash = (37 * hash) + PORT_SERVICE_ZMQ_FIELD_NUMBER;
      hash = (53 * hash) + getPortServiceZmq().hashCode();
      hash = (37 * hash) + PORT_SERVICE_REST_FIELD_NUMBER;
      hash = (53 * hash) + getPortServiceRest().hashCode();
      hash = (37 * hash) + PORT_TOPIC_DATA_ZMQ_FIELD_NUMBER;
      hash = (53 * hash) + getPortTopicDataZmq().hashCode();
      hash = (37 * hash) + PORT_TOPIC_DATA_WS_FIELD_NUMBER;
      hash = (53 * hash) + getPortTopicDataWs().hashCode();
      hash = (37 * hash) + CONSTANTS_JSON_FIELD_NUMBER;
      hash = (53 * hash) + getConstantsJson().hashCode();
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.servers.ServerOuterClass.Server parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.servers.ServerOuterClass.Server parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.servers.ServerOuterClass.Server parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.servers.ServerOuterClass.Server parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.servers.ServerOuterClass.Server prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.servers.Server}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.servers.Server)
        ubii.servers.ServerOuterClass.ServerOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.servers.ServerOuterClass.internal_static_ubii_servers_Server_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.servers.ServerOuterClass.internal_static_ubii_servers_Server_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.servers.ServerOuterClass.Server.class, ubii.servers.ServerOuterClass.Server.Builder.class);
      }

      // Construct using ubii.servers.ServerOuterClass.Server.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        id_ = "";

        name_ = "";

        ipEthernet_ = "";

        ipWlan_ = "";

        portServiceZmq_ = "";

        portServiceRest_ = "";

        portTopicDataZmq_ = "";

        portTopicDataWs_ = "";

        constantsJson_ = "";

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.servers.ServerOuterClass.internal_static_ubii_servers_Server_descriptor;
      }

      @java.lang.Override
      public ubii.servers.ServerOuterClass.Server getDefaultInstanceForType() {
        return ubii.servers.ServerOuterClass.Server.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.servers.ServerOuterClass.Server build() {
        ubii.servers.ServerOuterClass.Server result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.servers.ServerOuterClass.Server buildPartial() {
        ubii.servers.ServerOuterClass.Server result = new ubii.servers.ServerOuterClass.Server(this);
        result.id_ = id_;
        result.name_ = name_;
        result.ipEthernet_ = ipEthernet_;
        result.ipWlan_ = ipWlan_;
        result.portServiceZmq_ = portServiceZmq_;
        result.portServiceRest_ = portServiceRest_;
        result.portTopicDataZmq_ = portTopicDataZmq_;
        result.portTopicDataWs_ = portTopicDataWs_;
        result.constantsJson_ = constantsJson_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.servers.ServerOuterClass.Server) {
          return mergeFrom((ubii.servers.ServerOuterClass.Server)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.servers.ServerOuterClass.Server other) {
        if (other == ubii.servers.ServerOuterClass.Server.getDefaultInstance()) return this;
        if (!other.getId().isEmpty()) {
          id_ = other.id_;
          onChanged();
        }
        if (!other.getName().isEmpty()) {
          name_ = other.name_;
          onChanged();
        }
        if (!other.getIpEthernet().isEmpty()) {
          ipEthernet_ = other.ipEthernet_;
          onChanged();
        }
        if (!other.getIpWlan().isEmpty()) {
          ipWlan_ = other.ipWlan_;
          onChanged();
        }
        if (!other.getPortServiceZmq().isEmpty()) {
          portServiceZmq_ = other.portServiceZmq_;
          onChanged();
        }
        if (!other.getPortServiceRest().isEmpty()) {
          portServiceRest_ = other.portServiceRest_;
          onChanged();
        }
        if (!other.getPortTopicDataZmq().isEmpty()) {
          portTopicDataZmq_ = other.portTopicDataZmq_;
          onChanged();
        }
        if (!other.getPortTopicDataWs().isEmpty()) {
          portTopicDataWs_ = other.portTopicDataWs_;
          onChanged();
        }
        if (!other.getConstantsJson().isEmpty()) {
          constantsJson_ = other.constantsJson_;
          onChanged();
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.servers.ServerOuterClass.Server parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.servers.ServerOuterClass.Server) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }

      private java.lang.Object id_ = "";
      /**
       * <code>string id = 1;</code>
       */
      public java.lang.String getId() {
        java.lang.Object ref = id_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          id_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getIdBytes() {
        java.lang.Object ref = id_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          id_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        id_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder clearId() {
        
        id_ = getDefaultInstance().getId();
        onChanged();
        return this;
      }
      /**
       * <code>string id = 1;</code>
       */
      public Builder setIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        id_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object name_ = "";
      /**
       * <code>string name = 2;</code>
       */
      public java.lang.String getName() {
        java.lang.Object ref = name_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          name_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public com.google.protobuf.ByteString
          getNameBytes() {
        java.lang.Object ref = name_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          name_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        name_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder clearName() {
        
        name_ = getDefaultInstance().getName();
        onChanged();
        return this;
      }
      /**
       * <code>string name = 2;</code>
       */
      public Builder setNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        name_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object ipEthernet_ = "";
      /**
       * <code>string ip_ethernet = 3;</code>
       */
      public java.lang.String getIpEthernet() {
        java.lang.Object ref = ipEthernet_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          ipEthernet_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string ip_ethernet = 3;</code>
       */
      public com.google.protobuf.ByteString
          getIpEthernetBytes() {
        java.lang.Object ref = ipEthernet_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          ipEthernet_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string ip_ethernet = 3;</code>
       */
      public Builder setIpEthernet(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        ipEthernet_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string ip_ethernet = 3;</code>
       */
      public Builder clearIpEthernet() {
        
        ipEthernet_ = getDefaultInstance().getIpEthernet();
        onChanged();
        return this;
      }
      /**
       * <code>string ip_ethernet = 3;</code>
       */
      public Builder setIpEthernetBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        ipEthernet_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object ipWlan_ = "";
      /**
       * <code>string ip_wlan = 4;</code>
       */
      public java.lang.String getIpWlan() {
        java.lang.Object ref = ipWlan_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          ipWlan_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string ip_wlan = 4;</code>
       */
      public com.google.protobuf.ByteString
          getIpWlanBytes() {
        java.lang.Object ref = ipWlan_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          ipWlan_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string ip_wlan = 4;</code>
       */
      public Builder setIpWlan(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        ipWlan_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string ip_wlan = 4;</code>
       */
      public Builder clearIpWlan() {
        
        ipWlan_ = getDefaultInstance().getIpWlan();
        onChanged();
        return this;
      }
      /**
       * <code>string ip_wlan = 4;</code>
       */
      public Builder setIpWlanBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        ipWlan_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object portServiceZmq_ = "";
      /**
       * <code>string port_service_zmq = 5;</code>
       */
      public java.lang.String getPortServiceZmq() {
        java.lang.Object ref = portServiceZmq_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          portServiceZmq_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string port_service_zmq = 5;</code>
       */
      public com.google.protobuf.ByteString
          getPortServiceZmqBytes() {
        java.lang.Object ref = portServiceZmq_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          portServiceZmq_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string port_service_zmq = 5;</code>
       */
      public Builder setPortServiceZmq(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        portServiceZmq_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string port_service_zmq = 5;</code>
       */
      public Builder clearPortServiceZmq() {
        
        portServiceZmq_ = getDefaultInstance().getPortServiceZmq();
        onChanged();
        return this;
      }
      /**
       * <code>string port_service_zmq = 5;</code>
       */
      public Builder setPortServiceZmqBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        portServiceZmq_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object portServiceRest_ = "";
      /**
       * <code>string port_service_rest = 6;</code>
       */
      public java.lang.String getPortServiceRest() {
        java.lang.Object ref = portServiceRest_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          portServiceRest_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string port_service_rest = 6;</code>
       */
      public com.google.protobuf.ByteString
          getPortServiceRestBytes() {
        java.lang.Object ref = portServiceRest_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          portServiceRest_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string port_service_rest = 6;</code>
       */
      public Builder setPortServiceRest(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        portServiceRest_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string port_service_rest = 6;</code>
       */
      public Builder clearPortServiceRest() {
        
        portServiceRest_ = getDefaultInstance().getPortServiceRest();
        onChanged();
        return this;
      }
      /**
       * <code>string port_service_rest = 6;</code>
       */
      public Builder setPortServiceRestBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        portServiceRest_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object portTopicDataZmq_ = "";
      /**
       * <code>string port_topic_data_zmq = 7;</code>
       */
      public java.lang.String getPortTopicDataZmq() {
        java.lang.Object ref = portTopicDataZmq_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          portTopicDataZmq_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string port_topic_data_zmq = 7;</code>
       */
      public com.google.protobuf.ByteString
          getPortTopicDataZmqBytes() {
        java.lang.Object ref = portTopicDataZmq_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          portTopicDataZmq_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string port_topic_data_zmq = 7;</code>
       */
      public Builder setPortTopicDataZmq(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        portTopicDataZmq_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string port_topic_data_zmq = 7;</code>
       */
      public Builder clearPortTopicDataZmq() {
        
        portTopicDataZmq_ = getDefaultInstance().getPortTopicDataZmq();
        onChanged();
        return this;
      }
      /**
       * <code>string port_topic_data_zmq = 7;</code>
       */
      public Builder setPortTopicDataZmqBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        portTopicDataZmq_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object portTopicDataWs_ = "";
      /**
       * <code>string port_topic_data_ws = 8;</code>
       */
      public java.lang.String getPortTopicDataWs() {
        java.lang.Object ref = portTopicDataWs_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          portTopicDataWs_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string port_topic_data_ws = 8;</code>
       */
      public com.google.protobuf.ByteString
          getPortTopicDataWsBytes() {
        java.lang.Object ref = portTopicDataWs_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          portTopicDataWs_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string port_topic_data_ws = 8;</code>
       */
      public Builder setPortTopicDataWs(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        portTopicDataWs_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string port_topic_data_ws = 8;</code>
       */
      public Builder clearPortTopicDataWs() {
        
        portTopicDataWs_ = getDefaultInstance().getPortTopicDataWs();
        onChanged();
        return this;
      }
      /**
       * <code>string port_topic_data_ws = 8;</code>
       */
      public Builder setPortTopicDataWsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        portTopicDataWs_ = value;
        onChanged();
        return this;
      }

      private java.lang.Object constantsJson_ = "";
      /**
       * <code>string constants_json = 9;</code>
       */
      public java.lang.String getConstantsJson() {
        java.lang.Object ref = constantsJson_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          constantsJson_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string constants_json = 9;</code>
       */
      public com.google.protobuf.ByteString
          getConstantsJsonBytes() {
        java.lang.Object ref = constantsJson_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          constantsJson_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string constants_json = 9;</code>
       */
      public Builder setConstantsJson(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        constantsJson_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string constants_json = 9;</code>
       */
      public Builder clearConstantsJson() {
        
        constantsJson_ = getDefaultInstance().getConstantsJson();
        onChanged();
        return this;
      }
      /**
       * <code>string constants_json = 9;</code>
       */
      public Builder setConstantsJsonBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        constantsJson_ = value;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.servers.Server)
    }

    // @@protoc_insertion_point(class_scope:ubii.servers.Server)
    private static final ubii.servers.ServerOuterClass.Server DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.servers.ServerOuterClass.Server();
    }

    public static ubii.servers.ServerOuterClass.Server getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<Server>
        PARSER = new com.google.protobuf.AbstractParser<Server>() {
      @java.lang.Override
      public Server parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new Server(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<Server> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<Server> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.servers.ServerOuterClass.Server getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_servers_Server_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_servers_Server_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n\032proto/servers/server.proto\022\014ubii.serve" +
      "rs\"\316\001\n\006Server\022\n\n\002id\030\001 \001(\t\022\014\n\004name\030\002 \001(\t\022" +
      "\023\n\013ip_ethernet\030\003 \001(\t\022\017\n\007ip_wlan\030\004 \001(\t\022\030\n" +
      "\020port_service_zmq\030\005 \001(\t\022\031\n\021port_service_" +
      "rest\030\006 \001(\t\022\033\n\023port_topic_data_zmq\030\007 \001(\t\022" +
      "\032\n\022port_topic_data_ws\030\010 \001(\t\022\026\n\016constants" +
      "_json\030\t \001(\tb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
        }, assigner);
    internal_static_ubii_servers_Server_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_servers_Server_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_servers_Server_descriptor,
        new java.lang.String[] { "Id", "Name", "IpEthernet", "IpWlan", "PortServiceZmq", "PortServiceRest", "PortTopicDataZmq", "PortTopicDataWs", "ConstantsJson", });
  }

  // @@protoc_insertion_point(outer_class_scope)
}
