syntax = "proto3";
package ubii.proto_v2.types.general;

message Error {
    string title = 1;
    string message = 2;
    string stack = 3;
}

message ErrorList {
    repeated ubii.proto_v2.types.general.Error elements = 1;
}