"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
)

from ubii.proto_v1.types.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
    TopicDataRecordList,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicData",
    }
)


class TopicData(Message):
    topic_data_record = Field(
        TopicDataRecord,
        number=2,
        oneof='type',
    )
    topic_data_record_list = Field(
        TopicDataRecordList,
        number=3,
        oneof='type',
    )
    error = Field(
        Error,
        number=4,
        oneof='type',
    )


