"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Enum,
    FLOAT,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TouchEvent",
        "TouchEventList",
    }
)


class TouchEvent(Message):
    class TouchEventType(Enum):
        TOUCH_START = 0
        TOUCH_MOVE = 1
        TOUCH_END = 2


    type = Field(
        TouchEventType,
        number=1,
    )
    position = Field(
        Vector2,
        number=2,
    )
    id = Field(
        STRING,
        number=3,
    )
    force = Field(
        FLOAT,
        number=4,
    )



class TouchEventList(Message):
    elements = RepeatedField(
        TouchEvent,
        number=1,
    )


