# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/sessions/ioMappings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.devices import topicMux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2
from ubii.proto_v2.types.devices import topicDemux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/sessions/ioMappings.proto',
  package='ubii.proto_v2.types.sessions',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/sessions/ioMappings.proto\x12\x1cubii.proto_v2.types.sessions\x1a*ubii/proto_v2/types/devices/topicMux.proto\x1a,ubii/proto_v2/types/devices/topicDemux.proto\"\x84\x01\n\x11TopicInputMapping\x12\x12\n\ninput_name\x18\x01 \x01(\t\x12\x0f\n\x05topic\x18\x02 \x01(\tH\x00\x12:\n\ttopic_mux\x18\x03 \x01(\x0b\x32%.ubii.proto_v2.types.devices.TopicMuxH\x00\x42\x0e\n\x0ctopic_source\"Z\n\x15TopicInputMappingList\x12\x41\n\x08\x65lements\x18\x01 \x03(\x0b\x32/.ubii.proto_v2.types.sessions.TopicInputMapping\"\x8f\x01\n\x12TopicOutputMapping\x12\x13\n\x0boutput_name\x18\x01 \x01(\t\x12\x0f\n\x05topic\x18\x02 \x01(\tH\x00\x12>\n\x0btopic_demux\x18\x03 \x01(\x0b\x32\'.ubii.proto_v2.types.devices.TopicDemuxH\x00\x42\x13\n\x11topic_destination\"\\\n\x16TopicOutputMappingList\x12\x42\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x30.ubii.proto_v2.types.sessions.TopicOutputMapping\"\xdd\x01\n\tIOMapping\x12\x1c\n\x14processing_module_id\x18\x01 \x01(\t\x12G\n\x0einput_mappings\x18\x02 \x03(\x0b\x32/.ubii.proto_v2.types.sessions.TopicInputMapping\x12I\n\x0foutput_mappings\x18\x03 \x03(\x0b\x32\x30.ubii.proto_v2.types.sessions.TopicOutputMapping\x12\x1e\n\x16processing_module_name\x18\x04 \x01(\t\"J\n\rIOMappingList\x12\x39\n\x08\x65lements\x18\x01 \x03(\x0b\x32\'.ubii.proto_v2.types.sessions.IOMappingb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2.DESCRIPTOR,])




_TOPICINPUTMAPPING = _descriptor.Descriptor(
  name='TopicInputMapping',
  full_name='ubii.proto_v2.types.sessions.TopicInputMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_name', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.input_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_mux', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.topic_mux', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='topic_source', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.topic_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=170,
  serialized_end=302,
)


_TOPICINPUTMAPPINGLIST = _descriptor.Descriptor(
  name='TopicInputMappingList',
  full_name='ubii.proto_v2.types.sessions.TopicInputMappingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.TopicInputMappingList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=394,
)


_TOPICOUTPUTMAPPING = _descriptor.Descriptor(
  name='TopicOutputMapping',
  full_name='ubii.proto_v2.types.sessions.TopicOutputMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_name', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.output_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_demux', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.topic_demux', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='topic_destination', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.topic_destination',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=397,
  serialized_end=540,
)


_TOPICOUTPUTMAPPINGLIST = _descriptor.Descriptor(
  name='TopicOutputMappingList',
  full_name='ubii.proto_v2.types.sessions.TopicOutputMappingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.TopicOutputMappingList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=542,
  serialized_end=634,
)


_IOMAPPING = _descriptor.Descriptor(
  name='IOMapping',
  full_name='ubii.proto_v2.types.sessions.IOMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_module_id', full_name='ubii.proto_v2.types.sessions.IOMapping.processing_module_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_mappings', full_name='ubii.proto_v2.types.sessions.IOMapping.input_mappings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_mappings', full_name='ubii.proto_v2.types.sessions.IOMapping.output_mappings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_module_name', full_name='ubii.proto_v2.types.sessions.IOMapping.processing_module_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=858,
)


_IOMAPPINGLIST = _descriptor.Descriptor(
  name='IOMappingList',
  full_name='ubii.proto_v2.types.sessions.IOMappingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.IOMappingList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=934,
)

_TOPICINPUTMAPPING.fields_by_name['topic_mux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2._TOPICMUX
_TOPICINPUTMAPPING.oneofs_by_name['topic_source'].fields.append(
  _TOPICINPUTMAPPING.fields_by_name['topic'])
_TOPICINPUTMAPPING.fields_by_name['topic'].containing_oneof = _TOPICINPUTMAPPING.oneofs_by_name['topic_source']
_TOPICINPUTMAPPING.oneofs_by_name['topic_source'].fields.append(
  _TOPICINPUTMAPPING.fields_by_name['topic_mux'])
_TOPICINPUTMAPPING.fields_by_name['topic_mux'].containing_oneof = _TOPICINPUTMAPPING.oneofs_by_name['topic_source']
_TOPICINPUTMAPPINGLIST.fields_by_name['elements'].message_type = _TOPICINPUTMAPPING
_TOPICOUTPUTMAPPING.fields_by_name['topic_demux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2._TOPICDEMUX
_TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination'].fields.append(
  _TOPICOUTPUTMAPPING.fields_by_name['topic'])
_TOPICOUTPUTMAPPING.fields_by_name['topic'].containing_oneof = _TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination']
_TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination'].fields.append(
  _TOPICOUTPUTMAPPING.fields_by_name['topic_demux'])
_TOPICOUTPUTMAPPING.fields_by_name['topic_demux'].containing_oneof = _TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination']
_TOPICOUTPUTMAPPINGLIST.fields_by_name['elements'].message_type = _TOPICOUTPUTMAPPING
_IOMAPPING.fields_by_name['input_mappings'].message_type = _TOPICINPUTMAPPING
_IOMAPPING.fields_by_name['output_mappings'].message_type = _TOPICOUTPUTMAPPING
_IOMAPPINGLIST.fields_by_name['elements'].message_type = _IOMAPPING
DESCRIPTOR.message_types_by_name['TopicInputMapping'] = _TOPICINPUTMAPPING
DESCRIPTOR.message_types_by_name['TopicInputMappingList'] = _TOPICINPUTMAPPINGLIST
DESCRIPTOR.message_types_by_name['TopicOutputMapping'] = _TOPICOUTPUTMAPPING
DESCRIPTOR.message_types_by_name['TopicOutputMappingList'] = _TOPICOUTPUTMAPPINGLIST
DESCRIPTOR.message_types_by_name['IOMapping'] = _IOMAPPING
DESCRIPTOR.message_types_by_name['IOMappingList'] = _IOMAPPINGLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicInputMapping = _reflection.GeneratedProtocolMessageType('TopicInputMapping', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINPUTMAPPING,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicInputMapping)
  })
_sym_db.RegisterMessage(TopicInputMapping)

TopicInputMappingList = _reflection.GeneratedProtocolMessageType('TopicInputMappingList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINPUTMAPPINGLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicInputMappingList)
  })
_sym_db.RegisterMessage(TopicInputMappingList)

TopicOutputMapping = _reflection.GeneratedProtocolMessageType('TopicOutputMapping', (_message.Message,), {
  'DESCRIPTOR' : _TOPICOUTPUTMAPPING,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicOutputMapping)
  })
_sym_db.RegisterMessage(TopicOutputMapping)

TopicOutputMappingList = _reflection.GeneratedProtocolMessageType('TopicOutputMappingList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICOUTPUTMAPPINGLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicOutputMappingList)
  })
_sym_db.RegisterMessage(TopicOutputMappingList)

IOMapping = _reflection.GeneratedProtocolMessageType('IOMapping', (_message.Message,), {
  'DESCRIPTOR' : _IOMAPPING,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.IOMapping)
  })
_sym_db.RegisterMessage(IOMapping)

IOMappingList = _reflection.GeneratedProtocolMessageType('IOMappingList', (_message.Message,), {
  'DESCRIPTOR' : _IOMAPPINGLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.IOMappingList)
  })
_sym_db.RegisterMessage(IOMappingList)


# @@protoc_insertion_point(module_scope)
