// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/services/request/topicSubscription.proto

package ubii.services.request;

public final class TopicSubscriptionOuterClass {
  private TopicSubscriptionOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface TopicSubscriptionOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.services.request.TopicSubscription)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string client_id = 1;</code>
     */
    java.lang.String getClientId();
    /**
     * <code>string client_id = 1;</code>
     */
    com.google.protobuf.ByteString
        getClientIdBytes();

    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    java.util.List<java.lang.String>
        getSubscribeTopicsList();
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    int getSubscribeTopicsCount();
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    java.lang.String getSubscribeTopics(int index);
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    com.google.protobuf.ByteString
        getSubscribeTopicsBytes(int index);

    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    java.util.List<java.lang.String>
        getUnsubscribeTopicsList();
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    int getUnsubscribeTopicsCount();
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    java.lang.String getUnsubscribeTopics(int index);
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    com.google.protobuf.ByteString
        getUnsubscribeTopicsBytes(int index);

    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    java.util.List<java.lang.String>
        getSubscribeTopicRegexpList();
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    int getSubscribeTopicRegexpCount();
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    java.lang.String getSubscribeTopicRegexp(int index);
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    com.google.protobuf.ByteString
        getSubscribeTopicRegexpBytes(int index);

    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    java.util.List<java.lang.String>
        getUnsubscribeTopicRegexpList();
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    int getUnsubscribeTopicRegexpCount();
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    java.lang.String getUnsubscribeTopicRegexp(int index);
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    com.google.protobuf.ByteString
        getUnsubscribeTopicRegexpBytes(int index);
  }
  /**
   * Protobuf type {@code ubii.services.request.TopicSubscription}
   */
  public  static final class TopicSubscription extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.services.request.TopicSubscription)
      TopicSubscriptionOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicSubscription.newBuilder() to construct.
    private TopicSubscription(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicSubscription() {
      clientId_ = "";
      subscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      unsubscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      subscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      unsubscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicSubscription(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              clientId_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
                subscribeTopics_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000002;
              }
              subscribeTopics_.add(s);
              break;
            }
            case 26: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
                unsubscribeTopics_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000004;
              }
              unsubscribeTopics_.add(s);
              break;
            }
            case 34: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000008) == 0x00000008)) {
                subscribeTopicRegexp_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000008;
              }
              subscribeTopicRegexp_.add(s);
              break;
            }
            case 42: {
              java.lang.String s = input.readStringRequireUtf8();
              if (!((mutable_bitField0_ & 0x00000010) == 0x00000010)) {
                unsubscribeTopicRegexp_ = new com.google.protobuf.LazyStringArrayList();
                mutable_bitField0_ |= 0x00000010;
              }
              unsubscribeTopicRegexp_.add(s);
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
          subscribeTopics_ = subscribeTopics_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
          unsubscribeTopics_ = unsubscribeTopics_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000008) == 0x00000008)) {
          subscribeTopicRegexp_ = subscribeTopicRegexp_.getUnmodifiableView();
        }
        if (((mutable_bitField0_ & 0x00000010) == 0x00000010)) {
          unsubscribeTopicRegexp_ = unsubscribeTopicRegexp_.getUnmodifiableView();
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.services.request.TopicSubscriptionOuterClass.internal_static_ubii_services_request_TopicSubscription_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.services.request.TopicSubscriptionOuterClass.internal_static_ubii_services_request_TopicSubscription_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.class, ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.Builder.class);
    }

    private int bitField0_;
    public static final int CLIENT_ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object clientId_;
    /**
     * <code>string client_id = 1;</code>
     */
    public java.lang.String getClientId() {
      java.lang.Object ref = clientId_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        clientId_ = s;
        return s;
      }
    }
    /**
     * <code>string client_id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getClientIdBytes() {
      java.lang.Object ref = clientId_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        clientId_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int SUBSCRIBE_TOPICS_FIELD_NUMBER = 2;
    private com.google.protobuf.LazyStringList subscribeTopics_;
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getSubscribeTopicsList() {
      return subscribeTopics_;
    }
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    public int getSubscribeTopicsCount() {
      return subscribeTopics_.size();
    }
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    public java.lang.String getSubscribeTopics(int index) {
      return subscribeTopics_.get(index);
    }
    /**
     * <code>repeated string subscribe_topics = 2;</code>
     */
    public com.google.protobuf.ByteString
        getSubscribeTopicsBytes(int index) {
      return subscribeTopics_.getByteString(index);
    }

    public static final int UNSUBSCRIBE_TOPICS_FIELD_NUMBER = 3;
    private com.google.protobuf.LazyStringList unsubscribeTopics_;
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getUnsubscribeTopicsList() {
      return unsubscribeTopics_;
    }
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    public int getUnsubscribeTopicsCount() {
      return unsubscribeTopics_.size();
    }
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    public java.lang.String getUnsubscribeTopics(int index) {
      return unsubscribeTopics_.get(index);
    }
    /**
     * <code>repeated string unsubscribe_topics = 3;</code>
     */
    public com.google.protobuf.ByteString
        getUnsubscribeTopicsBytes(int index) {
      return unsubscribeTopics_.getByteString(index);
    }

    public static final int SUBSCRIBE_TOPIC_REGEXP_FIELD_NUMBER = 4;
    private com.google.protobuf.LazyStringList subscribeTopicRegexp_;
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getSubscribeTopicRegexpList() {
      return subscribeTopicRegexp_;
    }
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    public int getSubscribeTopicRegexpCount() {
      return subscribeTopicRegexp_.size();
    }
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    public java.lang.String getSubscribeTopicRegexp(int index) {
      return subscribeTopicRegexp_.get(index);
    }
    /**
     * <code>repeated string subscribe_topic_regexp = 4;</code>
     */
    public com.google.protobuf.ByteString
        getSubscribeTopicRegexpBytes(int index) {
      return subscribeTopicRegexp_.getByteString(index);
    }

    public static final int UNSUBSCRIBE_TOPIC_REGEXP_FIELD_NUMBER = 5;
    private com.google.protobuf.LazyStringList unsubscribeTopicRegexp_;
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    public com.google.protobuf.ProtocolStringList
        getUnsubscribeTopicRegexpList() {
      return unsubscribeTopicRegexp_;
    }
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    public int getUnsubscribeTopicRegexpCount() {
      return unsubscribeTopicRegexp_.size();
    }
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    public java.lang.String getUnsubscribeTopicRegexp(int index) {
      return unsubscribeTopicRegexp_.get(index);
    }
    /**
     * <code>repeated string unsubscribe_topic_regexp = 5;</code>
     */
    public com.google.protobuf.ByteString
        getUnsubscribeTopicRegexpBytes(int index) {
      return unsubscribeTopicRegexp_.getByteString(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getClientIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, clientId_);
      }
      for (int i = 0; i < subscribeTopics_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, subscribeTopics_.getRaw(i));
      }
      for (int i = 0; i < unsubscribeTopics_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 3, unsubscribeTopics_.getRaw(i));
      }
      for (int i = 0; i < subscribeTopicRegexp_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 4, subscribeTopicRegexp_.getRaw(i));
      }
      for (int i = 0; i < unsubscribeTopicRegexp_.size(); i++) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 5, unsubscribeTopicRegexp_.getRaw(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getClientIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, clientId_);
      }
      {
        int dataSize = 0;
        for (int i = 0; i < subscribeTopics_.size(); i++) {
          dataSize += computeStringSizeNoTag(subscribeTopics_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getSubscribeTopicsList().size();
      }
      {
        int dataSize = 0;
        for (int i = 0; i < unsubscribeTopics_.size(); i++) {
          dataSize += computeStringSizeNoTag(unsubscribeTopics_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getUnsubscribeTopicsList().size();
      }
      {
        int dataSize = 0;
        for (int i = 0; i < subscribeTopicRegexp_.size(); i++) {
          dataSize += computeStringSizeNoTag(subscribeTopicRegexp_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getSubscribeTopicRegexpList().size();
      }
      {
        int dataSize = 0;
        for (int i = 0; i < unsubscribeTopicRegexp_.size(); i++) {
          dataSize += computeStringSizeNoTag(unsubscribeTopicRegexp_.getRaw(i));
        }
        size += dataSize;
        size += 1 * getUnsubscribeTopicRegexpList().size();
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription)) {
        return super.equals(obj);
      }
      ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription other = (ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription) obj;

      boolean result = true;
      result = result && getClientId()
          .equals(other.getClientId());
      result = result && getSubscribeTopicsList()
          .equals(other.getSubscribeTopicsList());
      result = result && getUnsubscribeTopicsList()
          .equals(other.getUnsubscribeTopicsList());
      result = result && getSubscribeTopicRegexpList()
          .equals(other.getSubscribeTopicRegexpList());
      result = result && getUnsubscribeTopicRegexpList()
          .equals(other.getUnsubscribeTopicRegexpList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + CLIENT_ID_FIELD_NUMBER;
      hash = (53 * hash) + getClientId().hashCode();
      if (getSubscribeTopicsCount() > 0) {
        hash = (37 * hash) + SUBSCRIBE_TOPICS_FIELD_NUMBER;
        hash = (53 * hash) + getSubscribeTopicsList().hashCode();
      }
      if (getUnsubscribeTopicsCount() > 0) {
        hash = (37 * hash) + UNSUBSCRIBE_TOPICS_FIELD_NUMBER;
        hash = (53 * hash) + getUnsubscribeTopicsList().hashCode();
      }
      if (getSubscribeTopicRegexpCount() > 0) {
        hash = (37 * hash) + SUBSCRIBE_TOPIC_REGEXP_FIELD_NUMBER;
        hash = (53 * hash) + getSubscribeTopicRegexpList().hashCode();
      }
      if (getUnsubscribeTopicRegexpCount() > 0) {
        hash = (37 * hash) + UNSUBSCRIBE_TOPIC_REGEXP_FIELD_NUMBER;
        hash = (53 * hash) + getUnsubscribeTopicRegexpList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.services.request.TopicSubscription}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.services.request.TopicSubscription)
        ubii.services.request.TopicSubscriptionOuterClass.TopicSubscriptionOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.services.request.TopicSubscriptionOuterClass.internal_static_ubii_services_request_TopicSubscription_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.services.request.TopicSubscriptionOuterClass.internal_static_ubii_services_request_TopicSubscription_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.class, ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.Builder.class);
      }

      // Construct using ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        clientId_ = "";

        subscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000002);
        unsubscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000004);
        subscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000008);
        unsubscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000010);
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.services.request.TopicSubscriptionOuterClass.internal_static_ubii_services_request_TopicSubscription_descriptor;
      }

      @java.lang.Override
      public ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription getDefaultInstanceForType() {
        return ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription build() {
        ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription buildPartial() {
        ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription result = new ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription(this);
        int from_bitField0_ = bitField0_;
        int to_bitField0_ = 0;
        result.clientId_ = clientId_;
        if (((bitField0_ & 0x00000002) == 0x00000002)) {
          subscribeTopics_ = subscribeTopics_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000002);
        }
        result.subscribeTopics_ = subscribeTopics_;
        if (((bitField0_ & 0x00000004) == 0x00000004)) {
          unsubscribeTopics_ = unsubscribeTopics_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000004);
        }
        result.unsubscribeTopics_ = unsubscribeTopics_;
        if (((bitField0_ & 0x00000008) == 0x00000008)) {
          subscribeTopicRegexp_ = subscribeTopicRegexp_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000008);
        }
        result.subscribeTopicRegexp_ = subscribeTopicRegexp_;
        if (((bitField0_ & 0x00000010) == 0x00000010)) {
          unsubscribeTopicRegexp_ = unsubscribeTopicRegexp_.getUnmodifiableView();
          bitField0_ = (bitField0_ & ~0x00000010);
        }
        result.unsubscribeTopicRegexp_ = unsubscribeTopicRegexp_;
        result.bitField0_ = to_bitField0_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription) {
          return mergeFrom((ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription other) {
        if (other == ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription.getDefaultInstance()) return this;
        if (!other.getClientId().isEmpty()) {
          clientId_ = other.clientId_;
          onChanged();
        }
        if (!other.subscribeTopics_.isEmpty()) {
          if (subscribeTopics_.isEmpty()) {
            subscribeTopics_ = other.subscribeTopics_;
            bitField0_ = (bitField0_ & ~0x00000002);
          } else {
            ensureSubscribeTopicsIsMutable();
            subscribeTopics_.addAll(other.subscribeTopics_);
          }
          onChanged();
        }
        if (!other.unsubscribeTopics_.isEmpty()) {
          if (unsubscribeTopics_.isEmpty()) {
            unsubscribeTopics_ = other.unsubscribeTopics_;
            bitField0_ = (bitField0_ & ~0x00000004);
          } else {
            ensureUnsubscribeTopicsIsMutable();
            unsubscribeTopics_.addAll(other.unsubscribeTopics_);
          }
          onChanged();
        }
        if (!other.subscribeTopicRegexp_.isEmpty()) {
          if (subscribeTopicRegexp_.isEmpty()) {
            subscribeTopicRegexp_ = other.subscribeTopicRegexp_;
            bitField0_ = (bitField0_ & ~0x00000008);
          } else {
            ensureSubscribeTopicRegexpIsMutable();
            subscribeTopicRegexp_.addAll(other.subscribeTopicRegexp_);
          }
          onChanged();
        }
        if (!other.unsubscribeTopicRegexp_.isEmpty()) {
          if (unsubscribeTopicRegexp_.isEmpty()) {
            unsubscribeTopicRegexp_ = other.unsubscribeTopicRegexp_;
            bitField0_ = (bitField0_ & ~0x00000010);
          } else {
            ensureUnsubscribeTopicRegexpIsMutable();
            unsubscribeTopicRegexp_.addAll(other.unsubscribeTopicRegexp_);
          }
          onChanged();
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.lang.Object clientId_ = "";
      /**
       * <code>string client_id = 1;</code>
       */
      public java.lang.String getClientId() {
        java.lang.Object ref = clientId_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          clientId_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string client_id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getClientIdBytes() {
        java.lang.Object ref = clientId_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          clientId_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string client_id = 1;</code>
       */
      public Builder setClientId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        clientId_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string client_id = 1;</code>
       */
      public Builder clearClientId() {
        
        clientId_ = getDefaultInstance().getClientId();
        onChanged();
        return this;
      }
      /**
       * <code>string client_id = 1;</code>
       */
      public Builder setClientIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        clientId_ = value;
        onChanged();
        return this;
      }

      private com.google.protobuf.LazyStringList subscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureSubscribeTopicsIsMutable() {
        if (!((bitField0_ & 0x00000002) == 0x00000002)) {
          subscribeTopics_ = new com.google.protobuf.LazyStringArrayList(subscribeTopics_);
          bitField0_ |= 0x00000002;
         }
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getSubscribeTopicsList() {
        return subscribeTopics_.getUnmodifiableView();
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public int getSubscribeTopicsCount() {
        return subscribeTopics_.size();
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public java.lang.String getSubscribeTopics(int index) {
        return subscribeTopics_.get(index);
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public com.google.protobuf.ByteString
          getSubscribeTopicsBytes(int index) {
        return subscribeTopics_.getByteString(index);
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public Builder setSubscribeTopics(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureSubscribeTopicsIsMutable();
        subscribeTopics_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public Builder addSubscribeTopics(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureSubscribeTopicsIsMutable();
        subscribeTopics_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public Builder addAllSubscribeTopics(
          java.lang.Iterable<java.lang.String> values) {
        ensureSubscribeTopicsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, subscribeTopics_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public Builder clearSubscribeTopics() {
        subscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000002);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topics = 2;</code>
       */
      public Builder addSubscribeTopicsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureSubscribeTopicsIsMutable();
        subscribeTopics_.add(value);
        onChanged();
        return this;
      }

      private com.google.protobuf.LazyStringList unsubscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureUnsubscribeTopicsIsMutable() {
        if (!((bitField0_ & 0x00000004) == 0x00000004)) {
          unsubscribeTopics_ = new com.google.protobuf.LazyStringArrayList(unsubscribeTopics_);
          bitField0_ |= 0x00000004;
         }
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getUnsubscribeTopicsList() {
        return unsubscribeTopics_.getUnmodifiableView();
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public int getUnsubscribeTopicsCount() {
        return unsubscribeTopics_.size();
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public java.lang.String getUnsubscribeTopics(int index) {
        return unsubscribeTopics_.get(index);
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public com.google.protobuf.ByteString
          getUnsubscribeTopicsBytes(int index) {
        return unsubscribeTopics_.getByteString(index);
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public Builder setUnsubscribeTopics(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureUnsubscribeTopicsIsMutable();
        unsubscribeTopics_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public Builder addUnsubscribeTopics(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureUnsubscribeTopicsIsMutable();
        unsubscribeTopics_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public Builder addAllUnsubscribeTopics(
          java.lang.Iterable<java.lang.String> values) {
        ensureUnsubscribeTopicsIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, unsubscribeTopics_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public Builder clearUnsubscribeTopics() {
        unsubscribeTopics_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000004);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topics = 3;</code>
       */
      public Builder addUnsubscribeTopicsBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureUnsubscribeTopicsIsMutable();
        unsubscribeTopics_.add(value);
        onChanged();
        return this;
      }

      private com.google.protobuf.LazyStringList subscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureSubscribeTopicRegexpIsMutable() {
        if (!((bitField0_ & 0x00000008) == 0x00000008)) {
          subscribeTopicRegexp_ = new com.google.protobuf.LazyStringArrayList(subscribeTopicRegexp_);
          bitField0_ |= 0x00000008;
         }
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getSubscribeTopicRegexpList() {
        return subscribeTopicRegexp_.getUnmodifiableView();
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public int getSubscribeTopicRegexpCount() {
        return subscribeTopicRegexp_.size();
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public java.lang.String getSubscribeTopicRegexp(int index) {
        return subscribeTopicRegexp_.get(index);
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public com.google.protobuf.ByteString
          getSubscribeTopicRegexpBytes(int index) {
        return subscribeTopicRegexp_.getByteString(index);
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public Builder setSubscribeTopicRegexp(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureSubscribeTopicRegexpIsMutable();
        subscribeTopicRegexp_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public Builder addSubscribeTopicRegexp(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureSubscribeTopicRegexpIsMutable();
        subscribeTopicRegexp_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public Builder addAllSubscribeTopicRegexp(
          java.lang.Iterable<java.lang.String> values) {
        ensureSubscribeTopicRegexpIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, subscribeTopicRegexp_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public Builder clearSubscribeTopicRegexp() {
        subscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000008);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string subscribe_topic_regexp = 4;</code>
       */
      public Builder addSubscribeTopicRegexpBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureSubscribeTopicRegexpIsMutable();
        subscribeTopicRegexp_.add(value);
        onChanged();
        return this;
      }

      private com.google.protobuf.LazyStringList unsubscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
      private void ensureUnsubscribeTopicRegexpIsMutable() {
        if (!((bitField0_ & 0x00000010) == 0x00000010)) {
          unsubscribeTopicRegexp_ = new com.google.protobuf.LazyStringArrayList(unsubscribeTopicRegexp_);
          bitField0_ |= 0x00000010;
         }
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public com.google.protobuf.ProtocolStringList
          getUnsubscribeTopicRegexpList() {
        return unsubscribeTopicRegexp_.getUnmodifiableView();
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public int getUnsubscribeTopicRegexpCount() {
        return unsubscribeTopicRegexp_.size();
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public java.lang.String getUnsubscribeTopicRegexp(int index) {
        return unsubscribeTopicRegexp_.get(index);
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public com.google.protobuf.ByteString
          getUnsubscribeTopicRegexpBytes(int index) {
        return unsubscribeTopicRegexp_.getByteString(index);
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public Builder setUnsubscribeTopicRegexp(
          int index, java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureUnsubscribeTopicRegexpIsMutable();
        unsubscribeTopicRegexp_.set(index, value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public Builder addUnsubscribeTopicRegexp(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  ensureUnsubscribeTopicRegexpIsMutable();
        unsubscribeTopicRegexp_.add(value);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public Builder addAllUnsubscribeTopicRegexp(
          java.lang.Iterable<java.lang.String> values) {
        ensureUnsubscribeTopicRegexpIsMutable();
        com.google.protobuf.AbstractMessageLite.Builder.addAll(
            values, unsubscribeTopicRegexp_);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public Builder clearUnsubscribeTopicRegexp() {
        unsubscribeTopicRegexp_ = com.google.protobuf.LazyStringArrayList.EMPTY;
        bitField0_ = (bitField0_ & ~0x00000010);
        onChanged();
        return this;
      }
      /**
       * <code>repeated string unsubscribe_topic_regexp = 5;</code>
       */
      public Builder addUnsubscribeTopicRegexpBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        ensureUnsubscribeTopicRegexpIsMutable();
        unsubscribeTopicRegexp_.add(value);
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.services.request.TopicSubscription)
    }

    // @@protoc_insertion_point(class_scope:ubii.services.request.TopicSubscription)
    private static final ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription();
    }

    public static ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicSubscription>
        PARSER = new com.google.protobuf.AbstractParser<TopicSubscription>() {
      @java.lang.Override
      public TopicSubscription parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicSubscription(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicSubscription> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicSubscription> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.services.request.TopicSubscriptionOuterClass.TopicSubscription getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_services_request_TopicSubscription_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_services_request_TopicSubscription_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n.proto/services/request/topicSubscripti" +
      "on.proto\022\025ubii.services.request\"\236\001\n\021Topi" +
      "cSubscription\022\021\n\tclient_id\030\001 \001(\t\022\030\n\020subs" +
      "cribe_topics\030\002 \003(\t\022\032\n\022unsubscribe_topics" +
      "\030\003 \003(\t\022\036\n\026subscribe_topic_regexp\030\004 \003(\t\022 " +
      "\n\030unsubscribe_topic_regexp\030\005 \003(\tb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
        }, assigner);
    internal_static_ubii_services_request_TopicSubscription_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_services_request_TopicSubscription_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_services_request_TopicSubscription_descriptor,
        new java.lang.String[] { "ClientId", "SubscribeTopics", "UnsubscribeTopics", "SubscribeTopicRegexp", "UnsubscribeTopicRegexp", });
  }

  // @@protoc_insertion_point(outer_class_scope)
}
