"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Service",
        "ServiceList",
    }
)


class Service(Message):
    topic = Field(
        STRING,
        number=1,
    )
    request_message_format = Field(
        STRING,
        number=2,
    )
    response_message_format = Field(
        STRING,
        number=3,
    )
    tags = RepeatedField(
        STRING,
        number=4,
    )
    description = Field(
        STRING,
        number=5,
    )



class ServiceList(Message):
    elements = RepeatedField(
        Service,
        number=1,
    )


