"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Enum,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Component",
        "ComponentList",
    }
)


class Component(Message):
    class IOType(Enum):
        PUBLISHER = 0
        SUBSCRIBER = 1


    topic = Field(
        STRING,
        number=1,
    )
    message_format = Field(
        STRING,
        number=2,
    )
    io_type = Field(
        IOType,
        number=3,
    )
    device_id = Field(
        STRING,
        number=4,
    )
    tags = RepeatedField(
        STRING,
        number=5,
    )
    description = Field(
        STRING,
        number=6,
    )
    id = Field(
        STRING,
        number=7,
    )
    name = Field(
        STRING,
        number=8,
    )



class ComponentList(Message):
    elements = RepeatedField(
        Component,
        number=1,
    )


