// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/dataStructure/handGestureType.proto

package ubii.dataStructure;

public final class HandGestureTypeOuterClass {
  private HandGestureTypeOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  /**
   * Protobuf enum {@code ubii.dataStructure.HandGestureType}
   */
  public enum HandGestureType
      implements com.google.protobuf.ProtocolMessageEnum {
    /**
     * <code>REST = 0;</code>
     */
    REST(0),
    /**
     * <code>FINGERS_SPREAD = 1;</code>
     */
    FINGERS_SPREAD(1),
    /**
     * <code>WAVE_IN = 2;</code>
     */
    WAVE_IN(2),
    /**
     * <code>WAVE_OUT = 3;</code>
     */
    WAVE_OUT(3),
    /**
     * <code>FIST = 4;</code>
     */
    FIST(4),
    /**
     * <code>DOUBLE_TAP = 5;</code>
     */
    DOUBLE_TAP(5),
    UNRECOGNIZED(-1),
    ;

    /**
     * <code>REST = 0;</code>
     */
    public static final int REST_VALUE = 0;
    /**
     * <code>FINGERS_SPREAD = 1;</code>
     */
    public static final int FINGERS_SPREAD_VALUE = 1;
    /**
     * <code>WAVE_IN = 2;</code>
     */
    public static final int WAVE_IN_VALUE = 2;
    /**
     * <code>WAVE_OUT = 3;</code>
     */
    public static final int WAVE_OUT_VALUE = 3;
    /**
     * <code>FIST = 4;</code>
     */
    public static final int FIST_VALUE = 4;
    /**
     * <code>DOUBLE_TAP = 5;</code>
     */
    public static final int DOUBLE_TAP_VALUE = 5;


    public final int getNumber() {
      if (this == UNRECOGNIZED) {
        throw new java.lang.IllegalArgumentException(
            "Can't get the number of an unknown enum value.");
      }
      return value;
    }

    /**
     * @deprecated Use {@link #forNumber(int)} instead.
     */
    @java.lang.Deprecated
    public static HandGestureType valueOf(int value) {
      return forNumber(value);
    }

    public static HandGestureType forNumber(int value) {
      switch (value) {
        case 0: return REST;
        case 1: return FINGERS_SPREAD;
        case 2: return WAVE_IN;
        case 3: return WAVE_OUT;
        case 4: return FIST;
        case 5: return DOUBLE_TAP;
        default: return null;
      }
    }

    public static com.google.protobuf.Internal.EnumLiteMap<HandGestureType>
        internalGetValueMap() {
      return internalValueMap;
    }
    private static final com.google.protobuf.Internal.EnumLiteMap<
        HandGestureType> internalValueMap =
          new com.google.protobuf.Internal.EnumLiteMap<HandGestureType>() {
            public HandGestureType findValueByNumber(int number) {
              return HandGestureType.forNumber(number);
            }
          };

    public final com.google.protobuf.Descriptors.EnumValueDescriptor
        getValueDescriptor() {
      return getDescriptor().getValues().get(ordinal());
    }
    public final com.google.protobuf.Descriptors.EnumDescriptor
        getDescriptorForType() {
      return getDescriptor();
    }
    public static final com.google.protobuf.Descriptors.EnumDescriptor
        getDescriptor() {
      return ubii.dataStructure.HandGestureTypeOuterClass.getDescriptor().getEnumTypes().get(0);
    }

    private static final HandGestureType[] VALUES = values();

    public static HandGestureType valueOf(
        com.google.protobuf.Descriptors.EnumValueDescriptor desc) {
      if (desc.getType() != getDescriptor()) {
        throw new java.lang.IllegalArgumentException(
          "EnumValueDescriptor is not for this type.");
      }
      if (desc.getIndex() == -1) {
        return UNRECOGNIZED;
      }
      return VALUES[desc.getIndex()];
    }

    private final int value;

    private HandGestureType(int value) {
      this.value = value;
    }

    // @@protoc_insertion_point(enum_scope:ubii.dataStructure.HandGestureType)
  }


  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\nCproto/topicData/topicDataRecord/dataSt" +
      "ructure/handGestureType.proto\022\022ubii.data" +
      "Structure*d\n\017HandGestureType\022\010\n\004REST\020\000\022\022" +
      "\n\016FINGERS_SPREAD\020\001\022\013\n\007WAVE_IN\020\002\022\014\n\010WAVE_" +
      "OUT\020\003\022\010\n\004FIST\020\004\022\016\n\nDOUBLE_TAP\020\005b\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
        }, assigner);
  }

  // @@protoc_insertion_point(outer_class_scope)
}
