"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.clients.client_pb_plus import (
    Client,
    ClientList,
)

from ubii.proto_v1.types.dataStructure.lists_pb_plus import (
    StringList,
)

from ubii.proto_v1.types.devices.device_pb_plus import (
    Device,
    DeviceList,
)

from ubii.proto_v1.types.devices.topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from ubii.proto_v1.types.devices.topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)

from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
)

from ubii.proto_v1.types.general.success_pb_plus import (
    Success,
)

from ubii.proto_v1.types.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingReply,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ProcessingModule,
    ProcessingModuleList,
)

from ubii.proto_v1.types.servers.server_pb_plus import (
    Server,
)

from ubii.proto_v1.types.services.service_pb_plus import (
    Service,
    ServiceList,
)

from ubii.proto_v1.types.sessions.session_pb_plus import (
    Session,
    SessionList,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "ServiceReply",
    }
)


class ServiceReply(Message):
    success = Field(
        Success,
        number=1,
        oneof='type',
    )
    error = Field(
        Error,
        number=2,
        oneof='type',
    )
    client = Field(
        Client,
        number=3,
        oneof='type',
    )
    device = Field(
        Device,
        number=4,
        oneof='type',
    )
    server = Field(
        Server,
        number=5,
        oneof='type',
    )
    session = Field(
        Session,
        number=6,
        oneof='type',
    )
    session_list = Field(
        SessionList,
        number=7,
        oneof='type',
    )
    processing_module = Field(
        ProcessingModule,
        number=8,
        oneof='type',
    )
    processing_module_list = Field(
        ProcessingModuleList,
        number=9,
        oneof='type',
    )
    string_list = Field(
        StringList,
        number=10,
        oneof='type',
    )
    topic_mux = Field(
        TopicMux,
        number=11,
        oneof='type',
    )
    topic_mux_list = Field(
        TopicMuxList,
        number=12,
        oneof='type',
    )
    topic_demux = Field(
        TopicDemux,
        number=13,
        oneof='type',
    )
    topic_demux_list = Field(
        TopicDemuxList,
        number=14,
        oneof='type',
    )
    client_list = Field(
        ClientList,
        number=15,
        oneof='type',
    )
    device_list = Field(
        DeviceList,
        number=16,
        oneof='type',
    )
    service = Field(
        Service,
        number=17,
        oneof='type',
    )
    service_list = Field(
        ServiceList,
        number=18,
        oneof='type',
    )
    lockstep_processing_reply = Field(
        LockstepProcessingReply,
        number=19,
        oneof='type',
    )


