# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/services/serviceReply.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.general import success_pb2 as ubii_dot_proto__v2_dot_types_dot_general_dot_success__pb2
from ubii.proto_v2.types.general import error_pb2 as ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2
from ubii.proto_v2.types.dataStructure import lists_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2
from ubii.proto_v2.types.clients import client_pb2 as ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2
from ubii.proto_v2.types.devices import device_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2
from ubii.proto_v2.types.devices import topicMux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2
from ubii.proto_v2.types.devices import topicDemux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2
from ubii.proto_v2.types.servers import server_pb2 as ubii_dot_proto__v2_dot_types_dot_servers_dot_server__pb2
from ubii.proto_v2.types.sessions import session_pb2 as ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2
from ubii.proto_v2.types.services import service_pb2 as ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2
from ubii.proto_v2.types.processing import processingModule_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2
from ubii.proto_v2.types.processing import lockstepProcessing_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_lockstepProcessing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/services/serviceReply.proto',
  package='ubii.proto_v2.types.services',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/ubii/proto_v2/types/services/serviceReply.proto\x12\x1cubii.proto_v2.types.services\x1a)ubii/proto_v2/types/general/success.proto\x1a\'ubii/proto_v2/types/general/error.proto\x1a-ubii/proto_v2/types/dataStructure/lists.proto\x1a(ubii/proto_v2/types/clients/client.proto\x1a(ubii/proto_v2/types/devices/device.proto\x1a*ubii/proto_v2/types/devices/topicMux.proto\x1a,ubii/proto_v2/types/devices/topicDemux.proto\x1a(ubii/proto_v2/types/servers/server.proto\x1a*ubii/proto_v2/types/sessions/session.proto\x1a*ubii/proto_v2/types/services/service.proto\x1a\x35ubii/proto_v2/types/processing/processingModule.proto\x1a\x37ubii/proto_v2/types/processing/lockstepProcessing.proto\"\xf8\t\n\x0cServiceReply\x12\x37\n\x07success\x18\x01 \x01(\x0b\x32$.ubii.proto_v2.types.general.SuccessH\x00\x12\x33\n\x05\x65rror\x18\x02 \x01(\x0b\x32\".ubii.proto_v2.types.general.ErrorH\x00\x12\x35\n\x06\x63lient\x18\x03 \x01(\x0b\x32#.ubii.proto_v2.types.clients.ClientH\x00\x12\x35\n\x06\x64\x65vice\x18\x04 \x01(\x0b\x32#.ubii.proto_v2.types.devices.DeviceH\x00\x12\x35\n\x06server\x18\x05 \x01(\x0b\x32#.ubii.proto_v2.types.servers.ServerH\x00\x12\x38\n\x07session\x18\x06 \x01(\x0b\x32%.ubii.proto_v2.types.sessions.SessionH\x00\x12\x41\n\x0csession_list\x18\x07 \x01(\x0b\x32).ubii.proto_v2.types.sessions.SessionListH\x00\x12M\n\x11processing_module\x18\x08 \x01(\x0b\x32\x30.ubii.proto_v2.types.processing.ProcessingModuleH\x00\x12V\n\x16processing_module_list\x18\t \x01(\x0b\x32\x34.ubii.proto_v2.types.processing.ProcessingModuleListH\x00\x12\x44\n\x0bstring_list\x18\n \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.StringListH\x00\x12:\n\ttopic_mux\x18\x0b \x01(\x0b\x32%.ubii.proto_v2.types.devices.TopicMuxH\x00\x12\x43\n\x0etopic_mux_list\x18\x0c \x01(\x0b\x32).ubii.proto_v2.types.devices.TopicMuxListH\x00\x12>\n\x0btopic_demux\x18\r \x01(\x0b\x32\'.ubii.proto_v2.types.devices.TopicDemuxH\x00\x12G\n\x10topic_demux_list\x18\x0e \x01(\x0b\x32+.ubii.proto_v2.types.devices.TopicDemuxListH\x00\x12>\n\x0b\x63lient_list\x18\x0f \x01(\x0b\x32\'.ubii.proto_v2.types.clients.ClientListH\x00\x12>\n\x0b\x64\x65vice_list\x18\x10 \x01(\x0b\x32\'.ubii.proto_v2.types.devices.DeviceListH\x00\x12\x38\n\x07service\x18\x11 \x01(\x0b\x32%.ubii.proto_v2.types.services.ServiceH\x00\x12\x41\n\x0cservice_list\x18\x12 \x01(\x0b\x32).ubii.proto_v2.types.services.ServiceListH\x00\x12\\\n\x19lockstep_processing_reply\x18\x13 \x01(\x0b\x32\x37.ubii.proto_v2.types.processing.LockstepProcessingReplyH\x00\x42\x06\n\x04typeb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_general_dot_success__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_servers_dot_server__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_lockstepProcessing__pb2.DESCRIPTOR,])




_SERVICEREPLY = _descriptor.Descriptor(
  name='ServiceReply',
  full_name='ubii.proto_v2.types.services.ServiceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='ubii.proto_v2.types.services.ServiceReply.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ubii.proto_v2.types.services.ServiceReply.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client', full_name='ubii.proto_v2.types.services.ServiceReply.client', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='ubii.proto_v2.types.services.ServiceReply.device', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server', full_name='ubii.proto_v2.types.services.ServiceReply.server', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='ubii.proto_v2.types.services.ServiceReply.session', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_list', full_name='ubii.proto_v2.types.services.ServiceReply.session_list', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_module', full_name='ubii.proto_v2.types.services.ServiceReply.processing_module', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_module_list', full_name='ubii.proto_v2.types.services.ServiceReply.processing_module_list', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='ubii.proto_v2.types.services.ServiceReply.string_list', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_mux', full_name='ubii.proto_v2.types.services.ServiceReply.topic_mux', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_mux_list', full_name='ubii.proto_v2.types.services.ServiceReply.topic_mux_list', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_demux', full_name='ubii.proto_v2.types.services.ServiceReply.topic_demux', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_demux_list', full_name='ubii.proto_v2.types.services.ServiceReply.topic_demux_list', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_list', full_name='ubii.proto_v2.types.services.ServiceReply.client_list', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_list', full_name='ubii.proto_v2.types.services.ServiceReply.device_list', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='ubii.proto_v2.types.services.ServiceReply.service', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_list', full_name='ubii.proto_v2.types.services.ServiceReply.service_list', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_processing_reply', full_name='ubii.proto_v2.types.services.ServiceReply.lockstep_processing_reply', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ubii.proto_v2.types.services.ServiceReply.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=629,
  serialized_end=1901,
)

_SERVICEREPLY.fields_by_name['success'].message_type = ubii_dot_proto__v2_dot_types_dot_general_dot_success__pb2._SUCCESS
_SERVICEREPLY.fields_by_name['error'].message_type = ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2._ERROR
_SERVICEREPLY.fields_by_name['client'].message_type = ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2._CLIENT
_SERVICEREPLY.fields_by_name['device'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2._DEVICE
_SERVICEREPLY.fields_by_name['server'].message_type = ubii_dot_proto__v2_dot_types_dot_servers_dot_server__pb2._SERVER
_SERVICEREPLY.fields_by_name['session'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2._SESSION
_SERVICEREPLY.fields_by_name['session_list'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2._SESSIONLIST
_SERVICEREPLY.fields_by_name['processing_module'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULE
_SERVICEREPLY.fields_by_name['processing_module_list'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULELIST
_SERVICEREPLY.fields_by_name['string_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._STRINGLIST
_SERVICEREPLY.fields_by_name['topic_mux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2._TOPICMUX
_SERVICEREPLY.fields_by_name['topic_mux_list'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2._TOPICMUXLIST
_SERVICEREPLY.fields_by_name['topic_demux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2._TOPICDEMUX
_SERVICEREPLY.fields_by_name['topic_demux_list'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2._TOPICDEMUXLIST
_SERVICEREPLY.fields_by_name['client_list'].message_type = ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2._CLIENTLIST
_SERVICEREPLY.fields_by_name['device_list'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2._DEVICELIST
_SERVICEREPLY.fields_by_name['service'].message_type = ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2._SERVICE
_SERVICEREPLY.fields_by_name['service_list'].message_type = ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2._SERVICELIST
_SERVICEREPLY.fields_by_name['lockstep_processing_reply'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_lockstepProcessing__pb2._LOCKSTEPPROCESSINGREPLY
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['success'])
_SERVICEREPLY.fields_by_name['success'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['error'])
_SERVICEREPLY.fields_by_name['error'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['client'])
_SERVICEREPLY.fields_by_name['client'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['device'])
_SERVICEREPLY.fields_by_name['device'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['server'])
_SERVICEREPLY.fields_by_name['server'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['session'])
_SERVICEREPLY.fields_by_name['session'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['session_list'])
_SERVICEREPLY.fields_by_name['session_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['processing_module'])
_SERVICEREPLY.fields_by_name['processing_module'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['processing_module_list'])
_SERVICEREPLY.fields_by_name['processing_module_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['string_list'])
_SERVICEREPLY.fields_by_name['string_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_mux'])
_SERVICEREPLY.fields_by_name['topic_mux'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_mux_list'])
_SERVICEREPLY.fields_by_name['topic_mux_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_demux'])
_SERVICEREPLY.fields_by_name['topic_demux'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_demux_list'])
_SERVICEREPLY.fields_by_name['topic_demux_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['client_list'])
_SERVICEREPLY.fields_by_name['client_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['device_list'])
_SERVICEREPLY.fields_by_name['device_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['service'])
_SERVICEREPLY.fields_by_name['service'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['service_list'])
_SERVICEREPLY.fields_by_name['service_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['lockstep_processing_reply'])
_SERVICEREPLY.fields_by_name['lockstep_processing_reply'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['ServiceReply'] = _SERVICEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceReply = _reflection.GeneratedProtocolMessageType('ServiceReply', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEREPLY,
  '__module__' : 'ubii.proto_v2.types.services.serviceReply_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.services.ServiceReply)
  })
_sym_db.RegisterMessage(ServiceReply)


# @@protoc_insertion_point(module_scope)
