// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/devices/device.proto

#ifndef PROTOBUF_INCLUDED_proto_2fdevices_2fdevice_2eproto
#define PROTOBUF_INCLUDED_proto_2fdevices_2fdevice_2eproto

#include <string>

#include <google/protobuf/stubs/common.h>

#if GOOGLE_PROTOBUF_VERSION < 3006001
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please update
#error your headers.
#endif
#if 3006001 < GOOGLE_PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers.  Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "proto/devices/component.pb.h"
// @@protoc_insertion_point(includes)
#define PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fdevices_2fdevice_2eproto 

namespace protobuf_proto_2fdevices_2fdevice_2eproto {
// Internal implementation detail -- do not use these members.
struct TableStruct {
  static const ::google::protobuf::internal::ParseTableField entries[];
  static const ::google::protobuf::internal::AuxillaryParseTableField aux[];
  static const ::google::protobuf::internal::ParseTable schema[2];
  static const ::google::protobuf::internal::FieldMetadata field_metadata[];
  static const ::google::protobuf::internal::SerializationTable serialization_table[];
  static const ::google::protobuf::uint32 offsets[];
};
void AddDescriptors();
}  // namespace protobuf_proto_2fdevices_2fdevice_2eproto
namespace ubii {
namespace devices {
class Device;
class DeviceDefaultTypeInternal;
extern DeviceDefaultTypeInternal _Device_default_instance_;
class DeviceList;
class DeviceListDefaultTypeInternal;
extern DeviceListDefaultTypeInternal _DeviceList_default_instance_;
}  // namespace devices
}  // namespace ubii
namespace google {
namespace protobuf {
template<> ::ubii::devices::Device* Arena::CreateMaybeMessage<::ubii::devices::Device>(Arena*);
template<> ::ubii::devices::DeviceList* Arena::CreateMaybeMessage<::ubii::devices::DeviceList>(Arena*);
}  // namespace protobuf
}  // namespace google
namespace ubii {
namespace devices {

enum Device_DeviceType {
  Device_DeviceType_PARTICIPANT = 0,
  Device_DeviceType_WATCHER = 1,
  Device_DeviceType_Device_DeviceType_INT_MIN_SENTINEL_DO_NOT_USE_ = ::google::protobuf::kint32min,
  Device_DeviceType_Device_DeviceType_INT_MAX_SENTINEL_DO_NOT_USE_ = ::google::protobuf::kint32max
};
bool Device_DeviceType_IsValid(int value);
const Device_DeviceType Device_DeviceType_DeviceType_MIN = Device_DeviceType_PARTICIPANT;
const Device_DeviceType Device_DeviceType_DeviceType_MAX = Device_DeviceType_WATCHER;
const int Device_DeviceType_DeviceType_ARRAYSIZE = Device_DeviceType_DeviceType_MAX + 1;

const ::google::protobuf::EnumDescriptor* Device_DeviceType_descriptor();
inline const ::std::string& Device_DeviceType_Name(Device_DeviceType value) {
  return ::google::protobuf::internal::NameOfEnum(
    Device_DeviceType_descriptor(), value);
}
inline bool Device_DeviceType_Parse(
    const ::std::string& name, Device_DeviceType* value) {
  return ::google::protobuf::internal::ParseNamedEnum<Device_DeviceType>(
    Device_DeviceType_descriptor(), name, value);
}
// ===================================================================

class Device : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.devices.Device) */ {
 public:
  Device();
  virtual ~Device();

  Device(const Device& from);

  inline Device& operator=(const Device& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  Device(Device&& from) noexcept
    : Device() {
    *this = ::std::move(from);
  }

  inline Device& operator=(Device&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const Device& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Device* internal_default_instance() {
    return reinterpret_cast<const Device*>(
               &_Device_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  void Swap(Device* other);
  friend void swap(Device& a, Device& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline Device* New() const final {
    return CreateMaybeMessage<Device>(NULL);
  }

  Device* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<Device>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const Device& from);
  void MergeFrom(const Device& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Device* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Device_DeviceType DeviceType;
  static const DeviceType PARTICIPANT =
    Device_DeviceType_PARTICIPANT;
  static const DeviceType WATCHER =
    Device_DeviceType_WATCHER;
  static inline bool DeviceType_IsValid(int value) {
    return Device_DeviceType_IsValid(value);
  }
  static const DeviceType DeviceType_MIN =
    Device_DeviceType_DeviceType_MIN;
  static const DeviceType DeviceType_MAX =
    Device_DeviceType_DeviceType_MAX;
  static const int DeviceType_ARRAYSIZE =
    Device_DeviceType_DeviceType_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor*
  DeviceType_descriptor() {
    return Device_DeviceType_descriptor();
  }
  static inline const ::std::string& DeviceType_Name(DeviceType value) {
    return Device_DeviceType_Name(value);
  }
  static inline bool DeviceType_Parse(const ::std::string& name,
      DeviceType* value) {
    return Device_DeviceType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  // repeated .ubii.devices.Component components = 4;
  int components_size() const;
  void clear_components();
  static const int kComponentsFieldNumber = 4;
  ::ubii::devices::Component* mutable_components(int index);
  ::google::protobuf::RepeatedPtrField< ::ubii::devices::Component >*
      mutable_components();
  const ::ubii::devices::Component& components(int index) const;
  ::ubii::devices::Component* add_components();
  const ::google::protobuf::RepeatedPtrField< ::ubii::devices::Component >&
      components() const;

  // repeated string tags = 6;
  int tags_size() const;
  void clear_tags();
  static const int kTagsFieldNumber = 6;
  const ::std::string& tags(int index) const;
  ::std::string* mutable_tags(int index);
  void set_tags(int index, const ::std::string& value);
  #if LANG_CXX11
  void set_tags(int index, ::std::string&& value);
  #endif
  void set_tags(int index, const char* value);
  void set_tags(int index, const char* value, size_t size);
  ::std::string* add_tags();
  void add_tags(const ::std::string& value);
  #if LANG_CXX11
  void add_tags(::std::string&& value);
  #endif
  void add_tags(const char* value);
  void add_tags(const char* value, size_t size);
  const ::google::protobuf::RepeatedPtrField< ::std::string>& tags() const;
  ::google::protobuf::RepeatedPtrField< ::std::string>* mutable_tags();

  // string id = 1;
  void clear_id();
  static const int kIdFieldNumber = 1;
  const ::std::string& id() const;
  void set_id(const ::std::string& value);
  #if LANG_CXX11
  void set_id(::std::string&& value);
  #endif
  void set_id(const char* value);
  void set_id(const char* value, size_t size);
  ::std::string* mutable_id();
  ::std::string* release_id();
  void set_allocated_id(::std::string* id);

  // string name = 2;
  void clear_name();
  static const int kNameFieldNumber = 2;
  const ::std::string& name() const;
  void set_name(const ::std::string& value);
  #if LANG_CXX11
  void set_name(::std::string&& value);
  #endif
  void set_name(const char* value);
  void set_name(const char* value, size_t size);
  ::std::string* mutable_name();
  ::std::string* release_name();
  void set_allocated_name(::std::string* name);

  // string client_id = 5;
  void clear_client_id();
  static const int kClientIdFieldNumber = 5;
  const ::std::string& client_id() const;
  void set_client_id(const ::std::string& value);
  #if LANG_CXX11
  void set_client_id(::std::string&& value);
  #endif
  void set_client_id(const char* value);
  void set_client_id(const char* value, size_t size);
  ::std::string* mutable_client_id();
  ::std::string* release_client_id();
  void set_allocated_client_id(::std::string* client_id);

  // string description = 7;
  void clear_description();
  static const int kDescriptionFieldNumber = 7;
  const ::std::string& description() const;
  void set_description(const ::std::string& value);
  #if LANG_CXX11
  void set_description(::std::string&& value);
  #endif
  void set_description(const char* value);
  void set_description(const char* value, size_t size);
  ::std::string* mutable_description();
  ::std::string* release_description();
  void set_allocated_description(::std::string* description);

  // .ubii.devices.Device.DeviceType device_type = 3;
  void clear_device_type();
  static const int kDeviceTypeFieldNumber = 3;
  ::ubii::devices::Device_DeviceType device_type() const;
  void set_device_type(::ubii::devices::Device_DeviceType value);

  // @@protoc_insertion_point(class_scope:ubii.devices.Device)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::RepeatedPtrField< ::ubii::devices::Component > components_;
  ::google::protobuf::RepeatedPtrField< ::std::string> tags_;
  ::google::protobuf::internal::ArenaStringPtr id_;
  ::google::protobuf::internal::ArenaStringPtr name_;
  ::google::protobuf::internal::ArenaStringPtr client_id_;
  ::google::protobuf::internal::ArenaStringPtr description_;
  int device_type_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2fdevices_2fdevice_2eproto::TableStruct;
};
// -------------------------------------------------------------------

class DeviceList : public ::google::protobuf::Message /* @@protoc_insertion_point(class_definition:ubii.devices.DeviceList) */ {
 public:
  DeviceList();
  virtual ~DeviceList();

  DeviceList(const DeviceList& from);

  inline DeviceList& operator=(const DeviceList& from) {
    CopyFrom(from);
    return *this;
  }
  #if LANG_CXX11
  DeviceList(DeviceList&& from) noexcept
    : DeviceList() {
    *this = ::std::move(from);
  }

  inline DeviceList& operator=(DeviceList&& from) noexcept {
    if (GetArenaNoVirtual() == from.GetArenaNoVirtual()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }
  #endif
  static const ::google::protobuf::Descriptor* descriptor();
  static const DeviceList& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const DeviceList* internal_default_instance() {
    return reinterpret_cast<const DeviceList*>(
               &_DeviceList_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  void Swap(DeviceList* other);
  friend void swap(DeviceList& a, DeviceList& b) {
    a.Swap(&b);
  }

  // implements Message ----------------------------------------------

  inline DeviceList* New() const final {
    return CreateMaybeMessage<DeviceList>(NULL);
  }

  DeviceList* New(::google::protobuf::Arena* arena) const final {
    return CreateMaybeMessage<DeviceList>(arena);
  }
  void CopyFrom(const ::google::protobuf::Message& from) final;
  void MergeFrom(const ::google::protobuf::Message& from) final;
  void CopyFrom(const DeviceList& from);
  void MergeFrom(const DeviceList& from);
  void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  bool MergePartialFromCodedStream(
      ::google::protobuf::io::CodedInputStream* input) final;
  void SerializeWithCachedSizes(
      ::google::protobuf::io::CodedOutputStream* output) const final;
  ::google::protobuf::uint8* InternalSerializeWithCachedSizesToArray(
      bool deterministic, ::google::protobuf::uint8* target) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(DeviceList* other);
  private:
  inline ::google::protobuf::Arena* GetArenaNoVirtual() const {
    return NULL;
  }
  inline void* MaybeArenaPtr() const {
    return NULL;
  }
  public:

  ::google::protobuf::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  // repeated .ubii.devices.Device elements = 1;
  int elements_size() const;
  void clear_elements();
  static const int kElementsFieldNumber = 1;
  ::ubii::devices::Device* mutable_elements(int index);
  ::google::protobuf::RepeatedPtrField< ::ubii::devices::Device >*
      mutable_elements();
  const ::ubii::devices::Device& elements(int index) const;
  ::ubii::devices::Device* add_elements();
  const ::google::protobuf::RepeatedPtrField< ::ubii::devices::Device >&
      elements() const;

  // @@protoc_insertion_point(class_scope:ubii.devices.DeviceList)
 private:

  ::google::protobuf::internal::InternalMetadataWithArena _internal_metadata_;
  ::google::protobuf::RepeatedPtrField< ::ubii::devices::Device > elements_;
  mutable ::google::protobuf::internal::CachedSize _cached_size_;
  friend struct ::protobuf_proto_2fdevices_2fdevice_2eproto::TableStruct;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Device

// string id = 1;
inline void Device::clear_id() {
  id_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline const ::std::string& Device::id() const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.id)
  return id_.GetNoArena();
}
inline void Device::set_id(const ::std::string& value) {
  
  id_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), value);
  // @@protoc_insertion_point(field_set:ubii.devices.Device.id)
}
#if LANG_CXX11
inline void Device::set_id(::std::string&& value) {
  
  id_.SetNoArena(
    &::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::move(value));
  // @@protoc_insertion_point(field_set_rvalue:ubii.devices.Device.id)
}
#endif
inline void Device::set_id(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  
  id_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::string(value));
  // @@protoc_insertion_point(field_set_char:ubii.devices.Device.id)
}
inline void Device::set_id(const char* value, size_t size) {
  
  id_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(),
      ::std::string(reinterpret_cast<const char*>(value), size));
  // @@protoc_insertion_point(field_set_pointer:ubii.devices.Device.id)
}
inline ::std::string* Device::mutable_id() {
  
  // @@protoc_insertion_point(field_mutable:ubii.devices.Device.id)
  return id_.MutableNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline ::std::string* Device::release_id() {
  // @@protoc_insertion_point(field_release:ubii.devices.Device.id)
  
  return id_.ReleaseNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline void Device::set_allocated_id(::std::string* id) {
  if (id != NULL) {
    
  } else {
    
  }
  id_.SetAllocatedNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), id);
  // @@protoc_insertion_point(field_set_allocated:ubii.devices.Device.id)
}

// string name = 2;
inline void Device::clear_name() {
  name_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline const ::std::string& Device::name() const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.name)
  return name_.GetNoArena();
}
inline void Device::set_name(const ::std::string& value) {
  
  name_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), value);
  // @@protoc_insertion_point(field_set:ubii.devices.Device.name)
}
#if LANG_CXX11
inline void Device::set_name(::std::string&& value) {
  
  name_.SetNoArena(
    &::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::move(value));
  // @@protoc_insertion_point(field_set_rvalue:ubii.devices.Device.name)
}
#endif
inline void Device::set_name(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  
  name_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::string(value));
  // @@protoc_insertion_point(field_set_char:ubii.devices.Device.name)
}
inline void Device::set_name(const char* value, size_t size) {
  
  name_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(),
      ::std::string(reinterpret_cast<const char*>(value), size));
  // @@protoc_insertion_point(field_set_pointer:ubii.devices.Device.name)
}
inline ::std::string* Device::mutable_name() {
  
  // @@protoc_insertion_point(field_mutable:ubii.devices.Device.name)
  return name_.MutableNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline ::std::string* Device::release_name() {
  // @@protoc_insertion_point(field_release:ubii.devices.Device.name)
  
  return name_.ReleaseNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline void Device::set_allocated_name(::std::string* name) {
  if (name != NULL) {
    
  } else {
    
  }
  name_.SetAllocatedNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), name);
  // @@protoc_insertion_point(field_set_allocated:ubii.devices.Device.name)
}

// .ubii.devices.Device.DeviceType device_type = 3;
inline void Device::clear_device_type() {
  device_type_ = 0;
}
inline ::ubii::devices::Device_DeviceType Device::device_type() const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.device_type)
  return static_cast< ::ubii::devices::Device_DeviceType >(device_type_);
}
inline void Device::set_device_type(::ubii::devices::Device_DeviceType value) {
  
  device_type_ = value;
  // @@protoc_insertion_point(field_set:ubii.devices.Device.device_type)
}

// repeated .ubii.devices.Component components = 4;
inline int Device::components_size() const {
  return components_.size();
}
inline ::ubii::devices::Component* Device::mutable_components(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.devices.Device.components)
  return components_.Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField< ::ubii::devices::Component >*
Device::mutable_components() {
  // @@protoc_insertion_point(field_mutable_list:ubii.devices.Device.components)
  return &components_;
}
inline const ::ubii::devices::Component& Device::components(int index) const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.components)
  return components_.Get(index);
}
inline ::ubii::devices::Component* Device::add_components() {
  // @@protoc_insertion_point(field_add:ubii.devices.Device.components)
  return components_.Add();
}
inline const ::google::protobuf::RepeatedPtrField< ::ubii::devices::Component >&
Device::components() const {
  // @@protoc_insertion_point(field_list:ubii.devices.Device.components)
  return components_;
}

// string client_id = 5;
inline void Device::clear_client_id() {
  client_id_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline const ::std::string& Device::client_id() const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.client_id)
  return client_id_.GetNoArena();
}
inline void Device::set_client_id(const ::std::string& value) {
  
  client_id_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), value);
  // @@protoc_insertion_point(field_set:ubii.devices.Device.client_id)
}
#if LANG_CXX11
inline void Device::set_client_id(::std::string&& value) {
  
  client_id_.SetNoArena(
    &::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::move(value));
  // @@protoc_insertion_point(field_set_rvalue:ubii.devices.Device.client_id)
}
#endif
inline void Device::set_client_id(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  
  client_id_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::string(value));
  // @@protoc_insertion_point(field_set_char:ubii.devices.Device.client_id)
}
inline void Device::set_client_id(const char* value, size_t size) {
  
  client_id_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(),
      ::std::string(reinterpret_cast<const char*>(value), size));
  // @@protoc_insertion_point(field_set_pointer:ubii.devices.Device.client_id)
}
inline ::std::string* Device::mutable_client_id() {
  
  // @@protoc_insertion_point(field_mutable:ubii.devices.Device.client_id)
  return client_id_.MutableNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline ::std::string* Device::release_client_id() {
  // @@protoc_insertion_point(field_release:ubii.devices.Device.client_id)
  
  return client_id_.ReleaseNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline void Device::set_allocated_client_id(::std::string* client_id) {
  if (client_id != NULL) {
    
  } else {
    
  }
  client_id_.SetAllocatedNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), client_id);
  // @@protoc_insertion_point(field_set_allocated:ubii.devices.Device.client_id)
}

// repeated string tags = 6;
inline int Device::tags_size() const {
  return tags_.size();
}
inline void Device::clear_tags() {
  tags_.Clear();
}
inline const ::std::string& Device::tags(int index) const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.tags)
  return tags_.Get(index);
}
inline ::std::string* Device::mutable_tags(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.devices.Device.tags)
  return tags_.Mutable(index);
}
inline void Device::set_tags(int index, const ::std::string& value) {
  // @@protoc_insertion_point(field_set:ubii.devices.Device.tags)
  tags_.Mutable(index)->assign(value);
}
#if LANG_CXX11
inline void Device::set_tags(int index, ::std::string&& value) {
  // @@protoc_insertion_point(field_set:ubii.devices.Device.tags)
  tags_.Mutable(index)->assign(std::move(value));
}
#endif
inline void Device::set_tags(int index, const char* value) {
  GOOGLE_DCHECK(value != NULL);
  tags_.Mutable(index)->assign(value);
  // @@protoc_insertion_point(field_set_char:ubii.devices.Device.tags)
}
inline void Device::set_tags(int index, const char* value, size_t size) {
  tags_.Mutable(index)->assign(
    reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_set_pointer:ubii.devices.Device.tags)
}
inline ::std::string* Device::add_tags() {
  // @@protoc_insertion_point(field_add_mutable:ubii.devices.Device.tags)
  return tags_.Add();
}
inline void Device::add_tags(const ::std::string& value) {
  tags_.Add()->assign(value);
  // @@protoc_insertion_point(field_add:ubii.devices.Device.tags)
}
#if LANG_CXX11
inline void Device::add_tags(::std::string&& value) {
  tags_.Add(std::move(value));
  // @@protoc_insertion_point(field_add:ubii.devices.Device.tags)
}
#endif
inline void Device::add_tags(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  tags_.Add()->assign(value);
  // @@protoc_insertion_point(field_add_char:ubii.devices.Device.tags)
}
inline void Device::add_tags(const char* value, size_t size) {
  tags_.Add()->assign(reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_add_pointer:ubii.devices.Device.tags)
}
inline const ::google::protobuf::RepeatedPtrField< ::std::string>&
Device::tags() const {
  // @@protoc_insertion_point(field_list:ubii.devices.Device.tags)
  return tags_;
}
inline ::google::protobuf::RepeatedPtrField< ::std::string>*
Device::mutable_tags() {
  // @@protoc_insertion_point(field_mutable_list:ubii.devices.Device.tags)
  return &tags_;
}

// string description = 7;
inline void Device::clear_description() {
  description_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline const ::std::string& Device::description() const {
  // @@protoc_insertion_point(field_get:ubii.devices.Device.description)
  return description_.GetNoArena();
}
inline void Device::set_description(const ::std::string& value) {
  
  description_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), value);
  // @@protoc_insertion_point(field_set:ubii.devices.Device.description)
}
#if LANG_CXX11
inline void Device::set_description(::std::string&& value) {
  
  description_.SetNoArena(
    &::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::move(value));
  // @@protoc_insertion_point(field_set_rvalue:ubii.devices.Device.description)
}
#endif
inline void Device::set_description(const char* value) {
  GOOGLE_DCHECK(value != NULL);
  
  description_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), ::std::string(value));
  // @@protoc_insertion_point(field_set_char:ubii.devices.Device.description)
}
inline void Device::set_description(const char* value, size_t size) {
  
  description_.SetNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(),
      ::std::string(reinterpret_cast<const char*>(value), size));
  // @@protoc_insertion_point(field_set_pointer:ubii.devices.Device.description)
}
inline ::std::string* Device::mutable_description() {
  
  // @@protoc_insertion_point(field_mutable:ubii.devices.Device.description)
  return description_.MutableNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline ::std::string* Device::release_description() {
  // @@protoc_insertion_point(field_release:ubii.devices.Device.description)
  
  return description_.ReleaseNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}
inline void Device::set_allocated_description(::std::string* description) {
  if (description != NULL) {
    
  } else {
    
  }
  description_.SetAllocatedNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), description);
  // @@protoc_insertion_point(field_set_allocated:ubii.devices.Device.description)
}

// -------------------------------------------------------------------

// DeviceList

// repeated .ubii.devices.Device elements = 1;
inline int DeviceList::elements_size() const {
  return elements_.size();
}
inline void DeviceList::clear_elements() {
  elements_.Clear();
}
inline ::ubii::devices::Device* DeviceList::mutable_elements(int index) {
  // @@protoc_insertion_point(field_mutable:ubii.devices.DeviceList.elements)
  return elements_.Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField< ::ubii::devices::Device >*
DeviceList::mutable_elements() {
  // @@protoc_insertion_point(field_mutable_list:ubii.devices.DeviceList.elements)
  return &elements_;
}
inline const ::ubii::devices::Device& DeviceList::elements(int index) const {
  // @@protoc_insertion_point(field_get:ubii.devices.DeviceList.elements)
  return elements_.Get(index);
}
inline ::ubii::devices::Device* DeviceList::add_elements() {
  // @@protoc_insertion_point(field_add:ubii.devices.DeviceList.elements)
  return elements_.Add();
}
inline const ::google::protobuf::RepeatedPtrField< ::ubii::devices::Device >&
DeviceList::elements() const {
  // @@protoc_insertion_point(field_list:ubii.devices.DeviceList.elements)
  return elements_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


// @@protoc_insertion_point(namespace_scope)

}  // namespace devices
}  // namespace ubii

namespace google {
namespace protobuf {

template <> struct is_proto_enum< ::ubii::devices::Device_DeviceType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ubii::devices::Device_DeviceType>() {
  return ::ubii::devices::Device_DeviceType_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#endif  // PROTOBUF_INCLUDED_proto_2fdevices_2fdevice_2eproto
