// <auto-generated>
//     Generated by the protocol buffer compiler.  DO NOT EDIT!
//     source: proto/topicData/topicDataRecord/dataStructure/matrix3x2.proto
// </auto-generated>
#pragma warning disable 1591, 0612, 3021
#region Designer generated code

using pb = global::Google.Protobuf;
using pbc = global::Google.Protobuf.Collections;
using pbr = global::Google.Protobuf.Reflection;
using scg = global::System.Collections.Generic;
namespace Ubii.DataStructure {

  /// <summary>Holder for reflection information generated from proto/topicData/topicDataRecord/dataStructure/matrix3x2.proto</summary>
  public static partial class Matrix3X2Reflection {

    #region Descriptor
    /// <summary>File descriptor for proto/topicData/topicDataRecord/dataStructure/matrix3x2.proto</summary>
    public static pbr::FileDescriptor Descriptor {
      get { return descriptor; }
    }
    private static pbr::FileDescriptor descriptor;

    static Matrix3X2Reflection() {
      byte[] descriptorData = global::System.Convert.FromBase64String(
          string.Concat(
            "Cj1wcm90by90b3BpY0RhdGEvdG9waWNEYXRhUmVjb3JkL2RhdGFTdHJ1Y3R1",
            "cmUvbWF0cml4M3gyLnByb3RvEhJ1YmlpLmRhdGFTdHJ1Y3R1cmUiWQoJTWF0",
            "cml4M3gyEgsKA20wMBgBIAEoARILCgNtMDEYAiABKAESCwoDbTEwGAMgASgB",
            "EgsKA20xMRgEIAEoARILCgNtMjAYBSABKAESCwoDbTIxGAYgASgBYgZwcm90",
            "bzM="));
      descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
          new pbr::FileDescriptor[] { },
          new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
            new pbr::GeneratedClrTypeInfo(typeof(global::Ubii.DataStructure.Matrix3x2), global::Ubii.DataStructure.Matrix3x2.Parser, new[]{ "M00", "M01", "M10", "M11", "M20", "M21" }, null, null, null)
          }));
    }
    #endregion

  }
  #region Messages
  public sealed partial class Matrix3x2 : pb::IMessage<Matrix3x2> {
    private static readonly pb::MessageParser<Matrix3x2> _parser = new pb::MessageParser<Matrix3x2>(() => new Matrix3x2());
    private pb::UnknownFieldSet _unknownFields;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public static pb::MessageParser<Matrix3x2> Parser { get { return _parser; } }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public static pbr::MessageDescriptor Descriptor {
      get { return global::Ubii.DataStructure.Matrix3X2Reflection.Descriptor.MessageTypes[0]; }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    pbr::MessageDescriptor pb::IMessage.Descriptor {
      get { return Descriptor; }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public Matrix3x2() {
      OnConstruction();
    }

    partial void OnConstruction();

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public Matrix3x2(Matrix3x2 other) : this() {
      m00_ = other.m00_;
      m01_ = other.m01_;
      m10_ = other.m10_;
      m11_ = other.m11_;
      m20_ = other.m20_;
      m21_ = other.m21_;
      _unknownFields = pb::UnknownFieldSet.Clone(other._unknownFields);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public Matrix3x2 Clone() {
      return new Matrix3x2(this);
    }

    /// <summary>Field number for the "m00" field.</summary>
    public const int M00FieldNumber = 1;
    private double m00_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public double M00 {
      get { return m00_; }
      set {
        m00_ = value;
      }
    }

    /// <summary>Field number for the "m01" field.</summary>
    public const int M01FieldNumber = 2;
    private double m01_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public double M01 {
      get { return m01_; }
      set {
        m01_ = value;
      }
    }

    /// <summary>Field number for the "m10" field.</summary>
    public const int M10FieldNumber = 3;
    private double m10_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public double M10 {
      get { return m10_; }
      set {
        m10_ = value;
      }
    }

    /// <summary>Field number for the "m11" field.</summary>
    public const int M11FieldNumber = 4;
    private double m11_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public double M11 {
      get { return m11_; }
      set {
        m11_ = value;
      }
    }

    /// <summary>Field number for the "m20" field.</summary>
    public const int M20FieldNumber = 5;
    private double m20_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public double M20 {
      get { return m20_; }
      set {
        m20_ = value;
      }
    }

    /// <summary>Field number for the "m21" field.</summary>
    public const int M21FieldNumber = 6;
    private double m21_;
    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public double M21 {
      get { return m21_; }
      set {
        m21_ = value;
      }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public override bool Equals(object other) {
      return Equals(other as Matrix3x2);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public bool Equals(Matrix3x2 other) {
      if (ReferenceEquals(other, null)) {
        return false;
      }
      if (ReferenceEquals(other, this)) {
        return true;
      }
      if (!pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.Equals(M00, other.M00)) return false;
      if (!pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.Equals(M01, other.M01)) return false;
      if (!pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.Equals(M10, other.M10)) return false;
      if (!pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.Equals(M11, other.M11)) return false;
      if (!pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.Equals(M20, other.M20)) return false;
      if (!pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.Equals(M21, other.M21)) return false;
      return Equals(_unknownFields, other._unknownFields);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public override int GetHashCode() {
      int hash = 1;
      if (M00 != 0D) hash ^= pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.GetHashCode(M00);
      if (M01 != 0D) hash ^= pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.GetHashCode(M01);
      if (M10 != 0D) hash ^= pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.GetHashCode(M10);
      if (M11 != 0D) hash ^= pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.GetHashCode(M11);
      if (M20 != 0D) hash ^= pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.GetHashCode(M20);
      if (M21 != 0D) hash ^= pbc::ProtobufEqualityComparers.BitwiseDoubleEqualityComparer.GetHashCode(M21);
      if (_unknownFields != null) {
        hash ^= _unknownFields.GetHashCode();
      }
      return hash;
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public override string ToString() {
      return pb::JsonFormatter.ToDiagnosticString(this);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public void WriteTo(pb::CodedOutputStream output) {
      if (M00 != 0D) {
        output.WriteRawTag(9);
        output.WriteDouble(M00);
      }
      if (M01 != 0D) {
        output.WriteRawTag(17);
        output.WriteDouble(M01);
      }
      if (M10 != 0D) {
        output.WriteRawTag(25);
        output.WriteDouble(M10);
      }
      if (M11 != 0D) {
        output.WriteRawTag(33);
        output.WriteDouble(M11);
      }
      if (M20 != 0D) {
        output.WriteRawTag(41);
        output.WriteDouble(M20);
      }
      if (M21 != 0D) {
        output.WriteRawTag(49);
        output.WriteDouble(M21);
      }
      if (_unknownFields != null) {
        _unknownFields.WriteTo(output);
      }
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public int CalculateSize() {
      int size = 0;
      if (M00 != 0D) {
        size += 1 + 8;
      }
      if (M01 != 0D) {
        size += 1 + 8;
      }
      if (M10 != 0D) {
        size += 1 + 8;
      }
      if (M11 != 0D) {
        size += 1 + 8;
      }
      if (M20 != 0D) {
        size += 1 + 8;
      }
      if (M21 != 0D) {
        size += 1 + 8;
      }
      if (_unknownFields != null) {
        size += _unknownFields.CalculateSize();
      }
      return size;
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public void MergeFrom(Matrix3x2 other) {
      if (other == null) {
        return;
      }
      if (other.M00 != 0D) {
        M00 = other.M00;
      }
      if (other.M01 != 0D) {
        M01 = other.M01;
      }
      if (other.M10 != 0D) {
        M10 = other.M10;
      }
      if (other.M11 != 0D) {
        M11 = other.M11;
      }
      if (other.M20 != 0D) {
        M20 = other.M20;
      }
      if (other.M21 != 0D) {
        M21 = other.M21;
      }
      _unknownFields = pb::UnknownFieldSet.MergeFrom(_unknownFields, other._unknownFields);
    }

    [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
    public void MergeFrom(pb::CodedInputStream input) {
      uint tag;
      while ((tag = input.ReadTag()) != 0) {
        switch(tag) {
          default:
            _unknownFields = pb::UnknownFieldSet.MergeFieldFrom(_unknownFields, input);
            break;
          case 9: {
            M00 = input.ReadDouble();
            break;
          }
          case 17: {
            M01 = input.ReadDouble();
            break;
          }
          case 25: {
            M10 = input.ReadDouble();
            break;
          }
          case 33: {
            M11 = input.ReadDouble();
            break;
          }
          case 41: {
            M20 = input.ReadDouble();
            break;
          }
          case 49: {
            M21 = input.ReadDouble();
            break;
          }
        }
      }
    }

  }

  #endregion

}

#endregion Designer generated code
