"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto_v1.types.dataStructure.vector3_pb_plus import (
    Vector3,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Pose3D",
    }
)


class Pose3D(Message):
    position = Field(
        Vector3,
        number=1,
    )
    quaternion = Field(
        Quaternion,
        number=2,
        oneof='orientation',
    )
    euler = Field(
        Vector3,
        number=3,
        oneof='orientation',
    )


