// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/topicData/topicDataRecord/topicDataRecord.proto

package ubii.topicData;

public final class TopicDataRecordOuterClass {
  private TopicDataRecordOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface TopicDataRecordOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.topicData.TopicDataRecord)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string topic = 1;</code>
     */
    java.lang.String getTopic();
    /**
     * <code>string topic = 1;</code>
     */
    com.google.protobuf.ByteString
        getTopicBytes();

    /**
     * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
     */
    boolean hasTimestamp();
    /**
     * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
     */
    ubii.topicData.TimestampOuterClass.Timestamp getTimestamp();
    /**
     * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
     */
    ubii.topicData.TimestampOuterClass.TimestampOrBuilder getTimestampOrBuilder();

    /**
     * <code>double double = 3;</code>
     */
    double getDouble();

    /**
     * <code>bool bool = 4;</code>
     */
    boolean getBool();

    /**
     * <code>string string = 5;</code>
     */
    java.lang.String getString();
    /**
     * <code>string string = 5;</code>
     */
    com.google.protobuf.ByteString
        getStringBytes();

    /**
     * <code>int32 int32 = 23;</code>
     */
    int getInt32();

    /**
     * <code>float float = 24;</code>
     */
    float getFloat();

    /**
     * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
     */
    boolean hasVector2();
    /**
     * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2 getVector2();
    /**
     * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getVector2OrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
     */
    boolean hasVector2List();
    /**
     * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2List getVector2List();
    /**
     * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
     */
    ubii.dataStructure.Vector2OuterClass.Vector2ListOrBuilder getVector2ListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
     */
    boolean hasVector3();
    /**
     * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3 getVector3();
    /**
     * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getVector3OrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
     */
    boolean hasVector3List();
    /**
     * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3List getVector3List();
    /**
     * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
     */
    ubii.dataStructure.Vector3OuterClass.Vector3ListOrBuilder getVector3ListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
     */
    boolean hasVector4();
    /**
     * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
     */
    ubii.dataStructure.Vector4OuterClass.Vector4 getVector4();
    /**
     * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
     */
    ubii.dataStructure.Vector4OuterClass.Vector4OrBuilder getVector4OrBuilder();

    /**
     * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
     */
    boolean hasVector4List();
    /**
     * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
     */
    ubii.dataStructure.Vector4OuterClass.Vector4List getVector4List();
    /**
     * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
     */
    ubii.dataStructure.Vector4OuterClass.Vector4ListOrBuilder getVector4ListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
     */
    boolean hasQuaternion();
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
     */
    ubii.dataStructure.QuaternionOuterClass.Quaternion getQuaternion();
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
     */
    ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getQuaternionOrBuilder();

    /**
     * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
     */
    boolean hasQuaternionList();
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
     */
    ubii.dataStructure.QuaternionOuterClass.Quaternion getQuaternionList();
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
     */
    ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getQuaternionListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
     */
    boolean hasMatrix3X2();
    /**
     * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
     */
    ubii.dataStructure.Matrix3X2.Matrix3x2 getMatrix3X2();
    /**
     * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
     */
    ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder getMatrix3X2OrBuilder();

    /**
     * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
     */
    boolean hasMatrix4X4();
    /**
     * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
     */
    ubii.dataStructure.Matrix4X4.Matrix4x4 getMatrix4X4();
    /**
     * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
     */
    ubii.dataStructure.Matrix4X4.Matrix4x4OrBuilder getMatrix4X4OrBuilder();

    /**
     * <code>.ubii.dataStructure.Color color = 12;</code>
     */
    boolean hasColor();
    /**
     * <code>.ubii.dataStructure.Color color = 12;</code>
     */
    ubii.dataStructure.ColorOuterClass.Color getColor();
    /**
     * <code>.ubii.dataStructure.Color color = 12;</code>
     */
    ubii.dataStructure.ColorOuterClass.ColorOrBuilder getColorOrBuilder();

    /**
     * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
     */
    boolean hasTouchEvent();
    /**
     * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEvent getTouchEvent();
    /**
     * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder getTouchEventOrBuilder();

    /**
     * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
     */
    boolean hasTouchEventList();
    /**
     * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEventList getTouchEventList();
    /**
     * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
     */
    ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder getTouchEventListOrBuilder();

    /**
     * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
     */
    boolean hasKeyEvent();
    /**
     * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
     */
    ubii.dataStructure.KeyEventOuterClass.KeyEvent getKeyEvent();
    /**
     * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
     */
    ubii.dataStructure.KeyEventOuterClass.KeyEventOrBuilder getKeyEventOrBuilder();

    /**
     * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
     */
    boolean hasMouseEvent();
    /**
     * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
     */
    ubii.dataStructure.MouseEventOuterClass.MouseEvent getMouseEvent();
    /**
     * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
     */
    ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder getMouseEventOrBuilder();

    /**
     * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
     */
    boolean hasMyoEvent();
    /**
     * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
     */
    ubii.dataStructure.MyoEventOuterClass.MyoEvent getMyoEvent();
    /**
     * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
     */
    ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder getMyoEventOrBuilder();

    /**
     * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
     */
    boolean hasPose2D();
    /**
     * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
     */
    ubii.dataStructure.Pose2DOuterClass.Pose2D getPose2D();
    /**
     * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
     */
    ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder getPose2DOrBuilder();

    /**
     * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
     */
    boolean hasPose3D();
    /**
     * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
     */
    ubii.dataStructure.Pose3DOuterClass.Pose3D getPose3D();
    /**
     * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
     */
    ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder getPose3DOrBuilder();

    /**
     * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
     */
    boolean hasObject2D();
    /**
     * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
     */
    ubii.dataStructure.Object2DOuterClass.Object2D getObject2D();
    /**
     * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
     */
    ubii.dataStructure.Object2DOuterClass.Object2DOrBuilder getObject2DOrBuilder();

    /**
     * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
     */
    boolean hasObject3D();
    /**
     * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
     */
    ubii.dataStructure.Object3DOuterClass.Object3D getObject3D();
    /**
     * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
     */
    ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder getObject3DOrBuilder();

    /**
     * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
     */
    boolean hasObject2DList();
    /**
     * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
     */
    ubii.dataStructure.Object2DOuterClass.Object2DList getObject2DList();
    /**
     * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
     */
    ubii.dataStructure.Object2DOuterClass.Object2DListOrBuilder getObject2DListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
     */
    boolean hasObject3DList();
    /**
     * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
     */
    ubii.dataStructure.Object3DOuterClass.Object3DList getObject3DList();
    /**
     * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
     */
    ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder getObject3DListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
     */
    boolean hasInt32List();
    /**
     * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
     */
    ubii.dataStructure.Lists.Int32List getInt32List();
    /**
     * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
     */
    ubii.dataStructure.Lists.Int32ListOrBuilder getInt32ListOrBuilder();

    /**
     * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
     */
    boolean hasFloatList();
    /**
     * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
     */
    ubii.dataStructure.Lists.FloatList getFloatList();
    /**
     * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
     */
    ubii.dataStructure.Lists.FloatListOrBuilder getFloatListOrBuilder();

    /**
     * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
     */
    boolean hasDoubleList();
    /**
     * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
     */
    ubii.dataStructure.Lists.DoubleList getDoubleList();
    /**
     * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
     */
    ubii.dataStructure.Lists.DoubleListOrBuilder getDoubleListOrBuilder();

    /**
     * <code>.ubii.dataStructure.StringList string_list = 28;</code>
     */
    boolean hasStringList();
    /**
     * <code>.ubii.dataStructure.StringList string_list = 28;</code>
     */
    ubii.dataStructure.Lists.StringList getStringList();
    /**
     * <code>.ubii.dataStructure.StringList string_list = 28;</code>
     */
    ubii.dataStructure.Lists.StringListOrBuilder getStringListOrBuilder();

    /**
     * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
     */
    boolean hasBoolList();
    /**
     * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
     */
    ubii.dataStructure.Lists.BoolList getBoolList();
    /**
     * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
     */
    ubii.dataStructure.Lists.BoolListOrBuilder getBoolListOrBuilder();

    /**
     * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
     */
    boolean hasImage2D();
    /**
     * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
     */
    ubii.dataStructure.Image.Image2D getImage2D();
    /**
     * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
     */
    ubii.dataStructure.Image.Image2DOrBuilder getImage2DOrBuilder();

    /**
     * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
     */
    boolean hasImage2DList();
    /**
     * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
     */
    ubii.dataStructure.Image.Image2DList getImage2DList();
    /**
     * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
     */
    ubii.dataStructure.Image.Image2DListOrBuilder getImage2DListOrBuilder();

    /**
     * <code>.ubii.sessions.Session session = 32;</code>
     */
    boolean hasSession();
    /**
     * <code>.ubii.sessions.Session session = 32;</code>
     */
    ubii.sessions.SessionOuterClass.Session getSession();
    /**
     * <code>.ubii.sessions.Session session = 32;</code>
     */
    ubii.sessions.SessionOuterClass.SessionOrBuilder getSessionOrBuilder();

    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.TypeCase getTypeCase();
  }
  /**
   * <pre>
   * continuous index: 38
   * </pre>
   *
   * Protobuf type {@code ubii.topicData.TopicDataRecord}
   */
  public  static final class TopicDataRecord extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.topicData.TopicDataRecord)
      TopicDataRecordOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicDataRecord.newBuilder() to construct.
    private TopicDataRecord(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicDataRecord() {
      topic_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicDataRecord(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      int mutable_bitField1_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              topic_ = s;
              break;
            }
            case 18: {
              ubii.topicData.TimestampOuterClass.Timestamp.Builder subBuilder = null;
              if (timestamp_ != null) {
                subBuilder = timestamp_.toBuilder();
              }
              timestamp_ = input.readMessage(ubii.topicData.TimestampOuterClass.Timestamp.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom(timestamp_);
                timestamp_ = subBuilder.buildPartial();
              }

              break;
            }
            case 25: {
              typeCase_ = 3;
              type_ = input.readDouble();
              break;
            }
            case 32: {
              typeCase_ = 4;
              type_ = input.readBool();
              break;
            }
            case 42: {
              java.lang.String s = input.readStringRequireUtf8();
              typeCase_ = 5;
              type_ = s;
              break;
            }
            case 50: {
              ubii.dataStructure.Vector2OuterClass.Vector2.Builder subBuilder = null;
              if (typeCase_ == 6) {
                subBuilder = ((ubii.dataStructure.Vector2OuterClass.Vector2) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Vector2OuterClass.Vector2.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector2OuterClass.Vector2) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 6;
              break;
            }
            case 58: {
              ubii.dataStructure.Vector3OuterClass.Vector3.Builder subBuilder = null;
              if (typeCase_ == 7) {
                subBuilder = ((ubii.dataStructure.Vector3OuterClass.Vector3) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Vector3OuterClass.Vector3.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector3OuterClass.Vector3) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 7;
              break;
            }
            case 66: {
              ubii.dataStructure.Vector4OuterClass.Vector4.Builder subBuilder = null;
              if (typeCase_ == 8) {
                subBuilder = ((ubii.dataStructure.Vector4OuterClass.Vector4) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Vector4OuterClass.Vector4.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector4OuterClass.Vector4) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 8;
              break;
            }
            case 74: {
              ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder subBuilder = null;
              if (typeCase_ == 9) {
                subBuilder = ((ubii.dataStructure.QuaternionOuterClass.Quaternion) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.QuaternionOuterClass.Quaternion.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.QuaternionOuterClass.Quaternion) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 9;
              break;
            }
            case 82: {
              ubii.dataStructure.Matrix3X2.Matrix3x2.Builder subBuilder = null;
              if (typeCase_ == 10) {
                subBuilder = ((ubii.dataStructure.Matrix3X2.Matrix3x2) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Matrix3X2.Matrix3x2.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Matrix3X2.Matrix3x2) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 10;
              break;
            }
            case 90: {
              ubii.dataStructure.Matrix4X4.Matrix4x4.Builder subBuilder = null;
              if (typeCase_ == 11) {
                subBuilder = ((ubii.dataStructure.Matrix4X4.Matrix4x4) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Matrix4X4.Matrix4x4.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Matrix4X4.Matrix4x4) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 11;
              break;
            }
            case 98: {
              ubii.dataStructure.ColorOuterClass.Color.Builder subBuilder = null;
              if (typeCase_ == 12) {
                subBuilder = ((ubii.dataStructure.ColorOuterClass.Color) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.ColorOuterClass.Color.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.ColorOuterClass.Color) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 12;
              break;
            }
            case 106: {
              ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder subBuilder = null;
              if (typeCase_ == 13) {
                subBuilder = ((ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.TouchEventOuterClass.TouchEvent.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 13;
              break;
            }
            case 114: {
              ubii.dataStructure.KeyEventOuterClass.KeyEvent.Builder subBuilder = null;
              if (typeCase_ == 14) {
                subBuilder = ((ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.KeyEventOuterClass.KeyEvent.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 14;
              break;
            }
            case 122: {
              ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder subBuilder = null;
              if (typeCase_ == 15) {
                subBuilder = ((ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.MouseEventOuterClass.MouseEvent.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 15;
              break;
            }
            case 130: {
              ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder subBuilder = null;
              if (typeCase_ == 16) {
                subBuilder = ((ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.MyoEventOuterClass.MyoEvent.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 16;
              break;
            }
            case 138: {
              ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder subBuilder = null;
              if (typeCase_ == 17) {
                subBuilder = ((ubii.dataStructure.Pose2DOuterClass.Pose2D) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Pose2DOuterClass.Pose2D.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Pose2DOuterClass.Pose2D) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 17;
              break;
            }
            case 146: {
              ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder subBuilder = null;
              if (typeCase_ == 18) {
                subBuilder = ((ubii.dataStructure.Pose3DOuterClass.Pose3D) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Pose3DOuterClass.Pose3D.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Pose3DOuterClass.Pose3D) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 18;
              break;
            }
            case 154: {
              ubii.dataStructure.Object2DOuterClass.Object2D.Builder subBuilder = null;
              if (typeCase_ == 19) {
                subBuilder = ((ubii.dataStructure.Object2DOuterClass.Object2D) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Object2DOuterClass.Object2D.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Object2DOuterClass.Object2D) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 19;
              break;
            }
            case 162: {
              ubii.dataStructure.Object3DOuterClass.Object3D.Builder subBuilder = null;
              if (typeCase_ == 20) {
                subBuilder = ((ubii.dataStructure.Object3DOuterClass.Object3D) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Object3DOuterClass.Object3D.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Object3DOuterClass.Object3D) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 20;
              break;
            }
            case 170: {
              ubii.dataStructure.Object2DOuterClass.Object2DList.Builder subBuilder = null;
              if (typeCase_ == 21) {
                subBuilder = ((ubii.dataStructure.Object2DOuterClass.Object2DList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Object2DOuterClass.Object2DList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Object2DOuterClass.Object2DList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 21;
              break;
            }
            case 178: {
              ubii.dataStructure.Object3DOuterClass.Object3DList.Builder subBuilder = null;
              if (typeCase_ == 22) {
                subBuilder = ((ubii.dataStructure.Object3DOuterClass.Object3DList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Object3DOuterClass.Object3DList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Object3DOuterClass.Object3DList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 22;
              break;
            }
            case 184: {
              typeCase_ = 23;
              type_ = input.readInt32();
              break;
            }
            case 197: {
              typeCase_ = 24;
              type_ = input.readFloat();
              break;
            }
            case 202: {
              ubii.dataStructure.Lists.Int32List.Builder subBuilder = null;
              if (typeCase_ == 25) {
                subBuilder = ((ubii.dataStructure.Lists.Int32List) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Lists.Int32List.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Lists.Int32List) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 25;
              break;
            }
            case 210: {
              ubii.dataStructure.Lists.FloatList.Builder subBuilder = null;
              if (typeCase_ == 26) {
                subBuilder = ((ubii.dataStructure.Lists.FloatList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Lists.FloatList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Lists.FloatList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 26;
              break;
            }
            case 218: {
              ubii.dataStructure.Lists.DoubleList.Builder subBuilder = null;
              if (typeCase_ == 27) {
                subBuilder = ((ubii.dataStructure.Lists.DoubleList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Lists.DoubleList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Lists.DoubleList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 27;
              break;
            }
            case 226: {
              ubii.dataStructure.Lists.StringList.Builder subBuilder = null;
              if (typeCase_ == 28) {
                subBuilder = ((ubii.dataStructure.Lists.StringList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Lists.StringList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Lists.StringList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 28;
              break;
            }
            case 234: {
              ubii.dataStructure.Lists.BoolList.Builder subBuilder = null;
              if (typeCase_ == 29) {
                subBuilder = ((ubii.dataStructure.Lists.BoolList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Lists.BoolList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Lists.BoolList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 29;
              break;
            }
            case 242: {
              ubii.dataStructure.Image.Image2D.Builder subBuilder = null;
              if (typeCase_ == 30) {
                subBuilder = ((ubii.dataStructure.Image.Image2D) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Image.Image2D.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Image.Image2D) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 30;
              break;
            }
            case 250: {
              ubii.dataStructure.Image.Image2DList.Builder subBuilder = null;
              if (typeCase_ == 31) {
                subBuilder = ((ubii.dataStructure.Image.Image2DList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Image.Image2DList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Image.Image2DList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 31;
              break;
            }
            case 258: {
              ubii.sessions.SessionOuterClass.Session.Builder subBuilder = null;
              if (typeCase_ == 32) {
                subBuilder = ((ubii.sessions.SessionOuterClass.Session) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.sessions.SessionOuterClass.Session.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.sessions.SessionOuterClass.Session) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 32;
              break;
            }
            case 274: {
              ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder subBuilder = null;
              if (typeCase_ == 34) {
                subBuilder = ((ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.TouchEventOuterClass.TouchEventList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 34;
              break;
            }
            case 282: {
              ubii.dataStructure.Vector2OuterClass.Vector2List.Builder subBuilder = null;
              if (typeCase_ == 35) {
                subBuilder = ((ubii.dataStructure.Vector2OuterClass.Vector2List) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Vector2OuterClass.Vector2List.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector2OuterClass.Vector2List) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 35;
              break;
            }
            case 290: {
              ubii.dataStructure.Vector3OuterClass.Vector3List.Builder subBuilder = null;
              if (typeCase_ == 36) {
                subBuilder = ((ubii.dataStructure.Vector3OuterClass.Vector3List) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Vector3OuterClass.Vector3List.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector3OuterClass.Vector3List) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 36;
              break;
            }
            case 298: {
              ubii.dataStructure.Vector4OuterClass.Vector4List.Builder subBuilder = null;
              if (typeCase_ == 37) {
                subBuilder = ((ubii.dataStructure.Vector4OuterClass.Vector4List) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Vector4OuterClass.Vector4List.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Vector4OuterClass.Vector4List) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 37;
              break;
            }
            case 306: {
              ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder subBuilder = null;
              if (typeCase_ == 38) {
                subBuilder = ((ubii.dataStructure.QuaternionOuterClass.Quaternion) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.QuaternionOuterClass.Quaternion.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.QuaternionOuterClass.Quaternion) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 38;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecord_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecord_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.class, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder.class);
    }

    private int typeCase_ = 0;
    private java.lang.Object type_;
    public enum TypeCase
        implements com.google.protobuf.Internal.EnumLite {
      DOUBLE(3),
      BOOL(4),
      STRING(5),
      INT32(23),
      FLOAT(24),
      VECTOR2(6),
      VECTOR2_LIST(35),
      VECTOR3(7),
      VECTOR3_LIST(36),
      VECTOR4(8),
      VECTOR4_LIST(37),
      QUATERNION(9),
      QUATERNION_LIST(38),
      MATRIX3X2(10),
      MATRIX4X4(11),
      COLOR(12),
      TOUCH_EVENT(13),
      TOUCH_EVENT_LIST(34),
      KEY_EVENT(14),
      MOUSE_EVENT(15),
      MYO_EVENT(16),
      POSE2D(17),
      POSE3D(18),
      OBJECT2D(19),
      OBJECT3D(20),
      OBJECT2D_LIST(21),
      OBJECT3D_LIST(22),
      INT32_LIST(25),
      FLOAT_LIST(26),
      DOUBLE_LIST(27),
      STRING_LIST(28),
      BOOL_LIST(29),
      IMAGE2D(30),
      IMAGE2D_LIST(31),
      SESSION(32),
      TYPE_NOT_SET(0);
      private final int value;
      private TypeCase(int value) {
        this.value = value;
      }
      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static TypeCase valueOf(int value) {
        return forNumber(value);
      }

      public static TypeCase forNumber(int value) {
        switch (value) {
          case 3: return DOUBLE;
          case 4: return BOOL;
          case 5: return STRING;
          case 23: return INT32;
          case 24: return FLOAT;
          case 6: return VECTOR2;
          case 35: return VECTOR2_LIST;
          case 7: return VECTOR3;
          case 36: return VECTOR3_LIST;
          case 8: return VECTOR4;
          case 37: return VECTOR4_LIST;
          case 9: return QUATERNION;
          case 38: return QUATERNION_LIST;
          case 10: return MATRIX3X2;
          case 11: return MATRIX4X4;
          case 12: return COLOR;
          case 13: return TOUCH_EVENT;
          case 34: return TOUCH_EVENT_LIST;
          case 14: return KEY_EVENT;
          case 15: return MOUSE_EVENT;
          case 16: return MYO_EVENT;
          case 17: return POSE2D;
          case 18: return POSE3D;
          case 19: return OBJECT2D;
          case 20: return OBJECT3D;
          case 21: return OBJECT2D_LIST;
          case 22: return OBJECT3D_LIST;
          case 25: return INT32_LIST;
          case 26: return FLOAT_LIST;
          case 27: return DOUBLE_LIST;
          case 28: return STRING_LIST;
          case 29: return BOOL_LIST;
          case 30: return IMAGE2D;
          case 31: return IMAGE2D_LIST;
          case 32: return SESSION;
          case 0: return TYPE_NOT_SET;
          default: return null;
        }
      }
      public int getNumber() {
        return this.value;
      }
    };

    public TypeCase
    getTypeCase() {
      return TypeCase.forNumber(
          typeCase_);
    }

    public static final int TOPIC_FIELD_NUMBER = 1;
    private volatile java.lang.Object topic_;
    /**
     * <code>string topic = 1;</code>
     */
    public java.lang.String getTopic() {
      java.lang.Object ref = topic_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        topic_ = s;
        return s;
      }
    }
    /**
     * <code>string topic = 1;</code>
     */
    public com.google.protobuf.ByteString
        getTopicBytes() {
      java.lang.Object ref = topic_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        topic_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int TIMESTAMP_FIELD_NUMBER = 2;
    private ubii.topicData.TimestampOuterClass.Timestamp timestamp_;
    /**
     * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
     */
    public boolean hasTimestamp() {
      return timestamp_ != null;
    }
    /**
     * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
     */
    public ubii.topicData.TimestampOuterClass.Timestamp getTimestamp() {
      return timestamp_ == null ? ubii.topicData.TimestampOuterClass.Timestamp.getDefaultInstance() : timestamp_;
    }
    /**
     * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
     */
    public ubii.topicData.TimestampOuterClass.TimestampOrBuilder getTimestampOrBuilder() {
      return getTimestamp();
    }

    public static final int DOUBLE_FIELD_NUMBER = 3;
    /**
     * <code>double double = 3;</code>
     */
    public double getDouble() {
      if (typeCase_ == 3) {
        return (java.lang.Double) type_;
      }
      return 0D;
    }

    public static final int BOOL_FIELD_NUMBER = 4;
    /**
     * <code>bool bool = 4;</code>
     */
    public boolean getBool() {
      if (typeCase_ == 4) {
        return (java.lang.Boolean) type_;
      }
      return false;
    }

    public static final int STRING_FIELD_NUMBER = 5;
    /**
     * <code>string string = 5;</code>
     */
    public java.lang.String getString() {
      java.lang.Object ref = "";
      if (typeCase_ == 5) {
        ref = type_;
      }
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        if (typeCase_ == 5) {
          type_ = s;
        }
        return s;
      }
    }
    /**
     * <code>string string = 5;</code>
     */
    public com.google.protobuf.ByteString
        getStringBytes() {
      java.lang.Object ref = "";
      if (typeCase_ == 5) {
        ref = type_;
      }
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        if (typeCase_ == 5) {
          type_ = b;
        }
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int INT32_FIELD_NUMBER = 23;
    /**
     * <code>int32 int32 = 23;</code>
     */
    public int getInt32() {
      if (typeCase_ == 23) {
        return (java.lang.Integer) type_;
      }
      return 0;
    }

    public static final int FLOAT_FIELD_NUMBER = 24;
    /**
     * <code>float float = 24;</code>
     */
    public float getFloat() {
      if (typeCase_ == 24) {
        return (java.lang.Float) type_;
      }
      return 0F;
    }

    public static final int VECTOR2_FIELD_NUMBER = 6;
    /**
     * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
     */
    public boolean hasVector2() {
      return typeCase_ == 6;
    }
    /**
     * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2 getVector2() {
      if (typeCase_ == 6) {
         return (ubii.dataStructure.Vector2OuterClass.Vector2) type_;
      }
      return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getVector2OrBuilder() {
      if (typeCase_ == 6) {
         return (ubii.dataStructure.Vector2OuterClass.Vector2) type_;
      }
      return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
    }

    public static final int VECTOR2_LIST_FIELD_NUMBER = 35;
    /**
     * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
     */
    public boolean hasVector2List() {
      return typeCase_ == 35;
    }
    /**
     * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2List getVector2List() {
      if (typeCase_ == 35) {
         return (ubii.dataStructure.Vector2OuterClass.Vector2List) type_;
      }
      return ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
     */
    public ubii.dataStructure.Vector2OuterClass.Vector2ListOrBuilder getVector2ListOrBuilder() {
      if (typeCase_ == 35) {
         return (ubii.dataStructure.Vector2OuterClass.Vector2List) type_;
      }
      return ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance();
    }

    public static final int VECTOR3_FIELD_NUMBER = 7;
    /**
     * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
     */
    public boolean hasVector3() {
      return typeCase_ == 7;
    }
    /**
     * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3 getVector3() {
      if (typeCase_ == 7) {
         return (ubii.dataStructure.Vector3OuterClass.Vector3) type_;
      }
      return ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getVector3OrBuilder() {
      if (typeCase_ == 7) {
         return (ubii.dataStructure.Vector3OuterClass.Vector3) type_;
      }
      return ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance();
    }

    public static final int VECTOR3_LIST_FIELD_NUMBER = 36;
    /**
     * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
     */
    public boolean hasVector3List() {
      return typeCase_ == 36;
    }
    /**
     * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3List getVector3List() {
      if (typeCase_ == 36) {
         return (ubii.dataStructure.Vector3OuterClass.Vector3List) type_;
      }
      return ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
     */
    public ubii.dataStructure.Vector3OuterClass.Vector3ListOrBuilder getVector3ListOrBuilder() {
      if (typeCase_ == 36) {
         return (ubii.dataStructure.Vector3OuterClass.Vector3List) type_;
      }
      return ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance();
    }

    public static final int VECTOR4_FIELD_NUMBER = 8;
    /**
     * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
     */
    public boolean hasVector4() {
      return typeCase_ == 8;
    }
    /**
     * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
     */
    public ubii.dataStructure.Vector4OuterClass.Vector4 getVector4() {
      if (typeCase_ == 8) {
         return (ubii.dataStructure.Vector4OuterClass.Vector4) type_;
      }
      return ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
     */
    public ubii.dataStructure.Vector4OuterClass.Vector4OrBuilder getVector4OrBuilder() {
      if (typeCase_ == 8) {
         return (ubii.dataStructure.Vector4OuterClass.Vector4) type_;
      }
      return ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance();
    }

    public static final int VECTOR4_LIST_FIELD_NUMBER = 37;
    /**
     * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
     */
    public boolean hasVector4List() {
      return typeCase_ == 37;
    }
    /**
     * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
     */
    public ubii.dataStructure.Vector4OuterClass.Vector4List getVector4List() {
      if (typeCase_ == 37) {
         return (ubii.dataStructure.Vector4OuterClass.Vector4List) type_;
      }
      return ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
     */
    public ubii.dataStructure.Vector4OuterClass.Vector4ListOrBuilder getVector4ListOrBuilder() {
      if (typeCase_ == 37) {
         return (ubii.dataStructure.Vector4OuterClass.Vector4List) type_;
      }
      return ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance();
    }

    public static final int QUATERNION_FIELD_NUMBER = 9;
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
     */
    public boolean hasQuaternion() {
      return typeCase_ == 9;
    }
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
     */
    public ubii.dataStructure.QuaternionOuterClass.Quaternion getQuaternion() {
      if (typeCase_ == 9) {
         return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
      }
      return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
     */
    public ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getQuaternionOrBuilder() {
      if (typeCase_ == 9) {
         return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
      }
      return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
    }

    public static final int QUATERNION_LIST_FIELD_NUMBER = 38;
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
     */
    public boolean hasQuaternionList() {
      return typeCase_ == 38;
    }
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
     */
    public ubii.dataStructure.QuaternionOuterClass.Quaternion getQuaternionList() {
      if (typeCase_ == 38) {
         return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
      }
      return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
     */
    public ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getQuaternionListOrBuilder() {
      if (typeCase_ == 38) {
         return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
      }
      return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
    }

    public static final int MATRIX3X2_FIELD_NUMBER = 10;
    /**
     * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
     */
    public boolean hasMatrix3X2() {
      return typeCase_ == 10;
    }
    /**
     * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
     */
    public ubii.dataStructure.Matrix3X2.Matrix3x2 getMatrix3X2() {
      if (typeCase_ == 10) {
         return (ubii.dataStructure.Matrix3X2.Matrix3x2) type_;
      }
      return ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
     */
    public ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder getMatrix3X2OrBuilder() {
      if (typeCase_ == 10) {
         return (ubii.dataStructure.Matrix3X2.Matrix3x2) type_;
      }
      return ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
    }

    public static final int MATRIX4X4_FIELD_NUMBER = 11;
    /**
     * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
     */
    public boolean hasMatrix4X4() {
      return typeCase_ == 11;
    }
    /**
     * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
     */
    public ubii.dataStructure.Matrix4X4.Matrix4x4 getMatrix4X4() {
      if (typeCase_ == 11) {
         return (ubii.dataStructure.Matrix4X4.Matrix4x4) type_;
      }
      return ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
     */
    public ubii.dataStructure.Matrix4X4.Matrix4x4OrBuilder getMatrix4X4OrBuilder() {
      if (typeCase_ == 11) {
         return (ubii.dataStructure.Matrix4X4.Matrix4x4) type_;
      }
      return ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance();
    }

    public static final int COLOR_FIELD_NUMBER = 12;
    /**
     * <code>.ubii.dataStructure.Color color = 12;</code>
     */
    public boolean hasColor() {
      return typeCase_ == 12;
    }
    /**
     * <code>.ubii.dataStructure.Color color = 12;</code>
     */
    public ubii.dataStructure.ColorOuterClass.Color getColor() {
      if (typeCase_ == 12) {
         return (ubii.dataStructure.ColorOuterClass.Color) type_;
      }
      return ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Color color = 12;</code>
     */
    public ubii.dataStructure.ColorOuterClass.ColorOrBuilder getColorOrBuilder() {
      if (typeCase_ == 12) {
         return (ubii.dataStructure.ColorOuterClass.Color) type_;
      }
      return ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance();
    }

    public static final int TOUCH_EVENT_FIELD_NUMBER = 13;
    /**
     * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
     */
    public boolean hasTouchEvent() {
      return typeCase_ == 13;
    }
    /**
     * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEvent getTouchEvent() {
      if (typeCase_ == 13) {
         return (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_;
      }
      return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder getTouchEventOrBuilder() {
      if (typeCase_ == 13) {
         return (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_;
      }
      return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
    }

    public static final int TOUCH_EVENT_LIST_FIELD_NUMBER = 34;
    /**
     * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
     */
    public boolean hasTouchEventList() {
      return typeCase_ == 34;
    }
    /**
     * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEventList getTouchEventList() {
      if (typeCase_ == 34) {
         return (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_;
      }
      return ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
     */
    public ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder getTouchEventListOrBuilder() {
      if (typeCase_ == 34) {
         return (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_;
      }
      return ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
    }

    public static final int KEY_EVENT_FIELD_NUMBER = 14;
    /**
     * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
     */
    public boolean hasKeyEvent() {
      return typeCase_ == 14;
    }
    /**
     * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
     */
    public ubii.dataStructure.KeyEventOuterClass.KeyEvent getKeyEvent() {
      if (typeCase_ == 14) {
         return (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_;
      }
      return ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
     */
    public ubii.dataStructure.KeyEventOuterClass.KeyEventOrBuilder getKeyEventOrBuilder() {
      if (typeCase_ == 14) {
         return (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_;
      }
      return ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance();
    }

    public static final int MOUSE_EVENT_FIELD_NUMBER = 15;
    /**
     * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
     */
    public boolean hasMouseEvent() {
      return typeCase_ == 15;
    }
    /**
     * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
     */
    public ubii.dataStructure.MouseEventOuterClass.MouseEvent getMouseEvent() {
      if (typeCase_ == 15) {
         return (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_;
      }
      return ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
     */
    public ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder getMouseEventOrBuilder() {
      if (typeCase_ == 15) {
         return (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_;
      }
      return ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
    }

    public static final int MYO_EVENT_FIELD_NUMBER = 16;
    /**
     * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
     */
    public boolean hasMyoEvent() {
      return typeCase_ == 16;
    }
    /**
     * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
     */
    public ubii.dataStructure.MyoEventOuterClass.MyoEvent getMyoEvent() {
      if (typeCase_ == 16) {
         return (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_;
      }
      return ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
     */
    public ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder getMyoEventOrBuilder() {
      if (typeCase_ == 16) {
         return (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_;
      }
      return ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
    }

    public static final int POSE2D_FIELD_NUMBER = 17;
    /**
     * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
     */
    public boolean hasPose2D() {
      return typeCase_ == 17;
    }
    /**
     * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
     */
    public ubii.dataStructure.Pose2DOuterClass.Pose2D getPose2D() {
      if (typeCase_ == 17) {
         return (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_;
      }
      return ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
     */
    public ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder getPose2DOrBuilder() {
      if (typeCase_ == 17) {
         return (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_;
      }
      return ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
    }

    public static final int POSE3D_FIELD_NUMBER = 18;
    /**
     * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
     */
    public boolean hasPose3D() {
      return typeCase_ == 18;
    }
    /**
     * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
     */
    public ubii.dataStructure.Pose3DOuterClass.Pose3D getPose3D() {
      if (typeCase_ == 18) {
         return (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_;
      }
      return ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
     */
    public ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder getPose3DOrBuilder() {
      if (typeCase_ == 18) {
         return (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_;
      }
      return ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance();
    }

    public static final int OBJECT2D_FIELD_NUMBER = 19;
    /**
     * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
     */
    public boolean hasObject2D() {
      return typeCase_ == 19;
    }
    /**
     * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
     */
    public ubii.dataStructure.Object2DOuterClass.Object2D getObject2D() {
      if (typeCase_ == 19) {
         return (ubii.dataStructure.Object2DOuterClass.Object2D) type_;
      }
      return ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
     */
    public ubii.dataStructure.Object2DOuterClass.Object2DOrBuilder getObject2DOrBuilder() {
      if (typeCase_ == 19) {
         return (ubii.dataStructure.Object2DOuterClass.Object2D) type_;
      }
      return ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance();
    }

    public static final int OBJECT3D_FIELD_NUMBER = 20;
    /**
     * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
     */
    public boolean hasObject3D() {
      return typeCase_ == 20;
    }
    /**
     * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
     */
    public ubii.dataStructure.Object3DOuterClass.Object3D getObject3D() {
      if (typeCase_ == 20) {
         return (ubii.dataStructure.Object3DOuterClass.Object3D) type_;
      }
      return ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
     */
    public ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder getObject3DOrBuilder() {
      if (typeCase_ == 20) {
         return (ubii.dataStructure.Object3DOuterClass.Object3D) type_;
      }
      return ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
    }

    public static final int OBJECT2D_LIST_FIELD_NUMBER = 21;
    /**
     * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
     */
    public boolean hasObject2DList() {
      return typeCase_ == 21;
    }
    /**
     * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
     */
    public ubii.dataStructure.Object2DOuterClass.Object2DList getObject2DList() {
      if (typeCase_ == 21) {
         return (ubii.dataStructure.Object2DOuterClass.Object2DList) type_;
      }
      return ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
     */
    public ubii.dataStructure.Object2DOuterClass.Object2DListOrBuilder getObject2DListOrBuilder() {
      if (typeCase_ == 21) {
         return (ubii.dataStructure.Object2DOuterClass.Object2DList) type_;
      }
      return ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance();
    }

    public static final int OBJECT3D_LIST_FIELD_NUMBER = 22;
    /**
     * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
     */
    public boolean hasObject3DList() {
      return typeCase_ == 22;
    }
    /**
     * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
     */
    public ubii.dataStructure.Object3DOuterClass.Object3DList getObject3DList() {
      if (typeCase_ == 22) {
         return (ubii.dataStructure.Object3DOuterClass.Object3DList) type_;
      }
      return ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
     */
    public ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder getObject3DListOrBuilder() {
      if (typeCase_ == 22) {
         return (ubii.dataStructure.Object3DOuterClass.Object3DList) type_;
      }
      return ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
    }

    public static final int INT32_LIST_FIELD_NUMBER = 25;
    /**
     * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
     */
    public boolean hasInt32List() {
      return typeCase_ == 25;
    }
    /**
     * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
     */
    public ubii.dataStructure.Lists.Int32List getInt32List() {
      if (typeCase_ == 25) {
         return (ubii.dataStructure.Lists.Int32List) type_;
      }
      return ubii.dataStructure.Lists.Int32List.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
     */
    public ubii.dataStructure.Lists.Int32ListOrBuilder getInt32ListOrBuilder() {
      if (typeCase_ == 25) {
         return (ubii.dataStructure.Lists.Int32List) type_;
      }
      return ubii.dataStructure.Lists.Int32List.getDefaultInstance();
    }

    public static final int FLOAT_LIST_FIELD_NUMBER = 26;
    /**
     * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
     */
    public boolean hasFloatList() {
      return typeCase_ == 26;
    }
    /**
     * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
     */
    public ubii.dataStructure.Lists.FloatList getFloatList() {
      if (typeCase_ == 26) {
         return (ubii.dataStructure.Lists.FloatList) type_;
      }
      return ubii.dataStructure.Lists.FloatList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
     */
    public ubii.dataStructure.Lists.FloatListOrBuilder getFloatListOrBuilder() {
      if (typeCase_ == 26) {
         return (ubii.dataStructure.Lists.FloatList) type_;
      }
      return ubii.dataStructure.Lists.FloatList.getDefaultInstance();
    }

    public static final int DOUBLE_LIST_FIELD_NUMBER = 27;
    /**
     * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
     */
    public boolean hasDoubleList() {
      return typeCase_ == 27;
    }
    /**
     * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
     */
    public ubii.dataStructure.Lists.DoubleList getDoubleList() {
      if (typeCase_ == 27) {
         return (ubii.dataStructure.Lists.DoubleList) type_;
      }
      return ubii.dataStructure.Lists.DoubleList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
     */
    public ubii.dataStructure.Lists.DoubleListOrBuilder getDoubleListOrBuilder() {
      if (typeCase_ == 27) {
         return (ubii.dataStructure.Lists.DoubleList) type_;
      }
      return ubii.dataStructure.Lists.DoubleList.getDefaultInstance();
    }

    public static final int STRING_LIST_FIELD_NUMBER = 28;
    /**
     * <code>.ubii.dataStructure.StringList string_list = 28;</code>
     */
    public boolean hasStringList() {
      return typeCase_ == 28;
    }
    /**
     * <code>.ubii.dataStructure.StringList string_list = 28;</code>
     */
    public ubii.dataStructure.Lists.StringList getStringList() {
      if (typeCase_ == 28) {
         return (ubii.dataStructure.Lists.StringList) type_;
      }
      return ubii.dataStructure.Lists.StringList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.StringList string_list = 28;</code>
     */
    public ubii.dataStructure.Lists.StringListOrBuilder getStringListOrBuilder() {
      if (typeCase_ == 28) {
         return (ubii.dataStructure.Lists.StringList) type_;
      }
      return ubii.dataStructure.Lists.StringList.getDefaultInstance();
    }

    public static final int BOOL_LIST_FIELD_NUMBER = 29;
    /**
     * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
     */
    public boolean hasBoolList() {
      return typeCase_ == 29;
    }
    /**
     * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
     */
    public ubii.dataStructure.Lists.BoolList getBoolList() {
      if (typeCase_ == 29) {
         return (ubii.dataStructure.Lists.BoolList) type_;
      }
      return ubii.dataStructure.Lists.BoolList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
     */
    public ubii.dataStructure.Lists.BoolListOrBuilder getBoolListOrBuilder() {
      if (typeCase_ == 29) {
         return (ubii.dataStructure.Lists.BoolList) type_;
      }
      return ubii.dataStructure.Lists.BoolList.getDefaultInstance();
    }

    public static final int IMAGE2D_FIELD_NUMBER = 30;
    /**
     * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
     */
    public boolean hasImage2D() {
      return typeCase_ == 30;
    }
    /**
     * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
     */
    public ubii.dataStructure.Image.Image2D getImage2D() {
      if (typeCase_ == 30) {
         return (ubii.dataStructure.Image.Image2D) type_;
      }
      return ubii.dataStructure.Image.Image2D.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
     */
    public ubii.dataStructure.Image.Image2DOrBuilder getImage2DOrBuilder() {
      if (typeCase_ == 30) {
         return (ubii.dataStructure.Image.Image2D) type_;
      }
      return ubii.dataStructure.Image.Image2D.getDefaultInstance();
    }

    public static final int IMAGE2D_LIST_FIELD_NUMBER = 31;
    /**
     * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
     */
    public boolean hasImage2DList() {
      return typeCase_ == 31;
    }
    /**
     * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
     */
    public ubii.dataStructure.Image.Image2DList getImage2DList() {
      if (typeCase_ == 31) {
         return (ubii.dataStructure.Image.Image2DList) type_;
      }
      return ubii.dataStructure.Image.Image2DList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
     */
    public ubii.dataStructure.Image.Image2DListOrBuilder getImage2DListOrBuilder() {
      if (typeCase_ == 31) {
         return (ubii.dataStructure.Image.Image2DList) type_;
      }
      return ubii.dataStructure.Image.Image2DList.getDefaultInstance();
    }

    public static final int SESSION_FIELD_NUMBER = 32;
    /**
     * <code>.ubii.sessions.Session session = 32;</code>
     */
    public boolean hasSession() {
      return typeCase_ == 32;
    }
    /**
     * <code>.ubii.sessions.Session session = 32;</code>
     */
    public ubii.sessions.SessionOuterClass.Session getSession() {
      if (typeCase_ == 32) {
         return (ubii.sessions.SessionOuterClass.Session) type_;
      }
      return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
    }
    /**
     * <code>.ubii.sessions.Session session = 32;</code>
     */
    public ubii.sessions.SessionOuterClass.SessionOrBuilder getSessionOrBuilder() {
      if (typeCase_ == 32) {
         return (ubii.sessions.SessionOuterClass.Session) type_;
      }
      return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getTopicBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, topic_);
      }
      if (timestamp_ != null) {
        output.writeMessage(2, getTimestamp());
      }
      if (typeCase_ == 3) {
        output.writeDouble(
            3, (double)((java.lang.Double) type_));
      }
      if (typeCase_ == 4) {
        output.writeBool(
            4, (boolean)((java.lang.Boolean) type_));
      }
      if (typeCase_ == 5) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 5, type_);
      }
      if (typeCase_ == 6) {
        output.writeMessage(6, (ubii.dataStructure.Vector2OuterClass.Vector2) type_);
      }
      if (typeCase_ == 7) {
        output.writeMessage(7, (ubii.dataStructure.Vector3OuterClass.Vector3) type_);
      }
      if (typeCase_ == 8) {
        output.writeMessage(8, (ubii.dataStructure.Vector4OuterClass.Vector4) type_);
      }
      if (typeCase_ == 9) {
        output.writeMessage(9, (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_);
      }
      if (typeCase_ == 10) {
        output.writeMessage(10, (ubii.dataStructure.Matrix3X2.Matrix3x2) type_);
      }
      if (typeCase_ == 11) {
        output.writeMessage(11, (ubii.dataStructure.Matrix4X4.Matrix4x4) type_);
      }
      if (typeCase_ == 12) {
        output.writeMessage(12, (ubii.dataStructure.ColorOuterClass.Color) type_);
      }
      if (typeCase_ == 13) {
        output.writeMessage(13, (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_);
      }
      if (typeCase_ == 14) {
        output.writeMessage(14, (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_);
      }
      if (typeCase_ == 15) {
        output.writeMessage(15, (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_);
      }
      if (typeCase_ == 16) {
        output.writeMessage(16, (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_);
      }
      if (typeCase_ == 17) {
        output.writeMessage(17, (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_);
      }
      if (typeCase_ == 18) {
        output.writeMessage(18, (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_);
      }
      if (typeCase_ == 19) {
        output.writeMessage(19, (ubii.dataStructure.Object2DOuterClass.Object2D) type_);
      }
      if (typeCase_ == 20) {
        output.writeMessage(20, (ubii.dataStructure.Object3DOuterClass.Object3D) type_);
      }
      if (typeCase_ == 21) {
        output.writeMessage(21, (ubii.dataStructure.Object2DOuterClass.Object2DList) type_);
      }
      if (typeCase_ == 22) {
        output.writeMessage(22, (ubii.dataStructure.Object3DOuterClass.Object3DList) type_);
      }
      if (typeCase_ == 23) {
        output.writeInt32(
            23, (int)((java.lang.Integer) type_));
      }
      if (typeCase_ == 24) {
        output.writeFloat(
            24, (float)((java.lang.Float) type_));
      }
      if (typeCase_ == 25) {
        output.writeMessage(25, (ubii.dataStructure.Lists.Int32List) type_);
      }
      if (typeCase_ == 26) {
        output.writeMessage(26, (ubii.dataStructure.Lists.FloatList) type_);
      }
      if (typeCase_ == 27) {
        output.writeMessage(27, (ubii.dataStructure.Lists.DoubleList) type_);
      }
      if (typeCase_ == 28) {
        output.writeMessage(28, (ubii.dataStructure.Lists.StringList) type_);
      }
      if (typeCase_ == 29) {
        output.writeMessage(29, (ubii.dataStructure.Lists.BoolList) type_);
      }
      if (typeCase_ == 30) {
        output.writeMessage(30, (ubii.dataStructure.Image.Image2D) type_);
      }
      if (typeCase_ == 31) {
        output.writeMessage(31, (ubii.dataStructure.Image.Image2DList) type_);
      }
      if (typeCase_ == 32) {
        output.writeMessage(32, (ubii.sessions.SessionOuterClass.Session) type_);
      }
      if (typeCase_ == 34) {
        output.writeMessage(34, (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_);
      }
      if (typeCase_ == 35) {
        output.writeMessage(35, (ubii.dataStructure.Vector2OuterClass.Vector2List) type_);
      }
      if (typeCase_ == 36) {
        output.writeMessage(36, (ubii.dataStructure.Vector3OuterClass.Vector3List) type_);
      }
      if (typeCase_ == 37) {
        output.writeMessage(37, (ubii.dataStructure.Vector4OuterClass.Vector4List) type_);
      }
      if (typeCase_ == 38) {
        output.writeMessage(38, (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getTopicBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, topic_);
      }
      if (timestamp_ != null) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, getTimestamp());
      }
      if (typeCase_ == 3) {
        size += com.google.protobuf.CodedOutputStream
          .computeDoubleSize(
              3, (double)((java.lang.Double) type_));
      }
      if (typeCase_ == 4) {
        size += com.google.protobuf.CodedOutputStream
          .computeBoolSize(
              4, (boolean)((java.lang.Boolean) type_));
      }
      if (typeCase_ == 5) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(5, type_);
      }
      if (typeCase_ == 6) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(6, (ubii.dataStructure.Vector2OuterClass.Vector2) type_);
      }
      if (typeCase_ == 7) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(7, (ubii.dataStructure.Vector3OuterClass.Vector3) type_);
      }
      if (typeCase_ == 8) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(8, (ubii.dataStructure.Vector4OuterClass.Vector4) type_);
      }
      if (typeCase_ == 9) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(9, (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_);
      }
      if (typeCase_ == 10) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(10, (ubii.dataStructure.Matrix3X2.Matrix3x2) type_);
      }
      if (typeCase_ == 11) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(11, (ubii.dataStructure.Matrix4X4.Matrix4x4) type_);
      }
      if (typeCase_ == 12) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(12, (ubii.dataStructure.ColorOuterClass.Color) type_);
      }
      if (typeCase_ == 13) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(13, (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_);
      }
      if (typeCase_ == 14) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(14, (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_);
      }
      if (typeCase_ == 15) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(15, (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_);
      }
      if (typeCase_ == 16) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(16, (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_);
      }
      if (typeCase_ == 17) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(17, (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_);
      }
      if (typeCase_ == 18) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(18, (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_);
      }
      if (typeCase_ == 19) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(19, (ubii.dataStructure.Object2DOuterClass.Object2D) type_);
      }
      if (typeCase_ == 20) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(20, (ubii.dataStructure.Object3DOuterClass.Object3D) type_);
      }
      if (typeCase_ == 21) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(21, (ubii.dataStructure.Object2DOuterClass.Object2DList) type_);
      }
      if (typeCase_ == 22) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(22, (ubii.dataStructure.Object3DOuterClass.Object3DList) type_);
      }
      if (typeCase_ == 23) {
        size += com.google.protobuf.CodedOutputStream
          .computeInt32Size(
              23, (int)((java.lang.Integer) type_));
      }
      if (typeCase_ == 24) {
        size += com.google.protobuf.CodedOutputStream
          .computeFloatSize(
              24, (float)((java.lang.Float) type_));
      }
      if (typeCase_ == 25) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(25, (ubii.dataStructure.Lists.Int32List) type_);
      }
      if (typeCase_ == 26) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(26, (ubii.dataStructure.Lists.FloatList) type_);
      }
      if (typeCase_ == 27) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(27, (ubii.dataStructure.Lists.DoubleList) type_);
      }
      if (typeCase_ == 28) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(28, (ubii.dataStructure.Lists.StringList) type_);
      }
      if (typeCase_ == 29) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(29, (ubii.dataStructure.Lists.BoolList) type_);
      }
      if (typeCase_ == 30) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(30, (ubii.dataStructure.Image.Image2D) type_);
      }
      if (typeCase_ == 31) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(31, (ubii.dataStructure.Image.Image2DList) type_);
      }
      if (typeCase_ == 32) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(32, (ubii.sessions.SessionOuterClass.Session) type_);
      }
      if (typeCase_ == 34) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(34, (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_);
      }
      if (typeCase_ == 35) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(35, (ubii.dataStructure.Vector2OuterClass.Vector2List) type_);
      }
      if (typeCase_ == 36) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(36, (ubii.dataStructure.Vector3OuterClass.Vector3List) type_);
      }
      if (typeCase_ == 37) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(37, (ubii.dataStructure.Vector4OuterClass.Vector4List) type_);
      }
      if (typeCase_ == 38) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(38, (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord)) {
        return super.equals(obj);
      }
      ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord other = (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) obj;

      boolean result = true;
      result = result && getTopic()
          .equals(other.getTopic());
      result = result && (hasTimestamp() == other.hasTimestamp());
      if (hasTimestamp()) {
        result = result && getTimestamp()
            .equals(other.getTimestamp());
      }
      result = result && getTypeCase().equals(
          other.getTypeCase());
      if (!result) return false;
      switch (typeCase_) {
        case 3:
          result = result && (
              java.lang.Double.doubleToLongBits(getDouble())
              == java.lang.Double.doubleToLongBits(
                  other.getDouble()));
          break;
        case 4:
          result = result && (getBool()
              == other.getBool());
          break;
        case 5:
          result = result && getString()
              .equals(other.getString());
          break;
        case 23:
          result = result && (getInt32()
              == other.getInt32());
          break;
        case 24:
          result = result && (
              java.lang.Float.floatToIntBits(getFloat())
              == java.lang.Float.floatToIntBits(
                  other.getFloat()));
          break;
        case 6:
          result = result && getVector2()
              .equals(other.getVector2());
          break;
        case 35:
          result = result && getVector2List()
              .equals(other.getVector2List());
          break;
        case 7:
          result = result && getVector3()
              .equals(other.getVector3());
          break;
        case 36:
          result = result && getVector3List()
              .equals(other.getVector3List());
          break;
        case 8:
          result = result && getVector4()
              .equals(other.getVector4());
          break;
        case 37:
          result = result && getVector4List()
              .equals(other.getVector4List());
          break;
        case 9:
          result = result && getQuaternion()
              .equals(other.getQuaternion());
          break;
        case 38:
          result = result && getQuaternionList()
              .equals(other.getQuaternionList());
          break;
        case 10:
          result = result && getMatrix3X2()
              .equals(other.getMatrix3X2());
          break;
        case 11:
          result = result && getMatrix4X4()
              .equals(other.getMatrix4X4());
          break;
        case 12:
          result = result && getColor()
              .equals(other.getColor());
          break;
        case 13:
          result = result && getTouchEvent()
              .equals(other.getTouchEvent());
          break;
        case 34:
          result = result && getTouchEventList()
              .equals(other.getTouchEventList());
          break;
        case 14:
          result = result && getKeyEvent()
              .equals(other.getKeyEvent());
          break;
        case 15:
          result = result && getMouseEvent()
              .equals(other.getMouseEvent());
          break;
        case 16:
          result = result && getMyoEvent()
              .equals(other.getMyoEvent());
          break;
        case 17:
          result = result && getPose2D()
              .equals(other.getPose2D());
          break;
        case 18:
          result = result && getPose3D()
              .equals(other.getPose3D());
          break;
        case 19:
          result = result && getObject2D()
              .equals(other.getObject2D());
          break;
        case 20:
          result = result && getObject3D()
              .equals(other.getObject3D());
          break;
        case 21:
          result = result && getObject2DList()
              .equals(other.getObject2DList());
          break;
        case 22:
          result = result && getObject3DList()
              .equals(other.getObject3DList());
          break;
        case 25:
          result = result && getInt32List()
              .equals(other.getInt32List());
          break;
        case 26:
          result = result && getFloatList()
              .equals(other.getFloatList());
          break;
        case 27:
          result = result && getDoubleList()
              .equals(other.getDoubleList());
          break;
        case 28:
          result = result && getStringList()
              .equals(other.getStringList());
          break;
        case 29:
          result = result && getBoolList()
              .equals(other.getBoolList());
          break;
        case 30:
          result = result && getImage2D()
              .equals(other.getImage2D());
          break;
        case 31:
          result = result && getImage2DList()
              .equals(other.getImage2DList());
          break;
        case 32:
          result = result && getSession()
              .equals(other.getSession());
          break;
        case 0:
        default:
      }
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + TOPIC_FIELD_NUMBER;
      hash = (53 * hash) + getTopic().hashCode();
      if (hasTimestamp()) {
        hash = (37 * hash) + TIMESTAMP_FIELD_NUMBER;
        hash = (53 * hash) + getTimestamp().hashCode();
      }
      switch (typeCase_) {
        case 3:
          hash = (37 * hash) + DOUBLE_FIELD_NUMBER;
          hash = (53 * hash) + com.google.protobuf.Internal.hashLong(
              java.lang.Double.doubleToLongBits(getDouble()));
          break;
        case 4:
          hash = (37 * hash) + BOOL_FIELD_NUMBER;
          hash = (53 * hash) + com.google.protobuf.Internal.hashBoolean(
              getBool());
          break;
        case 5:
          hash = (37 * hash) + STRING_FIELD_NUMBER;
          hash = (53 * hash) + getString().hashCode();
          break;
        case 23:
          hash = (37 * hash) + INT32_FIELD_NUMBER;
          hash = (53 * hash) + getInt32();
          break;
        case 24:
          hash = (37 * hash) + FLOAT_FIELD_NUMBER;
          hash = (53 * hash) + java.lang.Float.floatToIntBits(
              getFloat());
          break;
        case 6:
          hash = (37 * hash) + VECTOR2_FIELD_NUMBER;
          hash = (53 * hash) + getVector2().hashCode();
          break;
        case 35:
          hash = (37 * hash) + VECTOR2_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getVector2List().hashCode();
          break;
        case 7:
          hash = (37 * hash) + VECTOR3_FIELD_NUMBER;
          hash = (53 * hash) + getVector3().hashCode();
          break;
        case 36:
          hash = (37 * hash) + VECTOR3_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getVector3List().hashCode();
          break;
        case 8:
          hash = (37 * hash) + VECTOR4_FIELD_NUMBER;
          hash = (53 * hash) + getVector4().hashCode();
          break;
        case 37:
          hash = (37 * hash) + VECTOR4_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getVector4List().hashCode();
          break;
        case 9:
          hash = (37 * hash) + QUATERNION_FIELD_NUMBER;
          hash = (53 * hash) + getQuaternion().hashCode();
          break;
        case 38:
          hash = (37 * hash) + QUATERNION_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getQuaternionList().hashCode();
          break;
        case 10:
          hash = (37 * hash) + MATRIX3X2_FIELD_NUMBER;
          hash = (53 * hash) + getMatrix3X2().hashCode();
          break;
        case 11:
          hash = (37 * hash) + MATRIX4X4_FIELD_NUMBER;
          hash = (53 * hash) + getMatrix4X4().hashCode();
          break;
        case 12:
          hash = (37 * hash) + COLOR_FIELD_NUMBER;
          hash = (53 * hash) + getColor().hashCode();
          break;
        case 13:
          hash = (37 * hash) + TOUCH_EVENT_FIELD_NUMBER;
          hash = (53 * hash) + getTouchEvent().hashCode();
          break;
        case 34:
          hash = (37 * hash) + TOUCH_EVENT_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getTouchEventList().hashCode();
          break;
        case 14:
          hash = (37 * hash) + KEY_EVENT_FIELD_NUMBER;
          hash = (53 * hash) + getKeyEvent().hashCode();
          break;
        case 15:
          hash = (37 * hash) + MOUSE_EVENT_FIELD_NUMBER;
          hash = (53 * hash) + getMouseEvent().hashCode();
          break;
        case 16:
          hash = (37 * hash) + MYO_EVENT_FIELD_NUMBER;
          hash = (53 * hash) + getMyoEvent().hashCode();
          break;
        case 17:
          hash = (37 * hash) + POSE2D_FIELD_NUMBER;
          hash = (53 * hash) + getPose2D().hashCode();
          break;
        case 18:
          hash = (37 * hash) + POSE3D_FIELD_NUMBER;
          hash = (53 * hash) + getPose3D().hashCode();
          break;
        case 19:
          hash = (37 * hash) + OBJECT2D_FIELD_NUMBER;
          hash = (53 * hash) + getObject2D().hashCode();
          break;
        case 20:
          hash = (37 * hash) + OBJECT3D_FIELD_NUMBER;
          hash = (53 * hash) + getObject3D().hashCode();
          break;
        case 21:
          hash = (37 * hash) + OBJECT2D_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getObject2DList().hashCode();
          break;
        case 22:
          hash = (37 * hash) + OBJECT3D_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getObject3DList().hashCode();
          break;
        case 25:
          hash = (37 * hash) + INT32_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getInt32List().hashCode();
          break;
        case 26:
          hash = (37 * hash) + FLOAT_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getFloatList().hashCode();
          break;
        case 27:
          hash = (37 * hash) + DOUBLE_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getDoubleList().hashCode();
          break;
        case 28:
          hash = (37 * hash) + STRING_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getStringList().hashCode();
          break;
        case 29:
          hash = (37 * hash) + BOOL_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getBoolList().hashCode();
          break;
        case 30:
          hash = (37 * hash) + IMAGE2D_FIELD_NUMBER;
          hash = (53 * hash) + getImage2D().hashCode();
          break;
        case 31:
          hash = (37 * hash) + IMAGE2D_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getImage2DList().hashCode();
          break;
        case 32:
          hash = (37 * hash) + SESSION_FIELD_NUMBER;
          hash = (53 * hash) + getSession().hashCode();
          break;
        case 0:
        default:
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * <pre>
     * continuous index: 38
     * </pre>
     *
     * Protobuf type {@code ubii.topicData.TopicDataRecord}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.topicData.TopicDataRecord)
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecord_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecord_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.class, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder.class);
      }

      // Construct using ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        topic_ = "";

        if (timestampBuilder_ == null) {
          timestamp_ = null;
        } else {
          timestamp_ = null;
          timestampBuilder_ = null;
        }
        typeCase_ = 0;
        type_ = null;
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecord_descriptor;
      }

      @java.lang.Override
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getDefaultInstanceForType() {
        return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord build() {
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord buildPartial() {
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord result = new ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord(this);
        result.topic_ = topic_;
        if (timestampBuilder_ == null) {
          result.timestamp_ = timestamp_;
        } else {
          result.timestamp_ = timestampBuilder_.build();
        }
        if (typeCase_ == 3) {
          result.type_ = type_;
        }
        if (typeCase_ == 4) {
          result.type_ = type_;
        }
        if (typeCase_ == 5) {
          result.type_ = type_;
        }
        if (typeCase_ == 23) {
          result.type_ = type_;
        }
        if (typeCase_ == 24) {
          result.type_ = type_;
        }
        if (typeCase_ == 6) {
          if (vector2Builder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = vector2Builder_.build();
          }
        }
        if (typeCase_ == 35) {
          if (vector2ListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = vector2ListBuilder_.build();
          }
        }
        if (typeCase_ == 7) {
          if (vector3Builder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = vector3Builder_.build();
          }
        }
        if (typeCase_ == 36) {
          if (vector3ListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = vector3ListBuilder_.build();
          }
        }
        if (typeCase_ == 8) {
          if (vector4Builder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = vector4Builder_.build();
          }
        }
        if (typeCase_ == 37) {
          if (vector4ListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = vector4ListBuilder_.build();
          }
        }
        if (typeCase_ == 9) {
          if (quaternionBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = quaternionBuilder_.build();
          }
        }
        if (typeCase_ == 38) {
          if (quaternionListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = quaternionListBuilder_.build();
          }
        }
        if (typeCase_ == 10) {
          if (matrix3X2Builder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = matrix3X2Builder_.build();
          }
        }
        if (typeCase_ == 11) {
          if (matrix4X4Builder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = matrix4X4Builder_.build();
          }
        }
        if (typeCase_ == 12) {
          if (colorBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = colorBuilder_.build();
          }
        }
        if (typeCase_ == 13) {
          if (touchEventBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = touchEventBuilder_.build();
          }
        }
        if (typeCase_ == 34) {
          if (touchEventListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = touchEventListBuilder_.build();
          }
        }
        if (typeCase_ == 14) {
          if (keyEventBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = keyEventBuilder_.build();
          }
        }
        if (typeCase_ == 15) {
          if (mouseEventBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = mouseEventBuilder_.build();
          }
        }
        if (typeCase_ == 16) {
          if (myoEventBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = myoEventBuilder_.build();
          }
        }
        if (typeCase_ == 17) {
          if (pose2DBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = pose2DBuilder_.build();
          }
        }
        if (typeCase_ == 18) {
          if (pose3DBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = pose3DBuilder_.build();
          }
        }
        if (typeCase_ == 19) {
          if (object2DBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = object2DBuilder_.build();
          }
        }
        if (typeCase_ == 20) {
          if (object3DBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = object3DBuilder_.build();
          }
        }
        if (typeCase_ == 21) {
          if (object2DListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = object2DListBuilder_.build();
          }
        }
        if (typeCase_ == 22) {
          if (object3DListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = object3DListBuilder_.build();
          }
        }
        if (typeCase_ == 25) {
          if (int32ListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = int32ListBuilder_.build();
          }
        }
        if (typeCase_ == 26) {
          if (floatListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = floatListBuilder_.build();
          }
        }
        if (typeCase_ == 27) {
          if (doubleListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = doubleListBuilder_.build();
          }
        }
        if (typeCase_ == 28) {
          if (stringListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = stringListBuilder_.build();
          }
        }
        if (typeCase_ == 29) {
          if (boolListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = boolListBuilder_.build();
          }
        }
        if (typeCase_ == 30) {
          if (image2DBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = image2DBuilder_.build();
          }
        }
        if (typeCase_ == 31) {
          if (image2DListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = image2DListBuilder_.build();
          }
        }
        if (typeCase_ == 32) {
          if (sessionBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = sessionBuilder_.build();
          }
        }
        result.typeCase_ = typeCase_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) {
          return mergeFrom((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord other) {
        if (other == ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance()) return this;
        if (!other.getTopic().isEmpty()) {
          topic_ = other.topic_;
          onChanged();
        }
        if (other.hasTimestamp()) {
          mergeTimestamp(other.getTimestamp());
        }
        switch (other.getTypeCase()) {
          case DOUBLE: {
            setDouble(other.getDouble());
            break;
          }
          case BOOL: {
            setBool(other.getBool());
            break;
          }
          case STRING: {
            typeCase_ = 5;
            type_ = other.type_;
            onChanged();
            break;
          }
          case INT32: {
            setInt32(other.getInt32());
            break;
          }
          case FLOAT: {
            setFloat(other.getFloat());
            break;
          }
          case VECTOR2: {
            mergeVector2(other.getVector2());
            break;
          }
          case VECTOR2_LIST: {
            mergeVector2List(other.getVector2List());
            break;
          }
          case VECTOR3: {
            mergeVector3(other.getVector3());
            break;
          }
          case VECTOR3_LIST: {
            mergeVector3List(other.getVector3List());
            break;
          }
          case VECTOR4: {
            mergeVector4(other.getVector4());
            break;
          }
          case VECTOR4_LIST: {
            mergeVector4List(other.getVector4List());
            break;
          }
          case QUATERNION: {
            mergeQuaternion(other.getQuaternion());
            break;
          }
          case QUATERNION_LIST: {
            mergeQuaternionList(other.getQuaternionList());
            break;
          }
          case MATRIX3X2: {
            mergeMatrix3X2(other.getMatrix3X2());
            break;
          }
          case MATRIX4X4: {
            mergeMatrix4X4(other.getMatrix4X4());
            break;
          }
          case COLOR: {
            mergeColor(other.getColor());
            break;
          }
          case TOUCH_EVENT: {
            mergeTouchEvent(other.getTouchEvent());
            break;
          }
          case TOUCH_EVENT_LIST: {
            mergeTouchEventList(other.getTouchEventList());
            break;
          }
          case KEY_EVENT: {
            mergeKeyEvent(other.getKeyEvent());
            break;
          }
          case MOUSE_EVENT: {
            mergeMouseEvent(other.getMouseEvent());
            break;
          }
          case MYO_EVENT: {
            mergeMyoEvent(other.getMyoEvent());
            break;
          }
          case POSE2D: {
            mergePose2D(other.getPose2D());
            break;
          }
          case POSE3D: {
            mergePose3D(other.getPose3D());
            break;
          }
          case OBJECT2D: {
            mergeObject2D(other.getObject2D());
            break;
          }
          case OBJECT3D: {
            mergeObject3D(other.getObject3D());
            break;
          }
          case OBJECT2D_LIST: {
            mergeObject2DList(other.getObject2DList());
            break;
          }
          case OBJECT3D_LIST: {
            mergeObject3DList(other.getObject3DList());
            break;
          }
          case INT32_LIST: {
            mergeInt32List(other.getInt32List());
            break;
          }
          case FLOAT_LIST: {
            mergeFloatList(other.getFloatList());
            break;
          }
          case DOUBLE_LIST: {
            mergeDoubleList(other.getDoubleList());
            break;
          }
          case STRING_LIST: {
            mergeStringList(other.getStringList());
            break;
          }
          case BOOL_LIST: {
            mergeBoolList(other.getBoolList());
            break;
          }
          case IMAGE2D: {
            mergeImage2D(other.getImage2D());
            break;
          }
          case IMAGE2D_LIST: {
            mergeImage2DList(other.getImage2DList());
            break;
          }
          case SESSION: {
            mergeSession(other.getSession());
            break;
          }
          case TYPE_NOT_SET: {
            break;
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int typeCase_ = 0;
      private java.lang.Object type_;
      public TypeCase
          getTypeCase() {
        return TypeCase.forNumber(
            typeCase_);
      }

      public Builder clearType() {
        typeCase_ = 0;
        type_ = null;
        onChanged();
        return this;
      }


      private java.lang.Object topic_ = "";
      /**
       * <code>string topic = 1;</code>
       */
      public java.lang.String getTopic() {
        java.lang.Object ref = topic_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          topic_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string topic = 1;</code>
       */
      public com.google.protobuf.ByteString
          getTopicBytes() {
        java.lang.Object ref = topic_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          topic_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string topic = 1;</code>
       */
      public Builder setTopic(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        topic_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string topic = 1;</code>
       */
      public Builder clearTopic() {
        
        topic_ = getDefaultInstance().getTopic();
        onChanged();
        return this;
      }
      /**
       * <code>string topic = 1;</code>
       */
      public Builder setTopicBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        topic_ = value;
        onChanged();
        return this;
      }

      private ubii.topicData.TimestampOuterClass.Timestamp timestamp_ = null;
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.topicData.TimestampOuterClass.Timestamp, ubii.topicData.TimestampOuterClass.Timestamp.Builder, ubii.topicData.TimestampOuterClass.TimestampOrBuilder> timestampBuilder_;
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public boolean hasTimestamp() {
        return timestampBuilder_ != null || timestamp_ != null;
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public ubii.topicData.TimestampOuterClass.Timestamp getTimestamp() {
        if (timestampBuilder_ == null) {
          return timestamp_ == null ? ubii.topicData.TimestampOuterClass.Timestamp.getDefaultInstance() : timestamp_;
        } else {
          return timestampBuilder_.getMessage();
        }
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public Builder setTimestamp(ubii.topicData.TimestampOuterClass.Timestamp value) {
        if (timestampBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          timestamp_ = value;
          onChanged();
        } else {
          timestampBuilder_.setMessage(value);
        }

        return this;
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public Builder setTimestamp(
          ubii.topicData.TimestampOuterClass.Timestamp.Builder builderForValue) {
        if (timestampBuilder_ == null) {
          timestamp_ = builderForValue.build();
          onChanged();
        } else {
          timestampBuilder_.setMessage(builderForValue.build());
        }

        return this;
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public Builder mergeTimestamp(ubii.topicData.TimestampOuterClass.Timestamp value) {
        if (timestampBuilder_ == null) {
          if (timestamp_ != null) {
            timestamp_ =
              ubii.topicData.TimestampOuterClass.Timestamp.newBuilder(timestamp_).mergeFrom(value).buildPartial();
          } else {
            timestamp_ = value;
          }
          onChanged();
        } else {
          timestampBuilder_.mergeFrom(value);
        }

        return this;
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public Builder clearTimestamp() {
        if (timestampBuilder_ == null) {
          timestamp_ = null;
          onChanged();
        } else {
          timestamp_ = null;
          timestampBuilder_ = null;
        }

        return this;
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public ubii.topicData.TimestampOuterClass.Timestamp.Builder getTimestampBuilder() {
        
        onChanged();
        return getTimestampFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      public ubii.topicData.TimestampOuterClass.TimestampOrBuilder getTimestampOrBuilder() {
        if (timestampBuilder_ != null) {
          return timestampBuilder_.getMessageOrBuilder();
        } else {
          return timestamp_ == null ?
              ubii.topicData.TimestampOuterClass.Timestamp.getDefaultInstance() : timestamp_;
        }
      }
      /**
       * <code>.ubii.topicData.Timestamp timestamp = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.topicData.TimestampOuterClass.Timestamp, ubii.topicData.TimestampOuterClass.Timestamp.Builder, ubii.topicData.TimestampOuterClass.TimestampOrBuilder> 
          getTimestampFieldBuilder() {
        if (timestampBuilder_ == null) {
          timestampBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.topicData.TimestampOuterClass.Timestamp, ubii.topicData.TimestampOuterClass.Timestamp.Builder, ubii.topicData.TimestampOuterClass.TimestampOrBuilder>(
                  getTimestamp(),
                  getParentForChildren(),
                  isClean());
          timestamp_ = null;
        }
        return timestampBuilder_;
      }

      /**
       * <code>double double = 3;</code>
       */
      public double getDouble() {
        if (typeCase_ == 3) {
          return (java.lang.Double) type_;
        }
        return 0D;
      }
      /**
       * <code>double double = 3;</code>
       */
      public Builder setDouble(double value) {
        typeCase_ = 3;
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>double double = 3;</code>
       */
      public Builder clearDouble() {
        if (typeCase_ == 3) {
          typeCase_ = 0;
          type_ = null;
          onChanged();
        }
        return this;
      }

      /**
       * <code>bool bool = 4;</code>
       */
      public boolean getBool() {
        if (typeCase_ == 4) {
          return (java.lang.Boolean) type_;
        }
        return false;
      }
      /**
       * <code>bool bool = 4;</code>
       */
      public Builder setBool(boolean value) {
        typeCase_ = 4;
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>bool bool = 4;</code>
       */
      public Builder clearBool() {
        if (typeCase_ == 4) {
          typeCase_ = 0;
          type_ = null;
          onChanged();
        }
        return this;
      }

      /**
       * <code>string string = 5;</code>
       */
      public java.lang.String getString() {
        java.lang.Object ref = "";
        if (typeCase_ == 5) {
          ref = type_;
        }
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          if (typeCase_ == 5) {
            type_ = s;
          }
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string string = 5;</code>
       */
      public com.google.protobuf.ByteString
          getStringBytes() {
        java.lang.Object ref = "";
        if (typeCase_ == 5) {
          ref = type_;
        }
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          if (typeCase_ == 5) {
            type_ = b;
          }
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string string = 5;</code>
       */
      public Builder setString(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  typeCase_ = 5;
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string string = 5;</code>
       */
      public Builder clearString() {
        if (typeCase_ == 5) {
          typeCase_ = 0;
          type_ = null;
          onChanged();
        }
        return this;
      }
      /**
       * <code>string string = 5;</code>
       */
      public Builder setStringBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        typeCase_ = 5;
        type_ = value;
        onChanged();
        return this;
      }

      /**
       * <code>int32 int32 = 23;</code>
       */
      public int getInt32() {
        if (typeCase_ == 23) {
          return (java.lang.Integer) type_;
        }
        return 0;
      }
      /**
       * <code>int32 int32 = 23;</code>
       */
      public Builder setInt32(int value) {
        typeCase_ = 23;
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>int32 int32 = 23;</code>
       */
      public Builder clearInt32() {
        if (typeCase_ == 23) {
          typeCase_ = 0;
          type_ = null;
          onChanged();
        }
        return this;
      }

      /**
       * <code>float float = 24;</code>
       */
      public float getFloat() {
        if (typeCase_ == 24) {
          return (java.lang.Float) type_;
        }
        return 0F;
      }
      /**
       * <code>float float = 24;</code>
       */
      public Builder setFloat(float value) {
        typeCase_ = 24;
        type_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>float float = 24;</code>
       */
      public Builder clearFloat() {
        if (typeCase_ == 24) {
          typeCase_ = 0;
          type_ = null;
          onChanged();
        }
        return this;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> vector2Builder_;
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public boolean hasVector2() {
        return typeCase_ == 6;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2 getVector2() {
        if (vector2Builder_ == null) {
          if (typeCase_ == 6) {
            return (ubii.dataStructure.Vector2OuterClass.Vector2) type_;
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
        } else {
          if (typeCase_ == 6) {
            return vector2Builder_.getMessage();
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public Builder setVector2(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (vector2Builder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          vector2Builder_.setMessage(value);
        }
        typeCase_ = 6;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public Builder setVector2(
          ubii.dataStructure.Vector2OuterClass.Vector2.Builder builderForValue) {
        if (vector2Builder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          vector2Builder_.setMessage(builderForValue.build());
        }
        typeCase_ = 6;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public Builder mergeVector2(ubii.dataStructure.Vector2OuterClass.Vector2 value) {
        if (vector2Builder_ == null) {
          if (typeCase_ == 6 &&
              type_ != ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance()) {
            type_ = ubii.dataStructure.Vector2OuterClass.Vector2.newBuilder((ubii.dataStructure.Vector2OuterClass.Vector2) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 6) {
            vector2Builder_.mergeFrom(value);
          }
          vector2Builder_.setMessage(value);
        }
        typeCase_ = 6;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public Builder clearVector2() {
        if (vector2Builder_ == null) {
          if (typeCase_ == 6) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 6) {
            typeCase_ = 0;
            type_ = null;
          }
          vector2Builder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2.Builder getVector2Builder() {
        return getVector2FieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder getVector2OrBuilder() {
        if ((typeCase_ == 6) && (vector2Builder_ != null)) {
          return vector2Builder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 6) {
            return (ubii.dataStructure.Vector2OuterClass.Vector2) type_;
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2 vector2 = 6;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder> 
          getVector2FieldBuilder() {
        if (vector2Builder_ == null) {
          if (!(typeCase_ == 6)) {
            type_ = ubii.dataStructure.Vector2OuterClass.Vector2.getDefaultInstance();
          }
          vector2Builder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector2OuterClass.Vector2, ubii.dataStructure.Vector2OuterClass.Vector2.Builder, ubii.dataStructure.Vector2OuterClass.Vector2OrBuilder>(
                  (ubii.dataStructure.Vector2OuterClass.Vector2) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 6;
        onChanged();;
        return vector2Builder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2List, ubii.dataStructure.Vector2OuterClass.Vector2List.Builder, ubii.dataStructure.Vector2OuterClass.Vector2ListOrBuilder> vector2ListBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public boolean hasVector2List() {
        return typeCase_ == 35;
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2List getVector2List() {
        if (vector2ListBuilder_ == null) {
          if (typeCase_ == 35) {
            return (ubii.dataStructure.Vector2OuterClass.Vector2List) type_;
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance();
        } else {
          if (typeCase_ == 35) {
            return vector2ListBuilder_.getMessage();
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public Builder setVector2List(ubii.dataStructure.Vector2OuterClass.Vector2List value) {
        if (vector2ListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          vector2ListBuilder_.setMessage(value);
        }
        typeCase_ = 35;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public Builder setVector2List(
          ubii.dataStructure.Vector2OuterClass.Vector2List.Builder builderForValue) {
        if (vector2ListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          vector2ListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 35;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public Builder mergeVector2List(ubii.dataStructure.Vector2OuterClass.Vector2List value) {
        if (vector2ListBuilder_ == null) {
          if (typeCase_ == 35 &&
              type_ != ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance()) {
            type_ = ubii.dataStructure.Vector2OuterClass.Vector2List.newBuilder((ubii.dataStructure.Vector2OuterClass.Vector2List) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 35) {
            vector2ListBuilder_.mergeFrom(value);
          }
          vector2ListBuilder_.setMessage(value);
        }
        typeCase_ = 35;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public Builder clearVector2List() {
        if (vector2ListBuilder_ == null) {
          if (typeCase_ == 35) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 35) {
            typeCase_ = 0;
            type_ = null;
          }
          vector2ListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2List.Builder getVector2ListBuilder() {
        return getVector2ListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      public ubii.dataStructure.Vector2OuterClass.Vector2ListOrBuilder getVector2ListOrBuilder() {
        if ((typeCase_ == 35) && (vector2ListBuilder_ != null)) {
          return vector2ListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 35) {
            return (ubii.dataStructure.Vector2OuterClass.Vector2List) type_;
          }
          return ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector2List vector2_list = 35;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector2OuterClass.Vector2List, ubii.dataStructure.Vector2OuterClass.Vector2List.Builder, ubii.dataStructure.Vector2OuterClass.Vector2ListOrBuilder> 
          getVector2ListFieldBuilder() {
        if (vector2ListBuilder_ == null) {
          if (!(typeCase_ == 35)) {
            type_ = ubii.dataStructure.Vector2OuterClass.Vector2List.getDefaultInstance();
          }
          vector2ListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector2OuterClass.Vector2List, ubii.dataStructure.Vector2OuterClass.Vector2List.Builder, ubii.dataStructure.Vector2OuterClass.Vector2ListOrBuilder>(
                  (ubii.dataStructure.Vector2OuterClass.Vector2List) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 35;
        onChanged();;
        return vector2ListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> vector3Builder_;
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public boolean hasVector3() {
        return typeCase_ == 7;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3 getVector3() {
        if (vector3Builder_ == null) {
          if (typeCase_ == 7) {
            return (ubii.dataStructure.Vector3OuterClass.Vector3) type_;
          }
          return ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance();
        } else {
          if (typeCase_ == 7) {
            return vector3Builder_.getMessage();
          }
          return ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public Builder setVector3(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (vector3Builder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          vector3Builder_.setMessage(value);
        }
        typeCase_ = 7;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public Builder setVector3(
          ubii.dataStructure.Vector3OuterClass.Vector3.Builder builderForValue) {
        if (vector3Builder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          vector3Builder_.setMessage(builderForValue.build());
        }
        typeCase_ = 7;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public Builder mergeVector3(ubii.dataStructure.Vector3OuterClass.Vector3 value) {
        if (vector3Builder_ == null) {
          if (typeCase_ == 7 &&
              type_ != ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance()) {
            type_ = ubii.dataStructure.Vector3OuterClass.Vector3.newBuilder((ubii.dataStructure.Vector3OuterClass.Vector3) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 7) {
            vector3Builder_.mergeFrom(value);
          }
          vector3Builder_.setMessage(value);
        }
        typeCase_ = 7;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public Builder clearVector3() {
        if (vector3Builder_ == null) {
          if (typeCase_ == 7) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 7) {
            typeCase_ = 0;
            type_ = null;
          }
          vector3Builder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3.Builder getVector3Builder() {
        return getVector3FieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder getVector3OrBuilder() {
        if ((typeCase_ == 7) && (vector3Builder_ != null)) {
          return vector3Builder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 7) {
            return (ubii.dataStructure.Vector3OuterClass.Vector3) type_;
          }
          return ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3 vector3 = 7;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder> 
          getVector3FieldBuilder() {
        if (vector3Builder_ == null) {
          if (!(typeCase_ == 7)) {
            type_ = ubii.dataStructure.Vector3OuterClass.Vector3.getDefaultInstance();
          }
          vector3Builder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector3OuterClass.Vector3, ubii.dataStructure.Vector3OuterClass.Vector3.Builder, ubii.dataStructure.Vector3OuterClass.Vector3OrBuilder>(
                  (ubii.dataStructure.Vector3OuterClass.Vector3) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 7;
        onChanged();;
        return vector3Builder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3List, ubii.dataStructure.Vector3OuterClass.Vector3List.Builder, ubii.dataStructure.Vector3OuterClass.Vector3ListOrBuilder> vector3ListBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public boolean hasVector3List() {
        return typeCase_ == 36;
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3List getVector3List() {
        if (vector3ListBuilder_ == null) {
          if (typeCase_ == 36) {
            return (ubii.dataStructure.Vector3OuterClass.Vector3List) type_;
          }
          return ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance();
        } else {
          if (typeCase_ == 36) {
            return vector3ListBuilder_.getMessage();
          }
          return ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public Builder setVector3List(ubii.dataStructure.Vector3OuterClass.Vector3List value) {
        if (vector3ListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          vector3ListBuilder_.setMessage(value);
        }
        typeCase_ = 36;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public Builder setVector3List(
          ubii.dataStructure.Vector3OuterClass.Vector3List.Builder builderForValue) {
        if (vector3ListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          vector3ListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 36;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public Builder mergeVector3List(ubii.dataStructure.Vector3OuterClass.Vector3List value) {
        if (vector3ListBuilder_ == null) {
          if (typeCase_ == 36 &&
              type_ != ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance()) {
            type_ = ubii.dataStructure.Vector3OuterClass.Vector3List.newBuilder((ubii.dataStructure.Vector3OuterClass.Vector3List) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 36) {
            vector3ListBuilder_.mergeFrom(value);
          }
          vector3ListBuilder_.setMessage(value);
        }
        typeCase_ = 36;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public Builder clearVector3List() {
        if (vector3ListBuilder_ == null) {
          if (typeCase_ == 36) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 36) {
            typeCase_ = 0;
            type_ = null;
          }
          vector3ListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3List.Builder getVector3ListBuilder() {
        return getVector3ListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      public ubii.dataStructure.Vector3OuterClass.Vector3ListOrBuilder getVector3ListOrBuilder() {
        if ((typeCase_ == 36) && (vector3ListBuilder_ != null)) {
          return vector3ListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 36) {
            return (ubii.dataStructure.Vector3OuterClass.Vector3List) type_;
          }
          return ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector3List vector3_list = 36;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector3OuterClass.Vector3List, ubii.dataStructure.Vector3OuterClass.Vector3List.Builder, ubii.dataStructure.Vector3OuterClass.Vector3ListOrBuilder> 
          getVector3ListFieldBuilder() {
        if (vector3ListBuilder_ == null) {
          if (!(typeCase_ == 36)) {
            type_ = ubii.dataStructure.Vector3OuterClass.Vector3List.getDefaultInstance();
          }
          vector3ListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector3OuterClass.Vector3List, ubii.dataStructure.Vector3OuterClass.Vector3List.Builder, ubii.dataStructure.Vector3OuterClass.Vector3ListOrBuilder>(
                  (ubii.dataStructure.Vector3OuterClass.Vector3List) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 36;
        onChanged();;
        return vector3ListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector4OuterClass.Vector4, ubii.dataStructure.Vector4OuterClass.Vector4.Builder, ubii.dataStructure.Vector4OuterClass.Vector4OrBuilder> vector4Builder_;
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public boolean hasVector4() {
        return typeCase_ == 8;
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public ubii.dataStructure.Vector4OuterClass.Vector4 getVector4() {
        if (vector4Builder_ == null) {
          if (typeCase_ == 8) {
            return (ubii.dataStructure.Vector4OuterClass.Vector4) type_;
          }
          return ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance();
        } else {
          if (typeCase_ == 8) {
            return vector4Builder_.getMessage();
          }
          return ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public Builder setVector4(ubii.dataStructure.Vector4OuterClass.Vector4 value) {
        if (vector4Builder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          vector4Builder_.setMessage(value);
        }
        typeCase_ = 8;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public Builder setVector4(
          ubii.dataStructure.Vector4OuterClass.Vector4.Builder builderForValue) {
        if (vector4Builder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          vector4Builder_.setMessage(builderForValue.build());
        }
        typeCase_ = 8;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public Builder mergeVector4(ubii.dataStructure.Vector4OuterClass.Vector4 value) {
        if (vector4Builder_ == null) {
          if (typeCase_ == 8 &&
              type_ != ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance()) {
            type_ = ubii.dataStructure.Vector4OuterClass.Vector4.newBuilder((ubii.dataStructure.Vector4OuterClass.Vector4) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 8) {
            vector4Builder_.mergeFrom(value);
          }
          vector4Builder_.setMessage(value);
        }
        typeCase_ = 8;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public Builder clearVector4() {
        if (vector4Builder_ == null) {
          if (typeCase_ == 8) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 8) {
            typeCase_ = 0;
            type_ = null;
          }
          vector4Builder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public ubii.dataStructure.Vector4OuterClass.Vector4.Builder getVector4Builder() {
        return getVector4FieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      public ubii.dataStructure.Vector4OuterClass.Vector4OrBuilder getVector4OrBuilder() {
        if ((typeCase_ == 8) && (vector4Builder_ != null)) {
          return vector4Builder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 8) {
            return (ubii.dataStructure.Vector4OuterClass.Vector4) type_;
          }
          return ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector4 vector4 = 8;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector4OuterClass.Vector4, ubii.dataStructure.Vector4OuterClass.Vector4.Builder, ubii.dataStructure.Vector4OuterClass.Vector4OrBuilder> 
          getVector4FieldBuilder() {
        if (vector4Builder_ == null) {
          if (!(typeCase_ == 8)) {
            type_ = ubii.dataStructure.Vector4OuterClass.Vector4.getDefaultInstance();
          }
          vector4Builder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector4OuterClass.Vector4, ubii.dataStructure.Vector4OuterClass.Vector4.Builder, ubii.dataStructure.Vector4OuterClass.Vector4OrBuilder>(
                  (ubii.dataStructure.Vector4OuterClass.Vector4) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 8;
        onChanged();;
        return vector4Builder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector4OuterClass.Vector4List, ubii.dataStructure.Vector4OuterClass.Vector4List.Builder, ubii.dataStructure.Vector4OuterClass.Vector4ListOrBuilder> vector4ListBuilder_;
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public boolean hasVector4List() {
        return typeCase_ == 37;
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public ubii.dataStructure.Vector4OuterClass.Vector4List getVector4List() {
        if (vector4ListBuilder_ == null) {
          if (typeCase_ == 37) {
            return (ubii.dataStructure.Vector4OuterClass.Vector4List) type_;
          }
          return ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance();
        } else {
          if (typeCase_ == 37) {
            return vector4ListBuilder_.getMessage();
          }
          return ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public Builder setVector4List(ubii.dataStructure.Vector4OuterClass.Vector4List value) {
        if (vector4ListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          vector4ListBuilder_.setMessage(value);
        }
        typeCase_ = 37;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public Builder setVector4List(
          ubii.dataStructure.Vector4OuterClass.Vector4List.Builder builderForValue) {
        if (vector4ListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          vector4ListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 37;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public Builder mergeVector4List(ubii.dataStructure.Vector4OuterClass.Vector4List value) {
        if (vector4ListBuilder_ == null) {
          if (typeCase_ == 37 &&
              type_ != ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance()) {
            type_ = ubii.dataStructure.Vector4OuterClass.Vector4List.newBuilder((ubii.dataStructure.Vector4OuterClass.Vector4List) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 37) {
            vector4ListBuilder_.mergeFrom(value);
          }
          vector4ListBuilder_.setMessage(value);
        }
        typeCase_ = 37;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public Builder clearVector4List() {
        if (vector4ListBuilder_ == null) {
          if (typeCase_ == 37) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 37) {
            typeCase_ = 0;
            type_ = null;
          }
          vector4ListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public ubii.dataStructure.Vector4OuterClass.Vector4List.Builder getVector4ListBuilder() {
        return getVector4ListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      public ubii.dataStructure.Vector4OuterClass.Vector4ListOrBuilder getVector4ListOrBuilder() {
        if ((typeCase_ == 37) && (vector4ListBuilder_ != null)) {
          return vector4ListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 37) {
            return (ubii.dataStructure.Vector4OuterClass.Vector4List) type_;
          }
          return ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Vector4List vector4_list = 37;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Vector4OuterClass.Vector4List, ubii.dataStructure.Vector4OuterClass.Vector4List.Builder, ubii.dataStructure.Vector4OuterClass.Vector4ListOrBuilder> 
          getVector4ListFieldBuilder() {
        if (vector4ListBuilder_ == null) {
          if (!(typeCase_ == 37)) {
            type_ = ubii.dataStructure.Vector4OuterClass.Vector4List.getDefaultInstance();
          }
          vector4ListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Vector4OuterClass.Vector4List, ubii.dataStructure.Vector4OuterClass.Vector4List.Builder, ubii.dataStructure.Vector4OuterClass.Vector4ListOrBuilder>(
                  (ubii.dataStructure.Vector4OuterClass.Vector4List) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 37;
        onChanged();;
        return vector4ListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder> quaternionBuilder_;
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public boolean hasQuaternion() {
        return typeCase_ == 9;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.Quaternion getQuaternion() {
        if (quaternionBuilder_ == null) {
          if (typeCase_ == 9) {
            return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
          }
          return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
        } else {
          if (typeCase_ == 9) {
            return quaternionBuilder_.getMessage();
          }
          return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public Builder setQuaternion(ubii.dataStructure.QuaternionOuterClass.Quaternion value) {
        if (quaternionBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          quaternionBuilder_.setMessage(value);
        }
        typeCase_ = 9;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public Builder setQuaternion(
          ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder builderForValue) {
        if (quaternionBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          quaternionBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 9;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public Builder mergeQuaternion(ubii.dataStructure.QuaternionOuterClass.Quaternion value) {
        if (quaternionBuilder_ == null) {
          if (typeCase_ == 9 &&
              type_ != ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance()) {
            type_ = ubii.dataStructure.QuaternionOuterClass.Quaternion.newBuilder((ubii.dataStructure.QuaternionOuterClass.Quaternion) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 9) {
            quaternionBuilder_.mergeFrom(value);
          }
          quaternionBuilder_.setMessage(value);
        }
        typeCase_ = 9;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public Builder clearQuaternion() {
        if (quaternionBuilder_ == null) {
          if (typeCase_ == 9) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 9) {
            typeCase_ = 0;
            type_ = null;
          }
          quaternionBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder getQuaternionBuilder() {
        return getQuaternionFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getQuaternionOrBuilder() {
        if ((typeCase_ == 9) && (quaternionBuilder_ != null)) {
          return quaternionBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 9) {
            return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
          }
          return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion = 9;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder> 
          getQuaternionFieldBuilder() {
        if (quaternionBuilder_ == null) {
          if (!(typeCase_ == 9)) {
            type_ = ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
          }
          quaternionBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder>(
                  (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 9;
        onChanged();;
        return quaternionBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder> quaternionListBuilder_;
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public boolean hasQuaternionList() {
        return typeCase_ == 38;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.Quaternion getQuaternionList() {
        if (quaternionListBuilder_ == null) {
          if (typeCase_ == 38) {
            return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
          }
          return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
        } else {
          if (typeCase_ == 38) {
            return quaternionListBuilder_.getMessage();
          }
          return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public Builder setQuaternionList(ubii.dataStructure.QuaternionOuterClass.Quaternion value) {
        if (quaternionListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          quaternionListBuilder_.setMessage(value);
        }
        typeCase_ = 38;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public Builder setQuaternionList(
          ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder builderForValue) {
        if (quaternionListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          quaternionListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 38;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public Builder mergeQuaternionList(ubii.dataStructure.QuaternionOuterClass.Quaternion value) {
        if (quaternionListBuilder_ == null) {
          if (typeCase_ == 38 &&
              type_ != ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance()) {
            type_ = ubii.dataStructure.QuaternionOuterClass.Quaternion.newBuilder((ubii.dataStructure.QuaternionOuterClass.Quaternion) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 38) {
            quaternionListBuilder_.mergeFrom(value);
          }
          quaternionListBuilder_.setMessage(value);
        }
        typeCase_ = 38;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public Builder clearQuaternionList() {
        if (quaternionListBuilder_ == null) {
          if (typeCase_ == 38) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 38) {
            typeCase_ = 0;
            type_ = null;
          }
          quaternionListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder getQuaternionListBuilder() {
        return getQuaternionListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      public ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder getQuaternionListOrBuilder() {
        if ((typeCase_ == 38) && (quaternionListBuilder_ != null)) {
          return quaternionListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 38) {
            return (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_;
          }
          return ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Quaternion quaternion_list = 38;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder> 
          getQuaternionListFieldBuilder() {
        if (quaternionListBuilder_ == null) {
          if (!(typeCase_ == 38)) {
            type_ = ubii.dataStructure.QuaternionOuterClass.Quaternion.getDefaultInstance();
          }
          quaternionListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.QuaternionOuterClass.Quaternion, ubii.dataStructure.QuaternionOuterClass.Quaternion.Builder, ubii.dataStructure.QuaternionOuterClass.QuaternionOrBuilder>(
                  (ubii.dataStructure.QuaternionOuterClass.Quaternion) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 38;
        onChanged();;
        return quaternionListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Matrix3X2.Matrix3x2, ubii.dataStructure.Matrix3X2.Matrix3x2.Builder, ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder> matrix3X2Builder_;
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public boolean hasMatrix3X2() {
        return typeCase_ == 10;
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public ubii.dataStructure.Matrix3X2.Matrix3x2 getMatrix3X2() {
        if (matrix3X2Builder_ == null) {
          if (typeCase_ == 10) {
            return (ubii.dataStructure.Matrix3X2.Matrix3x2) type_;
          }
          return ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
        } else {
          if (typeCase_ == 10) {
            return matrix3X2Builder_.getMessage();
          }
          return ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public Builder setMatrix3X2(ubii.dataStructure.Matrix3X2.Matrix3x2 value) {
        if (matrix3X2Builder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          matrix3X2Builder_.setMessage(value);
        }
        typeCase_ = 10;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public Builder setMatrix3X2(
          ubii.dataStructure.Matrix3X2.Matrix3x2.Builder builderForValue) {
        if (matrix3X2Builder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          matrix3X2Builder_.setMessage(builderForValue.build());
        }
        typeCase_ = 10;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public Builder mergeMatrix3X2(ubii.dataStructure.Matrix3X2.Matrix3x2 value) {
        if (matrix3X2Builder_ == null) {
          if (typeCase_ == 10 &&
              type_ != ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance()) {
            type_ = ubii.dataStructure.Matrix3X2.Matrix3x2.newBuilder((ubii.dataStructure.Matrix3X2.Matrix3x2) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 10) {
            matrix3X2Builder_.mergeFrom(value);
          }
          matrix3X2Builder_.setMessage(value);
        }
        typeCase_ = 10;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public Builder clearMatrix3X2() {
        if (matrix3X2Builder_ == null) {
          if (typeCase_ == 10) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 10) {
            typeCase_ = 0;
            type_ = null;
          }
          matrix3X2Builder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public ubii.dataStructure.Matrix3X2.Matrix3x2.Builder getMatrix3X2Builder() {
        return getMatrix3X2FieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      public ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder getMatrix3X2OrBuilder() {
        if ((typeCase_ == 10) && (matrix3X2Builder_ != null)) {
          return matrix3X2Builder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 10) {
            return (ubii.dataStructure.Matrix3X2.Matrix3x2) type_;
          }
          return ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Matrix3x2 matrix3x2 = 10;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Matrix3X2.Matrix3x2, ubii.dataStructure.Matrix3X2.Matrix3x2.Builder, ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder> 
          getMatrix3X2FieldBuilder() {
        if (matrix3X2Builder_ == null) {
          if (!(typeCase_ == 10)) {
            type_ = ubii.dataStructure.Matrix3X2.Matrix3x2.getDefaultInstance();
          }
          matrix3X2Builder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Matrix3X2.Matrix3x2, ubii.dataStructure.Matrix3X2.Matrix3x2.Builder, ubii.dataStructure.Matrix3X2.Matrix3x2OrBuilder>(
                  (ubii.dataStructure.Matrix3X2.Matrix3x2) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 10;
        onChanged();;
        return matrix3X2Builder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Matrix4X4.Matrix4x4, ubii.dataStructure.Matrix4X4.Matrix4x4.Builder, ubii.dataStructure.Matrix4X4.Matrix4x4OrBuilder> matrix4X4Builder_;
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public boolean hasMatrix4X4() {
        return typeCase_ == 11;
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public ubii.dataStructure.Matrix4X4.Matrix4x4 getMatrix4X4() {
        if (matrix4X4Builder_ == null) {
          if (typeCase_ == 11) {
            return (ubii.dataStructure.Matrix4X4.Matrix4x4) type_;
          }
          return ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance();
        } else {
          if (typeCase_ == 11) {
            return matrix4X4Builder_.getMessage();
          }
          return ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public Builder setMatrix4X4(ubii.dataStructure.Matrix4X4.Matrix4x4 value) {
        if (matrix4X4Builder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          matrix4X4Builder_.setMessage(value);
        }
        typeCase_ = 11;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public Builder setMatrix4X4(
          ubii.dataStructure.Matrix4X4.Matrix4x4.Builder builderForValue) {
        if (matrix4X4Builder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          matrix4X4Builder_.setMessage(builderForValue.build());
        }
        typeCase_ = 11;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public Builder mergeMatrix4X4(ubii.dataStructure.Matrix4X4.Matrix4x4 value) {
        if (matrix4X4Builder_ == null) {
          if (typeCase_ == 11 &&
              type_ != ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance()) {
            type_ = ubii.dataStructure.Matrix4X4.Matrix4x4.newBuilder((ubii.dataStructure.Matrix4X4.Matrix4x4) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 11) {
            matrix4X4Builder_.mergeFrom(value);
          }
          matrix4X4Builder_.setMessage(value);
        }
        typeCase_ = 11;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public Builder clearMatrix4X4() {
        if (matrix4X4Builder_ == null) {
          if (typeCase_ == 11) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 11) {
            typeCase_ = 0;
            type_ = null;
          }
          matrix4X4Builder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public ubii.dataStructure.Matrix4X4.Matrix4x4.Builder getMatrix4X4Builder() {
        return getMatrix4X4FieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      public ubii.dataStructure.Matrix4X4.Matrix4x4OrBuilder getMatrix4X4OrBuilder() {
        if ((typeCase_ == 11) && (matrix4X4Builder_ != null)) {
          return matrix4X4Builder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 11) {
            return (ubii.dataStructure.Matrix4X4.Matrix4x4) type_;
          }
          return ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Matrix4x4 matrix4x4 = 11;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Matrix4X4.Matrix4x4, ubii.dataStructure.Matrix4X4.Matrix4x4.Builder, ubii.dataStructure.Matrix4X4.Matrix4x4OrBuilder> 
          getMatrix4X4FieldBuilder() {
        if (matrix4X4Builder_ == null) {
          if (!(typeCase_ == 11)) {
            type_ = ubii.dataStructure.Matrix4X4.Matrix4x4.getDefaultInstance();
          }
          matrix4X4Builder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Matrix4X4.Matrix4x4, ubii.dataStructure.Matrix4X4.Matrix4x4.Builder, ubii.dataStructure.Matrix4X4.Matrix4x4OrBuilder>(
                  (ubii.dataStructure.Matrix4X4.Matrix4x4) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 11;
        onChanged();;
        return matrix4X4Builder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.ColorOuterClass.Color, ubii.dataStructure.ColorOuterClass.Color.Builder, ubii.dataStructure.ColorOuterClass.ColorOrBuilder> colorBuilder_;
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public boolean hasColor() {
        return typeCase_ == 12;
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public ubii.dataStructure.ColorOuterClass.Color getColor() {
        if (colorBuilder_ == null) {
          if (typeCase_ == 12) {
            return (ubii.dataStructure.ColorOuterClass.Color) type_;
          }
          return ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance();
        } else {
          if (typeCase_ == 12) {
            return colorBuilder_.getMessage();
          }
          return ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public Builder setColor(ubii.dataStructure.ColorOuterClass.Color value) {
        if (colorBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          colorBuilder_.setMessage(value);
        }
        typeCase_ = 12;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public Builder setColor(
          ubii.dataStructure.ColorOuterClass.Color.Builder builderForValue) {
        if (colorBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          colorBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 12;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public Builder mergeColor(ubii.dataStructure.ColorOuterClass.Color value) {
        if (colorBuilder_ == null) {
          if (typeCase_ == 12 &&
              type_ != ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance()) {
            type_ = ubii.dataStructure.ColorOuterClass.Color.newBuilder((ubii.dataStructure.ColorOuterClass.Color) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 12) {
            colorBuilder_.mergeFrom(value);
          }
          colorBuilder_.setMessage(value);
        }
        typeCase_ = 12;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public Builder clearColor() {
        if (colorBuilder_ == null) {
          if (typeCase_ == 12) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 12) {
            typeCase_ = 0;
            type_ = null;
          }
          colorBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public ubii.dataStructure.ColorOuterClass.Color.Builder getColorBuilder() {
        return getColorFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      public ubii.dataStructure.ColorOuterClass.ColorOrBuilder getColorOrBuilder() {
        if ((typeCase_ == 12) && (colorBuilder_ != null)) {
          return colorBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 12) {
            return (ubii.dataStructure.ColorOuterClass.Color) type_;
          }
          return ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Color color = 12;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.ColorOuterClass.Color, ubii.dataStructure.ColorOuterClass.Color.Builder, ubii.dataStructure.ColorOuterClass.ColorOrBuilder> 
          getColorFieldBuilder() {
        if (colorBuilder_ == null) {
          if (!(typeCase_ == 12)) {
            type_ = ubii.dataStructure.ColorOuterClass.Color.getDefaultInstance();
          }
          colorBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.ColorOuterClass.Color, ubii.dataStructure.ColorOuterClass.Color.Builder, ubii.dataStructure.ColorOuterClass.ColorOrBuilder>(
                  (ubii.dataStructure.ColorOuterClass.Color) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 12;
        onChanged();;
        return colorBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.TouchEventOuterClass.TouchEvent, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> touchEventBuilder_;
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public boolean hasTouchEvent() {
        return typeCase_ == 13;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent getTouchEvent() {
        if (touchEventBuilder_ == null) {
          if (typeCase_ == 13) {
            return (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_;
          }
          return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
        } else {
          if (typeCase_ == 13) {
            return touchEventBuilder_.getMessage();
          }
          return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public Builder setTouchEvent(ubii.dataStructure.TouchEventOuterClass.TouchEvent value) {
        if (touchEventBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          touchEventBuilder_.setMessage(value);
        }
        typeCase_ = 13;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public Builder setTouchEvent(
          ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder builderForValue) {
        if (touchEventBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          touchEventBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 13;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public Builder mergeTouchEvent(ubii.dataStructure.TouchEventOuterClass.TouchEvent value) {
        if (touchEventBuilder_ == null) {
          if (typeCase_ == 13 &&
              type_ != ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance()) {
            type_ = ubii.dataStructure.TouchEventOuterClass.TouchEvent.newBuilder((ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 13) {
            touchEventBuilder_.mergeFrom(value);
          }
          touchEventBuilder_.setMessage(value);
        }
        typeCase_ = 13;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public Builder clearTouchEvent() {
        if (touchEventBuilder_ == null) {
          if (typeCase_ == 13) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 13) {
            typeCase_ = 0;
            type_ = null;
          }
          touchEventBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder getTouchEventBuilder() {
        return getTouchEventFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder getTouchEventOrBuilder() {
        if ((typeCase_ == 13) && (touchEventBuilder_ != null)) {
          return touchEventBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 13) {
            return (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_;
          }
          return ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.TouchEvent touch_event = 13;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.TouchEventOuterClass.TouchEvent, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder> 
          getTouchEventFieldBuilder() {
        if (touchEventBuilder_ == null) {
          if (!(typeCase_ == 13)) {
            type_ = ubii.dataStructure.TouchEventOuterClass.TouchEvent.getDefaultInstance();
          }
          touchEventBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.TouchEventOuterClass.TouchEvent, ubii.dataStructure.TouchEventOuterClass.TouchEvent.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventOrBuilder>(
                  (ubii.dataStructure.TouchEventOuterClass.TouchEvent) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 13;
        onChanged();;
        return touchEventBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.TouchEventOuterClass.TouchEventList, ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder> touchEventListBuilder_;
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public boolean hasTouchEventList() {
        return typeCase_ == 34;
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEventList getTouchEventList() {
        if (touchEventListBuilder_ == null) {
          if (typeCase_ == 34) {
            return (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_;
          }
          return ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
        } else {
          if (typeCase_ == 34) {
            return touchEventListBuilder_.getMessage();
          }
          return ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public Builder setTouchEventList(ubii.dataStructure.TouchEventOuterClass.TouchEventList value) {
        if (touchEventListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          touchEventListBuilder_.setMessage(value);
        }
        typeCase_ = 34;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public Builder setTouchEventList(
          ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder builderForValue) {
        if (touchEventListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          touchEventListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 34;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public Builder mergeTouchEventList(ubii.dataStructure.TouchEventOuterClass.TouchEventList value) {
        if (touchEventListBuilder_ == null) {
          if (typeCase_ == 34 &&
              type_ != ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance()) {
            type_ = ubii.dataStructure.TouchEventOuterClass.TouchEventList.newBuilder((ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 34) {
            touchEventListBuilder_.mergeFrom(value);
          }
          touchEventListBuilder_.setMessage(value);
        }
        typeCase_ = 34;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public Builder clearTouchEventList() {
        if (touchEventListBuilder_ == null) {
          if (typeCase_ == 34) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 34) {
            typeCase_ = 0;
            type_ = null;
          }
          touchEventListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder getTouchEventListBuilder() {
        return getTouchEventListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      public ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder getTouchEventListOrBuilder() {
        if ((typeCase_ == 34) && (touchEventListBuilder_ != null)) {
          return touchEventListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 34) {
            return (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_;
          }
          return ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.TouchEventList touch_event_list = 34;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.TouchEventOuterClass.TouchEventList, ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder> 
          getTouchEventListFieldBuilder() {
        if (touchEventListBuilder_ == null) {
          if (!(typeCase_ == 34)) {
            type_ = ubii.dataStructure.TouchEventOuterClass.TouchEventList.getDefaultInstance();
          }
          touchEventListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.TouchEventOuterClass.TouchEventList, ubii.dataStructure.TouchEventOuterClass.TouchEventList.Builder, ubii.dataStructure.TouchEventOuterClass.TouchEventListOrBuilder>(
                  (ubii.dataStructure.TouchEventOuterClass.TouchEventList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 34;
        onChanged();;
        return touchEventListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.KeyEventOuterClass.KeyEvent, ubii.dataStructure.KeyEventOuterClass.KeyEvent.Builder, ubii.dataStructure.KeyEventOuterClass.KeyEventOrBuilder> keyEventBuilder_;
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public boolean hasKeyEvent() {
        return typeCase_ == 14;
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public ubii.dataStructure.KeyEventOuterClass.KeyEvent getKeyEvent() {
        if (keyEventBuilder_ == null) {
          if (typeCase_ == 14) {
            return (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_;
          }
          return ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance();
        } else {
          if (typeCase_ == 14) {
            return keyEventBuilder_.getMessage();
          }
          return ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public Builder setKeyEvent(ubii.dataStructure.KeyEventOuterClass.KeyEvent value) {
        if (keyEventBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          keyEventBuilder_.setMessage(value);
        }
        typeCase_ = 14;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public Builder setKeyEvent(
          ubii.dataStructure.KeyEventOuterClass.KeyEvent.Builder builderForValue) {
        if (keyEventBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          keyEventBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 14;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public Builder mergeKeyEvent(ubii.dataStructure.KeyEventOuterClass.KeyEvent value) {
        if (keyEventBuilder_ == null) {
          if (typeCase_ == 14 &&
              type_ != ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance()) {
            type_ = ubii.dataStructure.KeyEventOuterClass.KeyEvent.newBuilder((ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 14) {
            keyEventBuilder_.mergeFrom(value);
          }
          keyEventBuilder_.setMessage(value);
        }
        typeCase_ = 14;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public Builder clearKeyEvent() {
        if (keyEventBuilder_ == null) {
          if (typeCase_ == 14) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 14) {
            typeCase_ = 0;
            type_ = null;
          }
          keyEventBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public ubii.dataStructure.KeyEventOuterClass.KeyEvent.Builder getKeyEventBuilder() {
        return getKeyEventFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      public ubii.dataStructure.KeyEventOuterClass.KeyEventOrBuilder getKeyEventOrBuilder() {
        if ((typeCase_ == 14) && (keyEventBuilder_ != null)) {
          return keyEventBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 14) {
            return (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_;
          }
          return ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.KeyEvent key_event = 14;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.KeyEventOuterClass.KeyEvent, ubii.dataStructure.KeyEventOuterClass.KeyEvent.Builder, ubii.dataStructure.KeyEventOuterClass.KeyEventOrBuilder> 
          getKeyEventFieldBuilder() {
        if (keyEventBuilder_ == null) {
          if (!(typeCase_ == 14)) {
            type_ = ubii.dataStructure.KeyEventOuterClass.KeyEvent.getDefaultInstance();
          }
          keyEventBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.KeyEventOuterClass.KeyEvent, ubii.dataStructure.KeyEventOuterClass.KeyEvent.Builder, ubii.dataStructure.KeyEventOuterClass.KeyEventOrBuilder>(
                  (ubii.dataStructure.KeyEventOuterClass.KeyEvent) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 14;
        onChanged();;
        return keyEventBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.MouseEventOuterClass.MouseEvent, ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder, ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder> mouseEventBuilder_;
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public boolean hasMouseEvent() {
        return typeCase_ == 15;
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public ubii.dataStructure.MouseEventOuterClass.MouseEvent getMouseEvent() {
        if (mouseEventBuilder_ == null) {
          if (typeCase_ == 15) {
            return (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_;
          }
          return ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
        } else {
          if (typeCase_ == 15) {
            return mouseEventBuilder_.getMessage();
          }
          return ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public Builder setMouseEvent(ubii.dataStructure.MouseEventOuterClass.MouseEvent value) {
        if (mouseEventBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          mouseEventBuilder_.setMessage(value);
        }
        typeCase_ = 15;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public Builder setMouseEvent(
          ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder builderForValue) {
        if (mouseEventBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          mouseEventBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 15;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public Builder mergeMouseEvent(ubii.dataStructure.MouseEventOuterClass.MouseEvent value) {
        if (mouseEventBuilder_ == null) {
          if (typeCase_ == 15 &&
              type_ != ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance()) {
            type_ = ubii.dataStructure.MouseEventOuterClass.MouseEvent.newBuilder((ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 15) {
            mouseEventBuilder_.mergeFrom(value);
          }
          mouseEventBuilder_.setMessage(value);
        }
        typeCase_ = 15;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public Builder clearMouseEvent() {
        if (mouseEventBuilder_ == null) {
          if (typeCase_ == 15) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 15) {
            typeCase_ = 0;
            type_ = null;
          }
          mouseEventBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder getMouseEventBuilder() {
        return getMouseEventFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      public ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder getMouseEventOrBuilder() {
        if ((typeCase_ == 15) && (mouseEventBuilder_ != null)) {
          return mouseEventBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 15) {
            return (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_;
          }
          return ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.MouseEvent mouse_event = 15;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.MouseEventOuterClass.MouseEvent, ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder, ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder> 
          getMouseEventFieldBuilder() {
        if (mouseEventBuilder_ == null) {
          if (!(typeCase_ == 15)) {
            type_ = ubii.dataStructure.MouseEventOuterClass.MouseEvent.getDefaultInstance();
          }
          mouseEventBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.MouseEventOuterClass.MouseEvent, ubii.dataStructure.MouseEventOuterClass.MouseEvent.Builder, ubii.dataStructure.MouseEventOuterClass.MouseEventOrBuilder>(
                  (ubii.dataStructure.MouseEventOuterClass.MouseEvent) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 15;
        onChanged();;
        return mouseEventBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.MyoEventOuterClass.MyoEvent, ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder, ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder> myoEventBuilder_;
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public boolean hasMyoEvent() {
        return typeCase_ == 16;
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public ubii.dataStructure.MyoEventOuterClass.MyoEvent getMyoEvent() {
        if (myoEventBuilder_ == null) {
          if (typeCase_ == 16) {
            return (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_;
          }
          return ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
        } else {
          if (typeCase_ == 16) {
            return myoEventBuilder_.getMessage();
          }
          return ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public Builder setMyoEvent(ubii.dataStructure.MyoEventOuterClass.MyoEvent value) {
        if (myoEventBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          myoEventBuilder_.setMessage(value);
        }
        typeCase_ = 16;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public Builder setMyoEvent(
          ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder builderForValue) {
        if (myoEventBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          myoEventBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 16;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public Builder mergeMyoEvent(ubii.dataStructure.MyoEventOuterClass.MyoEvent value) {
        if (myoEventBuilder_ == null) {
          if (typeCase_ == 16 &&
              type_ != ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance()) {
            type_ = ubii.dataStructure.MyoEventOuterClass.MyoEvent.newBuilder((ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 16) {
            myoEventBuilder_.mergeFrom(value);
          }
          myoEventBuilder_.setMessage(value);
        }
        typeCase_ = 16;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public Builder clearMyoEvent() {
        if (myoEventBuilder_ == null) {
          if (typeCase_ == 16) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 16) {
            typeCase_ = 0;
            type_ = null;
          }
          myoEventBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder getMyoEventBuilder() {
        return getMyoEventFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      public ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder getMyoEventOrBuilder() {
        if ((typeCase_ == 16) && (myoEventBuilder_ != null)) {
          return myoEventBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 16) {
            return (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_;
          }
          return ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.MyoEvent myo_event = 16;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.MyoEventOuterClass.MyoEvent, ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder, ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder> 
          getMyoEventFieldBuilder() {
        if (myoEventBuilder_ == null) {
          if (!(typeCase_ == 16)) {
            type_ = ubii.dataStructure.MyoEventOuterClass.MyoEvent.getDefaultInstance();
          }
          myoEventBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.MyoEventOuterClass.MyoEvent, ubii.dataStructure.MyoEventOuterClass.MyoEvent.Builder, ubii.dataStructure.MyoEventOuterClass.MyoEventOrBuilder>(
                  (ubii.dataStructure.MyoEventOuterClass.MyoEvent) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 16;
        onChanged();;
        return myoEventBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Pose2DOuterClass.Pose2D, ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder, ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder> pose2DBuilder_;
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public boolean hasPose2D() {
        return typeCase_ == 17;
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public ubii.dataStructure.Pose2DOuterClass.Pose2D getPose2D() {
        if (pose2DBuilder_ == null) {
          if (typeCase_ == 17) {
            return (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_;
          }
          return ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
        } else {
          if (typeCase_ == 17) {
            return pose2DBuilder_.getMessage();
          }
          return ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public Builder setPose2D(ubii.dataStructure.Pose2DOuterClass.Pose2D value) {
        if (pose2DBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          pose2DBuilder_.setMessage(value);
        }
        typeCase_ = 17;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public Builder setPose2D(
          ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder builderForValue) {
        if (pose2DBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          pose2DBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 17;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public Builder mergePose2D(ubii.dataStructure.Pose2DOuterClass.Pose2D value) {
        if (pose2DBuilder_ == null) {
          if (typeCase_ == 17 &&
              type_ != ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance()) {
            type_ = ubii.dataStructure.Pose2DOuterClass.Pose2D.newBuilder((ubii.dataStructure.Pose2DOuterClass.Pose2D) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 17) {
            pose2DBuilder_.mergeFrom(value);
          }
          pose2DBuilder_.setMessage(value);
        }
        typeCase_ = 17;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public Builder clearPose2D() {
        if (pose2DBuilder_ == null) {
          if (typeCase_ == 17) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 17) {
            typeCase_ = 0;
            type_ = null;
          }
          pose2DBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder getPose2DBuilder() {
        return getPose2DFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      public ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder getPose2DOrBuilder() {
        if ((typeCase_ == 17) && (pose2DBuilder_ != null)) {
          return pose2DBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 17) {
            return (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_;
          }
          return ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Pose2D pose2D = 17;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Pose2DOuterClass.Pose2D, ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder, ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder> 
          getPose2DFieldBuilder() {
        if (pose2DBuilder_ == null) {
          if (!(typeCase_ == 17)) {
            type_ = ubii.dataStructure.Pose2DOuterClass.Pose2D.getDefaultInstance();
          }
          pose2DBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Pose2DOuterClass.Pose2D, ubii.dataStructure.Pose2DOuterClass.Pose2D.Builder, ubii.dataStructure.Pose2DOuterClass.Pose2DOrBuilder>(
                  (ubii.dataStructure.Pose2DOuterClass.Pose2D) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 17;
        onChanged();;
        return pose2DBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Pose3DOuterClass.Pose3D, ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder, ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder> pose3DBuilder_;
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public boolean hasPose3D() {
        return typeCase_ == 18;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public ubii.dataStructure.Pose3DOuterClass.Pose3D getPose3D() {
        if (pose3DBuilder_ == null) {
          if (typeCase_ == 18) {
            return (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_;
          }
          return ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance();
        } else {
          if (typeCase_ == 18) {
            return pose3DBuilder_.getMessage();
          }
          return ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public Builder setPose3D(ubii.dataStructure.Pose3DOuterClass.Pose3D value) {
        if (pose3DBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          pose3DBuilder_.setMessage(value);
        }
        typeCase_ = 18;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public Builder setPose3D(
          ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder builderForValue) {
        if (pose3DBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          pose3DBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 18;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public Builder mergePose3D(ubii.dataStructure.Pose3DOuterClass.Pose3D value) {
        if (pose3DBuilder_ == null) {
          if (typeCase_ == 18 &&
              type_ != ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance()) {
            type_ = ubii.dataStructure.Pose3DOuterClass.Pose3D.newBuilder((ubii.dataStructure.Pose3DOuterClass.Pose3D) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 18) {
            pose3DBuilder_.mergeFrom(value);
          }
          pose3DBuilder_.setMessage(value);
        }
        typeCase_ = 18;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public Builder clearPose3D() {
        if (pose3DBuilder_ == null) {
          if (typeCase_ == 18) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 18) {
            typeCase_ = 0;
            type_ = null;
          }
          pose3DBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder getPose3DBuilder() {
        return getPose3DFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      public ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder getPose3DOrBuilder() {
        if ((typeCase_ == 18) && (pose3DBuilder_ != null)) {
          return pose3DBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 18) {
            return (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_;
          }
          return ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Pose3D pose3D = 18;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Pose3DOuterClass.Pose3D, ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder, ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder> 
          getPose3DFieldBuilder() {
        if (pose3DBuilder_ == null) {
          if (!(typeCase_ == 18)) {
            type_ = ubii.dataStructure.Pose3DOuterClass.Pose3D.getDefaultInstance();
          }
          pose3DBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Pose3DOuterClass.Pose3D, ubii.dataStructure.Pose3DOuterClass.Pose3D.Builder, ubii.dataStructure.Pose3DOuterClass.Pose3DOrBuilder>(
                  (ubii.dataStructure.Pose3DOuterClass.Pose3D) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 18;
        onChanged();;
        return pose3DBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object2DOuterClass.Object2D, ubii.dataStructure.Object2DOuterClass.Object2D.Builder, ubii.dataStructure.Object2DOuterClass.Object2DOrBuilder> object2DBuilder_;
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public boolean hasObject2D() {
        return typeCase_ == 19;
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public ubii.dataStructure.Object2DOuterClass.Object2D getObject2D() {
        if (object2DBuilder_ == null) {
          if (typeCase_ == 19) {
            return (ubii.dataStructure.Object2DOuterClass.Object2D) type_;
          }
          return ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance();
        } else {
          if (typeCase_ == 19) {
            return object2DBuilder_.getMessage();
          }
          return ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public Builder setObject2D(ubii.dataStructure.Object2DOuterClass.Object2D value) {
        if (object2DBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          object2DBuilder_.setMessage(value);
        }
        typeCase_ = 19;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public Builder setObject2D(
          ubii.dataStructure.Object2DOuterClass.Object2D.Builder builderForValue) {
        if (object2DBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          object2DBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 19;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public Builder mergeObject2D(ubii.dataStructure.Object2DOuterClass.Object2D value) {
        if (object2DBuilder_ == null) {
          if (typeCase_ == 19 &&
              type_ != ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance()) {
            type_ = ubii.dataStructure.Object2DOuterClass.Object2D.newBuilder((ubii.dataStructure.Object2DOuterClass.Object2D) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 19) {
            object2DBuilder_.mergeFrom(value);
          }
          object2DBuilder_.setMessage(value);
        }
        typeCase_ = 19;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public Builder clearObject2D() {
        if (object2DBuilder_ == null) {
          if (typeCase_ == 19) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 19) {
            typeCase_ = 0;
            type_ = null;
          }
          object2DBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public ubii.dataStructure.Object2DOuterClass.Object2D.Builder getObject2DBuilder() {
        return getObject2DFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      public ubii.dataStructure.Object2DOuterClass.Object2DOrBuilder getObject2DOrBuilder() {
        if ((typeCase_ == 19) && (object2DBuilder_ != null)) {
          return object2DBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 19) {
            return (ubii.dataStructure.Object2DOuterClass.Object2D) type_;
          }
          return ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object2D object2D = 19;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object2DOuterClass.Object2D, ubii.dataStructure.Object2DOuterClass.Object2D.Builder, ubii.dataStructure.Object2DOuterClass.Object2DOrBuilder> 
          getObject2DFieldBuilder() {
        if (object2DBuilder_ == null) {
          if (!(typeCase_ == 19)) {
            type_ = ubii.dataStructure.Object2DOuterClass.Object2D.getDefaultInstance();
          }
          object2DBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Object2DOuterClass.Object2D, ubii.dataStructure.Object2DOuterClass.Object2D.Builder, ubii.dataStructure.Object2DOuterClass.Object2DOrBuilder>(
                  (ubii.dataStructure.Object2DOuterClass.Object2D) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 19;
        onChanged();;
        return object2DBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object3DOuterClass.Object3D, ubii.dataStructure.Object3DOuterClass.Object3D.Builder, ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> object3DBuilder_;
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public boolean hasObject3D() {
        return typeCase_ == 20;
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3D getObject3D() {
        if (object3DBuilder_ == null) {
          if (typeCase_ == 20) {
            return (ubii.dataStructure.Object3DOuterClass.Object3D) type_;
          }
          return ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
        } else {
          if (typeCase_ == 20) {
            return object3DBuilder_.getMessage();
          }
          return ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public Builder setObject3D(ubii.dataStructure.Object3DOuterClass.Object3D value) {
        if (object3DBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          object3DBuilder_.setMessage(value);
        }
        typeCase_ = 20;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public Builder setObject3D(
          ubii.dataStructure.Object3DOuterClass.Object3D.Builder builderForValue) {
        if (object3DBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          object3DBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 20;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public Builder mergeObject3D(ubii.dataStructure.Object3DOuterClass.Object3D value) {
        if (object3DBuilder_ == null) {
          if (typeCase_ == 20 &&
              type_ != ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance()) {
            type_ = ubii.dataStructure.Object3DOuterClass.Object3D.newBuilder((ubii.dataStructure.Object3DOuterClass.Object3D) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 20) {
            object3DBuilder_.mergeFrom(value);
          }
          object3DBuilder_.setMessage(value);
        }
        typeCase_ = 20;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public Builder clearObject3D() {
        if (object3DBuilder_ == null) {
          if (typeCase_ == 20) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 20) {
            typeCase_ = 0;
            type_ = null;
          }
          object3DBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3D.Builder getObject3DBuilder() {
        return getObject3DFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder getObject3DOrBuilder() {
        if ((typeCase_ == 20) && (object3DBuilder_ != null)) {
          return object3DBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 20) {
            return (ubii.dataStructure.Object3DOuterClass.Object3D) type_;
          }
          return ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object3D object3D = 20;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object3DOuterClass.Object3D, ubii.dataStructure.Object3DOuterClass.Object3D.Builder, ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder> 
          getObject3DFieldBuilder() {
        if (object3DBuilder_ == null) {
          if (!(typeCase_ == 20)) {
            type_ = ubii.dataStructure.Object3DOuterClass.Object3D.getDefaultInstance();
          }
          object3DBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Object3DOuterClass.Object3D, ubii.dataStructure.Object3DOuterClass.Object3D.Builder, ubii.dataStructure.Object3DOuterClass.Object3DOrBuilder>(
                  (ubii.dataStructure.Object3DOuterClass.Object3D) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 20;
        onChanged();;
        return object3DBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object2DOuterClass.Object2DList, ubii.dataStructure.Object2DOuterClass.Object2DList.Builder, ubii.dataStructure.Object2DOuterClass.Object2DListOrBuilder> object2DListBuilder_;
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public boolean hasObject2DList() {
        return typeCase_ == 21;
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public ubii.dataStructure.Object2DOuterClass.Object2DList getObject2DList() {
        if (object2DListBuilder_ == null) {
          if (typeCase_ == 21) {
            return (ubii.dataStructure.Object2DOuterClass.Object2DList) type_;
          }
          return ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance();
        } else {
          if (typeCase_ == 21) {
            return object2DListBuilder_.getMessage();
          }
          return ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public Builder setObject2DList(ubii.dataStructure.Object2DOuterClass.Object2DList value) {
        if (object2DListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          object2DListBuilder_.setMessage(value);
        }
        typeCase_ = 21;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public Builder setObject2DList(
          ubii.dataStructure.Object2DOuterClass.Object2DList.Builder builderForValue) {
        if (object2DListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          object2DListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 21;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public Builder mergeObject2DList(ubii.dataStructure.Object2DOuterClass.Object2DList value) {
        if (object2DListBuilder_ == null) {
          if (typeCase_ == 21 &&
              type_ != ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Object2DOuterClass.Object2DList.newBuilder((ubii.dataStructure.Object2DOuterClass.Object2DList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 21) {
            object2DListBuilder_.mergeFrom(value);
          }
          object2DListBuilder_.setMessage(value);
        }
        typeCase_ = 21;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public Builder clearObject2DList() {
        if (object2DListBuilder_ == null) {
          if (typeCase_ == 21) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 21) {
            typeCase_ = 0;
            type_ = null;
          }
          object2DListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public ubii.dataStructure.Object2DOuterClass.Object2DList.Builder getObject2DListBuilder() {
        return getObject2DListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      public ubii.dataStructure.Object2DOuterClass.Object2DListOrBuilder getObject2DListOrBuilder() {
        if ((typeCase_ == 21) && (object2DListBuilder_ != null)) {
          return object2DListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 21) {
            return (ubii.dataStructure.Object2DOuterClass.Object2DList) type_;
          }
          return ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object2DList object2D_list = 21;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object2DOuterClass.Object2DList, ubii.dataStructure.Object2DOuterClass.Object2DList.Builder, ubii.dataStructure.Object2DOuterClass.Object2DListOrBuilder> 
          getObject2DListFieldBuilder() {
        if (object2DListBuilder_ == null) {
          if (!(typeCase_ == 21)) {
            type_ = ubii.dataStructure.Object2DOuterClass.Object2DList.getDefaultInstance();
          }
          object2DListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Object2DOuterClass.Object2DList, ubii.dataStructure.Object2DOuterClass.Object2DList.Builder, ubii.dataStructure.Object2DOuterClass.Object2DListOrBuilder>(
                  (ubii.dataStructure.Object2DOuterClass.Object2DList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 21;
        onChanged();;
        return object2DListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object3DOuterClass.Object3DList, ubii.dataStructure.Object3DOuterClass.Object3DList.Builder, ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder> object3DListBuilder_;
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public boolean hasObject3DList() {
        return typeCase_ == 22;
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3DList getObject3DList() {
        if (object3DListBuilder_ == null) {
          if (typeCase_ == 22) {
            return (ubii.dataStructure.Object3DOuterClass.Object3DList) type_;
          }
          return ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
        } else {
          if (typeCase_ == 22) {
            return object3DListBuilder_.getMessage();
          }
          return ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public Builder setObject3DList(ubii.dataStructure.Object3DOuterClass.Object3DList value) {
        if (object3DListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          object3DListBuilder_.setMessage(value);
        }
        typeCase_ = 22;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public Builder setObject3DList(
          ubii.dataStructure.Object3DOuterClass.Object3DList.Builder builderForValue) {
        if (object3DListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          object3DListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 22;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public Builder mergeObject3DList(ubii.dataStructure.Object3DOuterClass.Object3DList value) {
        if (object3DListBuilder_ == null) {
          if (typeCase_ == 22 &&
              type_ != ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Object3DOuterClass.Object3DList.newBuilder((ubii.dataStructure.Object3DOuterClass.Object3DList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 22) {
            object3DListBuilder_.mergeFrom(value);
          }
          object3DListBuilder_.setMessage(value);
        }
        typeCase_ = 22;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public Builder clearObject3DList() {
        if (object3DListBuilder_ == null) {
          if (typeCase_ == 22) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 22) {
            typeCase_ = 0;
            type_ = null;
          }
          object3DListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3DList.Builder getObject3DListBuilder() {
        return getObject3DListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      public ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder getObject3DListOrBuilder() {
        if ((typeCase_ == 22) && (object3DListBuilder_ != null)) {
          return object3DListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 22) {
            return (ubii.dataStructure.Object3DOuterClass.Object3DList) type_;
          }
          return ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Object3DList object3D_list = 22;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Object3DOuterClass.Object3DList, ubii.dataStructure.Object3DOuterClass.Object3DList.Builder, ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder> 
          getObject3DListFieldBuilder() {
        if (object3DListBuilder_ == null) {
          if (!(typeCase_ == 22)) {
            type_ = ubii.dataStructure.Object3DOuterClass.Object3DList.getDefaultInstance();
          }
          object3DListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Object3DOuterClass.Object3DList, ubii.dataStructure.Object3DOuterClass.Object3DList.Builder, ubii.dataStructure.Object3DOuterClass.Object3DListOrBuilder>(
                  (ubii.dataStructure.Object3DOuterClass.Object3DList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 22;
        onChanged();;
        return object3DListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.Int32List, ubii.dataStructure.Lists.Int32List.Builder, ubii.dataStructure.Lists.Int32ListOrBuilder> int32ListBuilder_;
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public boolean hasInt32List() {
        return typeCase_ == 25;
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public ubii.dataStructure.Lists.Int32List getInt32List() {
        if (int32ListBuilder_ == null) {
          if (typeCase_ == 25) {
            return (ubii.dataStructure.Lists.Int32List) type_;
          }
          return ubii.dataStructure.Lists.Int32List.getDefaultInstance();
        } else {
          if (typeCase_ == 25) {
            return int32ListBuilder_.getMessage();
          }
          return ubii.dataStructure.Lists.Int32List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public Builder setInt32List(ubii.dataStructure.Lists.Int32List value) {
        if (int32ListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          int32ListBuilder_.setMessage(value);
        }
        typeCase_ = 25;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public Builder setInt32List(
          ubii.dataStructure.Lists.Int32List.Builder builderForValue) {
        if (int32ListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          int32ListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 25;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public Builder mergeInt32List(ubii.dataStructure.Lists.Int32List value) {
        if (int32ListBuilder_ == null) {
          if (typeCase_ == 25 &&
              type_ != ubii.dataStructure.Lists.Int32List.getDefaultInstance()) {
            type_ = ubii.dataStructure.Lists.Int32List.newBuilder((ubii.dataStructure.Lists.Int32List) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 25) {
            int32ListBuilder_.mergeFrom(value);
          }
          int32ListBuilder_.setMessage(value);
        }
        typeCase_ = 25;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public Builder clearInt32List() {
        if (int32ListBuilder_ == null) {
          if (typeCase_ == 25) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 25) {
            typeCase_ = 0;
            type_ = null;
          }
          int32ListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public ubii.dataStructure.Lists.Int32List.Builder getInt32ListBuilder() {
        return getInt32ListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      public ubii.dataStructure.Lists.Int32ListOrBuilder getInt32ListOrBuilder() {
        if ((typeCase_ == 25) && (int32ListBuilder_ != null)) {
          return int32ListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 25) {
            return (ubii.dataStructure.Lists.Int32List) type_;
          }
          return ubii.dataStructure.Lists.Int32List.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Int32List int32_list = 25;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.Int32List, ubii.dataStructure.Lists.Int32List.Builder, ubii.dataStructure.Lists.Int32ListOrBuilder> 
          getInt32ListFieldBuilder() {
        if (int32ListBuilder_ == null) {
          if (!(typeCase_ == 25)) {
            type_ = ubii.dataStructure.Lists.Int32List.getDefaultInstance();
          }
          int32ListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Lists.Int32List, ubii.dataStructure.Lists.Int32List.Builder, ubii.dataStructure.Lists.Int32ListOrBuilder>(
                  (ubii.dataStructure.Lists.Int32List) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 25;
        onChanged();;
        return int32ListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.FloatList, ubii.dataStructure.Lists.FloatList.Builder, ubii.dataStructure.Lists.FloatListOrBuilder> floatListBuilder_;
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public boolean hasFloatList() {
        return typeCase_ == 26;
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public ubii.dataStructure.Lists.FloatList getFloatList() {
        if (floatListBuilder_ == null) {
          if (typeCase_ == 26) {
            return (ubii.dataStructure.Lists.FloatList) type_;
          }
          return ubii.dataStructure.Lists.FloatList.getDefaultInstance();
        } else {
          if (typeCase_ == 26) {
            return floatListBuilder_.getMessage();
          }
          return ubii.dataStructure.Lists.FloatList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public Builder setFloatList(ubii.dataStructure.Lists.FloatList value) {
        if (floatListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          floatListBuilder_.setMessage(value);
        }
        typeCase_ = 26;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public Builder setFloatList(
          ubii.dataStructure.Lists.FloatList.Builder builderForValue) {
        if (floatListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          floatListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 26;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public Builder mergeFloatList(ubii.dataStructure.Lists.FloatList value) {
        if (floatListBuilder_ == null) {
          if (typeCase_ == 26 &&
              type_ != ubii.dataStructure.Lists.FloatList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Lists.FloatList.newBuilder((ubii.dataStructure.Lists.FloatList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 26) {
            floatListBuilder_.mergeFrom(value);
          }
          floatListBuilder_.setMessage(value);
        }
        typeCase_ = 26;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public Builder clearFloatList() {
        if (floatListBuilder_ == null) {
          if (typeCase_ == 26) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 26) {
            typeCase_ = 0;
            type_ = null;
          }
          floatListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public ubii.dataStructure.Lists.FloatList.Builder getFloatListBuilder() {
        return getFloatListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      public ubii.dataStructure.Lists.FloatListOrBuilder getFloatListOrBuilder() {
        if ((typeCase_ == 26) && (floatListBuilder_ != null)) {
          return floatListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 26) {
            return (ubii.dataStructure.Lists.FloatList) type_;
          }
          return ubii.dataStructure.Lists.FloatList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.FloatList float_list = 26;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.FloatList, ubii.dataStructure.Lists.FloatList.Builder, ubii.dataStructure.Lists.FloatListOrBuilder> 
          getFloatListFieldBuilder() {
        if (floatListBuilder_ == null) {
          if (!(typeCase_ == 26)) {
            type_ = ubii.dataStructure.Lists.FloatList.getDefaultInstance();
          }
          floatListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Lists.FloatList, ubii.dataStructure.Lists.FloatList.Builder, ubii.dataStructure.Lists.FloatListOrBuilder>(
                  (ubii.dataStructure.Lists.FloatList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 26;
        onChanged();;
        return floatListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.DoubleList, ubii.dataStructure.Lists.DoubleList.Builder, ubii.dataStructure.Lists.DoubleListOrBuilder> doubleListBuilder_;
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public boolean hasDoubleList() {
        return typeCase_ == 27;
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public ubii.dataStructure.Lists.DoubleList getDoubleList() {
        if (doubleListBuilder_ == null) {
          if (typeCase_ == 27) {
            return (ubii.dataStructure.Lists.DoubleList) type_;
          }
          return ubii.dataStructure.Lists.DoubleList.getDefaultInstance();
        } else {
          if (typeCase_ == 27) {
            return doubleListBuilder_.getMessage();
          }
          return ubii.dataStructure.Lists.DoubleList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public Builder setDoubleList(ubii.dataStructure.Lists.DoubleList value) {
        if (doubleListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          doubleListBuilder_.setMessage(value);
        }
        typeCase_ = 27;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public Builder setDoubleList(
          ubii.dataStructure.Lists.DoubleList.Builder builderForValue) {
        if (doubleListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          doubleListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 27;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public Builder mergeDoubleList(ubii.dataStructure.Lists.DoubleList value) {
        if (doubleListBuilder_ == null) {
          if (typeCase_ == 27 &&
              type_ != ubii.dataStructure.Lists.DoubleList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Lists.DoubleList.newBuilder((ubii.dataStructure.Lists.DoubleList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 27) {
            doubleListBuilder_.mergeFrom(value);
          }
          doubleListBuilder_.setMessage(value);
        }
        typeCase_ = 27;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public Builder clearDoubleList() {
        if (doubleListBuilder_ == null) {
          if (typeCase_ == 27) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 27) {
            typeCase_ = 0;
            type_ = null;
          }
          doubleListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public ubii.dataStructure.Lists.DoubleList.Builder getDoubleListBuilder() {
        return getDoubleListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      public ubii.dataStructure.Lists.DoubleListOrBuilder getDoubleListOrBuilder() {
        if ((typeCase_ == 27) && (doubleListBuilder_ != null)) {
          return doubleListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 27) {
            return (ubii.dataStructure.Lists.DoubleList) type_;
          }
          return ubii.dataStructure.Lists.DoubleList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.DoubleList double_list = 27;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.DoubleList, ubii.dataStructure.Lists.DoubleList.Builder, ubii.dataStructure.Lists.DoubleListOrBuilder> 
          getDoubleListFieldBuilder() {
        if (doubleListBuilder_ == null) {
          if (!(typeCase_ == 27)) {
            type_ = ubii.dataStructure.Lists.DoubleList.getDefaultInstance();
          }
          doubleListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Lists.DoubleList, ubii.dataStructure.Lists.DoubleList.Builder, ubii.dataStructure.Lists.DoubleListOrBuilder>(
                  (ubii.dataStructure.Lists.DoubleList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 27;
        onChanged();;
        return doubleListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.StringList, ubii.dataStructure.Lists.StringList.Builder, ubii.dataStructure.Lists.StringListOrBuilder> stringListBuilder_;
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public boolean hasStringList() {
        return typeCase_ == 28;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public ubii.dataStructure.Lists.StringList getStringList() {
        if (stringListBuilder_ == null) {
          if (typeCase_ == 28) {
            return (ubii.dataStructure.Lists.StringList) type_;
          }
          return ubii.dataStructure.Lists.StringList.getDefaultInstance();
        } else {
          if (typeCase_ == 28) {
            return stringListBuilder_.getMessage();
          }
          return ubii.dataStructure.Lists.StringList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public Builder setStringList(ubii.dataStructure.Lists.StringList value) {
        if (stringListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          stringListBuilder_.setMessage(value);
        }
        typeCase_ = 28;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public Builder setStringList(
          ubii.dataStructure.Lists.StringList.Builder builderForValue) {
        if (stringListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          stringListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 28;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public Builder mergeStringList(ubii.dataStructure.Lists.StringList value) {
        if (stringListBuilder_ == null) {
          if (typeCase_ == 28 &&
              type_ != ubii.dataStructure.Lists.StringList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Lists.StringList.newBuilder((ubii.dataStructure.Lists.StringList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 28) {
            stringListBuilder_.mergeFrom(value);
          }
          stringListBuilder_.setMessage(value);
        }
        typeCase_ = 28;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public Builder clearStringList() {
        if (stringListBuilder_ == null) {
          if (typeCase_ == 28) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 28) {
            typeCase_ = 0;
            type_ = null;
          }
          stringListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public ubii.dataStructure.Lists.StringList.Builder getStringListBuilder() {
        return getStringListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      public ubii.dataStructure.Lists.StringListOrBuilder getStringListOrBuilder() {
        if ((typeCase_ == 28) && (stringListBuilder_ != null)) {
          return stringListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 28) {
            return (ubii.dataStructure.Lists.StringList) type_;
          }
          return ubii.dataStructure.Lists.StringList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 28;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.StringList, ubii.dataStructure.Lists.StringList.Builder, ubii.dataStructure.Lists.StringListOrBuilder> 
          getStringListFieldBuilder() {
        if (stringListBuilder_ == null) {
          if (!(typeCase_ == 28)) {
            type_ = ubii.dataStructure.Lists.StringList.getDefaultInstance();
          }
          stringListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Lists.StringList, ubii.dataStructure.Lists.StringList.Builder, ubii.dataStructure.Lists.StringListOrBuilder>(
                  (ubii.dataStructure.Lists.StringList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 28;
        onChanged();;
        return stringListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.BoolList, ubii.dataStructure.Lists.BoolList.Builder, ubii.dataStructure.Lists.BoolListOrBuilder> boolListBuilder_;
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public boolean hasBoolList() {
        return typeCase_ == 29;
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public ubii.dataStructure.Lists.BoolList getBoolList() {
        if (boolListBuilder_ == null) {
          if (typeCase_ == 29) {
            return (ubii.dataStructure.Lists.BoolList) type_;
          }
          return ubii.dataStructure.Lists.BoolList.getDefaultInstance();
        } else {
          if (typeCase_ == 29) {
            return boolListBuilder_.getMessage();
          }
          return ubii.dataStructure.Lists.BoolList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public Builder setBoolList(ubii.dataStructure.Lists.BoolList value) {
        if (boolListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          boolListBuilder_.setMessage(value);
        }
        typeCase_ = 29;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public Builder setBoolList(
          ubii.dataStructure.Lists.BoolList.Builder builderForValue) {
        if (boolListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          boolListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 29;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public Builder mergeBoolList(ubii.dataStructure.Lists.BoolList value) {
        if (boolListBuilder_ == null) {
          if (typeCase_ == 29 &&
              type_ != ubii.dataStructure.Lists.BoolList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Lists.BoolList.newBuilder((ubii.dataStructure.Lists.BoolList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 29) {
            boolListBuilder_.mergeFrom(value);
          }
          boolListBuilder_.setMessage(value);
        }
        typeCase_ = 29;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public Builder clearBoolList() {
        if (boolListBuilder_ == null) {
          if (typeCase_ == 29) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 29) {
            typeCase_ = 0;
            type_ = null;
          }
          boolListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public ubii.dataStructure.Lists.BoolList.Builder getBoolListBuilder() {
        return getBoolListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      public ubii.dataStructure.Lists.BoolListOrBuilder getBoolListOrBuilder() {
        if ((typeCase_ == 29) && (boolListBuilder_ != null)) {
          return boolListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 29) {
            return (ubii.dataStructure.Lists.BoolList) type_;
          }
          return ubii.dataStructure.Lists.BoolList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.BoolList bool_list = 29;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.BoolList, ubii.dataStructure.Lists.BoolList.Builder, ubii.dataStructure.Lists.BoolListOrBuilder> 
          getBoolListFieldBuilder() {
        if (boolListBuilder_ == null) {
          if (!(typeCase_ == 29)) {
            type_ = ubii.dataStructure.Lists.BoolList.getDefaultInstance();
          }
          boolListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Lists.BoolList, ubii.dataStructure.Lists.BoolList.Builder, ubii.dataStructure.Lists.BoolListOrBuilder>(
                  (ubii.dataStructure.Lists.BoolList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 29;
        onChanged();;
        return boolListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Image.Image2D, ubii.dataStructure.Image.Image2D.Builder, ubii.dataStructure.Image.Image2DOrBuilder> image2DBuilder_;
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public boolean hasImage2D() {
        return typeCase_ == 30;
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public ubii.dataStructure.Image.Image2D getImage2D() {
        if (image2DBuilder_ == null) {
          if (typeCase_ == 30) {
            return (ubii.dataStructure.Image.Image2D) type_;
          }
          return ubii.dataStructure.Image.Image2D.getDefaultInstance();
        } else {
          if (typeCase_ == 30) {
            return image2DBuilder_.getMessage();
          }
          return ubii.dataStructure.Image.Image2D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public Builder setImage2D(ubii.dataStructure.Image.Image2D value) {
        if (image2DBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          image2DBuilder_.setMessage(value);
        }
        typeCase_ = 30;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public Builder setImage2D(
          ubii.dataStructure.Image.Image2D.Builder builderForValue) {
        if (image2DBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          image2DBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 30;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public Builder mergeImage2D(ubii.dataStructure.Image.Image2D value) {
        if (image2DBuilder_ == null) {
          if (typeCase_ == 30 &&
              type_ != ubii.dataStructure.Image.Image2D.getDefaultInstance()) {
            type_ = ubii.dataStructure.Image.Image2D.newBuilder((ubii.dataStructure.Image.Image2D) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 30) {
            image2DBuilder_.mergeFrom(value);
          }
          image2DBuilder_.setMessage(value);
        }
        typeCase_ = 30;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public Builder clearImage2D() {
        if (image2DBuilder_ == null) {
          if (typeCase_ == 30) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 30) {
            typeCase_ = 0;
            type_ = null;
          }
          image2DBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public ubii.dataStructure.Image.Image2D.Builder getImage2DBuilder() {
        return getImage2DFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      public ubii.dataStructure.Image.Image2DOrBuilder getImage2DOrBuilder() {
        if ((typeCase_ == 30) && (image2DBuilder_ != null)) {
          return image2DBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 30) {
            return (ubii.dataStructure.Image.Image2D) type_;
          }
          return ubii.dataStructure.Image.Image2D.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Image2D image2D = 30;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Image.Image2D, ubii.dataStructure.Image.Image2D.Builder, ubii.dataStructure.Image.Image2DOrBuilder> 
          getImage2DFieldBuilder() {
        if (image2DBuilder_ == null) {
          if (!(typeCase_ == 30)) {
            type_ = ubii.dataStructure.Image.Image2D.getDefaultInstance();
          }
          image2DBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Image.Image2D, ubii.dataStructure.Image.Image2D.Builder, ubii.dataStructure.Image.Image2DOrBuilder>(
                  (ubii.dataStructure.Image.Image2D) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 30;
        onChanged();;
        return image2DBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Image.Image2DList, ubii.dataStructure.Image.Image2DList.Builder, ubii.dataStructure.Image.Image2DListOrBuilder> image2DListBuilder_;
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public boolean hasImage2DList() {
        return typeCase_ == 31;
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public ubii.dataStructure.Image.Image2DList getImage2DList() {
        if (image2DListBuilder_ == null) {
          if (typeCase_ == 31) {
            return (ubii.dataStructure.Image.Image2DList) type_;
          }
          return ubii.dataStructure.Image.Image2DList.getDefaultInstance();
        } else {
          if (typeCase_ == 31) {
            return image2DListBuilder_.getMessage();
          }
          return ubii.dataStructure.Image.Image2DList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public Builder setImage2DList(ubii.dataStructure.Image.Image2DList value) {
        if (image2DListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          image2DListBuilder_.setMessage(value);
        }
        typeCase_ = 31;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public Builder setImage2DList(
          ubii.dataStructure.Image.Image2DList.Builder builderForValue) {
        if (image2DListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          image2DListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 31;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public Builder mergeImage2DList(ubii.dataStructure.Image.Image2DList value) {
        if (image2DListBuilder_ == null) {
          if (typeCase_ == 31 &&
              type_ != ubii.dataStructure.Image.Image2DList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Image.Image2DList.newBuilder((ubii.dataStructure.Image.Image2DList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 31) {
            image2DListBuilder_.mergeFrom(value);
          }
          image2DListBuilder_.setMessage(value);
        }
        typeCase_ = 31;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public Builder clearImage2DList() {
        if (image2DListBuilder_ == null) {
          if (typeCase_ == 31) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 31) {
            typeCase_ = 0;
            type_ = null;
          }
          image2DListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public ubii.dataStructure.Image.Image2DList.Builder getImage2DListBuilder() {
        return getImage2DListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      public ubii.dataStructure.Image.Image2DListOrBuilder getImage2DListOrBuilder() {
        if ((typeCase_ == 31) && (image2DListBuilder_ != null)) {
          return image2DListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 31) {
            return (ubii.dataStructure.Image.Image2DList) type_;
          }
          return ubii.dataStructure.Image.Image2DList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.Image2DList image2D_list = 31;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Image.Image2DList, ubii.dataStructure.Image.Image2DList.Builder, ubii.dataStructure.Image.Image2DListOrBuilder> 
          getImage2DListFieldBuilder() {
        if (image2DListBuilder_ == null) {
          if (!(typeCase_ == 31)) {
            type_ = ubii.dataStructure.Image.Image2DList.getDefaultInstance();
          }
          image2DListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Image.Image2DList, ubii.dataStructure.Image.Image2DList.Builder, ubii.dataStructure.Image.Image2DListOrBuilder>(
                  (ubii.dataStructure.Image.Image2DList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 31;
        onChanged();;
        return image2DListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder> sessionBuilder_;
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public boolean hasSession() {
        return typeCase_ == 32;
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public ubii.sessions.SessionOuterClass.Session getSession() {
        if (sessionBuilder_ == null) {
          if (typeCase_ == 32) {
            return (ubii.sessions.SessionOuterClass.Session) type_;
          }
          return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
        } else {
          if (typeCase_ == 32) {
            return sessionBuilder_.getMessage();
          }
          return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public Builder setSession(ubii.sessions.SessionOuterClass.Session value) {
        if (sessionBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          sessionBuilder_.setMessage(value);
        }
        typeCase_ = 32;
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public Builder setSession(
          ubii.sessions.SessionOuterClass.Session.Builder builderForValue) {
        if (sessionBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          sessionBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 32;
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public Builder mergeSession(ubii.sessions.SessionOuterClass.Session value) {
        if (sessionBuilder_ == null) {
          if (typeCase_ == 32 &&
              type_ != ubii.sessions.SessionOuterClass.Session.getDefaultInstance()) {
            type_ = ubii.sessions.SessionOuterClass.Session.newBuilder((ubii.sessions.SessionOuterClass.Session) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 32) {
            sessionBuilder_.mergeFrom(value);
          }
          sessionBuilder_.setMessage(value);
        }
        typeCase_ = 32;
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public Builder clearSession() {
        if (sessionBuilder_ == null) {
          if (typeCase_ == 32) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 32) {
            typeCase_ = 0;
            type_ = null;
          }
          sessionBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public ubii.sessions.SessionOuterClass.Session.Builder getSessionBuilder() {
        return getSessionFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionOrBuilder getSessionOrBuilder() {
        if ((typeCase_ == 32) && (sessionBuilder_ != null)) {
          return sessionBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 32) {
            return (ubii.sessions.SessionOuterClass.Session) type_;
          }
          return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.sessions.Session session = 32;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder> 
          getSessionFieldBuilder() {
        if (sessionBuilder_ == null) {
          if (!(typeCase_ == 32)) {
            type_ = ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
          }
          sessionBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder>(
                  (ubii.sessions.SessionOuterClass.Session) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 32;
        onChanged();;
        return sessionBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.topicData.TopicDataRecord)
    }

    // @@protoc_insertion_point(class_scope:ubii.topicData.TopicDataRecord)
    private static final ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord();
    }

    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicDataRecord>
        PARSER = new com.google.protobuf.AbstractParser<TopicDataRecord>() {
      @java.lang.Override
      public TopicDataRecord parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicDataRecord(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicDataRecord> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicDataRecord> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface TopicDataRecordListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.topicData.TopicDataRecordList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> 
        getElementsList();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getElements(int index);
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.topicData.TopicDataRecordList}
   */
  public  static final class TopicDataRecordList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.topicData.TopicDataRecordList)
      TopicDataRecordListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicDataRecordList.newBuilder() to construct.
    private TopicDataRecordList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicDataRecordList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicDataRecordList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecordList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecordList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.class, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> elements_;
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    public java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
     */
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList)) {
        return super.equals(obj);
      }
      ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList other = (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.topicData.TopicDataRecordList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.topicData.TopicDataRecordList)
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecordList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecordList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.class, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.Builder.class);
      }

      // Construct using ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.topicData.TopicDataRecordOuterClass.internal_static_ubii_topicData_TopicDataRecordList_descriptor;
      }

      @java.lang.Override
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList getDefaultInstanceForType() {
        return ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList build() {
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList buildPartial() {
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList result = new ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) {
          return mergeFrom((ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList other) {
        if (other == ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder addElements(ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder addElements(
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public java.util.List<? extends ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.topicData.TopicDataRecord elements = 1;</code>
       */
      public java.util.List<ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecord.Builder, ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.topicData.TopicDataRecordList)
    }

    // @@protoc_insertion_point(class_scope:ubii.topicData.TopicDataRecordList)
    private static final ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList();
    }

    public static ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicDataRecordList>
        PARSER = new com.google.protobuf.AbstractParser<TopicDataRecordList>() {
      @java.lang.Override
      public TopicDataRecordList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicDataRecordList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicDataRecordList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicDataRecordList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.topicData.TopicDataRecordOuterClass.TopicDataRecordList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_topicData_TopicDataRecord_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_topicData_TopicDataRecord_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_topicData_TopicDataRecordList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_topicData_TopicDataRecordList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n5proto/topicData/topicDataRecord/topicD" +
      "ataRecord.proto\022\016ubii.topicData\032/proto/t" +
      "opicData/topicDataRecord/timestamp.proto" +
      "\0329proto/topicData/topicDataRecord/dataSt" +
      "ructure/lists.proto\032;proto/topicData/top" +
      "icDataRecord/dataStructure/vector2.proto" +
      "\032;proto/topicData/topicDataRecord/dataSt" +
      "ructure/vector3.proto\032;proto/topicData/t" +
      "opicDataRecord/dataStructure/vector4.pro" +
      "to\032>proto/topicData/topicDataRecord/data" +
      "Structure/quaternion.proto\032=proto/topicD" +
      "ata/topicDataRecord/dataStructure/matrix" +
      "3x2.proto\032=proto/topicData/topicDataReco" +
      "rd/dataStructure/matrix4x4.proto\0329proto/" +
      "topicData/topicDataRecord/dataStructure/" +
      "color.proto\032>proto/topicData/topicDataRe" +
      "cord/dataStructure/touchEvent.proto\032<pro" +
      "to/topicData/topicDataRecord/dataStructu" +
      "re/keyEvent.proto\032>proto/topicData/topic" +
      "DataRecord/dataStructure/mouseEvent.prot" +
      "o\032<proto/topicData/topicDataRecord/dataS" +
      "tructure/myoEvent.proto\032:proto/topicData" +
      "/topicDataRecord/dataStructure/pose2d.pr" +
      "oto\032:proto/topicData/topicDataRecord/dat" +
      "aStructure/pose3d.proto\032<proto/topicData" +
      "/topicDataRecord/dataStructure/object2d." +
      "proto\032<proto/topicData/topicDataRecord/d" +
      "ataStructure/object3d.proto\0329proto/topic" +
      "Data/topicDataRecord/dataStructure/image" +
      ".proto\032\034proto/sessions/session.proto\032\'pr" +
      "oto/processing/processingModule.proto\"\325\r" +
      "\n\017TopicDataRecord\022\r\n\005topic\030\001 \001(\t\022,\n\ttime" +
      "stamp\030\002 \001(\0132\031.ubii.topicData.Timestamp\022\020" +
      "\n\006double\030\003 \001(\001H\000\022\016\n\004bool\030\004 \001(\010H\000\022\020\n\006stri" +
      "ng\030\005 \001(\tH\000\022\017\n\005int32\030\027 \001(\005H\000\022\017\n\005float\030\030 \001" +
      "(\002H\000\022.\n\007vector2\030\006 \001(\0132\033.ubii.dataStructu" +
      "re.Vector2H\000\0227\n\014vector2_list\030# \001(\0132\037.ubi" +
      "i.dataStructure.Vector2ListH\000\022.\n\007vector3" +
      "\030\007 \001(\0132\033.ubii.dataStructure.Vector3H\000\0227\n" +
      "\014vector3_list\030$ \001(\0132\037.ubii.dataStructure" +
      ".Vector3ListH\000\022.\n\007vector4\030\010 \001(\0132\033.ubii.d" +
      "ataStructure.Vector4H\000\0227\n\014vector4_list\030%" +
      " \001(\0132\037.ubii.dataStructure.Vector4ListH\000\022" +
      "4\n\nquaternion\030\t \001(\0132\036.ubii.dataStructure" +
      ".QuaternionH\000\0229\n\017quaternion_list\030& \001(\0132\036" +
      ".ubii.dataStructure.QuaternionH\000\0222\n\tmatr" +
      "ix3x2\030\n \001(\0132\035.ubii.dataStructure.Matrix3" +
      "x2H\000\0222\n\tmatrix4x4\030\013 \001(\0132\035.ubii.dataStruc" +
      "ture.Matrix4x4H\000\022*\n\005color\030\014 \001(\0132\031.ubii.d" +
      "ataStructure.ColorH\000\0225\n\013touch_event\030\r \001(" +
      "\0132\036.ubii.dataStructure.TouchEventH\000\022>\n\020t" +
      "ouch_event_list\030\" \001(\0132\".ubii.dataStructu" +
      "re.TouchEventListH\000\0221\n\tkey_event\030\016 \001(\0132\034" +
      ".ubii.dataStructure.KeyEventH\000\0225\n\013mouse_" +
      "event\030\017 \001(\0132\036.ubii.dataStructure.MouseEv" +
      "entH\000\0221\n\tmyo_event\030\020 \001(\0132\034.ubii.dataStru" +
      "cture.MyoEventH\000\022,\n\006pose2D\030\021 \001(\0132\032.ubii." +
      "dataStructure.Pose2DH\000\022,\n\006pose3D\030\022 \001(\0132\032" +
      ".ubii.dataStructure.Pose3DH\000\0220\n\010object2D" +
      "\030\023 \001(\0132\034.ubii.dataStructure.Object2DH\000\0220" +
      "\n\010object3D\030\024 \001(\0132\034.ubii.dataStructure.Ob" +
      "ject3DH\000\0229\n\robject2D_list\030\025 \001(\0132 .ubii.d" +
      "ataStructure.Object2DListH\000\0229\n\robject3D_" +
      "list\030\026 \001(\0132 .ubii.dataStructure.Object3D" +
      "ListH\000\0223\n\nint32_list\030\031 \001(\0132\035.ubii.dataSt" +
      "ructure.Int32ListH\000\0223\n\nfloat_list\030\032 \001(\0132" +
      "\035.ubii.dataStructure.FloatListH\000\0225\n\013doub" +
      "le_list\030\033 \001(\0132\036.ubii.dataStructure.Doubl" +
      "eListH\000\0225\n\013string_list\030\034 \001(\0132\036.ubii.data" +
      "Structure.StringListH\000\0221\n\tbool_list\030\035 \001(" +
      "\0132\034.ubii.dataStructure.BoolListH\000\022.\n\007ima" +
      "ge2D\030\036 \001(\0132\033.ubii.dataStructure.Image2DH" +
      "\000\0227\n\014image2D_list\030\037 \001(\0132\037.ubii.dataStruc" +
      "ture.Image2DListH\000\022)\n\007session\030  \001(\0132\026.ub" +
      "ii.sessions.SessionH\000B\006\n\004type\"H\n\023TopicDa" +
      "taRecordList\0221\n\010elements\030\001 \003(\0132\037.ubii.to" +
      "picData.TopicDataRecordb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.topicData.TimestampOuterClass.getDescriptor(),
          ubii.dataStructure.Lists.getDescriptor(),
          ubii.dataStructure.Vector2OuterClass.getDescriptor(),
          ubii.dataStructure.Vector3OuterClass.getDescriptor(),
          ubii.dataStructure.Vector4OuterClass.getDescriptor(),
          ubii.dataStructure.QuaternionOuterClass.getDescriptor(),
          ubii.dataStructure.Matrix3X2.getDescriptor(),
          ubii.dataStructure.Matrix4X4.getDescriptor(),
          ubii.dataStructure.ColorOuterClass.getDescriptor(),
          ubii.dataStructure.TouchEventOuterClass.getDescriptor(),
          ubii.dataStructure.KeyEventOuterClass.getDescriptor(),
          ubii.dataStructure.MouseEventOuterClass.getDescriptor(),
          ubii.dataStructure.MyoEventOuterClass.getDescriptor(),
          ubii.dataStructure.Pose2DOuterClass.getDescriptor(),
          ubii.dataStructure.Pose3DOuterClass.getDescriptor(),
          ubii.dataStructure.Object2DOuterClass.getDescriptor(),
          ubii.dataStructure.Object3DOuterClass.getDescriptor(),
          ubii.dataStructure.Image.getDescriptor(),
          ubii.sessions.SessionOuterClass.getDescriptor(),
          ubii.processing.ProcessingModuleOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_topicData_TopicDataRecord_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_topicData_TopicDataRecord_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_topicData_TopicDataRecord_descriptor,
        new java.lang.String[] { "Topic", "Timestamp", "Double", "Bool", "String", "Int32", "Float", "Vector2", "Vector2List", "Vector3", "Vector3List", "Vector4", "Vector4List", "Quaternion", "QuaternionList", "Matrix3X2", "Matrix4X4", "Color", "TouchEvent", "TouchEventList", "KeyEvent", "MouseEvent", "MyoEvent", "Pose2D", "Pose3D", "Object2D", "Object3D", "Object2DList", "Object3DList", "Int32List", "FloatList", "DoubleList", "StringList", "BoolList", "Image2D", "Image2DList", "Session", "Type", });
    internal_static_ubii_topicData_TopicDataRecordList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_topicData_TopicDataRecordList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_topicData_TopicDataRecordList_descriptor,
        new java.lang.String[] { "Elements", });
    ubii.topicData.TimestampOuterClass.getDescriptor();
    ubii.dataStructure.Lists.getDescriptor();
    ubii.dataStructure.Vector2OuterClass.getDescriptor();
    ubii.dataStructure.Vector3OuterClass.getDescriptor();
    ubii.dataStructure.Vector4OuterClass.getDescriptor();
    ubii.dataStructure.QuaternionOuterClass.getDescriptor();
    ubii.dataStructure.Matrix3X2.getDescriptor();
    ubii.dataStructure.Matrix4X4.getDescriptor();
    ubii.dataStructure.ColorOuterClass.getDescriptor();
    ubii.dataStructure.TouchEventOuterClass.getDescriptor();
    ubii.dataStructure.KeyEventOuterClass.getDescriptor();
    ubii.dataStructure.MouseEventOuterClass.getDescriptor();
    ubii.dataStructure.MyoEventOuterClass.getDescriptor();
    ubii.dataStructure.Pose2DOuterClass.getDescriptor();
    ubii.dataStructure.Pose3DOuterClass.getDescriptor();
    ubii.dataStructure.Object2DOuterClass.getDescriptor();
    ubii.dataStructure.Object3DOuterClass.getDescriptor();
    ubii.dataStructure.Image.getDescriptor();
    ubii.sessions.SessionOuterClass.getDescriptor();
    ubii.processing.ProcessingModuleOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
